@@ -489,9 +489,9 @@ abstract public class GenericURLContext implements Context {
 
     public String composeName(String name, String prefix)
         throws NamingException {
-            if (prefix.equals("")) {
+            if (prefix.isEmpty()) {
                 return name;
-            } else if (name.equals("")) {
+            } else if (name.isEmpty()) {
                 return prefix;
             } else {
                 return (prefix + "/" + name);
