@@ -230,6 +230,7 @@ public class FormatData_am extends ListResourceBundle {
                     "\u12d3\u1218\u1270 \u121d\u1215\u1228\u1275",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -248,6 +249,8 @@ public class FormatData_am extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -258,6 +261,7 @@ public class FormatData_am extends ListResourceBundle {
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "\u1325\u12cb\u1275/\u12a8\u1230\u12d3\u1275" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "\u12e8\u121a\u1295\u1309 \u12e8\u1240\u1295 \u12a0\u1246\u1323\u1320\u122d" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -265,13 +269,6 @@ public class FormatData_am extends ListResourceBundle {
             { "field.second", "\u1230\u12a8\u1295\u12f5" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "\u00a4#,##0.00",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u12a5\u1235\u120b\u121b\u12ca \u12e8\u1240\u1295 \u12a0\u1246\u1323\u1320\u122d" },
             { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -283,18 +280,18 @@ public class FormatData_am extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 \u123a",
-                    "00 \u123a",
-                    "000 \u123a",
-                    "0 \u121a\u120a\u12ee\u1295",
-                    "00 \u121a\u120a\u12ee\u1295",
-                    "000 \u121a\u120a\u12ee\u1295",
-                    "0 \u1262\u120a\u12ee\u1295",
-                    "00 \u1262\u120a\u12ee\u1295",
-                    "000 \u1262\u120a\u12ee\u1295",
-                    "0 \u1275\u122a\u120a\u12ee\u1295",
-                    "00 \u1275\u122a\u120a\u12ee\u1295",
-                    "000 \u1275\u122a\u120a\u12ee\u1295",
+                    "{one:0' '\u123a other:0' '\u123a}",
+                    "{one:00' '\u123a other:00' '\u123a}",
+                    "{one:000' '\u123a other:000' '\u123a}",
+                    "{one:0' '\u121a\u120a\u12ee\u1295 other:0' '\u121a\u120a\u12ee\u1295}",
+                    "{one:00' '\u121a\u120a\u12ee\u1295 other:00' '\u121a\u120a\u12ee\u1295}",
+                    "{one:000' '\u121a\u120a\u12ee\u1295 other:000' '\u121a\u120a\u12ee\u1295}",
+                    "{one:0' '\u1262\u120a\u12ee\u1295 other:0' '\u1262\u120a\u12ee\u1295}",
+                    "{one:00' '\u1262\u120a\u12ee\u1295 other:00' '\u1262\u120a\u12ee\u1295}",
+                    "{one:000' '\u1262\u120a\u12ee\u1295 other:000' '\u1262\u120a\u12ee\u1295}",
+                    "{one:0' '\u1275\u122a\u120a\u12ee\u1295 other:0' '\u1275\u122a\u120a\u12ee\u1295}",
+                    "{one:00' '\u1275\u122a\u120a\u12ee\u1295 other:00' '\u1275\u122a\u120a\u12ee\u1295}",
+                    "{one:000' '\u1275\u122a\u120a\u12ee\u1295 other:000' '\u1275\u122a\u120a\u12ee\u1295}",
                 }
             },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -345,18 +342,18 @@ public class FormatData_am extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0\u123a",
-                    "00\u00a0\u123a",
-                    "000\u00a0\u123a",
-                    "0\u00a0\u121c\u1275\u122d",
-                    "00\u00a0\u121c\u1275\u122d",
-                    "000\u121c",
-                    "0\u00a0\u1262",
-                    "00\u00a0\u1262",
-                    "000\u00a0\u1262",
-                    "0\u00a0\u1275",
-                    "00\u00a0\u1275",
-                    "000\u00a0\u1275",
+                    "{one:0\u00a0\u123a other:0\u00a0\u123a}",
+                    "{one:00\u00a0\u123a other:00\u00a0\u123a}",
+                    "{one:000\u00a0\u123a other:000\u00a0\u123a}",
+                    "{one:0\u00a0\u121c\u1275\u122d other:0\u00a0\u121c\u1275\u122d}",
+                    "{one:00\u00a0\u121c\u1275\u122d other:00\u00a0\u121c\u1275\u122d}",
+                    "{one:000\u121c other:000\u121c}",
+                    "{one:0\u00a0\u1262 other:0\u00a0\u1262}",
+                    "{one:00\u00a0\u1262 other:00\u00a0\u1262}",
+                    "{one:000\u00a0\u1262 other:000\u00a0\u1262}",
+                    "{one:0\u00a0\u1275 other:0\u00a0\u1275}",
+                    "{one:00\u00a0\u1275 other:00\u00a0\u1275}",
+                    "{one:000\u00a0\u1275 other:000\u00a0\u1275}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -377,6 +374,14 @@ public class FormatData_am extends ListResourceBundle {
             { "field.hour", "\u1230\u12d3\u1275" },
             { "calendarname.buddhist", "\u12e8\u1261\u12f2\u1235\u1275 \u1240\u1295 \u12a0\u1246\u1323\u1320\u122d" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "\u00a4#,##0.00",
+                    "#,##0%",
+                    "\u00a4#,##0.00;(\u00a4#,##0.00)",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
