@@ -263,6 +263,8 @@ public class FormatData_ar extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "\u0644\u064a\u0633\u00a0\u0631\u0642\u0645\u064b\u0627",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -289,6 +291,8 @@ public class FormatData_ar extends ListResourceBundle {
                     "\u0609",
                     "\u221e",
                     "\u0644\u064a\u0633\u00a0\u0631\u0642\u0645",
+                    "",
+                    "",
                 }
             },
             { "calendarname.roc", "\u062a\u0642\u0648\u064a\u0645 \u0645\u064a\u0646\u062c\u0648" },
@@ -325,13 +329,6 @@ public class FormatData_ar extends ListResourceBundle {
             },
             { "DayAbbreviations", metaValue_DayNames },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "\u00a4\u00a0#,##0.00",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u0627\u0644\u062a\u0642\u0648\u064a\u0645 \u0627\u0644\u0647\u062c\u0631\u064a" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
@@ -345,18 +342,18 @@ public class FormatData_ar extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 \u0623\u0644\u0641",
-                    "00 \u0623\u0644\u0641",
-                    "000 \u0623\u0644\u0641",
-                    "0 \u0645\u0644\u064a\u0648\u0646",
-                    "00 \u0645\u0644\u064a\u0648\u0646",
-                    "000 \u0645\u0644\u064a\u0648\u0646",
-                    "0 \u0645\u0644\u064a\u0627\u0631",
-                    "00 \u0645\u0644\u064a\u0627\u0631",
-                    "000 \u0645\u0644\u064a\u0627\u0631",
-                    "0 \u062a\u0631\u0644\u064a\u0648\u0646",
-                    "00 \u062a\u0631\u0644\u064a\u0648\u0646",
-                    "000 \u062a\u0631\u0644\u064a\u0648\u0646",
+                    "{zero:0' '\u0623\u0644\u0641 one:0' '\u0623\u0644\u0641 two:0' '\u0623\u0644\u0641 few:0' '\u0622\u0644\u0627\u0641 many:0' '\u0623\u0644\u0641 other:0' '\u0623\u0644\u0641}",
+                    "{zero:00' '\u0623\u0644\u0641 one:00' '\u0623\u0644\u0641 two:00' '\u0623\u0644\u0641 few:00' '\u0623\u0644\u0641 many:00' '\u0623\u0644\u0641 other:00' '\u0623\u0644\u0641}",
+                    "{zero:000' '\u0623\u0644\u0641 one:000' '\u0623\u0644\u0641 two:000' '\u0623\u0644\u0641 few:000' '\u0623\u0644\u0641 many:000' '\u0623\u0644\u0641 other:000' '\u0623\u0644\u0641}",
+                    "{zero:0' '\u0645\u0644\u064a\u0648\u0646 one:0' '\u0645\u0644\u064a\u0648\u0646 two:0' '\u0645\u0644\u064a\u0648\u0646 few:0' '\u0645\u0644\u0627\u064a\u064a\u0646 many:0' '\u0645\u0644\u064a\u0648\u0646 other:0' '\u0645\u0644\u064a\u0648\u0646}",
+                    "{zero:00' '\u0645\u0644\u064a\u0648\u0646 one:00' '\u0645\u0644\u064a\u0648\u0646 two:00' '\u0645\u0644\u064a\u0648\u0646 few:00' '\u0645\u0644\u0627\u064a\u064a\u0646 many:00' '\u0645\u0644\u064a\u0648\u0646 other:00' '\u0645\u0644\u064a\u0648\u0646}",
+                    "{zero:000' '\u0645\u0644\u064a\u0648\u0646 one:000' '\u0645\u0644\u064a\u0648\u0646 two:000' '\u0645\u0644\u064a\u0648\u0646 few:000' '\u0645\u0644\u064a\u0648\u0646 many:000' '\u0645\u0644\u064a\u0648\u0646 other:000' '\u0645\u0644\u064a\u0648\u0646}",
+                    "{zero:0' '\u0645\u0644\u064a\u0627\u0631 one:0' '\u0645\u0644\u064a\u0627\u0631 two:0' '\u0645\u0644\u064a\u0627\u0631 few:0' '\u0645\u0644\u064a\u0627\u0631 many:0' '\u0645\u0644\u064a\u0627\u0631 other:0' '\u0645\u0644\u064a\u0627\u0631}",
+                    "{zero:00' '\u0645\u0644\u064a\u0627\u0631 one:00' '\u0645\u0644\u064a\u0627\u0631 two:00' '\u0645\u0644\u064a\u0627\u0631 few:00' '\u0645\u0644\u064a\u0627\u0631 many:00' '\u0645\u0644\u064a\u0627\u0631 other:00' '\u0645\u0644\u064a\u0627\u0631}",
+                    "{zero:000' '\u0645\u0644\u064a\u0627\u0631 one:000' '\u0645\u0644\u064a\u0627\u0631 two:000' '\u0645\u0644\u064a\u0627\u0631 few:000' '\u0645\u0644\u064a\u0627\u0631 many:000' '\u0645\u0644\u064a\u0627\u0631 other:000' '\u0645\u0644\u064a\u0627\u0631}",
+                    "{zero:0' '\u062a\u0631\u0644\u064a\u0648\u0646 one:0' '\u062a\u0631\u0644\u064a\u0648\u0646 two:0' '\u062a\u0631\u0644\u064a\u0648\u0646 few:0' '\u062a\u0631\u0644\u064a\u0648\u0646 many:0' '\u062a\u0631\u0644\u064a\u0648\u0646 other:0' '\u062a\u0631\u0644\u064a\u0648\u0646}",
+                    "{zero:00' '\u062a\u0631\u0644\u064a\u0648\u0646 one:00' '\u062a\u0631\u0644\u064a\u0648\u0646 two:00' '\u062a\u0631\u0644\u064a\u0648\u0646 few:00' '\u062a\u0631\u0644\u064a\u0648\u0646 many:00' '\u062a\u0631\u0644\u064a\u0648\u0646 other:00' '\u062a\u0631\u0644\u064a\u0648\u0646}",
+                    "{zero:000' '\u062a\u0631\u0644\u064a\u0648\u0646 one:000' '\u062a\u0631\u0644\u064a\u0648\u0646 two:000' '\u062a\u0631\u0644\u064a\u0648\u0646 few:000' '\u062a\u0631\u0644\u064a\u0648\u0646 many:000' '\u062a\u0631\u0644\u064a\u0648\u0646 other:000' '\u062a\u0631\u0644\u064a\u0648\u0646}",
                 }
             },
             { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
@@ -375,6 +372,14 @@ public class FormatData_ar extends ListResourceBundle {
             { "field.zone", "\u0627\u0644\u062a\u0648\u0642\u064a\u062a" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterNames },
             { "roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
+            { "arab.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0%",
+                    "",
+                }
+            },
             { "buddhist.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "Eras", metaValue_Eras },
@@ -419,18 +424,18 @@ public class FormatData_ar extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0\u0623\u0644\u0641",
-                    "00\u00a0\u0623\u0644\u0641",
-                    "000\u00a0\u0623\u0644\u0641",
-                    "0\u00a0\u0645\u0644\u064a\u0648\u0646",
-                    "00\u00a0\u0645\u0644\u064a\u0648\u0646",
-                    "000\u00a0\u0645\u0644\u064a\u0648\u0646",
-                    "0\u00a0\u0645\u0644\u064a\u0627\u0631",
-                    "00\u00a0\u0645\u0644\u064a\u0627\u0631",
-                    "000\u00a0\u0645\u0644\u064a\u0627\u0631",
-                    "0\u00a0\u062a\u0631\u0644\u064a\u0648\u0646",
-                    "00\u00a0\u062a\u0631\u0644\u064a\u0648\u0646",
-                    "000\u00a0\u062a\u0631\u0644\u064a\u0648\u0646",
+                    "{zero:0\u00a0\u0623\u0644\u0641 one:0\u00a0\u0623\u0644\u0641 two:0\u00a0\u0623\u0644\u0641 few:0\u00a0\u0622\u0644\u0627\u0641 many:0\u00a0\u0623\u0644\u0641 other:0\u00a0\u0623\u0644\u0641}",
+                    "{zero:00\u00a0\u0623\u0644\u0641 one:00\u00a0\u0623\u0644\u0641 two:00\u00a0\u0623\u0644\u0641 few:00\u00a0\u0623\u0644\u0641 many:00\u00a0\u0623\u0644\u0641 other:00\u00a0\u0623\u0644\u0641}",
+                    "{zero:000\u00a0\u0623\u0644\u0641 one:000\u00a0\u0623\u0644\u0641 two:000\u00a0\u0623\u0644\u0641 few:000\u00a0\u0623\u0644\u0641 many:000\u00a0\u0623\u0644\u0641 other:000\u00a0\u0623\u0644\u0641}",
+                    "{zero:0\u00a0\u0645\u0644\u064a\u0648\u0646 one:0\u00a0\u0645\u0644\u064a\u0648\u0646 two:0\u00a0\u0645\u0644\u064a\u0648\u0646 few:0\u00a0\u0645\u0644\u064a\u0648\u0646 many:0\u00a0\u0645\u0644\u064a\u0648\u0646 other:0\u00a0\u0645\u0644\u064a\u0648\u0646}",
+                    "{zero:00\u00a0\u0645\u0644\u064a\u0648\u0646 one:00\u00a0\u0645\u0644\u064a\u0648\u0646 two:00\u00a0\u0645\u0644\u064a\u0648\u0646 few:00\u00a0\u0645\u0644\u064a\u0648\u0646 many:00\u00a0\u0645\u0644\u064a\u0648\u0646 other:00\u00a0\u0645\u0644\u064a\u0648\u0646}",
+                    "{zero:000\u00a0\u0645\u0644\u064a\u0648\u0646 one:000\u00a0\u0645\u0644\u064a\u0648\u0646 two:000\u00a0\u0645\u0644\u064a\u0648\u0646 few:000\u00a0\u0645\u0644\u064a\u0648\u0646 many:000\u00a0\u0645\u0644\u064a\u0648\u0646 other:000\u00a0\u0645\u0644\u064a\u0648\u0646}",
+                    "{zero:0\u00a0\u0645\u0644\u064a\u0627\u0631 one:0\u00a0\u0645\u0644\u064a\u0627\u0631 two:0\u00a0\u0645\u0644\u064a\u0627\u0631 few:0\u00a0\u0645\u0644\u064a\u0627\u0631 many:0\u00a0\u0645\u0644\u064a\u0627\u0631 other:0\u00a0\u0645\u0644\u064a\u0627\u0631}",
+                    "{zero:00\u00a0\u0645\u0644\u064a\u0627\u0631 one:00\u00a0\u0645\u0644\u064a\u0627\u0631 two:00\u00a0\u0645\u0644\u064a\u0627\u0631 few:00\u00a0\u0645\u0644\u064a\u0627\u0631 many:00\u00a0\u0645\u0644\u064a\u0627\u0631 other:00\u00a0\u0645\u0644\u064a\u0627\u0631}",
+                    "{zero:000\u00a0\u0645\u0644\u064a\u0627\u0631 one:000\u00a0\u0645\u0644\u064a\u0627\u0631 two:000\u00a0\u0645\u0644\u064a\u0627\u0631 few:000\u00a0\u0645\u0644\u064a\u0627\u0631 many:000\u00a0\u0645\u0644\u064a\u0627\u0631 other:000\u00a0\u0645\u0644\u064a\u0627\u0631}",
+                    "{zero:0\u00a0\u062a\u0631\u0644\u064a\u0648\u0646 one:0\u00a0\u062a\u0631\u0644\u064a\u0648\u0646 two:0\u00a0\u062a\u0631\u0644\u064a\u0648\u0646 few:0\u00a0\u062a\u0631\u0644\u064a\u0648\u0646 many:0\u00a0\u062a\u0631\u0644\u064a\u0648\u0646 other:0\u00a0\u062a\u0631\u0644\u064a\u0648\u0646}",
+                    "{zero:00\u00a0\u062a\u0631\u0644\u064a\u0648\u0646 one:00\u00a0\u062a\u0631\u0644\u064a\u0648\u0646 two:00\u00a0\u062a\u0631\u0644\u064a\u0648\u0646 few:00\u00a0\u062a\u0631\u0644\u064a\u0648\u0646 many:00\u00a0\u062a\u0631\u0644\u064a\u0648\u0646 other:00\u00a0\u062a\u0631\u0644\u064a\u0648\u0646}",
+                    "{zero:000\u00a0\u062a\u0631\u0644\u064a\u0648\u0646 one:000\u00a0\u062a\u0631\u0644\u064a\u0648\u0646 two:000\u00a0\u062a\u0631\u0644\u064a\u0648\u0646 few:000\u00a0\u062a\u0631\u0644\u064a\u0648\u0646 many:000\u00a0\u062a\u0631\u0644\u064a\u0648\u0646 other:000\u00a0\u062a\u0631\u0644\u064a\u0648\u0646}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -453,6 +458,14 @@ public class FormatData_ar extends ListResourceBundle {
             { "islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "calendarname.buddhist", "\u0627\u0644\u062a\u0642\u0648\u064a\u0645 \u0627\u0644\u0628\u0648\u0630\u064a" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "\u00a4\u00a0#,##0.00",
+                    "#,##0%",
+                    "\u00a4#,##0.00;(\u00a4#,##0.00)",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
