@@ -221,6 +221,8 @@ public class FormatData_as extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "long.Eras",
@@ -255,6 +257,8 @@ public class FormatData_as extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -266,6 +270,14 @@ public class FormatData_as extends ListResourceBundle {
             { "field.dayperiod", "\u09aa\u09c2\u09f0\u09cd\u09ac\u09be\u09b9\u09cd\u09a8/\u0985\u09aa\u09f0\u09be\u09b9\u09cd\u09a8" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
             { "japanese.QuarterNarrows", metaValue_QuarterNarrows },
+            { "beng.NumberPatterns",
+                new String[] {
+                    "#,##,##0.###",
+                    "\u00a4\u00a0#,##,##0.00",
+                    "#,##,##0%",
+                    "",
+                }
+            },
             { "calendarname.roc", "\u099a\u09c0\u09a8\u09be \u09aa\u09cd\u09f0\u099c\u09be\u09a4\u09a8\u09cd\u09a4\u09cd\u09f0\u09f0 \u0995\u09c7\u09b2\u09c7\u09a3\u09cd\u09a1\u09be\u09f0" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -273,13 +285,6 @@ public class FormatData_as extends ListResourceBundle {
             { "field.second", "\u099b\u09c7\u0995\u09c7\u09a3\u09cd\u09a1" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##,##0.###",
-                    "\u00a4\u00a0#,##,##0.00",
-                    "#,##,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u0987\u099b\u09b2\u09be\u09ae\u09c0 \u0995\u09c7\u09b2\u09c7\u09a3\u09cd\u09a1\u09be\u09f0" },
             { "japanese.narrow.AmPmMarkers", metaValue_AmPmMarkers },
@@ -291,18 +296,18 @@ public class FormatData_as extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 \u09b9\u09be\u099c\u09be\u09f0",
-                    "00 \u09b9\u09be\u099c\u09be\u09f0",
-                    "0 \u09b2\u09be\u0996",
-                    "0 \u09a8\u09bf\u09af\u09c1\u09a4",
-                    "00 \u09a8\u09bf\u09af\u09c1\u09a4",
-                    "000 \u09a8\u09bf\u09af\u09c1\u09a4",
-                    "0 \u09b6\u09a4 \u0995\u09cb\u099f\u09bf",
-                    "00 \u09b6\u09a4 \u0995\u09cb\u099f\u09bf",
-                    "000 \u09b6\u09a4 \u0995\u09cb\u099f\u09bf",
-                    "0 \u09b6\u09a4 \u09aa\u09f0\u09be\u09f0\u09cd\u09a6\u09cd\u09a7",
-                    "00 \u09b6\u09a4 \u09aa\u09f0\u09be\u09f0\u09cd\u09a6\u09cd\u09a7",
-                    "000 \u09b6\u09a4 \u09aa\u09f0\u09be\u09f0\u09cd\u09a6\u09cd\u09a7",
+                    "{one:0' '\u09b9\u09be\u099c\u09be\u09f0 other:0' '\u09b9\u09be\u099c\u09be\u09f0}",
+                    "{one:00' '\u09b9\u09be\u099c\u09be\u09f0 other:00' '\u09b9\u09be\u099c\u09be\u09f0}",
+                    "{one:0' '\u09b2\u09be\u0996 other:0' '\u09b2\u09be\u0996}",
+                    "{one:0' '\u09a8\u09bf\u09af\u09c1\u09a4 other:0' '\u09a8\u09bf\u09af\u09c1\u09a4}",
+                    "{one:00' '\u09a8\u09bf\u09af\u09c1\u09a4 other:00' '\u09a8\u09bf\u09af\u09c1\u09a4}",
+                    "{one:000' '\u09a8\u09bf\u09af\u09c1\u09a4 other:000' '\u09a8\u09bf\u09af\u09c1\u09a4}",
+                    "{one:0' '\u09b6\u09a4' '\u0995\u09cb\u099f\u09bf other:0' '\u09b6\u09a4' '\u0995\u09cb\u099f\u09bf}",
+                    "{one:00' '\u09b6\u09a4' '\u0995\u09cb\u099f\u09bf other:00' '\u09b6\u09a4' '\u0995\u09cb\u099f\u09bf}",
+                    "{one:000' '\u09b6\u09a4' '\u0995\u09cb\u099f\u09bf other:000' '\u09b6\u09a4' '\u0995\u09cb\u099f\u09bf}",
+                    "{one:0' '\u09b6\u09a4' '\u09aa\u09f0\u09be\u09f0\u09cd\u09a6\u09cd\u09a7 other:0' '\u09b6\u09a4' '\u09aa\u09f0\u09be\u09f0\u09cd\u09a6\u09cd\u09a7}",
+                    "{one:00' '\u09b6\u09a4' '\u09aa\u09f0\u09be\u09f0\u09cd\u09a6\u09cd\u09a7 other:00' '\u09b6\u09a4' '\u09aa\u09f0\u09be\u09f0\u09cd\u09a6\u09cd\u09a7}",
+                    "{one:000' '\u09b6\u09a4' '\u09aa\u09f0\u09be\u09f0\u09cd\u09a6\u09cd\u09a7 other:000' '\u09b6\u09a4' '\u09aa\u09f0\u09be\u09f0\u09cd\u09a6\u09cd\u09a7}",
                 }
             },
             { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
@@ -349,18 +354,18 @@ public class FormatData_as extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0\u09b9\u09be\u099c\u09be\u09f0",
-                    "00\u00a0\u09b9\u09be\u099c\u09be\u09f0",
-                    "0\u00a0\u09b2\u09be\u0996",
-                    "0\u00a0\u09a8\u09bf\u09af\u09c1\u09a4",
-                    "00\u00a0\u09a8\u09bf\u09af\u09c1\u09a4",
-                    "000\u00a0\u09a8\u09bf\u0983",
-                    "0\u00a0\u09b6\u0983\u00a0\u0995\u09cb\u0983",
-                    "00\u00a0\u09b6\u0983\u00a0\u0995\u09cb\u0983",
-                    "000\u00a0\u09b6\u0983\u00a0\u0995\u0983",
-                    "0\u00a0\u09b6\u0983\u00a0\u09aa\u0983",
-                    "00\u00a0\u09b6\u0983\u00a0\u09aa\u0983",
-                    "000\u00a0\u09b6\u0983\u00a0\u09aa\u0983",
+                    "{one:0\u00a0\u09b9\u09be\u099c\u09be\u09f0 other:0\u00a0\u09b9\u09be\u099c\u09be\u09f0}",
+                    "{one:00\u00a0\u09b9\u09be\u099c\u09be\u09f0 other:00\u00a0\u09b9\u09be\u099c\u09be\u09f0}",
+                    "{one:0\u00a0\u09b2\u09be\u0996 other:0\u00a0\u09b2\u09be\u0996}",
+                    "{one:0\u00a0\u09a8\u09bf\u09af\u09c1\u09a4 other:0\u00a0\u09a8\u09bf\u09af\u09c1\u09a4}",
+                    "{one:00\u00a0\u09a8\u09bf\u09af\u09c1\u09a4 other:00\u00a0\u09a8\u09bf\u09af\u09c1\u09a4}",
+                    "{one:000\u00a0\u09a8\u09bf\u0983 other:000\u00a0\u09a8\u09bf\u0983}",
+                    "{one:0\u00a0\u09b6\u0983\u00a0\u0995\u09cb\u0983 other:0\u00a0\u09b6\u0983\u00a0\u0995\u09cb\u0983}",
+                    "{one:00\u00a0\u09b6\u0983\u00a0\u0995\u09cb\u0983 other:00\u00a0\u09b6\u0983\u00a0\u0995\u09cb\u0983}",
+                    "{one:000\u00a0\u09b6\u0983\u00a0\u0995\u0983 other:000\u00a0\u09b6\u0983\u00a0\u0995\u0983}",
+                    "{one:0\u00a0\u09b6\u0983\u00a0\u09aa\u0983 other:0\u00a0\u09b6\u0983\u00a0\u09aa\u0983}",
+                    "{one:00\u00a0\u09b6\u0983\u00a0\u09aa\u0983 other:00\u00a0\u09b6\u0983\u00a0\u09aa\u0983}",
+                    "{one:000\u00a0\u09b6\u0983\u00a0\u09aa\u0983 other:000\u00a0\u09b6\u0983\u00a0\u09aa\u0983}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -380,6 +385,14 @@ public class FormatData_as extends ListResourceBundle {
             { "field.hour", "\u0998\u09a3\u09cd\u099f\u09be" },
             { "calendarname.buddhist", "\u09ac\u09cc\u09a6\u09cd\u09a7 \u0995\u09c7\u09b2\u09c7\u09a3\u09cd\u09a1\u09be\u09f0" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##,##0.###",
+                    "\u00a4\u00a0#,##,##0.00",
+                    "#,##,##0%",
+                    "\u00a4\u00a0#,##,##0.00",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
