@@ -164,6 +164,14 @@ public class FormatData_bn extends ListResourceBundle {
                "h:mm:ss a",
                "h:mm a",
             };
+        final String[] metaValue_buddhist_AmPmMarkers = new String[] {
+               "AM",
+               "PM",
+            };
+        final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
+               "BC",
+               "BE",
+            };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
                "EEEE, d MMMM, y G",
                "d MMMM, y G",
@@ -176,10 +184,6 @@ public class FormatData_bn extends ListResourceBundle {
                "d MMM, y GGGG",
                "d/M/y G",
             };
-        final String[] metaValue_japanese_narrow_AmPmMarkers = new String[] {
-               "AM",
-               "PM",
-            };
         final String[] metaValue_java_time_roc_long_Eras = new String[] {
                "\u0986\u0997\u09c7 R.O.C.",
                "\u09ae\u09bf\u0999\u09cd\u0997\u09c1\u09af\u09bc\u09be",
@@ -208,6 +212,8 @@ public class FormatData_bn extends ListResourceBundle {
             { "MonthNames", metaValue_MonthNames },
             { "field.year", "\u09ac\u099b\u09b0" },
             { "calendarname.islamic-umalqura", "\u0987\u09b8\u09b2\u09be\u09ae\u09bf\u0995 \u09ac\u09b0\u09cd\u09b7\u09aa\u099e\u09cd\u099c\u09c0 (\u0989\u09ae\u09cd\u09ae\u09be \u0986\u09b2-\u0995\u09c1\u09b0\u0986)" },
+            { "japanese.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
+            { "buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "timezone.gmtFormat", "GMT {0}" },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "standalone.QuarterAbbreviations",
@@ -221,7 +227,7 @@ public class FormatData_bn extends ListResourceBundle {
             { "roc.QuarterNames", metaValue_QuarterNames },
             { "roc.MonthNarrows", metaValue_MonthNarrows },
             { "calendarname.islamic-civil", "\u0987\u09b8\u09b2\u09be\u09ae\u09bf\u0995-\u09b8\u09bf\u09ad\u09bf\u09b2 \u09ac\u09b0\u09cd\u09b7\u09aa\u099e\u09cd\u099c\u09c0" },
-            { "islamic.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "islamic.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
             { "narrow.Eras", metaValue_Eras },
             { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
@@ -245,6 +251,8 @@ public class FormatData_bn extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "long.Eras",
@@ -278,6 +286,8 @@ public class FormatData_bn extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -285,10 +295,19 @@ public class FormatData_bn extends ListResourceBundle {
             { "buddhist.DayNames", metaValue_DayNames },
             { "field.minute", "\u09ae\u09bf\u09a8\u09bf\u099f" },
             { "field.era", "\u09af\u09c1\u0997" },
+            { "buddhist.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "field.dayperiod", "AM/PM" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
             { "islamic.MonthNames", metaValue_islamic_MonthNames },
             { "japanese.QuarterNarrows", metaValue_QuarterNarrows },
+            { "beng.NumberPatterns",
+                new String[] {
+                    "#,##,##0.###",
+                    "#,##,##0.00\u00a4",
+                    "#,##0%",
+                    "",
+                }
+            },
             { "calendarname.roc", "\u09ae\u09bf\u0999\u09cd\u0997\u09c1\u0993 \u0995\u09cd\u09af\u09be\u09b2\u09c7\u09a8\u09cd\u09a1\u09be\u09b0" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterNames },
@@ -315,18 +334,11 @@ public class FormatData_bn extends ListResourceBundle {
             },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##,##0.###",
-                    "#,##,##0.00\u00a4",
-                    "#,##,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u0987\u09b8\u09b2\u09be\u09ae\u09bf\u0995 \u0995\u09cd\u09af\u09be\u09b2\u09c7\u09a8\u09cd\u09a1\u09be\u09b0" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "java.time.roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
-            { "japanese.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "japanese.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations", metaValue_MonthNames },
             { "timezone.regionFormat", "{0} \u09b8\u09ae\u09af\u09bc" },
@@ -335,34 +347,37 @@ public class FormatData_bn extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 \u09b9\u09be\u099c\u09be\u09b0",
-                    "00 \u09b9\u09be\u099c\u09be\u09b0",
-                    "0 \u09b2\u09be\u0996",
-                    "00 \u09b2\u09be\u0996",
-                    "0 \u0995\u09cb\u099f\u09bf",
-                    "00 \u0995\u09cb\u099f\u09bf",
-                    "000 \u0995\u09cb\u099f\u09bf",
-                    "0000 \u0995\u09cb\u099f\u09bf",
-                    "00000 \u0995\u09cb\u099f\u09bf",
-                    "0 \u09b2\u09be\u0996 \u0995\u09cb\u099f\u09bf",
-                    "00 \u09b2\u09be\u0996 \u0995\u09cb\u099f\u09bf",
-                    "000 \u09b2\u09be\u0996 \u0995\u09cb\u099f\u09bf",
+                    "{one:0' '\u09b9\u09be\u099c\u09be\u09b0 other:0' '\u09b9\u09be\u099c\u09be\u09b0}",
+                    "{one:00' '\u09b9\u09be\u099c\u09be\u09b0 other:00' '\u09b9\u09be\u099c\u09be\u09b0}",
+                    "{one:0' '\u09b2\u09be\u0996 other:0' '\u09b2\u09be\u0996}",
+                    "{one:00' '\u09b2\u09be\u0996 other:00' '\u09b2\u09be\u0996}",
+                    "{one:0' '\u0995\u09cb\u099f\u09bf other:0' '\u0995\u09cb\u099f\u09bf}",
+                    "{one:00' '\u0995\u09cb\u099f\u09bf other:00' '\u0995\u09cb\u099f\u09bf}",
+                    "{one:000' '\u0995\u09cb\u099f\u09bf other:000' '\u0995\u09cb\u099f\u09bf}",
+                    "{one:0000' '\u0995\u09cb\u099f\u09bf other:0000' '\u0995\u09cb\u099f\u09bf}",
+                    "{one:00000' '\u0995\u09cb\u099f\u09bf other:00000' '\u0995\u09cb\u099f\u09bf}",
+                    "{one:0' '\u09b2\u09be\u0996' '\u0995\u09cb\u099f\u09bf other:0' '\u09b2\u09be\u0996' '\u0995\u09cb\u099f\u09bf}",
+                    "{one:00' '\u09b2\u09be\u0996' '\u0995\u09cb\u099f\u09bf other:00' '\u09b2\u09be\u0996' '\u0995\u09cb\u099f\u09bf}",
+                    "{one:000' '\u09b2\u09be\u0996' '\u0995\u09cb\u099f\u09bf other:000' '\u09b2\u09be\u0996' '\u0995\u09cb\u099f\u09bf}",
                 }
             },
             { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
-            { "roc.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "roc.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "standalone.QuarterNames", metaValue_QuarterNames },
             { "japanese.MonthNarrows", metaValue_MonthNarrows },
             { "islamic.QuarterAbbreviations", metaValue_QuarterNames },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.DayNarrows", metaValue_DayNarrows },
-            { "islamic.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
+            { "islamic.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
+            { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
             { "java.time.roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.zone", "\u09b8\u09ae\u09af\u09bc \u0985\u099e\u09cd\u099a\u09b2" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterNames },
             { "roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
+            { "buddhist.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "Eras", metaValue_Eras },
             { "roc.DayNames", metaValue_DayNames },
             { "islamic.QuarterNames", metaValue_QuarterNames },
@@ -376,17 +391,19 @@ public class FormatData_bn extends ListResourceBundle {
             { "java.time.islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.QuarterNames", metaValue_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_QuarterNames },
+            { "java.time.buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "japanese.DayNames", metaValue_DayNames },
             { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNames", metaValue_DayNames },
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.MonthNames", metaValue_MonthNames },
+            { "buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "field.week", "\u09b8\u09aa\u09cd\u09a4\u09be\u09b9" },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
             { "islamic.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.DayNarrows", metaValue_DayNarrows },
-            { "roc.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "roc.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "short.CompactNumberPatterns",
@@ -394,21 +411,22 @@ public class FormatData_bn extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0\u09b9\u09be",
-                    "00\u00a0\u09b9\u09be",
-                    "0\u00a0\u09b2\u09be",
-                    "00\u00a0\u09b2\u09be",
-                    "0\u00a0\u0995\u09cb",
-                    "00\u00a0\u0995\u09cb",
-                    "000\u00a0\u0995\u09cb",
-                    "0000\u00a0\u0995\u09cb",
-                    "00000\u00a0\u0995\u09cb",
-                    "0\u00a0\u09b2\u09be'.'\u0995\u09cb'.'",
-                    "00\u00a0\u09b2\u09be'.'\u0995\u09cb'.'",
-                    "000\u00a0\u09b2\u09be'.'\u0995\u09cb'.'",
+                    "{one:0\u00a0\u09b9\u09be other:0\u00a0\u09b9\u09be}",
+                    "{one:00\u00a0\u09b9\u09be other:00\u00a0\u09b9\u09be}",
+                    "{one:0\u00a0\u09b2\u09be other:0\u00a0\u09b2\u09be}",
+                    "{one:00\u00a0\u09b2\u09be other:00\u00a0\u09b2\u09be}",
+                    "{one:0\u00a0\u0995\u09cb other:0\u00a0\u0995\u09cb}",
+                    "{one:00\u00a0\u0995\u09cb other:00\u00a0\u0995\u09cb}",
+                    "{one:000\u00a0\u0995\u09cb other:000\u00a0\u0995\u09cb}",
+                    "{one:00\u00a0\u09b6\u09a4\u00a0\u0995\u09cb other:00\u09b6\u09a4\u00a0\u0995\u09cb}",
+                    "{one:00000\u00a0\u0995\u09cb other:00000\u00a0\u0995\u09cb}",
+                    "{one:0\u00a0\u09b2\u09be'.'\u0995\u09cb'.' other:0\u00a0\u09b2\u09be'.'\u0995\u09cb'.'}",
+                    "{one:00\u00a0\u09b2\u09be'.'\u0995\u09cb'.' other:00\u00a0\u09b2\u09be'.'\u0995\u09cb'.'}",
+                    "{one:000\u00a0\u09b2\u09be'.'\u0995\u09cb'.' other:000\u00a0\u09b2\u09be'.'\u0995\u09cb'.'}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
+            { "java.time.buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "timezone.regionFormat.daylight", "{0} \u09a6\u09bf\u09ac\u09be\u09b2\u09cb\u0995 \u09b8\u09ae\u09af\u09bc" },
             { "DatePatterns",
                 new String[] {
@@ -427,6 +445,14 @@ public class FormatData_bn extends ListResourceBundle {
             { "islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "calendarname.buddhist", "\u09ac\u09cc\u09a6\u09cd\u09a7 \u0995\u09cd\u09af\u09be\u09b2\u09c7\u09a8\u09cd\u09a1\u09be\u09b0" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##,##0.###",
+                    "#,##,##0.00\u00a4",
+                    "#,##,##0%",
+                    "#,##,##0.00\u00a4;(#,##,##0.00\u00a4)",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
