@@ -244,6 +244,8 @@ public class FormatData_bs extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -270,13 +272,6 @@ public class FormatData_bs extends ListResourceBundle {
             { "field.second", "sekunda" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0\u00a0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "islamski kalendar" },
             { "japanese.narrow.AmPmMarkers", metaValue_AmPmMarkers },
@@ -287,18 +282,18 @@ public class FormatData_bs extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 hiljada",
-                    "00 hiljada",
-                    "000 hiljada",
-                    "0 milion",
-                    "00 milion",
-                    "000 milion",
-                    "0 milijarda",
-                    "00 milijarda",
-                    "000 milijarda",
-                    "0 bilion",
-                    "00 bilion",
-                    "000 bilion",
+                    "{one:0' 'hiljada few:0' 'hiljade other:0' 'hiljada}",
+                    "{one:00' 'hiljada few:00' 'hiljade other:00' 'hiljada}",
+                    "{one:000' 'hiljada few:000' 'hiljade other:000' 'hiljada}",
+                    "{one:0' 'milion few:0' 'miliona other:0' 'miliona}",
+                    "{one:00' 'milion few:00' 'miliona other:00' 'miliona}",
+                    "{one:000' 'milion few:000' 'miliona other:000' 'miliona}",
+                    "{one:0' 'milijarda few:0' 'milijarde other:0' 'milijardi}",
+                    "{one:00' 'milijarda few:00' 'milijarde other:00' 'milijardi}",
+                    "{one:000' 'milijarda few:000' 'milijarde other:000' 'milijardi}",
+                    "{one:0' 'bilion few:0' 'biliona other:0' 'biliona}",
+                    "{one:00' 'bilion few:00' 'biliona other:00' 'biliona}",
+                    "{one:000' 'bilion few:000' 'biliona other:000' 'biliona}",
                 }
             },
             { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
@@ -368,18 +363,18 @@ public class FormatData_bs extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0hilj'.'",
-                    "00\u00a0hilj'.'",
-                    "000\u00a0hilj'.'",
-                    "0\u00a0mil'.'",
-                    "00\u00a0mil'.'",
-                    "000\u00a0mil'.'",
-                    "0\u00a0mlr'.'",
-                    "00\u00a0mlr'.'",
-                    "000\u00a0mlr'.'",
-                    "0\u00a0bil'.'",
-                    "00\u00a0bil'.'",
-                    "000\u00a0bil'.'",
+                    "{one:0\u00a0hilj'.' few:0\u00a0hilj'.' other:0\u00a0hilj'.'}",
+                    "{one:00\u00a0hilj'.' few:00\u00a0hilj'.' other:00\u00a0hilj'.'}",
+                    "{one:000\u00a0hilj'.' few:000\u00a0hilj'.' other:000\u00a0hilj'.'}",
+                    "{one:0\u00a0mil'.' few:0\u00a0mil'.' other:0\u00a0mil'.'}",
+                    "{one:00\u00a0mil'.' few:00\u00a0mil'.' other:00\u00a0mil'.'}",
+                    "{one:000\u00a0mil'.' few:000\u00a0mil'.' other:000\u00a0mil'.'}",
+                    "{one:0\u00a0mlr'.' few:0\u00a0mlr'.' other:0\u00a0mlr'.'}",
+                    "{one:00\u00a0mlr'.' few:00\u00a0mlr'.' other:00\u00a0mlr'.'}",
+                    "{one:000\u00a0mlr'.' few:000\u00a0mlr'.' other:000\u00a0mlr'.'}",
+                    "{one:0\u00a0bil'.' few:0\u00a0bil'.' other:0\u00a0bil'.'}",
+                    "{one:00\u00a0bil'.' few:00\u00a0bil'.' other:00\u00a0bil'.'}",
+                    "{one:000\u00a0bil'.' few:000\u00a0bil'.' other:000\u00a0bil'.'}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -400,6 +395,14 @@ public class FormatData_bs extends ListResourceBundle {
             { "islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "calendarname.buddhist", "budisti\u010dki kalendar" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0\u00a0%",
+                    "#,##0.00\u00a0\u00a4",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
