@@ -224,6 +224,7 @@ public class FormatData_ca extends ListResourceBundle {
                     "despr\u00e9s de Crist",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -249,6 +250,8 @@ public class FormatData_ca extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -259,6 +262,7 @@ public class FormatData_ca extends ListResourceBundle {
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "a.\u00a0m./p.\u00a0m." },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "calendari de la Rep\u00fablica de Xina" },
             { "islamic.DatePatterns", metaValue_japanese_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -266,13 +270,6 @@ public class FormatData_ca extends ListResourceBundle {
             { "field.second", "segon" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns",
                 new String[] {
                     "EEEE d MMMM 'de' y GGGG",
@@ -308,18 +305,18 @@ public class FormatData_ca extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 miler",
-                    "00 milers",
-                    "000 milers",
-                    "0 mili\u00f3",
-                    "00 milions",
-                    "000 milions",
-                    "0 miler de milions",
-                    "00 milers de milions",
-                    "000 milers de milions",
-                    "0 bili\u00f3",
-                    "00 bilions",
-                    "000 bilions",
+                    "{one:0' 'miler other:0' 'milers}",
+                    "{one:00' 'milers other:00' 'milers}",
+                    "{one:000' 'milers other:000' 'milers}",
+                    "{one:0' 'mili\u00f3 other:0' 'milions}",
+                    "{one:00' 'milions other:00' 'milions}",
+                    "{one:000' 'milions other:000' 'milions}",
+                    "{one:0' 'miler' 'de' 'milions other:0' 'milers' 'de' 'milions}",
+                    "{one:00' 'milers' 'de' 'milions other:00' 'milers' 'de' 'milions}",
+                    "{one:000' 'milers' 'de' 'milions other:000' 'milers' 'de' 'milions}",
+                    "{one:0' 'bili\u00f3 other:0' 'bilions}",
+                    "{one:00' 'bilions other:00' 'bilions}",
+                    "{one:000' 'bilions other:000' 'bilions}",
                 }
             },
             { "roc.narrow.AmPmMarkers", metaValue_AmPmMarkers },
@@ -397,18 +394,18 @@ public class FormatData_ca extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0m",
-                    "00m",
-                    "000m",
-                    "0\u00a0M",
-                    "00\u00a0M",
-                    "000\u00a0M",
-                    "0000\u00a0M",
-                    "00mM",
-                    "000mM",
-                    "0\u00a0B",
-                    "00\u00a0B",
-                    "000\u00a0B",
+                    "{one:0m other:0m}",
+                    "{one:00m other:00m}",
+                    "{one:000m other:000m}",
+                    "{one:0\u00a0M other:0\u00a0M}",
+                    "{one:00\u00a0M other:00\u00a0M}",
+                    "{one:000\u00a0M other:000\u00a0M}",
+                    "{one:0000\u00a0M other:0000\u00a0M}",
+                    "{one:00mM other:00mM}",
+                    "{one:000mM other:000mM}",
+                    "{one:0\u00a0B other:0\u00a0B}",
+                    "{one:00\u00a0B other:00\u00a0B}",
+                    "{one:000\u00a0B other:000\u00a0B}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -445,6 +442,14 @@ public class FormatData_ca extends ListResourceBundle {
                     "",
                 }
             },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0%",
+                    "#,##0.00\u00a0\u00a4;(#,##0.00\u00a0\u00a4)",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
