@@ -185,6 +185,10 @@ public class FormatData_ccp extends ListResourceBundle {
                "h:mm:ss a",
                "h:mm a",
             };
+        final String[] metaValue_buddhist_AmPmMarkers = new String[] {
+               "AM",
+               "PM",
+            };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
                "EEEE, d MMMM, y G",
                "d MMMM, y G",
@@ -197,10 +201,6 @@ public class FormatData_ccp extends ListResourceBundle {
                "d MMM, y GGGG",
                "d/M/y G",
             };
-        final String[] metaValue_japanese_narrow_AmPmMarkers = new String[] {
-               "AM",
-               "PM",
-            };
         final String[] metaValue_java_time_islamic_long_Eras = new String[] {
                "",
                "\ud804\udd21\ud804\udd2a\ud804\udd07\ud804\udd34",
@@ -218,31 +218,37 @@ public class FormatData_ccp extends ListResourceBundle {
                "\u2030",
                "\u221e",
                "NaN",
+               "",
+               "",
             };
         final String[] metaValue_short_CompactNumberPatterns = new String[] {
                "",
                "",
                "",
-               "",
-               "",
-               "",
-               "",
-               "",
-               "",
-               "0G",
-               "00G",
-               "000G",
+               "{other:0K}",
+               "{other:00K}",
+               "{other:000K}",
+               "{other:0M}",
+               "{other:00M}",
+               "{other:000M}",
+               "{other:0G}",
+               "{other:00G}",
+               "{other:000G}",
+               "{other:0T}",
+               "{other:00T}",
+               "{other:000T}",
             };
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
             { "field.year", "\ud804\udd1d\ud804\udd27\ud804\udd0f\ud804\udd27\ud804\udd22\ud804\udd34" },
+            { "japanese.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "timezone.gmtFormat", "GMT {0}" },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "standalone.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
             { "roc.QuarterNames", metaValue_QuarterNames },
             { "roc.MonthNarrows", metaValue_MonthNarrows },
             { "calendarname.islamic-civil", "\ud804\udd03\ud804\udd28\ud804\udd25\ud804\udd34\ud804\udd23\ud804\udd1f\ud804\udd28\ud804\udd07\ud804\udd34-\ud804\udd25\ud804\udd28\ud804\udd1e\ud804\udd28\ud804\udd23\ud804\udd34 \ud804\udd1d\ud804\udd27\ud804\udd22\ud804\udd34\ud804\udd25\ud804\udd27\ud804\udd1b\ud804\udd27\ud804\udd1a\ud804\udd34\ud804\udd0f\ud804\udd29" },
-            { "islamic.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "islamic.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
             { "narrow.Eras", metaValue_long_Eras },
             { "timezone.regionFormat.standard", "{0} \ud804\udd1f\ud804\udd1a\ud804\udd27\ud804\udd07\ud804\udd34 \ud804\udd03\ud804\udd27\ud804\udd07\ud804\udd34\ud804\udd16\ud804\udd27\ud804\udd16\ud804\udd34" },
@@ -265,12 +271,21 @@ public class FormatData_ccp extends ListResourceBundle {
                     "{1} {0}",
                 }
             },
+            { "cakm.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##,##0.00\u00a4",
+                    "#,##0%",
+                    "",
+                }
+            },
             { "latn.NumberElements", metaValue_cakm_NumberElements },
             { "MonthNarrows", metaValue_MonthNarrows },
             { "japanese.DatePatterns", metaValue_buddhist_DatePatterns },
             { "buddhist.DayNames", metaValue_DayNames },
             { "field.minute", "\ud804\udd1f\ud804\udd28\ud804\udd1a\ud804\udd28\ud804\udd16\ud804\udd34" },
             { "field.era", "\ud804\udd21\ud804\udd2a\ud804\udd07\ud804\udd34" },
+            { "buddhist.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "field.dayperiod", "AM/PM" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
             { "islamic.MonthNames",
@@ -316,32 +331,26 @@ public class FormatData_ccp extends ListResourceBundle {
             },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##,##0.###",
-                    "#,##,##0.00\u00a4",
-                    "#,##,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\ud804\udd03\ud804\udd28\ud804\udd25\ud804\udd34\ud804\udd23\ud804\udd1f\ud804\udd28\ud804\udd07\ud804\udd34 \ud804\udd07\ud804\udd33\ud804\udd20\ud804\udd23\ud804\udd2c\ud804\udd1a\ud804\udd34\ud804\udd13\ud804\udd22\ud804\udd34" },
-            { "japanese.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "japanese.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations", metaValue_standalone_MonthNames },
             { "long.CompactNumberPatterns", metaValue_short_CompactNumberPatterns },
             { "timezone.regionFormat", "{0} \ud804\udd03\ud804\udd27\ud804\udd07\ud804\udd34\ud804\udd16\ud804\udd27" },
             { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
-            { "roc.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "roc.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "standalone.QuarterNames", metaValue_QuarterNames },
             { "japanese.MonthNarrows", metaValue_MonthNarrows },
             { "islamic.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.DayNarrows", metaValue_DayNarrows },
-            { "islamic.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "islamic.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
             { "field.zone", "\ud804\udd03\ud804\udd27\ud804\udd07\ud804\udd34\ud804\udd16\ud804\udd27\ud804\udd22\ud804\udd34 \ud804\udd0e\ud804\udd09" },
             { "japanese.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
+            { "buddhist.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "Eras", metaValue_long_Eras },
             { "roc.DayNames", metaValue_DayNames },
             { "islamic.QuarterNames", metaValue_QuarterNames },
@@ -366,7 +375,7 @@ public class FormatData_ccp extends ListResourceBundle {
             { "buddhist.QuarterNames", metaValue_QuarterNames },
             { "islamic.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.DayNarrows", metaValue_DayNarrows },
-            { "roc.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "roc.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "short.CompactNumberPatterns", metaValue_short_CompactNumberPatterns },
@@ -388,6 +397,14 @@ public class FormatData_ccp extends ListResourceBundle {
             { "islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "calendarname.buddhist", "\ud804\udd1d\ud804\udd2a\ud804\udd16\ud804\udd34\ud804\udd19\ud804\udd2e \ud804\udd07\ud804\udd33\ud804\udd20\ud804\udd23\ud804\udd2c\ud804\udd1a\ud804\udd34\ud804\udd13\ud804\udd22\ud804\udd34" },
             { "standalone.MonthNames", metaValue_standalone_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##,##0.###",
+                    "#,##,##0.00\u00a4",
+                    "#,##,##0%",
+                    "#,##,##0.00\u00a4;(#,##,##0.00\u00a4)",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
