@@ -220,6 +220,7 @@ public class FormatData_chr extends ListResourceBundle {
                     "\u13a0\u13c3 \u13d9\u13bb\u13c2",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -245,6 +246,8 @@ public class FormatData_chr extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -255,6 +258,7 @@ public class FormatData_chr extends ListResourceBundle {
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "\u13cc\u13be\u13b4/\u13d2\u13af\u13f1" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "\u13cd\u13a6\u13da\u13a9 \u13be\u13bf \u13d3\u13b6\u13c2\u13a8\u13cd\u13db \u13c5\u13d9 \u13d7\u13ce\u13cd\u13d7" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
@@ -262,13 +266,6 @@ public class FormatData_chr extends ListResourceBundle {
             { "field.second", "\u13a0\u13ce\u13e2" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "\u00a4#,##0.00",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u13a2\u13cd\u13b3\u13bb\u13a9 \u13c5\u13d9 \u13d7\u13ce\u13cd\u13d7" },
             { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -280,18 +277,18 @@ public class FormatData_chr extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 \u13a2\u13ef\u13a6\u13f4\u13b5",
-                    "00 \u13a2\u13ef\u13a6\u13f4\u13b5",
-                    "000 \u13a2\u13ef\u13a6\u13f4\u13b5",
-                    "0 \u13a2\u13f3\u13c6\u13d7\u13c5\u13db",
-                    "00 \u13a2\u13f3\u13c6\u13d7\u13c5\u13db",
-                    "000 \u13a2\u13f3\u13c6\u13d7\u13c5\u13db",
-                    "0 \u13a2\u13ef\u13d4\u13b3\u13d7\u13c5\u13db",
-                    "00 \u13a2\u13ef\u13d4\u13b3\u13d7\u13c5\u13db",
-                    "000 \u13a2\u13ef\u13d4\u13b3\u13d7\u13c5\u13db",
-                    "0 \u13a2\u13ef\u13e6\u13a0\u13d7\u13c5\u13db",
-                    "00 \u13a2\u13ef\u13e6\u13a0\u13d7\u13c5\u13db",
-                    "000 \u13a2\u13ef\u13e6\u13a0\u13d7\u13c5\u13db",
+                    "{one:0' '\u13a2\u13ef\u13a6\u13f4\u13b5 other:0' '\u13a2\u13ef\u13a6\u13f4\u13b5}",
+                    "{one:00' '\u13a2\u13ef\u13a6\u13f4\u13b5 other:00' '\u13a2\u13ef\u13a6\u13f4\u13b5}",
+                    "{one:000' '\u13a2\u13ef\u13a6\u13f4\u13b5 other:000' '\u13a2\u13ef\u13a6\u13f4\u13b5}",
+                    "{one:0' '\u13a2\u13f3\u13c6\u13d7\u13c5\u13db other:0' '\u13a2\u13f3\u13c6\u13d7\u13c5\u13db}",
+                    "{one:00' '\u13a2\u13f3\u13c6\u13d7\u13c5\u13db other:00' '\u13a2\u13f3\u13c6\u13d7\u13c5\u13db}",
+                    "{one:000' '\u13a2\u13f3\u13c6\u13d7\u13c5\u13db other:000' '\u13a2\u13f3\u13c6\u13d7\u13c5\u13db}",
+                    "{one:0' '\u13a2\u13ef\u13d4\u13b3\u13d7\u13c5\u13db other:0' '\u13a2\u13ef\u13d4\u13b3\u13d7\u13c5\u13db}",
+                    "{one:00' '\u13a2\u13ef\u13d4\u13b3\u13d7\u13c5\u13db other:00' '\u13a2\u13ef\u13d4\u13b3\u13d7\u13c5\u13db}",
+                    "{one:000' '\u13a2\u13ef\u13d4\u13b3\u13d7\u13c5\u13db other:000' '\u13a2\u13ef\u13d4\u13b3\u13d7\u13c5\u13db}",
+                    "{one:0' '\u13a2\u13ef\u13e6\u13a0\u13d7\u13c5\u13db other:0' '\u13a2\u13ef\u13e6\u13a0\u13d7\u13c5\u13db}",
+                    "{one:00' '\u13a2\u13ef\u13e6\u13a0\u13d7\u13c5\u13db other:00' '\u13a2\u13ef\u13e6\u13a0\u13d7\u13c5\u13db}",
+                    "{one:000' '\u13a2\u13ef\u13e6\u13a0\u13d7\u13c5\u13db other:000' '\u13a2\u13ef\u13e6\u13a0\u13d7\u13c5\u13db}",
                 }
             },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -336,18 +333,18 @@ public class FormatData_chr extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0K",
-                    "00K",
-                    "000K",
-                    "0M",
-                    "00M",
-                    "000M",
-                    "0B",
-                    "00B",
-                    "000B",
-                    "0T",
-                    "00T",
-                    "000T",
+                    "{one:0K other:0K}",
+                    "{one:00K other:00K}",
+                    "{one:000K other:000K}",
+                    "{one:0M other:0M}",
+                    "{one:00M other:00M}",
+                    "{one:000M other:000M}",
+                    "{one:0B other:0B}",
+                    "{one:00B other:00B}",
+                    "{one:000B other:000B}",
+                    "{one:0T other:0T}",
+                    "{one:00T other:00T}",
+                    "{one:000T other:000T}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -367,6 +364,14 @@ public class FormatData_chr extends ListResourceBundle {
             { "field.hour", "\u13d1\u13df\u13b6\u13d3" },
             { "calendarname.buddhist", "\u13ca\u13d7\u13cd\u13d8 \u13c5\u13d9 \u13d7\u13ce\u13cd\u13d7" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "\u00a4#,##0.00",
+                    "#,##0%",
+                    "\u00a4#,##0.00;(\u00a4#,##0.00)",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
