@@ -89,7 +89,7 @@ public class FormatData_cy extends ListResourceBundle {
                "Ion",
                "Chwef",
                "Maw",
-               "Ebrill",
+               "Ebr",
                "Mai",
                "Meh",
                "Gorff",
@@ -203,6 +203,8 @@ public class FormatData_cy extends ListResourceBundle {
                     "\u0609",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
@@ -219,9 +221,7 @@ public class FormatData_cy extends ListResourceBundle {
                     "O",
                 }
             },
-            { "abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "timezone.regionFormat.standard", "Amser Safonol {0}" },
-            { "japanese.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "calendarname.japanese", "Calendr Japan" },
             { "japanese.MonthNames", metaValue_MonthNames },
             { "standalone.DayAbbreviations",
@@ -242,6 +242,7 @@ public class FormatData_cy extends ListResourceBundle {
                     "Oed Crist",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -267,6 +268,8 @@ public class FormatData_cy extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -277,6 +280,7 @@ public class FormatData_cy extends ListResourceBundle {
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "AM/PM" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "arab.NumberElements",
                 new String[] {
                     "\u066b",
@@ -290,22 +294,25 @@ public class FormatData_cy extends ListResourceBundle {
                     "\u0609",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "calendarname.roc", "Calendr Gweriniaeth Tseina" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "field.month", "mis" },
+            { "arabext.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "\u00a4\u00a0#,##0.00",
+                    "#,##0%",
+                    "",
+                }
+            },
             { "field.second", "eiliad" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "\u00a4#,##0.00",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "Calendr Islam" },
             { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -333,18 +340,18 @@ public class FormatData_cy extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 mil",
-                    "00 mil",
-                    "000 mil",
-                    "0 miliwn",
-                    "00 miliwn",
-                    "000 miliwn",
-                    "0 biliwn",
-                    "00 biliwn",
-                    "000 biliwn",
-                    "0 triliwn",
-                    "00 triliwn",
-                    "000T",
+                    "{zero:0' 'mil one:0' 'mil two:0K few:0K many:0K other:0' 'mil}",
+                    "{zero:00K one:00' 'mil two:00K few:00K many:00K other:00' 'mil}",
+                    "{zero:000K one:000' 'mil two:000K few:000K many:000K other:000' 'mil}",
+                    "{zero:0M one:0' 'miliwn two:0M few:0M many:0M other:0' 'miliwn}",
+                    "{zero:00M one:00' 'miliwn two:00M few:00M many:00M other:00' 'miliwn}",
+                    "{zero:000M one:000' 'miliwn two:000M few:000M many:000M other:000' 'miliwn}",
+                    "{zero:0B one:0' 'biliwn two:0B few:0B many:0B other:0' 'biliwn}",
+                    "{zero:00B one:00' 'biliwn two:00B few:00B many:00B other:00' 'biliwn}",
+                    "{zero:000B one:000' 'biliwn two:000B few:000B many:000B other:000' 'biliwn}",
+                    "{zero:0T one:0' 'triliwn two:0T few:0T many:0T other:0' 'triliwn}",
+                    "{zero:00T one:00' 'triliwn two:00T few:00T many:00T other:00' 'triliwn}",
+                    "{zero:000T one:000T two:000T few:000T many:000T other:000' 'triliwn}",
                 }
             },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -359,8 +366,15 @@ public class FormatData_cy extends ListResourceBundle {
             { "islamic.DayNarrows", metaValue_DayNarrows },
             { "field.zone", "cylchfa amser" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "arab.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0%",
+                    "",
+                }
+            },
             { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
-            { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "Eras",
                 new String[] {
                     "CC",
@@ -369,7 +383,6 @@ public class FormatData_cy extends ListResourceBundle {
             },
             { "roc.DayNames", metaValue_DayNames },
             { "islamic.QuarterNames", metaValue_QuarterNames },
-            { "islamic.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "field.weekday", "diwrnod o\u2019r wythnos" },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
@@ -394,18 +407,18 @@ public class FormatData_cy extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0K",
-                    "00K",
-                    "000K",
-                    "0M",
-                    "00M",
-                    "000M",
-                    "0B",
-                    "00B",
-                    "000B",
-                    "0T",
-                    "00T",
-                    "000T",
+                    "{zero:0K one:0K two:0K few:0K many:0K other:0K}",
+                    "{zero:00K one:00K two:00K few:00K many:00K other:00K}",
+                    "{zero:000K one:000K two:000K few:000K many:000K other:000K}",
+                    "{zero:0M one:0M two:0M few:0M many:0M other:0M}",
+                    "{zero:00M one:00M two:00M few:00M many:00M other:00M}",
+                    "{zero:000M one:000M two:000M few:000M many:000M other:000M}",
+                    "{zero:0B one:0B two:0B few:0B many:0B other:0B}",
+                    "{zero:00B one:00B two:00B few:00B many:00B other:00B}",
+                    "{zero:000B one:000B two:000B few:000B many:000B other:000B}",
+                    "{zero:0T one:0T two:0T few:0T many:0T other:0T}",
+                    "{zero:00T one:00T two:00T few:00T many:00T other:00T}",
+                    "{zero:000T one:000T two:000T few:000T many:000T other:000T}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -425,12 +438,19 @@ public class FormatData_cy extends ListResourceBundle {
             { "field.hour", "awr" },
             { "calendarname.buddhist", "Calendr y Bwdiaid" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "\u00a4#,##0.00",
+                    "#,##0%",
+                    "\u00a4#,##0.00;(\u00a4#,##0.00)",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
             { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
         return data;
