@@ -174,6 +174,14 @@ public class FormatData_da extends ListResourceBundle {
                "3",
                "4",
             };
+        final String[] metaValue_buddhist_AmPmMarkers = new String[] {
+               "AM",
+               "PM",
+            };
+        final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
+               "BC",
+               "BE",
+            };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
                "EEEE d. MMMM y G",
                "d. MMMM y G",
@@ -186,19 +194,21 @@ public class FormatData_da extends ListResourceBundle {
                "d. MMM y GGGG",
                "d/M/y",
             };
-        final String[] metaValue_roc_AmPmMarkers = new String[] {
-               "AM",
-               "PM",
-            };
         final String[] metaValue_java_time_roc_long_Eras = new String[] {
                "f\u00f8r R.O.C.",
                "Minguo",
             };
+        final String[] metaValue_java_time_islamic_long_Eras = new String[] {
+               "",
+               "AH",
+            };
         final String metaValue_calendarname_gregorian = "gregoriansk kalender";
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
             { "field.year", "\u00e5r" },
             { "calendarname.islamic-umalqura", "islamisk kalender (Umm al-Qura)" },
+            { "japanese.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
+            { "buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.QuarterNames", metaValue_QuarterNames },
@@ -227,7 +237,9 @@ public class FormatData_da extends ListResourceBundle {
                 }
             },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "java.time.islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "long.Eras", metaValue_long_Eras },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -253,6 +265,8 @@ public class FormatData_da extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -260,6 +274,7 @@ public class FormatData_da extends ListResourceBundle {
             { "buddhist.DayNames", metaValue_DayNames },
             { "field.minute", "minut" },
             { "field.era", "\u00e6ra" },
+            { "buddhist.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "field.dayperiod", "AM/PM" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
             { "islamic.MonthNames",
@@ -279,21 +294,16 @@ public class FormatData_da extends ListResourceBundle {
                     "",
                 }
             },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "kalender for Republikken Kina" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "field.month", "m\u00e5ned" },
             { "roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.second", "sekund" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0\u00a0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "islamisk kalender" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
@@ -306,18 +316,18 @@ public class FormatData_da extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 tusind",
-                    "00 tusind",
-                    "000 tusind",
-                    "0 million",
-                    "00 millioner",
-                    "000 millioner",
-                    "0 milliard",
-                    "00 milliarder",
-                    "000 milliarder",
-                    "0 billion",
-                    "00 billioner",
-                    "000 billioner",
+                    "{one:0' 'tusind other:0' 'tusind}",
+                    "{one:00' 'tusind other:00' 'tusind}",
+                    "{one:000' 'tusind other:000' 'tusind}",
+                    "{one:0' 'million other:0' 'millioner}",
+                    "{one:00' 'millioner other:00' 'millioner}",
+                    "{one:000' 'millioner other:000' 'millioner}",
+                    "{one:0' 'milliard other:0' 'milliarder}",
+                    "{one:00' 'milliarder other:00' 'milliarder}",
+                    "{one:000' 'milliarder other:000' 'milliarder}",
+                    "{one:0' 'billion other:0' 'billioner}",
+                    "{one:00' 'billioner other:00' 'billioner}",
+                    "{one:000' 'billioner other:000' 'billioner}",
                 }
             },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -327,7 +337,9 @@ public class FormatData_da extends ListResourceBundle {
             { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.DayNarrows", metaValue_DayNarrows },
-            { "islamic.AmPmMarkers", metaValue_roc_AmPmMarkers },
+            { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
+            { "islamic.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
+            { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
             { "java.time.roc.Eras", metaValue_java_time_roc_long_Eras },
@@ -342,20 +354,24 @@ public class FormatData_da extends ListResourceBundle {
             { "field.weekday", "ugedag" },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
+            { "islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
+            { "java.time.islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.QuarterNames", metaValue_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "java.time.buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "timezone.hourFormat", "+HH.mm;-HH.mm" },
             { "japanese.DayNames", metaValue_DayNames },
             { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNames", metaValue_DayNames },
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.MonthNames", metaValue_MonthNames },
+            { "buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "field.week", "uge" },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
             { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "roc.DayNarrows", metaValue_DayNarrows },
-            { "roc.AmPmMarkers", metaValue_roc_AmPmMarkers },
+            { "roc.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "short.CompactNumberPatterns",
@@ -363,21 +379,22 @@ public class FormatData_da extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0t",
-                    "00\u00a0t",
-                    "000\u00a0t",
-                    "0\u00a0mio'.'",
-                    "00\u00a0mio'.'",
-                    "000\u00a0mio'.'",
-                    "0\u00a0mia'.'",
-                    "00\u00a0mia'.'",
-                    "000\u00a0mia'.'",
-                    "0\u00a0bio'.'",
-                    "00\u00a0bio'.'",
-                    "000\u00a0bio'.'",
+                    "{one:0\u00a0t other:0\u00a0t}",
+                    "{one:00\u00a0t other:00\u00a0t}",
+                    "{one:000\u00a0t other:000\u00a0t}",
+                    "{one:0\u00a0mio'.' other:0\u00a0mio'.'}",
+                    "{one:00\u00a0mio'.' other:00\u00a0mio'.'}",
+                    "{one:000\u00a0mio'.' other:000\u00a0mio'.'}",
+                    "{one:0\u00a0mia'.' other:0\u00a0mia'.'}",
+                    "{one:00\u00a0mia'.' other:00\u00a0mia'.'}",
+                    "{one:000\u00a0mia'.' other:000\u00a0mia'.'}",
+                    "{one:0\u00a0bio'.' other:0\u00a0bio'.'}",
+                    "{one:00\u00a0bio'.' other:00\u00a0bio'.'}",
+                    "{one:000\u00a0bio'.' other:000\u00a0bio'.'}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
+            { "java.time.buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "DatePatterns",
                 new String[] {
                     "EEEE 'den' d. MMMM y",
@@ -391,9 +408,19 @@ public class FormatData_da extends ListResourceBundle {
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.DayNames", metaValue_DayNames },
             { "field.hour", "time" },
+            { "islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "calendarname.buddhist", "buddhistisk kalender" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0\u00a0%",
+                    "#,##0.00\u00a0\u00a4",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
+            { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
