@@ -164,6 +164,10 @@ public class FormatData_dz extends ListResourceBundle {
                "\u0f66\u0f94\u0f0b\u0f46\u0f0b",
                "\u0f55\u0fb1\u0f72\u0f0b\u0f46\u0f0b",
             };
+        final String[] metaValue_long_Eras = new String[] {
+               "BCE",
+               "CE",
+            };
         final String[] metaValue_TimePatterns = new String[] {
                "\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51\u0f0b h \u0f66\u0f90\u0f62\u0f0b\u0f58\u0f0b mm:ss a zzzz",
                "\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51\u0f0b h \u0f66\u0f90\u0f62\u0f0b\u0f58\u0f0b mm:ss a z",
@@ -195,6 +199,7 @@ public class FormatData_dz extends ListResourceBundle {
             { "roc.MonthNarrows", metaValue_MonthNarrows },
             { "islamic.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
+            { "narrow.Eras", metaValue_long_Eras },
             { "abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "DefaultNumberingSystem", "tibt" },
             { "japanese.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
@@ -202,6 +207,7 @@ public class FormatData_dz extends ListResourceBundle {
             { "japanese.MonthNames", metaValue_MonthNames },
             { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "long.Eras", metaValue_long_Eras },
             { "roc.QuarterNarrows", metaValue_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
@@ -228,6 +234,8 @@ public class FormatData_dz extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -261,13 +269,6 @@ public class FormatData_dz extends ListResourceBundle {
             { "field.second", "\u0f66\u0f90\u0f62\u0f0b\u0f46\u0f71\u0f0b" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##,##0.###",
-                    "\u00a4#,##,##0.00",
-                    "#,##,##0\u00a0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "japanese.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
@@ -294,24 +295,32 @@ public class FormatData_dz extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "\u0f66\u0f9f\u0f7c\u0f44\u0f0b\u0f55\u0fb2\u0f42 0",
-                    "\u0f41\u0fb2\u0f72\u0f0b\u0f55\u0fb2\u0f42 0",
-                    "\u0f60\u0f56\u0f74\u0f58\u0f0b\u0f55\u0fb2\u0f42 0",
-                    "\u0f66\u0f0b\u0f61\u0f0b 0",
-                    "\u0f56\u0fb1\u0f7a\u0f0b\u0f56\u0f0b 0",
-                    "\u0f51\u0f74\u0f44\u0f0b\u0f55\u0fb1\u0f74\u0f62\u0f0b 0",
-                    "\u0f51\u0f74\u0f44\u0f0b\u0f55\u0fb1\u0f74\u0f62\u0f0b 00",
-                    "\u0f51\u0f74\u0f44\u0f0b\u0f55\u0fb1\u0f74\u0f62\u0f0b\u0f56\u0f62\u0f92\u0fb1\u0f0b 0",
-                    "\u0f51\u0f74\u0f44\u0f0b\u0f55\u0fb1\u0f74\u0f62\u0f0b\u0f66\u0f9f\u0f7c\u0f44 0",
-                    "\u0f51\u0f74\u0f44\u0f0b\u0f55\u0fb1\u0f74\u0f62\u0f0b\u0f41\u0fb2\u0f72\u0f0b 0",
-                    "\u0f51\u0f74\u0f44\u0f0b\u0f55\u0fb1\u0f74\u0f62\u0f0b\u0f60\u0f56\u0f74\u0f58\u0f0b 0",
-                    "\u0f51\u0f74\u0f44\u0f0b\u0f55\u0fb1\u0f74\u0f62\u0f0b\u0f66\u0f0b\u0f61\u0f0b 0",
+                    "{other:\u0f66\u0f9f\u0f7c\u0f44\u0f0b\u0f55\u0fb2\u0f42' '0}",
+                    "{other:\u0f41\u0fb2\u0f72\u0f0b\u0f55\u0fb2\u0f42' '0}",
+                    "{other:\u0f60\u0f56\u0f74\u0f58\u0f0b\u0f55\u0fb2\u0f42' '0}",
+                    "{other:\u0f66\u0f0b\u0f61\u0f0b' '0}",
+                    "{other:\u0f56\u0fb1\u0f7a\u0f0b\u0f56\u0f0b' '0}",
+                    "{other:\u0f51\u0f74\u0f44\u0f0b\u0f55\u0fb1\u0f74\u0f62\u0f0b' '0}",
+                    "{other:\u0f51\u0f74\u0f44\u0f0b\u0f55\u0fb1\u0f74\u0f62\u0f0b' '00}",
+                    "{other:\u0f51\u0f74\u0f44\u0f0b\u0f55\u0fb1\u0f74\u0f62\u0f0b\u0f56\u0f62\u0f92\u0fb1\u0f0b' '0}",
+                    "{other:\u0f51\u0f74\u0f44\u0f0b\u0f55\u0fb1\u0f74\u0f62\u0f0b\u0f66\u0f9f\u0f7c\u0f44' '0}",
+                    "{other:\u0f51\u0f74\u0f44\u0f0b\u0f55\u0fb1\u0f74\u0f62\u0f0b\u0f41\u0fb2\u0f72\u0f0b' '0}",
+                    "{other:\u0f51\u0f74\u0f44\u0f0b\u0f55\u0fb1\u0f74\u0f62\u0f0b\u0f60\u0f56\u0f74\u0f58\u0f0b' '0}",
+                    "{other:\u0f51\u0f74\u0f44\u0f0b\u0f55\u0fb1\u0f74\u0f62\u0f0b\u0f66\u0f0b\u0f61\u0f0b' '0}",
                 }
             },
             { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "standalone.QuarterNames", metaValue_QuarterNames },
             { "japanese.MonthNarrows", metaValue_MonthNarrows },
+            { "tibt.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "\u00a4\u00a0#,##0.00",
+                    "#,##0%",
+                    "",
+                }
+            },
             { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.DayNarrows", metaValue_DayNarrows },
@@ -346,6 +355,8 @@ public class FormatData_dz extends ListResourceBundle {
                     "\u2030",
                     "\u0f42\u0fb2\u0f44\u0f66\u0f0b\u0f58\u0f7a\u0f51",
                     "\u0f68\u0f44\u0f0b\u0f58\u0f51",
+                    "",
+                    "",
                 }
             },
             { "japanese.DayNames", metaValue_DayNames },
@@ -392,6 +403,14 @@ public class FormatData_dz extends ListResourceBundle {
                     "",
                 }
             },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##,##0.###",
+                    "\u00a4#,##,##0.00",
+                    "#,##,##0\u00a0%",
+                    "",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
