@@ -174,6 +174,10 @@ public class FormatData_es extends ListResourceBundle {
                "3",
                "4",
             };
+        final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
+               "BC",
+               "BE",
+            };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
                "EEEE, d 'de' MMMM 'de' y G",
                "d 'de' MMMM 'de' y G",
@@ -190,12 +194,17 @@ public class FormatData_es extends ListResourceBundle {
                "antes de RDC",
                "minguo",
             };
+        final String[] metaValue_java_time_islamic_long_Eras = new String[] {
+               "",
+               "AH",
+            };
         final String metaValue_calendarname_gregorian = "calendario gregoriano";
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
             { "field.year", "a\u00f1o" },
             { "calendarname.islamic-umalqura", "calendario isl\u00e1mico umalqura" },
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
+            { "buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.japanese.DatePatterns",
                 new String[] {
@@ -220,12 +229,14 @@ public class FormatData_es extends ListResourceBundle {
             { "japanese.MonthNames", metaValue_MonthNames },
             { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "java.time.islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "long.Eras",
                 new String[] {
                     "antes de Cristo",
                     "despu\u00e9s de Cristo",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -251,6 +262,8 @@ public class FormatData_es extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -285,21 +298,16 @@ public class FormatData_es extends ListResourceBundle {
                     "",
                 }
             },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "calendario de la Rep\u00fablica de China" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "field.month", "mes" },
             { "roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.second", "segundo" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0\u00a0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "calendario isl\u00e1mico" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
@@ -313,18 +321,18 @@ public class FormatData_es extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 mil",
-                    "00 mil",
-                    "000 mil",
-                    "0 mill\u00f3n",
-                    "00 millones",
-                    "000 millones",
-                    "0 mil millones",
-                    "00 mil millones",
-                    "000 mil millones",
-                    "0 bill\u00f3n",
-                    "00 billones",
-                    "000 billones",
+                    "{one:0' 'mil other:0' 'mil}",
+                    "{one:00' 'mil other:00' 'mil}",
+                    "{one:000' 'mil other:000' 'mil}",
+                    "{one:0' 'mill\u00f3n other:0' 'millones}",
+                    "{one:00' 'millones other:00' 'millones}",
+                    "{one:000' 'millones other:000' 'millones}",
+                    "{one:0' 'mil' 'millones other:0' 'mil' 'millones}",
+                    "{one:00' 'mil' 'millones other:00' 'mil' 'millones}",
+                    "{one:000' 'mil' 'millones other:000' 'mil' 'millones}",
+                    "{one:0' 'bill\u00f3n other:0' 'billones}",
+                    "{one:00' 'billones other:00' 'billones}",
+                    "{one:000' 'billones other:000' 'billones}",
                 }
             },
             { "roc.narrow.AmPmMarkers", metaValue_AmPmMarkers },
@@ -334,7 +342,9 @@ public class FormatData_es extends ListResourceBundle {
             { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.DayNarrows", metaValue_DayNarrows },
+            { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
+            { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
             { "java.time.roc.Eras", metaValue_java_time_roc_long_Eras },
@@ -351,13 +361,17 @@ public class FormatData_es extends ListResourceBundle {
             { "field.weekday", "d\u00eda de la semana" },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
+            { "islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
+            { "java.time.islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.QuarterNames", metaValue_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "java.time.buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "japanese.DayNames", metaValue_DayNames },
             { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNames", metaValue_DayNames },
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.MonthNames", metaValue_MonthNames },
+            { "buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "field.week", "semana" },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
@@ -371,21 +385,22 @@ public class FormatData_es extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0mil",
-                    "00\u00a0mil",
-                    "000\u00a0mil",
-                    "0\u00a0M",
-                    "00\u00a0M",
-                    "000\u00a0M",
-                    "0000\u00a0M",
-                    "00\u00a0mil\u00a0M",
-                    "000\u00a0mil\u00a0M",
-                    "0\u00a0B",
-                    "00\u00a0B",
-                    "000\u00a0B",
+                    "{one:0\u00a0mil other:0\u00a0mil}",
+                    "{one:00\u00a0mil other:00\u00a0mil}",
+                    "{one:000\u00a0mil other:000\u00a0mil}",
+                    "{one:0\u00a0M other:0\u00a0M}",
+                    "{one:00\u00a0M other:00\u00a0M}",
+                    "{one:000\u00a0M other:000\u00a0M}",
+                    "{one:0000\u00a0M other:0000\u00a0M}",
+                    "{one:00\u00a0mil\u00a0M other:00\u00a0mil\u00a0M}",
+                    "{one:000\u00a0mil\u00a0M other:000\u00a0mil\u00a0M}",
+                    "{one:0\u00a0B other:0\u00a0B}",
+                    "{one:00\u00a0B other:00\u00a0B}",
+                    "{one:000\u00a0B other:000\u00a0B}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
+            { "java.time.buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "timezone.regionFormat.daylight", "horario de verano de {0}" },
             { "DatePatterns",
                 new String[] {
@@ -417,9 +432,19 @@ public class FormatData_es extends ListResourceBundle {
                     "",
                 }
             },
+            { "islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "calendarname.buddhist", "calendario budista" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0\u00a0%",
+                    "#,##0.00\u00a0\u00a4",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
+            { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
