@@ -71,18 +71,18 @@ public class FormatData_eu extends ListResourceBundle {
     @Override
     protected final Object[][] getContents() {
         final String[] metaValue_MonthNames = new String[] {
-               "urtarrila",
-               "otsaila",
-               "martxoa",
-               "apirila",
-               "maiatza",
-               "ekaina",
-               "uztaila",
-               "abuztua",
-               "iraila",
-               "urria",
-               "azaroa",
-               "abendua",
+               "urtarrilak",
+               "otsailak",
+               "martxoak",
+               "apirilak",
+               "maiatzak",
+               "ekainak",
+               "uztailak",
+               "abuztuak",
+               "irailak",
+               "urriak",
+               "azaroak",
+               "abenduak",
                "",
             };
         final String[] metaValue_MonthAbbreviations = new String[] {
@@ -174,6 +174,10 @@ public class FormatData_eu extends ListResourceBundle {
                "3",
                "4",
             };
+        final String[] metaValue_buddhist_AmPmMarkers = new String[] {
+               "AM",
+               "PM",
+            };
         final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
                "BC",
                "BG",
@@ -190,10 +194,6 @@ public class FormatData_eu extends ListResourceBundle {
                "GGGG. 'aroko' y('e')'ko' MMM d",
                "G y-MM-dd",
             };
-        final String[] metaValue_roc_AmPmMarkers = new String[] {
-               "AM",
-               "PM",
-            };
         final String[] metaValue_java_time_roc_long_Eras = new String[] {
                "R.O.C. aurretik",
                "R.O.C.",
@@ -202,6 +202,7 @@ public class FormatData_eu extends ListResourceBundle {
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
             { "field.year", "urtea" },
+            { "japanese.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -223,6 +224,7 @@ public class FormatData_eu extends ListResourceBundle {
                     "Kristo ondoren",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -248,6 +250,8 @@ public class FormatData_eu extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -255,8 +259,10 @@ public class FormatData_eu extends ListResourceBundle {
             { "buddhist.DayNames", metaValue_DayNames },
             { "field.minute", "minutua" },
             { "field.era", "aroa" },
+            { "buddhist.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "field.dayperiod", "AM/PM" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "Minguo egutegia" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -265,13 +271,6 @@ public class FormatData_eu extends ListResourceBundle {
             { "field.second", "segundoa" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "%\u00a0#,##0",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "Islamiar egutegia" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
@@ -285,18 +284,18 @@ public class FormatData_eu extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0000",
-                    "00000",
-                    "000000",
-                    "0 milioi",
-                    "00 milioi",
-                    "000 milioi",
-                    "0000 milioi",
-                    "00000 milioi",
-                    "000000 milioi",
-                    "0 bilioi",
-                    "00 bilioi",
-                    "000 bilioi",
+                    "{one:0000 other:0000}",
+                    "{one:00000 other:00000}",
+                    "{one:000000 other:000000}",
+                    "{one:0' 'milioi other:0' 'milioi}",
+                    "{one:00' 'milioi other:00' 'milioi}",
+                    "{one:000' 'milioi other:000' 'milioi}",
+                    "{one:0000' 'milioi other:0000' 'milioi}",
+                    "{one:00000' 'milioi other:00000' 'milioi}",
+                    "{one:000000' 'milioi other:000000' 'milioi}",
+                    "{one:0' 'bilioi other:0' 'bilioi}",
+                    "{one:00' 'bilioi other:00' 'bilioi}",
+                    "{one:000' 'bilioi other:000' 'bilioi}",
                 }
             },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -307,8 +306,8 @@ public class FormatData_eu extends ListResourceBundle {
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.DayNarrows", metaValue_DayNarrows },
             { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
+            { "islamic.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
-            { "islamic.AmPmMarkers", metaValue_roc_AmPmMarkers },
             { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
             { "java.time.roc.Eras", metaValue_java_time_roc_long_Eras },
@@ -337,7 +336,7 @@ public class FormatData_eu extends ListResourceBundle {
             { "buddhist.QuarterNames", metaValue_QuarterNames },
             { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "roc.DayNarrows", metaValue_DayNarrows },
-            { "roc.AmPmMarkers", metaValue_roc_AmPmMarkers },
+            { "roc.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "short.CompactNumberPatterns",
@@ -345,18 +344,18 @@ public class FormatData_eu extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0000",
-                    "00000",
-                    "000000",
-                    "0\u00a0M",
-                    "00\u00a0M",
-                    "000\u00a0M",
-                    "0000\u00a0M",
-                    "00000\u00a0M",
-                    "000000\u00a0M",
-                    "0\u00a0B",
-                    "00\u00a0B",
-                    "000\u00a0B",
+                    "{one:0000 other:0000}",
+                    "{one:00000 other:00000}",
+                    "{one:000000 other:000000}",
+                    "{one:0\u00a0M other:0\u00a0M}",
+                    "{one:00\u00a0M other:00\u00a0M}",
+                    "{one:000\u00a0M other:000\u00a0M}",
+                    "{one:0000\u00a0M other:0000\u00a0M}",
+                    "{one:00000\u00a0M other:00000\u00a0M}",
+                    "{one:000000\u00a0M other:000000\u00a0M}",
+                    "{one:0\u00a0B other:0\u00a0B}",
+                    "{one:00\u00a0B other:00\u00a0B}",
+                    "{one:000\u00a0B other:000\u00a0B}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -376,7 +375,31 @@ public class FormatData_eu extends ListResourceBundle {
             { "standalone.DayNames", metaValue_DayNames },
             { "field.hour", "ordua" },
             { "calendarname.buddhist", "Egutegi budista" },
-            { "standalone.MonthNames", metaValue_MonthNames },
+            { "standalone.MonthNames",
+                new String[] {
+                    "urtarrila",
+                    "otsaila",
+                    "martxoa",
+                    "apirila",
+                    "maiatza",
+                    "ekaina",
+                    "uztaila",
+                    "abuztua",
+                    "iraila",
+                    "urria",
+                    "azaroa",
+                    "abendua",
+                    "",
+                }
+            },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "%\u00a0#,##0",
+                    "#,##0.00\u00a0\u00a4;(#,##0.00\u00a0\u00a4)",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
