@@ -166,6 +166,10 @@ public class FormatData_fy extends ListResourceBundle {
                "3",
                "4",
             };
+        final String[] metaValue_buddhist_AmPmMarkers = new String[] {
+               "AM",
+               "PM",
+            };
         final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
                "BC",
                "BE",
@@ -182,10 +186,6 @@ public class FormatData_fy extends ListResourceBundle {
                "d MMM y GGGG",
                "dd-MM-yy G",
             };
-        final String[] metaValue_japanese_narrow_AmPmMarkers = new String[] {
-               "AM",
-               "PM",
-            };
         final String[] metaValue_java_time_roc_long_Eras = new String[] {
                "Before R.O.C.",
                "Minguo",
@@ -198,13 +198,14 @@ public class FormatData_fy extends ListResourceBundle {
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
             { "field.year", "Jier" },
+            { "japanese.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.QuarterNames", metaValue_QuarterNames },
             { "roc.MonthNarrows", metaValue_MonthNarrows },
             { "calendarname.islamic-civil", "Islamityske kalinder (cyclysk)" },
-            { "islamic.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "islamic.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
             { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "narrow.Eras",
@@ -225,6 +226,7 @@ public class FormatData_fy extends ListResourceBundle {
                     "nei Kristus",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -249,6 +251,8 @@ public class FormatData_fy extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -256,6 +260,7 @@ public class FormatData_fy extends ListResourceBundle {
             { "buddhist.DayNames", metaValue_DayNames },
             { "field.minute", "Min\u00fat" },
             { "field.era", "Tiidsrin" },
+            { "buddhist.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "field.dayperiod", "AM/PM" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
             { "islamic.MonthNames",
@@ -275,6 +280,7 @@ public class FormatData_fy extends ListResourceBundle {
                     "",
                 }
             },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "Kalinder fan de Sineeske Republyk" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -283,18 +289,11 @@ public class FormatData_fy extends ListResourceBundle {
             { "roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.second", "Sekonde" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "\u00a4\u00a0#,##0.00;\u00a4\u00a0#,##0.00-",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "Islamityske kalinder" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "java.time.roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
-            { "japanese.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "japanese.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "timezone.regionFormat", "{0}-tiid" },
@@ -303,34 +302,35 @@ public class FormatData_fy extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 t\u00fbzen",
-                    "00 t\u00fbzen",
-                    "000 t\u00fbzen",
-                    "0 miljoen",
-                    "00 miljoen",
-                    "000 miljoen",
-                    "0 miljard",
-                    "00 miljard",
-                    "000 miljard",
-                    "0 biljoen",
-                    "00 biljoen",
-                    "000 biljoen",
+                    "{one:0' 't\u00fbzen other:0' 't\u00fbzen}",
+                    "{one:00' 't\u00fbzen other:00' 't\u00fbzen}",
+                    "{one:000' 't\u00fbzen other:000' 't\u00fbzen}",
+                    "{one:0' 'miljoen other:0' 'miljoen}",
+                    "{one:00' 'miljoen other:00' 'miljoen}",
+                    "{one:000' 'miljoen other:000' 'miljoen}",
+                    "{one:0' 'miljard other:0' 'miljard}",
+                    "{one:00' 'miljard other:00' 'miljard}",
+                    "{one:000' 'miljard other:000' 'miljard}",
+                    "{one:0' 'biljoen other:0' 'biljoen}",
+                    "{one:00' 'biljoen other:00' 'biljoen}",
+                    "{one:000' 'biljoen other:000' 'biljoen}",
                 }
             },
             { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
-            { "roc.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "roc.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "standalone.QuarterNames", metaValue_QuarterNames },
             { "japanese.MonthNarrows", metaValue_MonthNarrows },
             { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
+            { "islamic.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
-            { "islamic.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
             { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_buddhist_DayNarrows },
             { "java.time.roc.Eras", metaValue_java_time_roc_long_Eras },
             { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
+            { "buddhist.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "Eras",
                 new String[] {
                     "f.Kr.",
@@ -358,7 +358,8 @@ public class FormatData_fy extends ListResourceBundle {
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
             { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
-            { "roc.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "roc.DayNarrows", metaValue_buddhist_DayNarrows },
+            { "roc.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "short.CompactNumberPatterns",
@@ -366,18 +367,18 @@ public class FormatData_fy extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0K",
-                    "00K",
-                    "000K",
-                    "0\u00a0mln'.'",
-                    "00\u00a0mln'.'",
-                    "000\u00a0mln'.'",
-                    "0\u00a0mld'.'",
-                    "00\u00a0mld'.'",
-                    "000\u00a0mld'.'",
-                    "0\u00a0bln'.'",
-                    "00\u00a0bln'.'",
-                    "000\u00a0bln'.'",
+                    "{one:0K other:0K}",
+                    "{one:00K other:00K}",
+                    "{one:000K other:000K}",
+                    "{one:0\u00a0mln'.' other:0\u00a0mln'.'}",
+                    "{one:00\u00a0mln'.' other:00\u00a0mln'.'}",
+                    "{one:000\u00a0mln'.' other:000\u00a0mln'.'}",
+                    "{one:0\u00a0mld'.' other:0\u00a0mld'.'}",
+                    "{one:00\u00a0mld'.' other:00\u00a0mld'.'}",
+                    "{one:000\u00a0mld'.' other:000\u00a0mld'.'}",
+                    "{one:0\u00a0bln'.' other:0\u00a0bln'.'}",
+                    "{one:00\u00a0bln'.' other:00\u00a0bln'.'}",
+                    "{one:000\u00a0bln'.' other:000\u00a0bln'.'}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -424,6 +425,14 @@ public class FormatData_fy extends ListResourceBundle {
             { "islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "calendarname.buddhist", "Boeddhistyske kalinder" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "\u00a4\u00a0#,##0.00;\u00a4\u00a0#,##0.00-",
+                    "#,##0%",
+                    "\u00a4\u00a0#,##0.00;(\u00a4\u00a0#,##0.00)",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_buddhist_DayNarrows },
             { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "QuarterNames", metaValue_QuarterNames },
