@@ -175,7 +175,7 @@ public class FormatData_gl extends ListResourceBundle {
                "4",
             };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
-               "cccc, d 'de' MMMM 'de' Y G",
+               "EEEE, d 'de' MMMM 'de' Y G",
                "d 'de' MMMM 'de' y G",
                "d 'de' MMM 'de' y G",
                "dd/MM/y GGGGG",
@@ -223,6 +223,7 @@ public class FormatData_gl extends ListResourceBundle {
                     "despois de Cristo",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -248,6 +249,8 @@ public class FormatData_gl extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -274,6 +277,7 @@ public class FormatData_gl extends ListResourceBundle {
                     "",
                 }
             },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "calendario Minguo" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -281,13 +285,6 @@ public class FormatData_gl extends ListResourceBundle {
             { "field.second", "segundo" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0\u00a0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "calendario isl\u00e1mico" },
             { "japanese.narrow.AmPmMarkers", metaValue_AmPmMarkers },
@@ -315,18 +312,18 @@ public class FormatData_gl extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0",
-                    "0",
-                    "0",
-                    "0 mill\u00f3n",
-                    "00 mill\u00f3ns",
-                    "000 mill\u00f3ns",
-                    "0",
-                    "0",
-                    "0",
-                    "0 bill\u00f3n",
-                    "00 bill\u00f3ns",
-                    "000 bill\u00f3ns",
+                    "{one:0 other:0}",
+                    "{one:0 other:0}",
+                    "{one:0 other:0}",
+                    "{one:0' 'mill\u00f3n other:0' 'mill\u00f3ns}",
+                    "{one:00' 'mill\u00f3ns other:00' 'mill\u00f3ns}",
+                    "{one:000' 'mill\u00f3ns other:000' 'mill\u00f3ns}",
+                    "{one:0 other:0}",
+                    "{one:0 other:0}",
+                    "{one:0 other:0}",
+                    "{one:0' 'bill\u00f3n other:0' 'bill\u00f3ns}",
+                    "{one:00' 'bill\u00f3ns other:00' 'bill\u00f3ns}",
+                    "{one:000' 'bill\u00f3ns other:000' 'bill\u00f3ns}",
                 }
             },
             { "roc.narrow.AmPmMarkers", metaValue_AmPmMarkers },
@@ -381,18 +378,18 @@ public class FormatData_gl extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0",
-                    "0",
-                    "0",
-                    "0\u00a0M",
-                    "00\u00a0M",
-                    "000\u00a0M",
-                    "0",
-                    "0",
-                    "0",
-                    "0\u00a0B",
-                    "00\u00a0B",
-                    "000\u00a0B",
+                    "{one:0 other:0}",
+                    "{one:0 other:0}",
+                    "{one:0 other:0}",
+                    "{one:0\u00a0M other:0\u00a0M}",
+                    "{one:00\u00a0M other:00\u00a0M}",
+                    "{one:000\u00a0M other:000\u00a0M}",
+                    "{one:0 other:0}",
+                    "{one:0 other:0}",
+                    "{one:0 other:0}",
+                    "{one:0\u00a0B other:0\u00a0B}",
+                    "{one:00\u00a0B other:00\u00a0B}",
+                    "{one:000\u00a0B other:000\u00a0B}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -438,6 +435,14 @@ public class FormatData_gl extends ListResourceBundle {
                     "",
                 }
             },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0\u00a0%",
+                    "#,##0.00\u00a0\u00a4",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
