@@ -230,6 +230,7 @@ public class FormatData_hi extends ListResourceBundle {
                     "\u0908\u0938\u0935\u0940 \u0938\u0928",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -255,6 +256,8 @@ public class FormatData_hi extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -283,6 +286,7 @@ public class FormatData_hi extends ListResourceBundle {
                     "",
                 }
             },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "\u091a\u0940\u0928\u0940 \u0917\u0923\u0924\u0902\u0924\u094d\u0930 \u092a\u0902\u091a\u093e\u0902\u0917" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "deva.NumberElements",
@@ -298,6 +302,8 @@ public class FormatData_hi extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -306,13 +312,6 @@ public class FormatData_hi extends ListResourceBundle {
             { "field.second", "\u0938\u0947\u0915\u0902\u0921" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##,##0.###",
-                    "\u00a4#,##,##0.00",
-                    "#,##,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u0907\u0938\u094d\u0932\u093e\u092e\u0940 \u092a\u0902\u091a\u093e\u0902\u0917" },
             { "japanese.narrow.AmPmMarkers", metaValue_AmPmMarkers },
@@ -324,18 +323,18 @@ public class FormatData_hi extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 \u0939\u091c\u093c\u093e\u0930",
-                    "00 \u0939\u091c\u093c\u093e\u0930",
-                    "0 \u0932\u093e\u0916",
-                    "00 \u0932\u093e\u0916",
-                    "0 \u0915\u0930\u094b\u0921\u093c",
-                    "00 \u0915\u0930\u094b\u0921\u093c",
-                    "0 \u0905\u0930\u092c",
-                    "00 \u0905\u0930\u092c",
-                    "0 \u0916\u0930\u092c",
-                    "00 \u0916\u0930\u092c",
-                    "000 \u0916\u0930\u092c",
-                    "0000 \u0916\u0930\u092c",
+                    "{one:0' '\u0939\u091c\u093c\u093e\u0930 other:0' '\u0939\u091c\u093c\u093e\u0930}",
+                    "{one:00' '\u0939\u091c\u093c\u093e\u0930 other:00' '\u0939\u091c\u093c\u093e\u0930}",
+                    "{one:0' '\u0932\u093e\u0916 other:0' '\u0932\u093e\u0916}",
+                    "{one:00' '\u0932\u093e\u0916 other:00' '\u0932\u093e\u0916}",
+                    "{one:0' '\u0915\u0930\u094b\u0921\u093c other:0' '\u0915\u0930\u094b\u0921\u093c}",
+                    "{one:00' '\u0915\u0930\u094b\u0921\u093c other:00' '\u0915\u0930\u094b\u0921\u093c}",
+                    "{one:0' '\u0905\u0930\u092c other:0' '\u0905\u0930\u092c}",
+                    "{one:00' '\u0905\u0930\u092c other:00' '\u0905\u0930\u092c}",
+                    "{one:0' '\u0916\u0930\u092c other:0' '\u0916\u0930\u092c}",
+                    "{one:00' '\u0916\u0930\u092c other:00' '\u0916\u0930\u092c}",
+                    "{one:000' '\u0916\u0930\u092c other:000' '\u0916\u0930\u092c}",
+                    "{one:0000' '\u0916\u0930\u092c other:0000' '\u0916\u0930\u092c}",
                 }
             },
             { "roc.narrow.AmPmMarkers", metaValue_AmPmMarkers },
@@ -381,18 +380,18 @@ public class FormatData_hi extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0\u0939\u091c\u093c\u093e\u0930",
-                    "00\u00a0\u0939\u091c\u093c\u093e\u0930",
-                    "0\u00a0\u0932\u093e\u0916",
-                    "00\u00a0\u0932\u093e\u0916",
-                    "0\u00a0\u0915\u0970",
-                    "00\u00a0\u0915\u0970",
-                    "0\u00a0\u0905\u0970",
-                    "00\u00a0\u0905\u0970",
-                    "0\u00a0\u0916\u0970",
-                    "00\u00a0\u0916\u0970",
-                    "0\u00a0\u0928\u0940\u0932",
-                    "00\u00a0\u0928\u0940\u0932",
+                    "{one:0\u00a0\u0939\u091c\u093c\u093e\u0930 other:0\u00a0\u0939\u091c\u093c\u093e\u0930}",
+                    "{one:00\u00a0\u0939\u091c\u093c\u093e\u0930 other:00\u00a0\u0939\u091c\u093c\u093e\u0930}",
+                    "{one:0\u00a0\u0932\u093e\u0916 other:0\u00a0\u0932\u093e\u0916}",
+                    "{one:00\u00a0\u0932\u093e\u0916 other:00\u00a0\u0932\u093e\u0916}",
+                    "{one:0\u00a0\u0915\u0970 other:0\u00a0\u0915\u0970}",
+                    "{one:00\u00a0\u0915\u0970 other:00\u00a0\u0915\u0970}",
+                    "{one:0\u00a0\u0905\u0970 other:0\u00a0\u0905\u0970}",
+                    "{one:00\u00a0\u0905\u0970 other:00\u00a0\u0905\u0970}",
+                    "{one:0\u00a0\u0916\u0970 other:0\u00a0\u0916\u0970}",
+                    "{one:00\u00a0\u0916\u0970 other:00\u00a0\u0916\u0970}",
+                    "{one:0\u00a0\u0928\u0940\u0932 other:0\u00a0\u0928\u0940\u0932}",
+                    "{one:00\u00a0\u0928\u0940\u0932 other:00\u00a0\u0928\u0940\u0932}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -412,12 +411,28 @@ public class FormatData_hi extends ListResourceBundle {
             { "field.hour", "\u0918\u0902\u091f\u093e" },
             { "calendarname.buddhist", "\u092c\u094c\u0926\u094d\u0927 \u092a\u0902\u091a\u093e\u0902\u0917" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##,##0.###",
+                    "\u00a4#,##,##0.00",
+                    "#,##,##0%",
+                    "\u00a4#,##,##0.00",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
             { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "japanese.Eras", metaValue_java_time_japanese_Eras },
+            { "deva.NumberPatterns",
+                new String[] {
+                    "#,##,##0.###",
+                    "\u00a4#,##,##0.00",
+                    "#,##,##0%",
+                    "",
+                }
+            },
             { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
