@@ -216,6 +216,7 @@ public class FormatData_hsb extends ListResourceBundle {
                     "po Chrystowym narod\u017aenju",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -241,6 +242,8 @@ public class FormatData_hsb extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -251,6 +254,7 @@ public class FormatData_hsb extends ListResourceBundle {
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "po\u0142ojca dnja" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "protyka republiki China" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
@@ -258,13 +262,6 @@ public class FormatData_hsb extends ListResourceBundle {
             { "field.second", "sekunda" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0\u00a0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "islamska protyka" },
             { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -292,18 +289,18 @@ public class FormatData_hsb extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 tysac",
-                    "00 tysac",
-                    "000 tysac",
-                    "0 milion",
-                    "00 milionow",
-                    "000 milionow",
-                    "0 miliarda",
-                    "00 miliardow",
-                    "000 miliardow",
-                    "0 bilion",
-                    "00 bilionow",
-                    "000 bilionow",
+                    "{one:0' 'tysac two:0' 'tysac few:0' 'tysac other:0' 'tysac}",
+                    "{one:00' 'tysac two:00' 'tysac few:00' 'tysac other:00' 'tysac}",
+                    "{one:000' 'tysac two:000' 'tysac few:000' 'tysac other:000' 'tysac}",
+                    "{one:0' 'milion two:0' 'milionaj few:0' 'miliony other:0' 'milionow}",
+                    "{one:00' 'milionow two:00' 'milionow few:00' 'milionow other:00' 'milionow}",
+                    "{one:000' 'milionow two:000' 'milionow few:000' 'milionow other:000' 'milionow}",
+                    "{one:0' 'miliarda two:0' 'miliard\u017ae few:0' 'miliardy other:0' 'miliardow}",
+                    "{one:00' 'miliardow two:00' 'miliardow few:00' 'miliardow other:00' 'miliardow}",
+                    "{one:000' 'miliardow two:000' 'miliardow few:000' 'miliardow other:000' 'miliardow}",
+                    "{one:0' 'bilion two:0' 'bilionaj few:0' 'biliony other:0' 'bilionow}",
+                    "{one:00' 'bilionow two:00' 'bilionow few:00' 'bilionow other:00' 'bilionow}",
+                    "{one:000' 'bilionow two:000' 'bilionow few:000' 'bilionow other:000' 'bilionow}",
                 }
             },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -348,18 +345,18 @@ public class FormatData_hsb extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0tys'.'",
-                    "00\u00a0tys'.'",
-                    "000\u00a0tys'.'",
-                    "0\u00a0mio'.'",
-                    "00\u00a0mio'.'",
-                    "000\u00a0mio'.'",
-                    "0\u00a0mrd'.'",
-                    "00\u00a0mrd'.'",
-                    "000\u00a0mrd'.'",
-                    "0\u00a0bil'.'",
-                    "00\u00a0bil'.'",
-                    "000\u00a0bil'.'",
+                    "{one:0\u00a0tys'.' two:0\u00a0tys'.' few:0\u00a0tys'.' other:0\u00a0tys'.'}",
+                    "{one:00\u00a0tys'.' two:00\u00a0tys'.' few:00\u00a0tys'.' other:00\u00a0tys'.'}",
+                    "{one:000\u00a0tys'.' two:000\u00a0tys'.' few:000\u00a0tys'.' other:000\u00a0tys'.'}",
+                    "{one:0\u00a0mio'.' two:0\u00a0mio'.' few:0\u00a0mio'.' other:0\u00a0mio'.'}",
+                    "{one:00\u00a0mio'.' two:00\u00a0mio'.' few:00\u00a0mio'.' other:00\u00a0mio'.'}",
+                    "{one:000\u00a0mio'.' two:000\u00a0mio'.' few:000\u00a0mio'.' other:000\u00a0mio'.'}",
+                    "{one:0\u00a0mrd'.' two:0\u00a0mrd'.' few:0\u00a0mrd'.' other:0\u00a0mrd'.'}",
+                    "{one:00\u00a0mrd'.' two:00\u00a0mrd'.' few:00\u00a0mrd'.' other:00\u00a0mrd'.'}",
+                    "{one:000\u00a0mrd'.' two:000\u00a0mrd'.' few:000\u00a0mrd'.' other:000\u00a0mrd'.'}",
+                    "{one:0\u00a0bil'.' two:0\u00a0bil'.' few:0\u00a0bil'.' other:0\u00a0bil'.'}",
+                    "{one:00\u00a0bil'.' two:00\u00a0bil'.' few:00\u00a0bil'.' other:00\u00a0bil'.'}",
+                    "{one:000\u00a0bil'.' two:000\u00a0bil'.' few:000\u00a0bil'.' other:000\u00a0bil'.'}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -395,6 +392,14 @@ public class FormatData_hsb extends ListResourceBundle {
                     "",
                 }
             },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0\u00a0%",
+                    "#,##0.00\u00a0\u00a4",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
