@@ -188,7 +188,7 @@ public class FormatData_hu extends ListResourceBundle {
             };
         final String[] metaValue_java_time_roc_long_Eras = new String[] {
                "R.O.C. el\u0151tt",
-               "",
+               "R.O.C.",
             };
         final String[] metaValue_java_time_islamic_long_Eras = new String[] {
                "",
@@ -270,6 +270,8 @@ public class FormatData_hu extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -314,13 +316,6 @@ public class FormatData_hu extends ListResourceBundle {
             { "field.second", "m\u00e1sodperc" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "Iszl\u00e1m napt\u00e1r" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
@@ -334,18 +329,18 @@ public class FormatData_hu extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 ezer",
-                    "00 ezer",
-                    "000 ezer",
-                    "0 milli\u00f3",
-                    "00 milli\u00f3",
-                    "000 milli\u00f3",
-                    "0 milli\u00e1rd",
-                    "00 milli\u00e1rd",
-                    "000 milli\u00e1rd",
-                    "0 billi\u00f3",
-                    "00 billi\u00f3",
-                    "000 billi\u00f3",
+                    "{one:0' 'ezer other:0' 'ezer}",
+                    "{one:00' 'ezer other:00' 'ezer}",
+                    "{one:000' 'ezer other:000' 'ezer}",
+                    "{one:0' 'milli\u00f3 other:0' 'milli\u00f3}",
+                    "{one:00' 'milli\u00f3 other:00' 'milli\u00f3}",
+                    "{one:000' 'milli\u00f3 other:000' 'milli\u00f3}",
+                    "{one:0' 'milli\u00e1rd other:0' 'milli\u00e1rd}",
+                    "{one:00' 'milli\u00e1rd other:00' 'milli\u00e1rd}",
+                    "{one:000' 'milli\u00e1rd other:000' 'milli\u00e1rd}",
+                    "{one:0' 'billi\u00f3 other:0' 'billi\u00f3}",
+                    "{one:00' 'billi\u00f3 other:00' 'billi\u00f3}",
+                    "{one:000' 'billi\u00f3 other:000' 'billi\u00f3}",
                 }
             },
             { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
@@ -419,18 +414,18 @@ public class FormatData_hu extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0E",
-                    "00\u00a0E",
-                    "000\u00a0E",
-                    "0\u00a0M",
-                    "00\u00a0M",
-                    "000\u00a0M",
-                    "0\u00a0Mrd",
-                    "00\u00a0Mrd",
-                    "000\u00a0Mrd",
-                    "0\u00a0B",
-                    "00\u00a0B",
-                    "000\u00a0B",
+                    "{one:0\u00a0E other:0\u00a0E}",
+                    "{one:00\u00a0E other:00\u00a0E}",
+                    "{one:000\u00a0E other:000\u00a0E}",
+                    "{one:0\u00a0M other:0\u00a0M}",
+                    "{one:00\u00a0M other:00\u00a0M}",
+                    "{one:000\u00a0M other:000\u00a0M}",
+                    "{one:0\u00a0Mrd other:0\u00a0Mrd}",
+                    "{one:00\u00a0Mrd other:00\u00a0Mrd}",
+                    "{one:000\u00a0Mrd other:000\u00a0Mrd}",
+                    "{one:0\u00a0B other:0\u00a0B}",
+                    "{one:00\u00a0B other:00\u00a0B}",
+                    "{one:000\u00a0B other:000\u00a0B}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -469,6 +464,14 @@ public class FormatData_hu extends ListResourceBundle {
             { "islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "calendarname.buddhist", "Buddhista napt\u00e1r" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0%",
+                    "#,##0.00\u00a0\u00a4",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
