@@ -256,6 +256,7 @@ public class FormatData_is extends ListResourceBundle {
                     "eftir Krist",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -274,6 +275,8 @@ public class FormatData_is extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -301,6 +304,24 @@ public class FormatData_is extends ListResourceBundle {
                     "",
                 }
             },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
+            { "arab.NumberElements",
+                new String[] {
+                    "\u066b",
+                    "\u066c",
+                    "\u061b",
+                    "\u066a\u061c",
+                    "\u0660",
+                    "#",
+                    "\u061c-",
+                    "\u0627\u0633",
+                    "\u0609",
+                    "\u221e",
+                    "NaN",
+                    "",
+                    "",
+                }
+            },
             { "calendarname.roc", "Minguo dagatal" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -310,13 +331,6 @@ public class FormatData_is extends ListResourceBundle {
             { "field.second", "sek\u00fanda" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u00cdslamskt dagatal" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
@@ -329,18 +343,18 @@ public class FormatData_is extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 \u00fe\u00fasund",
-                    "00 \u00fe\u00fasund",
-                    "000 \u00fe\u00fasund",
-                    "0 millj\u00f3n",
-                    "00 millj\u00f3n",
-                    "000 millj\u00f3n",
-                    "0 milljar\u00f0ur",
-                    "00 milljar\u00f0ur",
-                    "000 milljar\u00f0ur",
-                    "0 billj\u00f3n",
-                    "00 billj\u00f3n",
-                    "000 billj\u00f3n",
+                    "{one:0' '\u00fe\u00fasund other:0' '\u00fe\u00fasund}",
+                    "{one:00' '\u00fe\u00fasund other:00' '\u00fe\u00fasund}",
+                    "{one:000' '\u00fe\u00fasund other:000' '\u00fe\u00fasund}",
+                    "{one:0' 'millj\u00f3n other:0' 'millj\u00f3nir}",
+                    "{one:00' 'millj\u00f3n other:00' 'millj\u00f3nir}",
+                    "{one:000' 'millj\u00f3n other:000' 'millj\u00f3nir}",
+                    "{one:0' 'milljar\u00f0ur other:0' 'milljar\u00f0ar}",
+                    "{one:00' 'milljar\u00f0ur other:00' 'milljar\u00f0ar}",
+                    "{one:000' 'milljar\u00f0ur other:000' 'milljar\u00f0ar}",
+                    "{one:0' 'billj\u00f3n other:0' 'billj\u00f3nir}",
+                    "{one:00' 'billj\u00f3n other:00' 'billj\u00f3nir}",
+                    "{one:000' 'billj\u00f3n other:000' 'billj\u00f3nir}",
                 }
             },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -360,6 +374,14 @@ public class FormatData_is extends ListResourceBundle {
             { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.DateTimePatterns", metaValue_DateTimePatterns },
             { "roc.narrow.Eras", metaValue_java_time_roc_narrow_Eras },
+            { "arab.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0%",
+                    "",
+                }
+            },
             { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "Eras",
@@ -401,18 +423,18 @@ public class FormatData_is extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0\u00fe'.'",
-                    "00\u00a0\u00fe'.'",
-                    "000\u00a0\u00fe'.'",
-                    "0\u00a0m'.'",
-                    "00\u00a0m'.'",
-                    "000\u00a0m'.'",
-                    "0\u00a0ma'.'",
-                    "00\u00a0ma'.'",
-                    "000\u00a0ma'.'",
-                    "0\u00a0bn",
-                    "00\u00a0bn",
-                    "000\u00a0bn",
+                    "{one:0\u00a0\u00fe'.' other:0\u00a0\u00fe'.'}",
+                    "{one:00\u00a0\u00fe'.' other:00\u00a0\u00fe'.'}",
+                    "{one:000\u00a0\u00fe'.' other:000\u00a0\u00fe'.'}",
+                    "{one:0\u00a0m'.' other:0\u00a0m'.'}",
+                    "{one:00\u00a0m'.' other:00\u00a0m'.'}",
+                    "{one:000\u00a0m'.' other:000\u00a0m'.'}",
+                    "{one:0\u00a0ma'.' other:0\u00a0ma'.'}",
+                    "{one:00\u00a0ma'.' other:00\u00a0ma'.'}",
+                    "{one:000\u00a0ma'.' other:000\u00a0ma'.'}",
+                    "{one:0\u00a0bn other:0\u00a0bn}",
+                    "{one:00\u00a0bn other:00\u00a0bn}",
+                    "{one:000\u00a0bn other:000\u00a0bn}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -452,6 +474,14 @@ public class FormatData_is extends ListResourceBundle {
             { "islamic.narrow.Eras", metaValue_java_time_islamic_Eras },
             { "calendarname.buddhist", "B\u00fadd\u00edskt dagatal" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0%",
+                    "#,##0.00\u00a0\u00a4",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
