@@ -158,12 +158,22 @@ public class FormatData_it extends ListResourceBundle {
                "m.",
                "p.",
             };
+        final String[] metaValue_TimePatterns = new String[] {
+               "HH:mm:ss zzzz",
+               "HH:mm:ss z",
+               "HH:mm:ss",
+               "HH:mm",
+            };
         final String[] metaValue_buddhist_QuarterNarrows = new String[] {
                "1",
                "2",
                "3",
                "4",
             };
+        final String[] metaValue_buddhist_AmPmMarkers = new String[] {
+               "AM",
+               "PM",
+            };
         final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
                "BC",
                "EB",
@@ -180,10 +190,6 @@ public class FormatData_it extends ListResourceBundle {
                "dd MMM y GGGG",
                "dd/MM/yy G",
             };
-        final String[] metaValue_roc_AmPmMarkers = new String[] {
-               "AM",
-               "PM",
-            };
         final String[] metaValue_java_time_roc_long_Eras = new String[] {
                "Prima di R.O.C.",
                "Minguo",
@@ -197,6 +203,7 @@ public class FormatData_it extends ListResourceBundle {
             { "MonthNames", metaValue_MonthNames },
             { "field.year", "anno" },
             { "calendarname.islamic-umalqura", "Calendario islamico (Umm al-Qura)" },
+            { "japanese.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -204,6 +211,7 @@ public class FormatData_it extends ListResourceBundle {
             { "roc.MonthNarrows", metaValue_MonthNarrows },
             { "calendarname.islamic-civil", "calendario civile islamico" },
             { "islamic.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "japanese.TimePatterns", metaValue_TimePatterns },
             { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "narrow.Eras",
                 new String[] {
@@ -223,6 +231,7 @@ public class FormatData_it extends ListResourceBundle {
                     "dopo Cristo",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -248,6 +257,8 @@ public class FormatData_it extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -255,8 +266,10 @@ public class FormatData_it extends ListResourceBundle {
             { "buddhist.DayNames", metaValue_DayNames },
             { "field.minute", "minuto" },
             { "field.era", "era" },
+            { "buddhist.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "field.dayperiod", "AM/PM" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "Calendario minguo" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -266,18 +279,12 @@ public class FormatData_it extends ListResourceBundle {
             { "field.second", "secondo" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "Calendario islamico" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "java.time.roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
             { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "timezone.regionFormat", "Ora {0}" },
             { "long.CompactNumberPatterns",
@@ -285,18 +292,18 @@ public class FormatData_it extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 mille",
-                    "00 mila",
-                    "000 mila",
-                    "0 milione",
-                    "00 milioni",
-                    "000 milioni",
-                    "0 miliardo",
-                    "00 miliardi",
-                    "000 miliardi",
-                    "0 mille miliardi",
-                    "00 mila miliardi",
-                    "000 mila miliardi",
+                    "{one:0' 'mille other:0' 'mila}",
+                    "{one:00' 'mila other:00' 'mila}",
+                    "{one:000' 'mila other:000' 'mila}",
+                    "{one:0' 'milione other:0' 'milioni}",
+                    "{one:00' 'milioni other:00' 'milioni}",
+                    "{one:000' 'milioni other:000' 'milioni}",
+                    "{one:0' 'miliardo other:0' 'miliardi}",
+                    "{one:00' 'miliardi other:00' 'miliardi}",
+                    "{one:000' 'miliardi other:000' 'miliardi}",
+                    "{one:0' 'mille' 'miliardi other:0' 'mila' 'miliardi}",
+                    "{one:00' 'mila' 'miliardi other:00' 'mila' 'miliardi}",
+                    "{one:000' 'mila' 'miliardi other:000' 'mila' 'miliardi}",
                 }
             },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -307,8 +314,9 @@ public class FormatData_it extends ListResourceBundle {
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.DayNarrows", metaValue_DayNarrows },
             { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
+            { "islamic.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
-            { "islamic.AmPmMarkers", metaValue_roc_AmPmMarkers },
+            { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
             { "java.time.roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.zone", "fuso orario" },
@@ -343,7 +351,7 @@ public class FormatData_it extends ListResourceBundle {
             { "buddhist.QuarterNames", metaValue_QuarterNames },
             { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "roc.DayNarrows", metaValue_DayNarrows },
-            { "roc.AmPmMarkers", metaValue_roc_AmPmMarkers },
+            { "roc.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "short.CompactNumberPatterns",
@@ -351,18 +359,18 @@ public class FormatData_it extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0",
-                    "0",
-                    "0",
-                    "0\u00a0Mln",
-                    "00\u00a0Mln",
-                    "000\u00a0Mln",
-                    "0\u00a0Mrd",
-                    "00\u00a0Mrd",
-                    "000\u00a0Mrd",
-                    "0\u00a0Bln",
-                    "00\u00a0Bln",
-                    "000\u00a0Bln",
+                    "{one:0 other:0}",
+                    "{one:0 other:0}",
+                    "{one:0 other:0}",
+                    "{one:0\u00a0Mln other:0\u00a0Mln}",
+                    "{one:00\u00a0Mln other:00\u00a0Mln}",
+                    "{one:000\u00a0Mln other:000\u00a0Mln}",
+                    "{one:0\u00a0Mrd other:0\u00a0Mrd}",
+                    "{one:00\u00a0Mrd other:00\u00a0Mrd}",
+                    "{one:000\u00a0Mrd other:000\u00a0Mrd}",
+                    "{one:0\u00a0Bln other:0\u00a0Bln}",
+                    "{one:00\u00a0Bln other:00\u00a0Bln}",
+                    "{one:000\u00a0Bln other:000\u00a0Bln}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -377,16 +385,26 @@ public class FormatData_it extends ListResourceBundle {
                 }
             },
             { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
+            { "islamic.TimePatterns", metaValue_TimePatterns },
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.DayNames", metaValue_DayNames },
             { "field.hour", "ora" },
             { "islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "calendarname.buddhist", "Calendario buddista" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0%",
+                    "#,##0.00\u00a0\u00a4",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
+            { "roc.TimePatterns", metaValue_TimePatterns },
             { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
