@@ -153,6 +153,10 @@ public class FormatData_km extends ListResourceBundle {
                "3",
                "4",
             };
+        final String[] metaValue_buddhist_AmPmMarkers = new String[] {
+               "AM",
+               "PM",
+            };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
                "EEEE d MMMM y G",
                "d MMMM y G",
@@ -165,14 +169,11 @@ public class FormatData_km extends ListResourceBundle {
                "d MMM y GGGG",
                "d/M/y G",
             };
-        final String[] metaValue_roc_AmPmMarkers = new String[] {
-               "AM",
-               "PM",
-            };
         final String metaValue_calendarname_gregorian = "\u1794\u17d2\u179a\u178f\u17b7\u1791\u17b7\u1793\u200b\u17a0\u17d2\u179f\u1780\u17a0\u17d2\u179f\u17ca\u17b8";
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
             { "field.year", "\u1786\u17d2\u1793\u17b6\u17c6" },
+            { "japanese.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "timezone.gmtFormat", "\u1798\u17c9\u17c4\u1784\u200b\u179f\u1780\u179b {0}" },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "standalone.QuarterAbbreviations", metaValue_QuarterNames },
@@ -193,6 +194,7 @@ public class FormatData_km extends ListResourceBundle {
                     "\u1782\u17d2\u179a\u17b7\u179f\u17d2\u178f\u179f\u1780\u179a\u17b6\u1787",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthNames },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -218,6 +220,8 @@ public class FormatData_km extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -225,8 +229,10 @@ public class FormatData_km extends ListResourceBundle {
             { "buddhist.DayNames", metaValue_DayNames },
             { "field.minute", "\u1793\u17b6\u1791\u17b8" },
             { "field.era", "\u179f\u1780\u179a\u17b6\u1787" },
+            { "buddhist.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "field.dayperiod", "\u1796\u17d2\u179a\u17b9\u1780/\u179b\u17d2\u1784\u17b6\u1785" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "\u1794\u17d2\u179a\u178f\u17b7\u1791\u17b7\u1793\u1798\u17b8\u1784\u1782\u17d0\u179a" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterNames },
@@ -234,13 +240,6 @@ public class FormatData_km extends ListResourceBundle {
             { "field.second", "\u179c\u17b7\u1793\u17b6\u1791\u17b8" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a4",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u1794\u17d2\u179a\u178f\u17b7\u1791\u17b7\u1793\u17a2\u17ca\u17b8\u179f\u17d2\u179b\u17b6\u1798" },
             { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -252,18 +251,18 @@ public class FormatData_km extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 \u1796\u17b6\u1793\u17cb",
-                    "00 \u1796\u17b6\u1793\u17cb",
-                    "000\u1796\u17b6\u1793\u17cb",
-                    "0 \u179b\u17b6\u1793",
-                    "00 \u179b\u17b6\u1793",
-                    "000 \u179b\u17b6\u1793",
-                    "0 \u1794\u17ca\u17b8\u179b\u17b6\u1793",
-                    "00 \u1794\u17ca\u17b8\u179b\u17b6\u1793",
-                    "000 \u1794\u17ca\u17b8\u179b\u17b6\u1793",
-                    "0 \u1791\u17d2\u179a\u17b8\u179b\u17b6\u1793",
-                    "00 \u1791\u17d2\u179a\u17b8\u179b\u17b6\u1793",
-                    "000 \u1791\u17d2\u179a\u17b8\u179b\u17b6\u1793",
+                    "{other:0' '\u1796\u17b6\u1793\u17cb}",
+                    "{other:00' '\u1796\u17b6\u1793\u17cb}",
+                    "{other:000\u1796\u17b6\u1793\u17cb}",
+                    "{other:0' '\u179b\u17b6\u1793}",
+                    "{other:00' '\u179b\u17b6\u1793}",
+                    "{other:000' '\u179b\u17b6\u1793}",
+                    "{other:0' '\u1794\u17ca\u17b8\u179b\u17b6\u1793}",
+                    "{other:00' '\u1794\u17ca\u17b8\u179b\u17b6\u1793}",
+                    "{other:000' '\u1794\u17ca\u17b8\u179b\u17b6\u1793}",
+                    "{other:0' '\u1791\u17d2\u179a\u17b8\u179b\u17b6\u1793}",
+                    "{other:00' '\u1791\u17d2\u179a\u17b8\u179b\u17b6\u1793}",
+                    "{other:000' '\u1791\u17d2\u179a\u17b8\u179b\u17b6\u1793}",
                 }
             },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -273,7 +272,7 @@ public class FormatData_km extends ListResourceBundle {
             { "islamic.QuarterAbbreviations", metaValue_QuarterNames },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.DayNarrows", metaValue_DayNarrows },
-            { "islamic.AmPmMarkers", metaValue_roc_AmPmMarkers },
+            { "islamic.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
             { "field.zone", "\u179b\u17d2\u179c\u17c2\u1784\u1798\u17c9\u17c4\u1784" },
@@ -298,7 +297,7 @@ public class FormatData_km extends ListResourceBundle {
             { "buddhist.QuarterNames", metaValue_QuarterNames },
             { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "roc.DayNarrows", metaValue_DayNarrows },
-            { "roc.AmPmMarkers", metaValue_roc_AmPmMarkers },
+            { "roc.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "short.CompactNumberPatterns",
@@ -306,18 +305,18 @@ public class FormatData_km extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u1796\u17b6\u1793\u17cb",
-                    "00\u00a0\u1796\u17b6\u1793\u17cb",
-                    "000\u00a0\u1796\u17b6\u1793\u17cb",
-                    "0\u00a0\u179b\u17b6\u1793",
-                    "00\u00a0\u179b\u17b6\u1793",
-                    "000\u00a0\u179b\u17b6\u1793",
-                    "0\u00a0\u1794\u17ca\u17b8\u179b\u17b6\u1793",
-                    "00\u00a0\u1794\u17ca\u17b8\u179b\u17b6\u1793",
-                    "000\u00a0\u1794\u17ca\u17b8\u179b\u17b6\u1793",
-                    "0\u00a0\u1791\u17d2\u179a\u17b8\u179b\u17b6\u1793",
-                    "00\u00a0\u1791\u17d2\u179a\u17b8\u179b\u17b6\u1793",
-                    "000\u00a0\u1791\u17d2\u179a\u17b8\u179b\u17b6\u1793",
+                    "{other:0\u1796\u17b6\u1793\u17cb}",
+                    "{other:00\u00a0\u1796\u17b6\u1793\u17cb}",
+                    "{other:000\u00a0\u1796\u17b6\u1793\u17cb}",
+                    "{other:0\u00a0\u179b\u17b6\u1793}",
+                    "{other:00\u00a0\u179b\u17b6\u1793}",
+                    "{other:000\u00a0\u179b\u17b6\u1793}",
+                    "{other:0\u00a0\u1794\u17ca\u17b8\u179b\u17b6\u1793}",
+                    "{other:00\u00a0\u1794\u17ca\u17b8\u179b\u17b6\u1793}",
+                    "{other:000\u00a0\u1794\u17ca\u17b8\u179b\u17b6\u1793}",
+                    "{other:0\u00a0\u1791\u17d2\u179a\u17b8\u179b\u17b6\u1793}",
+                    "{other:00\u00a0\u1791\u17d2\u179a\u17b8\u179b\u17b6\u1793}",
+                    "{other:000\u00a0\u1791\u17d2\u179a\u17b8\u179b\u17b6\u1793}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -347,6 +346,14 @@ public class FormatData_km extends ListResourceBundle {
             { "field.hour", "\u1798\u17c9\u17c4\u1784" },
             { "calendarname.buddhist", "\u1794\u17d2\u179a\u178f\u17b7\u1791\u17b7\u1793\u1796\u17bb\u1791\u17d2\u1792\u179f\u17b6\u179f\u1793\u17b6" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a4",
+                    "#,##0%",
+                    "#,##0.00\u00a4;(#,##0.00\u00a4)",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
