@@ -178,6 +178,10 @@ public class FormatData_kn extends ListResourceBundle {
                "3",
                "4",
             };
+        final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
+               "BC",
+               "BE",
+            };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
                "G y MMMM d, EEEE",
                "G y MMMM d",
@@ -194,12 +198,17 @@ public class FormatData_kn extends ListResourceBundle {
                "\u0c86\u0cb0\u0ccd.\u0c93.\u0cb8\u0cbf.\u0c97\u0cc6 \u0cae\u0cc1\u0c82\u0c9a\u0cc6",
                "\u0cae\u0cbf\u0c82\u0c97\u0ccb",
             };
+        final String[] metaValue_java_time_islamic_long_Eras = new String[] {
+               "",
+               "AH",
+            };
         final String metaValue_calendarname_gregorian = "\u0c97\u0ccd\u0cb0\u0cc6\u0c97\u0ccb\u0cb0\u0cbf\u0caf\u0ca8\u0ccd \u0c95\u0ccd\u0caf\u0cbe\u0cb2\u0cc6\u0c82\u0ca1\u0cb0\u0ccd";
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
             { "field.year", "\u0cb5\u0cb0\u0ccd\u0cb7" },
             { "calendarname.islamic-umalqura", "\u0c87\u0cb8\u0ccd\u0cb2\u0cbe\u0cae\u0cbf\u0c95\u0ccd \u0c95\u0ccd\u0caf\u0cbe\u0cb2\u0cc6\u0c82\u0ca1\u0cb0\u0ccd (\u0c89\u0cae\u0ccd \u0c85\u0cb2\u0ccd-\u0c96\u0cc1\u0cb0\u0cbe)" },
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
+            { "buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -217,12 +226,14 @@ public class FormatData_kn extends ListResourceBundle {
             { "japanese.MonthNames", metaValue_MonthNames },
             { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "java.time.islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "long.Eras",
                 new String[] {
                     "\u0c95\u0ccd\u0cb0\u0cbf\u0cb8\u0ccd\u0ca4 \u0caa\u0cc2\u0cb0\u0ccd\u0cb5",
                     "\u0c95\u0ccd\u0cb0\u0cbf\u0cb8\u0ccd\u0ca4 \u0cb6\u0c95",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -248,6 +259,8 @@ public class FormatData_kn extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -275,21 +288,16 @@ public class FormatData_kn extends ListResourceBundle {
                     "",
                 }
             },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "\u0cae\u0cbf\u0c82\u0c97\u0ccb \u0c95\u0ccd\u0caf\u0cbe\u0cb2\u0cc6\u0c82\u0ca1\u0cb0\u0ccd" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "field.month", "\u0ca4\u0cbf\u0c82\u0c97\u0cb3\u0cc1" },
             { "roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.second", "\u0cb8\u0cc6\u0c95\u0cc6\u0c82\u0ca1\u0ccd" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "\u00a4#,##0.00",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u0c87\u0cb8\u0ccd\u0cb2\u0cbe\u0cae\u0cbf\u0c95\u0ccd \u0c95\u0ccd\u0caf\u0cbe\u0cb2\u0cc6\u0c82\u0ca1\u0cb0\u0ccd" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
@@ -306,6 +314,8 @@ public class FormatData_kn extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "java.time.roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
@@ -334,18 +344,18 @@ public class FormatData_kn extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 \u0cb8\u0cbe\u0cb5\u0cbf\u0cb0",
-                    "00 \u0cb8\u0cbe\u0cb5\u0cbf\u0cb0",
-                    "000 \u0cb8\u0cbe\u0cb5\u0cbf\u0cb0",
-                    "0 \u0cae\u0cbf\u0cb2\u0cbf\u0caf\u0ca8\u0ccd",
-                    "00 \u0cae\u0cbf\u0cb2\u0cbf\u0caf\u0ca8\u0ccd",
-                    "000 \u0cae\u0cbf\u0cb2\u0cbf\u0caf\u0ca8\u0ccd",
-                    "0 \u0cac\u0cbf\u0cb2\u0cbf\u0caf\u0ca8\u0ccd",
-                    "00 \u0cac\u0cbf\u0cb2\u0cbf\u0caf\u0ca8\u0ccd",
-                    "000 \u0cac\u0cbf\u0cb2\u0cbf\u0caf\u0ca8\u0ccd",
-                    "0 \u0c9f\u0ccd\u0cb0\u0cbf\u0cb2\u0cbf\u0caf\u0ca8\u0ccd\u200c",
-                    "00 \u0c9f\u0ccd\u0cb0\u0cbf\u0cb2\u0cbf\u0caf\u0ca8\u0ccd\u200c",
-                    "000 \u0c9f\u0ccd\u0cb0\u0cbf\u0cb2\u0cbf\u0caf\u0ca8\u0ccd\u200c",
+                    "{one:0' '\u0cb8\u0cbe\u0cb5\u0cbf\u0cb0 other:0' '\u0cb8\u0cbe\u0cb5\u0cbf\u0cb0}",
+                    "{one:00' '\u0cb8\u0cbe\u0cb5\u0cbf\u0cb0 other:00' '\u0cb8\u0cbe\u0cb5\u0cbf\u0cb0}",
+                    "{one:000' '\u0cb8\u0cbe\u0cb5\u0cbf\u0cb0 other:000' '\u0cb8\u0cbe\u0cb5\u0cbf\u0cb0}",
+                    "{one:0' '\u0cae\u0cbf\u0cb2\u0cbf\u0caf\u0ca8\u0ccd other:0' '\u0cae\u0cbf\u0cb2\u0cbf\u0caf\u0ca8\u0ccd}",
+                    "{one:00' '\u0cae\u0cbf\u0cb2\u0cbf\u0caf\u0ca8\u0ccd other:00' '\u0cae\u0cbf\u0cb2\u0cbf\u0caf\u0ca8\u0ccd}",
+                    "{one:000' '\u0cae\u0cbf\u0cb2\u0cbf\u0caf\u0ca8\u0ccd other:000' '\u0cae\u0cbf\u0cb2\u0cbf\u0caf\u0ca8\u0ccd}",
+                    "{one:0' '\u0cac\u0cbf\u0cb2\u0cbf\u0caf\u0ca8\u0ccd other:0' '\u0cac\u0cbf\u0cb2\u0cbf\u0caf\u0ca8\u0ccd}",
+                    "{one:00' '\u0cac\u0cbf\u0cb2\u0cbf\u0caf\u0ca8\u0ccd other:00' '\u0cac\u0cbf\u0cb2\u0cbf\u0caf\u0ca8\u0ccd}",
+                    "{one:000' '\u0cac\u0cbf\u0cb2\u0cbf\u0caf\u0ca8\u0ccd other:000' '\u0cac\u0cbf\u0cb2\u0cbf\u0caf\u0ca8\u0ccd}",
+                    "{one:0' '\u0c9f\u0ccd\u0cb0\u0cbf\u0cb2\u0cbf\u0caf\u0ca8\u0ccd\u200c other:0' '\u0c9f\u0ccd\u0cb0\u0cbf\u0cb2\u0cbf\u0caf\u0ca8\u0ccd\u200c}",
+                    "{one:00' '\u0c9f\u0ccd\u0cb0\u0cbf\u0cb2\u0cbf\u0caf\u0ca8\u0ccd\u200c other:00' '\u0c9f\u0ccd\u0cb0\u0cbf\u0cb2\u0cbf\u0caf\u0ca8\u0ccd\u200c}",
+                    "{one:000' '\u0c9f\u0ccd\u0cb0\u0cbf\u0cb2\u0cbf\u0caf\u0ca8\u0ccd\u200c other:000' '\u0c9f\u0ccd\u0cb0\u0cbf\u0cb2\u0cbf\u0caf\u0ca8\u0ccd\u200c}",
                 }
             },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -355,7 +365,9 @@ public class FormatData_kn extends ListResourceBundle {
             { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.DayNarrows", metaValue_DayNarrows },
+            { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
+            { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
             { "java.time.roc.Eras", metaValue_java_time_roc_long_Eras },
@@ -372,13 +384,25 @@ public class FormatData_kn extends ListResourceBundle {
             { "field.weekday", "\u0cb5\u0cbe\u0cb0\u0ca6 \u0ca6\u0cbf\u0ca8" },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
+            { "islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
+            { "java.time.islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.QuarterNames", metaValue_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "java.time.buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "japanese.DayNames", metaValue_DayNames },
+            { "knda.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "\u00a4#,##0.00",
+                    "#,##0%",
+                    "",
+                }
+            },
             { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNames", metaValue_DayNames },
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.MonthNames", metaValue_MonthNames },
+            { "buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "field.week", "\u0cb5\u0cbe\u0cb0" },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
@@ -392,21 +416,22 @@ public class FormatData_kn extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u0cb8\u0cbe",
-                    "00\u0cb8\u0cbe",
-                    "000\u0cb8\u0cbe",
-                    "0\u0cae\u0cbf",
-                    "00\u0cae\u0cbf",
-                    "000\u0cae\u0cbf",
-                    "0\u0cac\u0cbf",
-                    "00\u0cac\u0cbf",
-                    "000\u0cac\u0cbf",
-                    "0\u0c9f\u0ccd\u0cb0\u0cbf",
-                    "00\u0c9f\u0ccd\u0cb0\u0cbf",
-                    "000\u0c9f\u0ccd\u0cb0\u0cbf",
+                    "{one:0\u0cb8\u0cbe other:0\u0cb8\u0cbe}",
+                    "{one:00\u0cb8\u0cbe other:00\u0cb8\u0cbe}",
+                    "{one:000\u0cb8\u0cbe other:000\u0cb8\u0cbe}",
+                    "{one:0\u0cae\u0cbf other:0\u0cae\u0cbf}",
+                    "{one:00\u0cae\u0cbf other:00\u0cae\u0cbf}",
+                    "{one:000\u0cae\u0cbf other:000\u0cae\u0cbf}",
+                    "{one:0\u0cac\u0cbf other:0\u0cac\u0cbf}",
+                    "{one:00\u0cac\u0cbf other:00\u0cac\u0cbf}",
+                    "{one:000\u0cac\u0cbf other:000\u0cac\u0cbf}",
+                    "{one:0\u0c9f\u0ccd\u0cb0\u0cbf other:0\u0c9f\u0ccd\u0cb0\u0cbf}",
+                    "{one:00\u0c9f\u0ccd\u0cb0\u0cbf other:00\u0c9f\u0ccd\u0cb0\u0cbf}",
+                    "{one:000\u0c9f\u0ccd\u0cb0\u0cbf other:000\u0c9f\u0ccd\u0cb0\u0cbf}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
+            { "java.time.buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "timezone.regionFormat.daylight", "{0} \u0ca6\u0cbf\u0ca8\u0ca6 \u0cb8\u0cae\u0caf" },
             { "DatePatterns",
                 new String[] {
@@ -438,9 +463,19 @@ public class FormatData_kn extends ListResourceBundle {
                     "",
                 }
             },
+            { "islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "calendarname.buddhist", "\u0cac\u0ccc\u0ca6\u0ccd\u0ca7\u0cb0 \u0c95\u0ccd\u0caf\u0cbe\u0cb2\u0cc6\u0c82\u0ca1\u0cb0\u0ccd" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "\u00a4#,##0.00",
+                    "#,##0%",
+                    "\u00a4#,##0.00;(\u00a4#,##0.00)",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
+            { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
