@@ -135,6 +135,10 @@ public class FormatData_ko extends ListResourceBundle {
                "3",
                "4",
             };
+        final String[] metaValue_buddhist_narrow_AmPmMarkers = new String[] {
+               "AM",
+               "PM",
+            };
         final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
                "BC",
                "\ubd88\uae30",
@@ -151,10 +155,6 @@ public class FormatData_ko extends ListResourceBundle {
                "GGGG y. M. d.",
                "GGGG y. M. d.",
             };
-        final String[] metaValue_japanese_narrow_AmPmMarkers = new String[] {
-               "AM",
-               "PM",
-            };
         final String[] metaValue_java_time_japanese_long_Eras = new String[] {
                "\uc11c\uae30",
                "\uba54\uc774\uc9c0",
@@ -179,23 +179,27 @@ public class FormatData_ko extends ListResourceBundle {
                "",
                "\ud788\uc988\ub77c\ub825",
             };
+        final String[] metaValue_java_time_islamic_Eras = new String[] {
+               "",
+               "AH",
+            };
         final String metaValue_calendarname_gregorian = "\uc591\ub825";
         final String[] metaValue_short_CompactNumberPatterns = new String[] {
                "",
                "",
                "",
-               "0\ucc9c",
-               "0\ub9cc",
-               "00\ub9cc",
-               "000\ub9cc",
-               "0000\ub9cc",
-               "0\uc5b5",
-               "00\uc5b5",
-               "000\uc5b5",
-               "0000\uc5b5",
-               "0\uc870",
-               "00\uc870",
-               "000\uc870",
+               "{other:0\ucc9c}",
+               "{other:0\ub9cc}",
+               "{other:00\ub9cc}",
+               "{other:000\ub9cc}",
+               "{other:0000\ub9cc}",
+               "{other:0\uc5b5}",
+               "{other:00\uc5b5}",
+               "{other:000\uc5b5}",
+               "{other:0000\uc5b5}",
+               "{other:0\uc870}",
+               "{other:00\uc870}",
+               "{other:000\uc870}",
             };
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
@@ -209,7 +213,7 @@ public class FormatData_ko extends ListResourceBundle {
             { "roc.QuarterNames", metaValue_QuarterNames },
             { "roc.MonthNarrows", metaValue_MonthNames },
             { "calendarname.islamic-civil", "\uc774\uc2ac\ub78c \uc0c1\uc6a9\ub825" },
-            { "islamic.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "islamic.narrow.AmPmMarkers", metaValue_buddhist_narrow_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
             { "narrow.Eras", metaValue_Eras },
             { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
@@ -218,12 +222,14 @@ public class FormatData_ko extends ListResourceBundle {
             { "japanese.MonthNames", metaValue_MonthNames },
             { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
             { "roc.MonthAbbreviations", metaValue_MonthNames },
+            { "java.time.islamic.narrow.Eras", metaValue_java_time_islamic_Eras },
             { "long.Eras",
                 new String[] {
                     "\uae30\uc6d0\uc804",
                     "\uc11c\uae30",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthNames },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -248,6 +254,8 @@ public class FormatData_ko extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNames },
@@ -276,6 +284,7 @@ public class FormatData_ko extends ListResourceBundle {
                     "",
                 }
             },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "arab.NumberElements",
                 new String[] {
                     "\u066b",
@@ -289,35 +298,31 @@ public class FormatData_ko extends ListResourceBundle {
                     "\u0609",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "calendarname.roc", "\ub300\ub9cc\ub825" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "islamic.Eras", metaValue_java_time_islamic_Eras },
             { "field.month", "\uc6d4" },
             { "java.time.japanese.long.Eras", metaValue_java_time_japanese_long_Eras },
             { "roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.second", "\ucd08" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayAbbreviations },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "\u00a4#,##0.00",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\uc774\uc2ac\ub78c\ub825" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "java.time.roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
-            { "japanese.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "japanese.narrow.AmPmMarkers", metaValue_buddhist_narrow_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations", metaValue_MonthNames },
             { "long.CompactNumberPatterns", metaValue_short_CompactNumberPatterns },
             { "timezone.regionFormat", "{0} \uc2dc\uac04" },
             { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
-            { "roc.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "roc.narrow.AmPmMarkers", metaValue_buddhist_narrow_AmPmMarkers },
             { "standalone.QuarterNames", metaValue_QuarterNames },
             { "japanese.MonthNarrows", metaValue_MonthNames },
             { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -332,6 +337,15 @@ public class FormatData_ko extends ListResourceBundle {
             { "field.zone", "\uc2dc\uac04\ub300" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
+            { "arab.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0%",
+                    "",
+                }
+            },
+            { "buddhist.narrow.AmPmMarkers", metaValue_buddhist_narrow_AmPmMarkers },
             { "Eras", metaValue_Eras },
             { "roc.DayNames", metaValue_DayNames },
             { "islamic.QuarterNames", metaValue_QuarterNames },
@@ -340,6 +354,7 @@ public class FormatData_ko extends ListResourceBundle {
             { "japanese.MonthAbbreviations", metaValue_MonthNames },
             { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
             { "islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
+            { "java.time.islamic.Eras", metaValue_java_time_islamic_Eras },
             { "japanese.QuarterNames", metaValue_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "java.time.buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
@@ -375,8 +390,17 @@ public class FormatData_ko extends ListResourceBundle {
             { "MonthAbbreviations", metaValue_MonthNames },
             { "standalone.DayNames", metaValue_DayNames },
             { "field.hour", "\uc2dc" },
+            { "islamic.narrow.Eras", metaValue_java_time_islamic_Eras },
             { "calendarname.buddhist", "\ubd88\uad50\ub825" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "\u00a4#,##0.00",
+                    "#,##0%",
+                    "\u00a4#,##0.00;(\u00a4#,##0.00)",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayAbbreviations },
             { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayAbbreviations },
