@@ -195,7 +195,6 @@ public class FormatData_ksh extends ListResourceBundle {
             { "java.time.japanese.DatePatterns", metaValue_java_time_japanese_DatePatterns },
             { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.QuarterNames", metaValue_QuarterNames },
-            { "roc.MonthNarrows", metaValue_MonthNarrows },
             { "calendarname.islamic-civil", "w\u00e4ltlesche islaamesche Kal\u00e4nder" },
             { "japanese.TimePatterns", metaValue_TimePatterns },
             { "narrow.Eras",
@@ -217,6 +216,7 @@ public class FormatData_ksh extends ListResourceBundle {
                     "noh Krestos",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -234,6 +234,8 @@ public class FormatData_ksh extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -244,6 +246,7 @@ public class FormatData_ksh extends ListResourceBundle {
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "Daachteil" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "rotschineesesche Kal\u00e4nder" },
             { "islamic.DatePatterns", metaValue_japanese_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -251,13 +254,6 @@ public class FormatData_ksh extends ListResourceBundle {
             { "field.second", "Sekond" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0\u00a0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_japanese_DatePatterns },
             { "calendarname.islamic", "i\u00dflaamesche Kal\u00e4nder" },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
@@ -284,30 +280,27 @@ public class FormatData_ksh extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 Dousend",
-                    "00 Dousend",
-                    "000 Dousend",
-                    "0 Million",
-                    "00 Milljuhne",
-                    "000 Milljuhne",
-                    "0 Milliarde",
-                    "00 Milljarde",
-                    "000 Milliarde",
-                    "0 Billjuhn",
-                    "00 Billion",
-                    "000 Billion",
+                    "{zero:0' 'Dousend one:0' 'Dousend other:0' 'Dousend}",
+                    "{zero:00' 'Dousend one:00' 'Dousend other:00' 'Dousend}",
+                    "{zero:000' 'Dousend one:000' 'Dousend other:000' 'Dousend}",
+                    "{zero:0' 'Milljuhne one:0' 'Million other:0' 'Milljuhne}",
+                    "{zero:00' 'Milljuhne one:00' 'Milljuhne other:00' 'Millionen}",
+                    "{zero:000' 'Milljuhne one:000' 'Milljuhne other:000' 'Millionen}",
+                    "{zero:0' 'Milljard one:0' 'Milliarde other:0' 'Milljarde}",
+                    "{zero:00' 'Milljarde one:00' 'Milljarde other:00' 'Milliarden}",
+                    "{zero:000' 'Milljarde one:000' 'Milliarde other:000' 'Milliarden}",
+                    "{zero:0' 'Billjuhn one:0' 'Billjuhn other:0' 'Billjuhn}",
+                    "{zero:00' 'Billjuhn one:00' 'Billion other:00' 'Billionen}",
+                    "{zero:000' 'Billjuhn one:000' 'Billion other:000' 'Billionen}",
                 }
             },
-            { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "standalone.QuarterNames", metaValue_QuarterNames },
-            { "japanese.MonthNarrows", metaValue_MonthNarrows },
             { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.DayNarrows", metaValue_DayNarrows },
             { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
             { "TimePatterns", metaValue_TimePatterns },
-            { "islamic.DayNarrows", metaValue_DayNarrows },
             { "field.zone", "Zickzohn" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -348,7 +341,6 @@ public class FormatData_ksh extends ListResourceBundle {
             },
             { "roc.MonthNames", metaValue_MonthNames },
             { "field.week", "Woch" },
-            { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
             { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "roc.DayNarrows", metaValue_DayNarrows },
@@ -367,18 +359,18 @@ public class FormatData_ksh extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0tsd",
-                    "00\u00a0tsd",
-                    "000\u00a0tsd",
-                    "0\u00a0Mio",
-                    "00\u00a0Mio",
-                    "000\u00a0Mio",
-                    "0\u00a0Mrd",
-                    "00\u00a0Mrd",
-                    "000\u00a0Mrd",
-                    "0\u00a0Bio",
-                    "00\u00a0Bio",
-                    "000\u00a0Bio",
+                    "{zero:0\u00a0tsd one:0\u00a0tsd other:0\u00a0tsd}",
+                    "{zero:00\u00a0tsd one:00\u00a0tsd other:00\u00a0tsd}",
+                    "{zero:000\u00a0tsd one:000\u00a0tsd other:000\u00a0tsd}",
+                    "{zero:0\u00a0Mio one:0\u00a0Mio other:0\u00a0Mio}",
+                    "{zero:00\u00a0Mio one:00\u00a0Mio other:00\u00a0Mio}",
+                    "{zero:000\u00a0Mio one:000\u00a0Mio other:000\u00a0Mio}",
+                    "{zero:0\u00a0Mrd one:0\u00a0Mrd other:0\u00a0Mrd}",
+                    "{zero:00\u00a0Mrd one:00\u00a0Mrd other:00\u00a0Mrd}",
+                    "{zero:000\u00a0Mrd one:000\u00a0Mrd other:000\u00a0Mrd}",
+                    "{zero:0\u00a0Bio one:0\u00a0Bio other:0\u00a0Bio}",
+                    "{zero:00\u00a0Bio one:00\u00a0Bio other:00\u00a0Bio}",
+                    "{zero:000\u00a0Bio one:000\u00a0Bio other:000\u00a0Bio}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -398,8 +390,14 @@ public class FormatData_ksh extends ListResourceBundle {
             { "field.hour", "Schtund" },
             { "calendarname.buddhist", "buddistesche Kal\u00e4nder" },
             { "standalone.MonthNames", metaValue_MonthNames },
-            { "buddhist.DayNarrows", metaValue_DayNarrows },
-            { "japanese.DayNarrows", metaValue_DayNarrows },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0\u00a0%",
+                    "",
+                }
+            },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
             { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
