@@ -237,6 +237,7 @@ public class FormatData_lb extends ListResourceBundle {
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "java.time.islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "long.Eras", metaValue_long_Eras },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -262,6 +263,8 @@ public class FormatData_lb extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -272,6 +275,7 @@ public class FormatData_lb extends ListResourceBundle {
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "Dageshallschent" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "Kalenner vun der Republik China" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
@@ -281,13 +285,6 @@ public class FormatData_lb extends ListResourceBundle {
             { "field.second", "Sekonn" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0\u00a0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "Islamesche Kalenner" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
@@ -317,18 +314,18 @@ public class FormatData_lb extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 Dausend",
-                    "00 Dausend",
-                    "000 Dausend",
-                    "0 Millioun",
-                    "00 Milliounen",
-                    "000 Milliounen",
-                    "0 Milliard",
-                    "00 Milliarden",
-                    "000 Milliarden",
-                    "0 Billioun",
-                    "00 Billiounen",
-                    "000 Billiounen",
+                    "{one:0' 'Dausend other:0' 'Dausend}",
+                    "{one:00' 'Dausend other:00' 'Dausend}",
+                    "{one:000' 'Dausend other:000' 'Dausend}",
+                    "{one:0' 'Millioun other:0' 'Milliounen}",
+                    "{one:00' 'Milliounen other:00' 'Milliounen}",
+                    "{one:000' 'Milliounen other:000' 'Milliounen}",
+                    "{one:0' 'Milliard other:0' 'Milliarden}",
+                    "{one:00' 'Milliarden other:00' 'Milliarden}",
+                    "{one:000' 'Milliarden other:000' 'Milliarden}",
+                    "{one:0' 'Billioun other:0' 'Billiounen}",
+                    "{one:00' 'Billiounen other:00' 'Billiounen}",
+                    "{one:000' 'Billiounen other:000' 'Billiounen}",
                 }
             },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -381,18 +378,18 @@ public class FormatData_lb extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0Dsd'.'",
-                    "00\u00a0Dsd'.'",
-                    "000\u00a0Dsd'.'",
-                    "0\u00a0Mio'.'",
-                    "00\u00a0Mio'.'",
-                    "000\u00a0Mio'.'",
-                    "0\u00a0Mrd'.'",
-                    "00\u00a0Mrd'.'",
-                    "000\u00a0Mrd'.'",
-                    "0\u00a0Bio'.'",
-                    "00\u00a0Bio'.'",
-                    "000\u00a0Bio'.'",
+                    "{one:0\u00a0Dsd'.' other:0\u00a0Dsd'.'}",
+                    "{one:00\u00a0Dsd'.' other:00\u00a0Dsd'.'}",
+                    "{one:000\u00a0Dsd'.' other:000\u00a0Dsd'.'}",
+                    "{one:0\u00a0Mio'.' other:0\u00a0Mio'.'}",
+                    "{one:00\u00a0Mio'.' other:00\u00a0Mio'.'}",
+                    "{one:000\u00a0Mio'.' other:000\u00a0Mio'.'}",
+                    "{one:0\u00a0Mrd'.' other:0\u00a0Mrd'.'}",
+                    "{one:00\u00a0Mrd'.' other:00\u00a0Mrd'.'}",
+                    "{one:000\u00a0Mrd'.' other:000\u00a0Mrd'.'}",
+                    "{one:0\u00a0Bio'.' other:0\u00a0Bio'.'}",
+                    "{one:00\u00a0Bio'.' other:00\u00a0Bio'.'}",
+                    "{one:000\u00a0Bio'.' other:000\u00a0Bio'.'}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -414,6 +411,14 @@ public class FormatData_lb extends ListResourceBundle {
             { "islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "calendarname.buddhist", "Buddhistesche Kalenner" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0\u00a0%",
+                    "#,##0.00\u00a0\u00a4",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
