@@ -143,10 +143,6 @@ public class FormatData_lo extends ListResourceBundle {
                "\u0e81\u0ec8\u0ead\u0e99\u0e97\u0ec8\u0ebd\u0e87",
                "\u0eab\u0ebc\u0eb1\u0e87\u0e97\u0ec8\u0ebd\u0e87",
             };
-        final String[] metaValue_narrow_AmPmMarkers = new String[] {
-               "\u0e81\u0e97",
-               "\u0eab\u0ebc\u0e97",
-            };
         final String[] metaValue_Eras = new String[] {
                "\u0e81\u0ec8\u0ead\u0e99 \u0e84.\u0eaa.",
                "\u0e84.\u0eaa.",
@@ -208,7 +204,7 @@ public class FormatData_lo extends ListResourceBundle {
             };
         final String[] metaValue_java_time_roc_long_Eras = new String[] {
                "\u0e81\u0ec8\u0ead\u0e99 R.O.C.",
-               "",
+               "R.O.C.",
             };
         final String[] metaValue_java_time_islamic_long_Eras = new String[] {
                "",
@@ -232,7 +228,6 @@ public class FormatData_lo extends ListResourceBundle {
             { "roc.QuarterNames", metaValue_QuarterNames },
             { "roc.MonthNarrows", metaValue_buddhist_MonthNarrows },
             { "calendarname.islamic-civil", "\u0e9b\u0eb0\u0e95\u0eb4\u0e97\u0eb4\u0e99\u0ead\u0eb4\u0e94\u0eaa\u0eb0\u0ea5\u0eb2\u0ea1" },
-            { "islamic.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
             { "narrow.Eras", metaValue_Eras },
             { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
@@ -250,6 +245,7 @@ public class FormatData_lo extends ListResourceBundle {
                     "\u0e84\u0ea3\u0eb4\u0e94\u0eaa\u0eb1\u0e81\u0e81\u0eb0\u0ea5\u0eb2\u0e94",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -261,7 +257,7 @@ public class FormatData_lo extends ListResourceBundle {
                     "{1}, {0}",
                 }
             },
-            { "narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "latn.NumberElements",
                 new String[] {
                     ",",
@@ -275,6 +271,8 @@ public class FormatData_lo extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "\u0e9a\u0ecd\u0ec8\u200b\u0ec1\u0ea1\u0ec8\u0e99\u200b\u0ec2\u0e95\u200b\u0ec0\u0ea5\u0e81",
+                    "",
+                    "",
                 }
             },
             { "japanese.DatePatterns", metaValue_buddhist_DatePatterns },
@@ -301,6 +299,7 @@ public class FormatData_lo extends ListResourceBundle {
                     "",
                 }
             },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "\u0e9b\u0eb0\u0e95\u0eb4\u0e97\u0eb4\u0e99\u0ec4\u0e95\u0ec9\u0eab\u0ea7\u0eb1\u0e99" },
             { "islamic.DatePatterns",
                 new String[] {
@@ -318,18 +317,10 @@ public class FormatData_lo extends ListResourceBundle {
             { "field.second", "\u0ea7\u0eb4\u0e99\u0eb2\u0e97\u0eb5" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "\u00a4#,##0.00;\u00a4-#,##0.00",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u0e9b\u0eb0\u0e95\u0eb4\u0e97\u0eb4\u0e99\u0ead\u0eb4\u0eaa\u0eb0\u0ea5\u0eb2\u0ea1" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "java.time.roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
-            { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "timezone.regionFormat", "\u0ec0\u0ea7\u0ea5\u0eb2 {0}" },
@@ -338,21 +329,20 @@ public class FormatData_lo extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 \u0e9e\u0eb1\u0e99",
-                    "00 \u0e9e\u0eb1\u0e99",
-                    "0 \u0ec1\u0eaa\u0e99",
-                    "0 \u0ea5\u0ec9\u0eb2\u0e99",
-                    "00 \u0ea5\u0ec9\u0eb2\u0e99",
-                    "000 \u0ea5\u0ec9\u0eb2\u0e99",
-                    "0 \u0e95\u0eb7\u0ec9",
-                    "00 \u0e95\u0eb7\u0ec9",
-                    "000 \u0e95\u0eb7\u0ec9",
-                    "0 \u0ea5\u0ec9\u0eb2\u0e99\u0ea5\u0ec9\u0eb2\u0e99",
-                    "00 \u0ea5\u0ec9\u0eb2\u0e99\u0ea5\u0ec9\u0eb2\u0e99",
-                    "000 \u0ea5\u0ec9\u0eb2\u0e99\u0ea5\u0ec9\u0eb2\u0e99",
+                    "{other:0' '\u0e9e\u0eb1\u0e99}",
+                    "{other:00' '\u0e9e\u0eb1\u0e99}",
+                    "{other:0' '\u0ec1\u0eaa\u0e99}",
+                    "{other:0' '\u0ea5\u0ec9\u0eb2\u0e99}",
+                    "{other:00' '\u0ea5\u0ec9\u0eb2\u0e99}",
+                    "{other:000' '\u0ea5\u0ec9\u0eb2\u0e99}",
+                    "{other:0' '\u0e95\u0eb7\u0ec9}",
+                    "{other:00' '\u0e95\u0eb7\u0ec9}",
+                    "{other:000' '\u0e95\u0eb7\u0ec9}",
+                    "{other:0' '\u0ea5\u0ec9\u0eb2\u0e99\u0ea5\u0ec9\u0eb2\u0e99}",
+                    "{other:00' '\u0ea5\u0ec9\u0eb2\u0e99\u0ea5\u0ec9\u0eb2\u0e99}",
+                    "{other:000' '\u0ea5\u0ec9\u0eb2\u0e99\u0ea5\u0ec9\u0eb2\u0e99}",
                 }
             },
-            { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "standalone.QuarterNames", metaValue_QuarterNames },
             { "japanese.MonthNarrows", metaValue_buddhist_MonthNarrows },
@@ -366,7 +356,24 @@ public class FormatData_lo extends ListResourceBundle {
             { "field.zone", "\u0ec0\u0e82\u0e94\u0ec0\u0ea7\u0ea5\u0eb2" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
-            { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "laoo.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "\u0ed0",
+                    "#",
+                    "-",
+                    "E",
+                    "\u2030",
+                    "\u221e",
+                    "NaN",
+                    "",
+                    "",
+                }
+            },
+            { "buddhist.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "Eras", metaValue_Eras },
             { "roc.DayNames", metaValue_DayNames },
@@ -385,6 +392,14 @@ public class FormatData_lo extends ListResourceBundle {
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
             { "java.time.japanese.Eras", metaValue_java_time_japanese_Eras },
             { "roc.MonthNames", metaValue_MonthNames },
+            { "laoo.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "\u00a4\u00a0#,##0.00",
+                    "#,##0%",
+                    "",
+                }
+            },
             { "field.week", "\u0ead\u0eb2\u0e97\u0eb4\u0e94" },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
             { "buddhist.MonthNarrows", metaValue_buddhist_MonthNarrows },
@@ -398,18 +413,18 @@ public class FormatData_lo extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0\u0e9e\u0eb1\u0e99",
-                    "00\u00a0\u0e9e\u0eb1\u0e99",
-                    "000\u00a0\u0e81\u0eb5\u0e9a",
-                    "0\u00a0\u0ea5\u0ec9\u0eb2\u0e99",
-                    "00\u00a0\u0ea5\u0ec9\u0eb2\u0e99",
-                    "000\u00a0\u0ea5\u0ec9\u0eb2\u0e99",
-                    "0\u00a0\u0e95\u0eb7\u0ec9",
-                    "00\u00a0\u0e95\u0eb7\u0ec9",
-                    "000\u00a0\u0e95\u0eb7\u0ec9",
-                    "0\u00a0\u0ea5\u0ec9\u0eb2\u0e99\u0ea5\u0ec9\u0eb2\u0e99",
-                    "00\u0ea5\u0ea5",
-                    "000\u0ea5\u0ea5",
+                    "{other:0\u00a0\u0e9e\u0eb1\u0e99}",
+                    "{other:00\u00a0\u0e9e\u0eb1\u0e99}",
+                    "{other:000\u00a0\u0e81\u0eb5\u0e9a}",
+                    "{other:0\u00a0\u0ea5\u0ec9\u0eb2\u0e99}",
+                    "{other:00\u00a0\u0ea5\u0ec9\u0eb2\u0e99}",
+                    "{other:000\u00a0\u0ea5\u0ec9\u0eb2\u0e99}",
+                    "{other:0\u00a0\u0e95\u0eb7\u0ec9}",
+                    "{other:00\u00a0\u0e95\u0eb7\u0ec9}",
+                    "{other:000\u00a0\u0e95\u0eb7\u0ec9}",
+                    "{other:0\u00a0\u0ea5\u0ec9\u0eb2\u0e99\u0ea5\u0ec9\u0eb2\u0e99}",
+                    "{other:00\u0ea5\u0ea5}",
+                    "{other:000\u0ea5\u0ea5}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -447,6 +462,14 @@ public class FormatData_lo extends ListResourceBundle {
             { "islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "calendarname.buddhist", "\u0e9b\u0eb0\u0e95\u0eb4\u0e97\u0eb4\u0e99 \u0e9e\u0eb8\u0e94\u0e97\u0eb0\u0eaa\u0eb1\u0e87\u0e81\u0eb2\u0e94" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "\u00a4#,##0.00;\u00a4-#,##0.00",
+                    "#,##0%",
+                    "\u00a4#,##0.00;\u00a4-#,##0.00",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
