@@ -199,7 +199,7 @@ public class FormatData_lt extends ListResourceBundle {
                "Meid\u017ei",
                "Tai\u0161o",
                "\u0160ova",
-               "",
+               "Heisei",
                "Reiwa",
             };
         final String[] metaValue_java_time_japanese_Eras = new String[] {
@@ -207,7 +207,7 @@ public class FormatData_lt extends ListResourceBundle {
                "Meid\u017ei",
                "Tai\u0161o",
                "\u0160ova",
-               "",
+               "Heisei",
                "Reiwa",
             };
         final String[] metaValue_java_time_roc_long_Eras = new String[] {
@@ -256,6 +256,7 @@ public class FormatData_lt extends ListResourceBundle {
                     "po Kristaus",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -281,6 +282,8 @@ public class FormatData_lt extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -292,6 +295,7 @@ public class FormatData_lt extends ListResourceBundle {
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "iki piet\u0173 / po piet\u0173" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "Kinijos Respublikos kalendorius" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -302,13 +306,6 @@ public class FormatData_lt extends ListResourceBundle {
             { "field.second", "sekund\u0117" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0\u00a0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "islamo kalendorius" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
@@ -322,18 +319,18 @@ public class FormatData_lt extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 t\u016bkstantis",
-                    "00 t\u016bkstantis",
-                    "000 t\u016bkstantis",
-                    "0 milijonas",
-                    "00 milijonas",
-                    "000 milijonas",
-                    "0 milijardas",
-                    "00 milijardas",
-                    "000 milijardas",
-                    "0 trilijonas",
-                    "00 trilijonas",
-                    "000 trilijonas",
+                    "{one:0' 't\u016bkstantis few:0' 't\u016bkstan\u010diai many:0' 't\u016bkstan\u010dio other:0' 't\u016bkstan\u010di\u0173}",
+                    "{one:00' 't\u016bkstantis few:00' 't\u016bkstan\u010diai many:00' 't\u016bkstan\u010dio other:00' 't\u016bkstan\u010di\u0173}",
+                    "{one:000' 't\u016bkstantis few:000' 't\u016bkstan\u010diai many:000' 't\u016bkstan\u010dio other:000' 't\u016bkstan\u010di\u0173}",
+                    "{one:0' 'milijonas few:0' 'milijonai many:0' 'milijono other:0' 'milijon\u0173}",
+                    "{one:00' 'milijonas few:00' 'milijonai many:00' 'milijono other:00' 'milijon\u0173}",
+                    "{one:000' 'milijonas few:000' 'milijonai many:000' 'milijono other:000' 'milijon\u0173}",
+                    "{one:0' 'milijardas few:0' 'milijardai many:0' 'milijardo other:0' 'milijard\u0173}",
+                    "{one:00' 'milijardas few:00' 'milijardai many:00' 'milijardo other:00' 'milijard\u0173}",
+                    "{one:000' 'milijardas few:000' 'milijardai many:000' 'milijardo other:000' 'milijard\u0173}",
+                    "{one:0' 'trilijonas few:0' 'trilijonai many:0' 'trilijono other:0' 'trilijon\u0173}",
+                    "{one:00' 'trilijonas few:00' 'trilijonai many:00' 'trilijono other:00' 'trilijon\u0173}",
+                    "{one:000' 'trilijonas few:000' 'trilijonai many:000' 'trilijono other:000' 'trilijon\u0173}",
                 }
             },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -388,18 +385,18 @@ public class FormatData_lt extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0t\u016bkst'.'",
-                    "00\u00a0t\u016bkst'.'",
-                    "000\u00a0t\u016bkst'.'",
-                    "0\u00a0mln'.'",
-                    "00\u00a0mln'.'",
-                    "000\u00a0mln'.'",
-                    "0\u00a0mlrd'.'",
-                    "00\u00a0mlrd'.'",
-                    "000\u00a0mlrd'.'",
-                    "0\u00a0trln'.'",
-                    "00\u00a0trln'.'",
-                    "000\u00a0trln'.'",
+                    "{one:0\u00a0t\u016bkst'.' few:0\u00a0t\u016bkst'.' many:0\u00a0t\u016bkst'.' other:0\u00a0t\u016bkst'.'}",
+                    "{one:00\u00a0t\u016bkst'.' few:00\u00a0t\u016bkst'.' many:00\u00a0t\u016bkst'.' other:00\u00a0t\u016bkst'.'}",
+                    "{one:000\u00a0t\u016bkst'.' few:000\u00a0t\u016bkst'.' many:000\u00a0t\u016bkst'.' other:000\u00a0t\u016bkst'.'}",
+                    "{one:0\u00a0mln'.' few:0\u00a0mln'.' many:0\u00a0mln'.' other:0\u00a0mln'.'}",
+                    "{one:00\u00a0mln'.' few:00\u00a0mln'.' many:00\u00a0mln'.' other:00\u00a0mln'.'}",
+                    "{one:000\u00a0mln'.' few:000\u00a0mln'.' many:000\u00a0mln'.' other:000\u00a0mln'.'}",
+                    "{one:0\u00a0mlrd'.' few:0\u00a0mlrd'.' many:0\u00a0mlrd'.' other:0\u00a0mlrd'.'}",
+                    "{one:00\u00a0mlrd'.' few:00\u00a0mlrd'.' many:00\u00a0mlrd'.' other:00\u00a0mlrd'.'}",
+                    "{one:000\u00a0mlrd'.' few:000\u00a0mlrd'.' many:000\u00a0mlrd'.' other:000\u00a0mlrd'.'}",
+                    "{one:0\u00a0trln'.' few:0\u00a0trln'.' many:0\u00a0trln'.' other:0\u00a0trln'.'}",
+                    "{one:00\u00a0trln'.' few:00\u00a0trln'.' many:00\u00a0trln'.' other:00\u00a0trln'.'}",
+                    "{one:000\u00a0trln'.' few:000\u00a0trln'.' many:000\u00a0trln'.' other:000\u00a0trln'.'}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -437,6 +434,14 @@ public class FormatData_lt extends ListResourceBundle {
                     "",
                 }
             },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0\u00a0%",
+                    "#,##0.00\u00a0\u00a4",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
