@@ -280,6 +280,8 @@ public class FormatData_lv extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NS",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -316,13 +318,6 @@ public class FormatData_lv extends ListResourceBundle {
             { "field.second", "sekundes" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "isl\u0101ma kalend\u0101rs" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
@@ -336,18 +331,18 @@ public class FormatData_lv extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 t\u016bkstotis",
-                    "00 t\u016bkstotis",
-                    "000 t\u016bkstotis",
-                    "0 miljons",
-                    "00 miljons",
-                    "000 miljons",
-                    "0 miljards",
-                    "00 miljards",
-                    "000 miljards",
-                    "0 triljons",
-                    "00 triljons",
-                    "000 triljons",
+                    "{zero:0' 't\u016bksto\u0161u one:0' 't\u016bkstotis other:0' 't\u016bksto\u0161i}",
+                    "{zero:00' 't\u016bksto\u0161i one:00' 't\u016bkstotis other:00' 't\u016bksto\u0161i}",
+                    "{zero:000' 't\u016bksto\u0161i one:000' 't\u016bkstotis other:000' 't\u016bksto\u0161i}",
+                    "{zero:0' 'miljonu one:0' 'miljons other:0' 'miljoni}",
+                    "{zero:00' 'miljoni one:00' 'miljons other:00' 'miljoni}",
+                    "{zero:000' 'miljoni one:000' 'miljons other:000' 'miljoni}",
+                    "{zero:0' 'miljardu one:0' 'miljards other:0' 'miljardi}",
+                    "{zero:00' 'miljardi one:00' 'miljards other:00' 'miljardi}",
+                    "{zero:000' 'miljardi one:000' 'miljards other:000' 'miljardi}",
+                    "{zero:0' 'triljonu one:0' 'triljons other:0' 'triljoni}",
+                    "{zero:00' 'triljoni one:00' 'triljons other:00' 'triljoni}",
+                    "{zero:000' 'triljoni one:000' 'triljons other:000' 'triljoni}",
                 }
             },
             { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
@@ -401,18 +396,18 @@ public class FormatData_lv extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0t\u016bkst'.'",
-                    "00\u00a0t\u016bkst'.'",
-                    "000\u00a0t\u016bkst'.'",
-                    "0\u00a0milj'.'",
-                    "00\u00a0milj'.'",
-                    "000\u00a0milj'.'",
-                    "0\u00a0mljrd'.'",
-                    "00\u00a0mljrd'.'",
-                    "000\u00a0mljrd'.'",
-                    "0\u00a0trilj'.'",
-                    "00\u00a0trilj'.'",
-                    "000\u00a0trilj'.'",
+                    "{zero:0\u00a0t\u016bkst'.' one:0\u00a0t\u016bkst'.' other:0\u00a0t\u016bkst'.'}",
+                    "{zero:00\u00a0t\u016bkst'.' one:00\u00a0t\u016bkst'.' other:00\u00a0t\u016bkst'.'}",
+                    "{zero:000\u00a0t\u016bkst'.' one:000\u00a0t\u016bkst'.' other:000\u00a0t\u016bkst'.'}",
+                    "{zero:0\u00a0milj'.' one:0\u00a0milj'.' other:0\u00a0milj'.'}",
+                    "{zero:00\u00a0milj'.' one:00\u00a0milj'.' other:00\u00a0milj'.'}",
+                    "{zero:000\u00a0milj'.' one:000\u00a0milj'.' other:000\u00a0milj'.'}",
+                    "{zero:0\u00a0mljrd'.' one:0\u00a0mljrd'.' other:0\u00a0mljrd'.'}",
+                    "{zero:00\u00a0mljrd'.' one:00\u00a0mljrd'.' other:00\u00a0mljrd'.'}",
+                    "{zero:000\u00a0mljrd'.' one:000\u00a0mljrd'.' other:000\u00a0mljrd'.'}",
+                    "{zero:0\u00a0trilj'.' one:0\u00a0trilj'.' other:0\u00a0trilj'.'}",
+                    "{zero:00\u00a0trilj'.' one:00\u00a0trilj'.' other:00\u00a0trilj'.'}",
+                    "{zero:000\u00a0trilj'.' one:000\u00a0trilj'.' other:000\u00a0trilj'.'}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -443,6 +438,14 @@ public class FormatData_lv extends ListResourceBundle {
             { "field.hour", "stundas" },
             { "calendarname.buddhist", "budistu kalend\u0101rs" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0%",
+                    "#,##0.00\u00a0\u00a4",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
