@@ -236,6 +236,7 @@ public class FormatData_mk extends ListResourceBundle {
                     "\u043e\u0434 \u043d\u0430\u0448\u0430\u0442\u0430 \u0435\u0440\u0430",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -261,6 +262,8 @@ public class FormatData_mk extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -288,6 +291,7 @@ public class FormatData_mk extends ListResourceBundle {
                     "",
                 }
             },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "\u041c\u0438\u043d\u0433\u0443\u043e-\u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -296,13 +300,6 @@ public class FormatData_mk extends ListResourceBundle {
             { "field.second", "\u0441\u0435\u043a\u0443\u043d\u0434\u0430" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u0418\u0441\u043b\u0430\u043c\u0441\u043a\u0438 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
@@ -316,18 +313,18 @@ public class FormatData_mk extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 \u0438\u043b\u0458\u0430\u0434\u0430",
-                    "00 \u0438\u043b\u0458\u0430\u0434\u0430",
-                    "000 \u0438\u043b\u0458\u0430\u0434\u0430",
-                    "0 \u043c\u0438\u043b\u0438\u043e\u043d",
-                    "00 \u043c\u0438\u043b\u0438\u043e\u043d",
-                    "000 \u043c\u0438\u043b\u0438\u043e\u043d",
-                    "0 \u043c\u0438\u043b\u0438\u0458\u0430\u0440\u0434\u0430",
-                    "00 \u043c\u0438\u043b\u0438\u0458\u0430\u0440\u0434\u0430",
-                    "000 \u043c\u0438\u043b\u0438\u0458\u0430\u0440\u0434\u0430",
-                    "0 \u0431\u0438\u043b\u0438\u043e\u043d",
-                    "00 \u0431\u0438\u043b\u0438\u043e\u043d",
-                    "000 \u0431\u0438\u043b\u0438\u043e\u043d",
+                    "{one:0' '\u0438\u043b\u0458\u0430\u0434\u0430 other:0' '\u0438\u043b\u0458\u0430\u0434\u0438}",
+                    "{one:00' '\u0438\u043b\u0458\u0430\u0434\u0430 other:00' '\u0438\u043b\u0458\u0430\u0434\u0438}",
+                    "{one:000' '\u0438\u043b\u0458\u0430\u0434\u0430 other:000' '\u0438\u043b\u0458\u0430\u0434\u0438}",
+                    "{one:0' '\u043c\u0438\u043b\u0438\u043e\u043d other:0' '\u043c\u0438\u043b\u0438\u043e\u043d\u0438}",
+                    "{one:00' '\u043c\u0438\u043b\u0438\u043e\u043d other:00' '\u043c\u0438\u043b\u0438\u043e\u043d\u0438}",
+                    "{one:000' '\u043c\u0438\u043b\u0438\u043e\u043d other:000' '\u043c\u0438\u043b\u0438\u043e\u043d\u0438}",
+                    "{one:0' '\u043c\u0438\u043b\u0438\u0458\u0430\u0440\u0434\u0430 other:0' '\u043c\u0438\u043b\u0438\u0458\u0430\u0440\u0434\u0438}",
+                    "{one:00' '\u043c\u0438\u043b\u0438\u0458\u0430\u0440\u0434\u0430 other:00' '\u043c\u0438\u043b\u0438\u0458\u0430\u0440\u0434\u0438}",
+                    "{one:000' '\u043c\u0438\u043b\u0438\u0458\u0430\u0440\u0434\u0430 other:000' '\u043c\u0438\u043b\u0438\u0458\u0430\u0440\u0434\u0438}",
+                    "{one:0' '\u0431\u0438\u043b\u0438\u043e\u043d other:0' '\u0431\u0438\u043b\u0438\u043e\u043d\u0438}",
+                    "{one:00' '\u0431\u0438\u043b\u0438\u043e\u043d other:00' '\u0431\u0438\u043b\u0438\u043e\u043d\u0438}",
+                    "{one:000' '\u0431\u0438\u043b\u0438\u043e\u043d other:000' '\u0431\u0438\u043b\u0438\u043e\u043d\u0438}",
                 }
             },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -374,27 +371,27 @@ public class FormatData_mk extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0\u0438\u043b\u0458'.'",
-                    "00\u00a0\u0438\u043b\u0458'.'",
-                    "000\u00a0\u0438\u043b\u0458'.'",
-                    "0\u00a0\u043c\u0438\u043b'.'",
-                    "00\u00a0\u043c\u0438\u043b'.'",
-                    "000\u00a0\u041c",
-                    "0\u00a0\u043c\u0438\u043b\u0458'.'",
-                    "00\u00a0\u043c\u0438\u043b\u0458'.'",
-                    "000\u00a0\u043c\u0458'.'",
-                    "0\u00a0\u0431\u0438\u043b'.'",
-                    "00\u00a0\u0431\u0438\u043b'.'",
-                    "000\u00a0\u0431\u0438\u043b'.'",
+                    "{one:0\u00a0\u0438\u043b\u0458'.' other:0\u00a0\u0438\u043b\u0458'.'}",
+                    "{one:00\u00a0\u0438\u043b\u0458'.' other:00\u00a0\u0438\u043b\u0458'.'}",
+                    "{one:000\u00a0\u0438\u043b\u0458'.' other:000\u00a0\u0438\u043b\u0458'.'}",
+                    "{one:0\u00a0\u043c\u0438\u043b'.' other:0\u00a0\u043c\u0438\u043b'.'}",
+                    "{one:00\u00a0\u043c\u0438\u043b'.' other:00\u00a0\u043c\u0438\u043b'.'}",
+                    "{one:000\u00a0\u041c other:000\u00a0\u041c}",
+                    "{one:0\u00a0\u043c\u0438\u043b\u0458'.' other:0\u00a0\u043c\u0438\u043b\u0458'.'}",
+                    "{one:00\u00a0\u043c\u0438\u043b\u0458'.' other:00\u00a0\u043c\u0438\u043b\u0458'.'}",
+                    "{one:000\u00a0\u043c\u0458'.' other:000\u00a0\u043c\u0438'.'}",
+                    "{one:0\u00a0\u0431\u0438\u043b'.' other:0\u00a0\u0431\u0438\u043b'.'}",
+                    "{one:00\u00a0\u0431\u0438\u043b'.' other:00\u00a0\u0431\u0438\u043b'.'}",
+                    "{one:000\u00a0\u0431\u0438\u043b'.' other:000\u00a0\u0431\u0438\u043b'.'}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
             { "DatePatterns",
                 new String[] {
-                    "EEEE, dd MMMM y",
-                    "dd MMMM y",
-                    "dd.M.y",
-                    "dd.M.yy",
+                    "EEEE, d MMMM y",
+                    "d MMMM y",
+                    "d.M.y",
+                    "d.M.yy",
                 }
             },
             { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
@@ -421,6 +418,14 @@ public class FormatData_mk extends ListResourceBundle {
             },
             { "calendarname.buddhist", "\u0411\u0443\u0434\u0438\u0441\u0442\u0438\u0447\u043a\u0438 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0\u00a0%",
+                    "#,##0.00\u00a0\u00a4",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
