@@ -270,6 +270,8 @@ public class FormatData_mr extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -313,6 +315,8 @@ public class FormatData_mr extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -339,13 +343,6 @@ public class FormatData_mr extends ListResourceBundle {
             },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##,##0.###",
-                    "\u00a4#,##0.00",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u092e\u0941\u0938\u094d\u0932\u093f\u092e \u0926\u093f\u0928\u0926\u0930\u094d\u0936\u093f\u0915\u093e" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
@@ -359,18 +356,18 @@ public class FormatData_mr extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 \u0939\u091c\u093e\u0930",
-                    "00 \u0939\u091c\u093e\u0930",
-                    "0 \u0932\u093e\u0916",
-                    "00 \u0932\u093e\u0916",
-                    "0 \u0915\u094b\u091f\u0940",
-                    "00 \u0915\u094b\u091f\u0940",
-                    "0 \u0905\u092c\u094d\u091c",
-                    "00 \u0905\u092c\u094d\u091c",
-                    "0 \u0916\u0930\u094d\u0935",
-                    "00 \u0916\u0930\u094d\u0935",
-                    "0 \u092a\u0926\u094d\u092e",
-                    "00 \u092a\u0926\u094d\u092e",
+                    "{one:0' '\u0939\u091c\u093e\u0930 other:0' '\u0939\u091c\u093e\u0930}",
+                    "{one:00' '\u0939\u091c\u093e\u0930 other:00' '\u0939\u091c\u093e\u0930}",
+                    "{one:0' '\u0932\u093e\u0916 other:0' '\u0932\u093e\u0916}",
+                    "{one:00' '\u0932\u093e\u0916 other:00' '\u0932\u093e\u0916}",
+                    "{one:0' '\u0915\u094b\u091f\u0940 other:0' '\u0915\u094b\u091f\u0940}",
+                    "{one:00' '\u0915\u094b\u091f\u0940 other:00' '\u0915\u094b\u091f\u0940}",
+                    "{one:0' '\u0905\u092c\u094d\u091c other:0' '\u0905\u092c\u094d\u091c}",
+                    "{one:00' '\u0905\u092c\u094d\u091c other:00' '\u0905\u092c\u094d\u091c}",
+                    "{one:0' '\u0916\u0930\u094d\u0935 other:0' '\u0916\u0930\u094d\u0935}",
+                    "{one:00' '\u0916\u0930\u094d\u0935 other:00' '\u0916\u0930\u094d\u0935}",
+                    "{one:0' '\u092a\u0926\u094d\u092e other:0' '\u092a\u0926\u094d\u092e}",
+                    "{one:00' '\u092a\u0926\u094d\u092e other:00' '\u092a\u0926\u094d\u092e}",
                 }
             },
             { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
@@ -425,18 +422,18 @@ public class FormatData_mr extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0\u0939",
-                    "00\u00a0\u0939",
-                    "0\u00a0\u0932\u093e\u0916",
-                    "00\u00a0\u0932\u093e\u0916",
-                    "0\u00a0\u0915\u094b\u091f\u0940",
-                    "00\u00a0\u0915\u094b\u091f\u0940",
-                    "0\u00a0\u0905\u092c\u094d\u091c",
-                    "00\u00a0\u0905\u092c\u094d\u091c",
-                    "0\u00a0\u0916\u0930\u094d\u0935",
-                    "00\u00a0\u0916\u0930\u094d\u0935",
-                    "0\u00a0\u092a\u0926\u094d\u092e",
-                    "00\u00a0\u092a\u0926\u094d\u092e",
+                    "{one:0\u00a0\u0939 other:0\u00a0\u0939}",
+                    "{one:00\u00a0\u0939 other:00\u00a0\u0939}",
+                    "{one:0\u00a0\u0932\u093e\u0916 other:0\u00a0\u0932\u093e\u0916}",
+                    "{one:00\u00a0\u0932\u093e\u0916 other:00\u00a0\u0932\u093e\u0916}",
+                    "{one:0\u00a0\u0915\u094b\u091f\u0940 other:0\u00a0\u0915\u094b\u091f\u0940}",
+                    "{one:00\u00a0\u0915\u094b\u091f\u0940 other:00\u00a0\u0915\u094b\u091f\u0940}",
+                    "{one:0\u00a0\u0905\u092c\u094d\u091c other:0\u00a0\u0905\u092c\u094d\u091c}",
+                    "{one:00\u00a0\u0905\u092c\u094d\u091c other:00\u00a0\u0905\u092c\u094d\u091c}",
+                    "{one:0\u00a0\u0916\u0930\u094d\u0935 other:0\u00a0\u0916\u0930\u094d\u0935}",
+                    "{one:00\u00a0\u0916\u0930\u094d\u0935 other:00\u00a0\u0916\u0930\u094d\u0935}",
+                    "{one:0\u00a0\u092a\u0926\u094d\u092e other:0\u00a0\u092a\u0926\u094d\u092e}",
+                    "{one:00\u00a0\u092a\u0926\u094d\u092e other:00\u00a0\u092a\u0926\u094d\u092e}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -475,12 +472,28 @@ public class FormatData_mr extends ListResourceBundle {
             { "islamic.narrow.Eras", metaValue_java_time_islamic_Eras },
             { "calendarname.buddhist", "\u092c\u094c\u0926\u094d\u0927 \u0926\u093f\u0928\u0926\u0930\u094d\u0936\u093f\u0915\u093e" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##,##0.###",
+                    "\u00a4#,##0.00",
+                    "#,##0%",
+                    "\u00a4#,##0.00;(\u00a4#,##0.00)",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
             { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "deva.NumberPatterns",
+                new String[] {
+                    "#,##,##0.###",
+                    "\u00a4#,##0.00",
+                    "#,##0%",
+                    "",
+                }
+            },
             { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
