@@ -178,6 +178,10 @@ public class FormatData_ms extends ListResourceBundle {
                "3",
                "4",
             };
+        final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
+               "BC",
+               "BE",
+            };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
                "EEEE, d MMMM y G",
                "d MMMM y G",
@@ -192,15 +196,15 @@ public class FormatData_ms extends ListResourceBundle {
             };
         final String[] metaValue_java_time_roc_long_Eras = new String[] {
                "Sebelum R.O.C",
-               "",
-            };
-        final String[] metaValue_java_time_roc_Eras = new String[] {
-               "Before R.O.C.",
-               "",
+               "R.O.C.",
             };
         final String[] metaValue_java_time_roc_narrow_Eras = new String[] {
                "Sblm R.O.C",
+               "R.O.C.",
+            };
+        final String[] metaValue_java_time_islamic_long_Eras = new String[] {
                "",
+               "AH",
             };
         final String metaValue_calendarname_gregorian = "Kalendar Gregory";
         final Object[][] data = new Object[][] {
@@ -208,6 +212,7 @@ public class FormatData_ms extends ListResourceBundle {
             { "field.year", "tahun" },
             { "calendarname.islamic-umalqura", "Kalendar Islam (Umm Al-Quran)" },
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
+            { "buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -225,7 +230,9 @@ public class FormatData_ms extends ListResourceBundle {
             { "japanese.MonthNames", metaValue_MonthNames },
             { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "java.time.islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "long.Eras", metaValue_long_Eras },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -251,6 +258,8 @@ public class FormatData_ms extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -261,21 +270,15 @@ public class FormatData_ms extends ListResourceBundle {
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "PG/PTG" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "Kalendar Minguo" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "field.month", "bulan" },
-            { "roc.Eras", metaValue_java_time_roc_Eras },
             { "field.second", "saat" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "\u00a4#,##0.00",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "Kalendar Islam" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
@@ -289,18 +292,18 @@ public class FormatData_ms extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 ribu",
-                    "00 ribu",
-                    "000 ribu",
-                    "0 juta",
-                    "00 juta",
-                    "000 juta",
-                    "0 bilion",
-                    "00 bilion",
-                    "000 bilion",
-                    "0 trilion",
-                    "00 trilion",
-                    "000 trilion",
+                    "{other:0' 'ribu}",
+                    "{other:00' 'ribu}",
+                    "{other:000' 'ribu}",
+                    "{other:0' 'juta}",
+                    "{other:00' 'juta}",
+                    "{other:000' 'juta}",
+                    "{other:0' 'bilion}",
+                    "{other:00' 'bilion}",
+                    "{other:000' 'bilion}",
+                    "{other:0' 'trilion}",
+                    "{other:00' 'trilion}",
+                    "{other:000' 'trilion}",
                 }
             },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -310,10 +313,17 @@ public class FormatData_ms extends ListResourceBundle {
             { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.DayNarrows", metaValue_DayNarrows },
+            { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
+            { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
-            { "java.time.roc.Eras", metaValue_java_time_roc_Eras },
+            { "java.time.roc.Eras",
+                new String[] {
+                    "Before R.O.C.",
+                    "R.O.C.",
+                }
+            },
             { "field.zone", "zon waktu" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.narrow.Eras", metaValue_java_time_roc_narrow_Eras },
@@ -327,13 +337,17 @@ public class FormatData_ms extends ListResourceBundle {
             { "field.weekday", "Hari dalam Minggu" },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
+            { "islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
+            { "java.time.islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.QuarterNames", metaValue_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "java.time.buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "japanese.DayNames", metaValue_DayNames },
             { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNames", metaValue_DayNames },
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.MonthNames", metaValue_MonthNames },
+            { "buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "field.week", "minggu" },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
@@ -347,21 +361,22 @@ public class FormatData_ms extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0K",
-                    "00K",
-                    "000K",
-                    "0J",
-                    "00J",
-                    "000J",
-                    "0B",
-                    "00B",
-                    "000B",
-                    "0T",
-                    "00T",
-                    "000T",
+                    "{other:0K}",
+                    "{other:00K}",
+                    "{other:000K}",
+                    "{other:0J}",
+                    "{other:00J}",
+                    "{other:000J}",
+                    "{other:0B}",
+                    "{other:00B}",
+                    "{other:000B}",
+                    "{other:0T}",
+                    "{other:00T}",
+                    "{other:000T}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
+            { "java.time.buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "timezone.regionFormat.daylight", "Waktu Siang {0}" },
             { "DatePatterns",
                 new String[] {
@@ -376,9 +391,19 @@ public class FormatData_ms extends ListResourceBundle {
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.DayNames", metaValue_DayNames },
             { "field.hour", "jam" },
+            { "islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "calendarname.buddhist", "Kalendar Buddha" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "\u00a4#,##0.00",
+                    "#,##0%",
+                    "\u00a4#,##0.00;(\u00a4#,##0.00)",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
+            { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
