@@ -195,6 +195,8 @@ public class FormatData_my extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "\u1002\u100f\u1014\u103a\u1038\u1019\u101f\u102f\u1010\u103a\u101e\u1031\u102c",
+                    "",
+                    "",
                 }
             },
             { "japanese.TimePatterns", metaValue_TimePatterns },
@@ -239,6 +241,8 @@ public class FormatData_my extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "\u1002\u100f\u1014\u103a\u1038\u1019\u101f\u102f\u1010\u103a\u101e\u1031\u102c",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -257,13 +261,6 @@ public class FormatData_my extends ListResourceBundle {
             { "field.second", "\u1005\u1000\u1039\u1000\u1014\u1037\u103a" },
             { "DayAbbreviations", metaValue_DayNames },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u1021\u1005\u1039\u1005\u101c\u102c\u1019\u103a \u1015\u103c\u1000\u1039\u1001\u1012\u102d\u1014\u103a" },
             { "japanese.narrow.AmPmMarkers", metaValue_AmPmMarkers },
@@ -275,18 +272,18 @@ public class FormatData_my extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u1011\u1031\u102c\u1004\u103a",
-                    "0\u101e\u1031\u102c\u1004\u103a\u1038",
-                    "0\u101e\u102d\u1014\u103a\u1038",
-                    "0\u101e\u1014\u103a\u1038",
-                    "0\u1000\u102f\u100b\u1031",
-                    "00\u1000\u102f\u100b\u1031",
-                    "\u1000\u102f\u100b\u1031000",
-                    "\u1000\u102f\u100b\u10310000",
-                    "\u1000\u102f\u100b\u10310\u101e\u1031\u102c\u1004\u103a\u1038",
-                    "\u1000\u102f\u100b\u10310\u101e\u102d\u1014\u103a\u1038",
-                    "\u1000\u102f\u100b\u10310\u101e\u1014\u103a\u1038",
-                    "0\u1000\u1031\u102c\u100b\u102d",
+                    "{other:0\u1011\u1031\u102c\u1004\u103a}",
+                    "{other:0\u101e\u1031\u102c\u1004\u103a\u1038}",
+                    "{other:0\u101e\u102d\u1014\u103a\u1038}",
+                    "{other:0\u101e\u1014\u103a\u1038}",
+                    "{other:0\u1000\u102f\u100b\u1031}",
+                    "{other:00\u1000\u102f\u100b\u1031}",
+                    "{other:\u1000\u102f\u100b\u1031000}",
+                    "{other:\u1000\u102f\u100b\u10310000}",
+                    "{other:\u1000\u102f\u100b\u10310\u101e\u1031\u102c\u1004\u103a\u1038}",
+                    "{other:\u1000\u102f\u100b\u10310\u101e\u102d\u1014\u103a\u1038}",
+                    "{other:\u1000\u102f\u100b\u10310\u101e\u1014\u103a\u1038}",
+                    "{other:0\u1000\u1031\u102c\u100b\u102d}",
                 }
             },
             { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
@@ -315,6 +312,14 @@ public class FormatData_my extends ListResourceBundle {
             { "islamic.DayAbbreviations", metaValue_DayNames },
             { "japanese.QuarterNames", metaValue_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_QuarterNames },
+            { "mymr.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0%",
+                    "",
+                }
+            },
             { "japanese.DayNames", metaValue_DayNames },
             { "japanese.DayAbbreviations", metaValue_DayNames },
             { "DayNames", metaValue_DayNames },
@@ -333,18 +338,18 @@ public class FormatData_my extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u1011\u1031\u102c\u1004\u103a",
-                    "0\u101e\u1031\u102c\u1004\u103a\u1038",
-                    "0\u101e\u102d\u1014\u103a\u1038",
-                    "0\u101e\u1014\u103a\u1038",
-                    "0\u1000\u102f\u100b\u1031",
-                    "00\u1000\u102f\u100b\u1031",
-                    "\u1000\u102f\u100b\u1031000",
-                    "\u1000\u102f\u100b\u10310\u1011",
-                    "\u1000\u102f\u100b\u10310\u101e",
-                    "\u100b\u10310\u101e\u102d\u1014\u103a\u1038",
-                    "\u100b\u10310\u101e\u1014\u103a\u1038",
-                    "0\u1000\u1031\u102c\u100b\u102d",
+                    "{other:0\u1011\u1031\u102c\u1004\u103a}",
+                    "{other:0\u101e\u1031\u102c\u1004\u103a\u1038}",
+                    "{other:0\u101e\u102d\u1014\u103a\u1038}",
+                    "{other:0\u101e\u1014\u103a\u1038}",
+                    "{other:0\u1000\u102f\u100b\u1031}",
+                    "{other:00\u1000\u102f\u100b\u1031}",
+                    "{other:\u1000\u102f\u100b\u1031000}",
+                    "{other:\u1000\u102f\u100b\u10310\u1011}",
+                    "{other:\u1000\u102f\u100b\u10310\u101e}",
+                    "{other:\u100b\u10310\u101e\u102d\u1014\u103a\u1038}",
+                    "{other:\u100b\u10310\u101e\u1014\u103a\u1038}",
+                    "{other:0\u1000\u1031\u102c\u100b\u102d}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -364,6 +369,14 @@ public class FormatData_my extends ListResourceBundle {
             { "field.hour", "\u1014\u102c\u101b\u102e" },
             { "calendarname.buddhist", "\u1017\u102f\u1012\u1039\u1013 \u1015\u103c\u1000\u1039\u1001\u1012\u102d\u1014\u103a" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0%",
+                    "\u00a4\u00a0#,##0.00",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
