@@ -214,6 +214,8 @@ public class FormatData_ne extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -256,6 +258,8 @@ public class FormatData_ne extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "roc.QuarterAbbreviations", metaValue_QuarterNames },
@@ -263,13 +267,6 @@ public class FormatData_ne extends ListResourceBundle {
             { "field.second", "\u0938\u0947\u0915\u0947\u0928\u094d\u0921" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "\u00a4\u00a0#,##0.00",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u0907\u0938\u094d\u0932\u093e\u092e\u0940 \u092a\u093e\u0924\u094d\u0930\u094b" },
             { "japanese.narrow.AmPmMarkers", metaValue_AmPmMarkers },
@@ -281,18 +278,18 @@ public class FormatData_ne extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 \u0939\u091c\u093e\u0930",
-                    "00 \u0939\u091c\u093e\u0930",
-                    "0 \u0932\u093e\u0916",
-                    "0 \u0915\u0930\u094b\u0921",
-                    "00 \u0915\u0930\u094b\u0921",
-                    "000 \u0915\u0930\u094b\u0921",
-                    "0 \u0905\u0930\u092c",
-                    "00 \u0905\u0930\u092c",
-                    "000 \u0905\u0930\u092c",
-                    "00 \u0916\u0930\u092c",
-                    "0 \u0936\u0902\u0916",
-                    "00 \u0936\u0902\u0916",
+                    "{one:0' '\u0939\u091c\u093e\u0930 other:0' '\u0939\u091c\u093e\u0930}",
+                    "{one:00' '\u0939\u091c\u093e\u0930 other:00' '\u0939\u091c\u093e\u0930}",
+                    "{one:0' '\u0932\u093e\u0916 other:0' '\u0932\u093e\u0916}",
+                    "{one:0' '\u0915\u0930\u094b\u0921 other:0' '\u0915\u0930\u094b\u0921}",
+                    "{one:00' '\u0915\u0930\u094b\u0921 other:00' '\u0915\u0930\u094b\u0921}",
+                    "{one:000' '\u0915\u0930\u094b\u0921 other:000' '\u0915\u0930\u094b\u0921}",
+                    "{one:0' '\u0905\u0930\u092c other:0' '\u0905\u0930\u092c}",
+                    "{one:00' '\u0905\u0930\u092c other:00' '\u0905\u0930\u092c}",
+                    "{one:000' '\u0905\u0930\u092c other:000' '\u0905\u0930\u092c}",
+                    "{one:00' '\u0916\u0930\u092c other:00' '\u0916\u0930\u092c}",
+                    "{one:0' '\u0936\u0902\u0916 other:0' '\u0936\u0902\u0916}",
+                    "{one:00' '\u0936\u0902\u0916 other:00' '\u0936\u0902\u0916}",
                 }
             },
             { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
@@ -339,18 +336,18 @@ public class FormatData_ne extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0\u0939\u091c\u093e\u0930",
-                    "00\u00a0\u0939\u091c\u093e\u0930",
-                    "0\u00a0\u0932\u093e\u0916",
-                    "00\u00a0\u0932\u093e\u0916",
-                    "0\u00a0\u0915\u0930\u094b\u0921",
-                    "00\u00a0\u0915\u0930\u094b\u0921",
-                    "0\u00a0\u0905\u0930\u092c",
-                    "00\u00a0\u0905\u0930\u092c",
-                    "0\u00a0\u0916\u0930\u092c",
-                    "00\u00a0\u0916\u0930\u092c",
-                    "0\u00a0\u0936\u0902\u0916",
-                    "00\u00a0\u0936\u0902\u0916",
+                    "{one:0\u00a0\u0939\u091c\u093e\u0930 other:0\u00a0\u0939\u091c\u093e\u0930}",
+                    "{one:00\u00a0\u0939\u091c\u093e\u0930 other:00\u00a0\u0939\u091c\u093e\u0930}",
+                    "{one:0\u00a0\u0932\u093e\u0916 other:0\u00a0\u0932\u093e\u0916}",
+                    "{one:00\u00a0\u0932\u093e\u0916 other:00\u00a0\u0932\u093e\u0916}",
+                    "{one:0\u00a0\u0915\u0930\u094b\u0921 other:0\u00a0\u0915\u0930\u094b\u0921}",
+                    "{one:00\u00a0\u0915\u0930\u094b\u0921 other:00\u00a0\u0915\u0930\u094b\u0921}",
+                    "{one:0\u00a0\u0905\u0930\u092c other:0\u00a0\u0905\u0930\u092c}",
+                    "{one:00\u00a0\u0905\u0930\u092c other:00\u00a0\u0905\u0930\u092c}",
+                    "{one:0\u00a0\u0916\u0930\u092c other:0\u00a0\u0916\u0930\u092c}",
+                    "{one:00\u00a0\u0916\u0930\u092c other:00\u00a0\u0916\u0930\u092c}",
+                    "{one:0\u00a0\u0936\u0902\u0916 other:0\u00a0\u0936\u0902\u0916}",
+                    "{one:00\u00a0\u0936\u0902\u0916 other:00\u00a0\u0936\u0902\u0916}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -370,11 +367,27 @@ public class FormatData_ne extends ListResourceBundle {
             { "field.hour", "\u0918\u0923\u094d\u091f\u093e" },
             { "calendarname.buddhist", "\u092c\u0941\u0926\u094d\u0927\u093f\u0937\u094d\u091f \u092a\u093e\u0924\u094d\u0930\u094b" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##,##0.###",
+                    "\u00a4\u00a0#,##,##0.00",
+                    "#,##,##0%",
+                    "\u00a4\u00a0#,##,##0.00",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
             { "QuarterAbbreviations", metaValue_QuarterNames },
+            { "deva.NumberPatterns",
+                new String[] {
+                    "#,##,##0.###",
+                    "\u00a4\u00a0#,##,##0.00",
+                    "#,##,##0%",
+                    "",
+                }
+            },
             { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
