@@ -153,6 +153,10 @@ public class FormatData_or extends ListResourceBundle {
                "3",
                "4",
             };
+        final String[] metaValue_buddhist_AmPmMarkers = new String[] {
+               "AM",
+               "PM",
+            };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
                "EEEE, MMMM d, y G",
                "MMMM d, y G",
@@ -165,18 +169,11 @@ public class FormatData_or extends ListResourceBundle {
                "MMM d, y GGGG",
                "M/d/y G",
             };
-        final String[] metaValue_roc_AmPmMarkers = new String[] {
-               "AM",
-               "PM",
-            };
         final String metaValue_calendarname_gregorian = "\u0b17\u0b4d\u0b30\u0b47\u0b17\u0b4b\u0b30\u0b3f\u0b5f \u0b15\u0b4d\u0b5f\u0b3e\u0b32\u0b47\u0b23\u0b4d\u0b21\u0b30\u0b4d";
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
             { "field.year", "\u0b2c\u0b30\u0b4d\u0b37" },
-            { "islamic.QuarterAbbreviations", metaValue_QuarterNames },
-            { "roc.DayAbbreviations", metaValue_DayAbbreviations },
-            { "standalone.DayNarrows", metaValue_DayNarrows },
-            { "islamic.AmPmMarkers", metaValue_roc_AmPmMarkers },
+            { "japanese.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "standalone.QuarterAbbreviations",
                 new String[] {
@@ -187,33 +184,24 @@ public class FormatData_or extends ListResourceBundle {
                 }
             },
             { "roc.QuarterNames", metaValue_QuarterNames },
-            { "TimePatterns", metaValue_TimePatterns },
-            { "islamic.DayNarrows", metaValue_DayNarrows },
-            { "field.zone", "\u0b38\u0b2e\u0b5f \u0b15\u0b4d\u0b37\u0b47\u0b24\u0b4d\u0b30" },
             { "roc.MonthNarrows", metaValue_MonthNarrows },
-            { "japanese.QuarterAbbreviations", metaValue_QuarterNames },
             { "islamic.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
             { "narrow.Eras", metaValue_Eras },
             { "timezone.regionFormat.standard", "{0} \u0b2e\u0b3e\u0b28\u0b3e\u0b19\u0b4d\u0b15 \u0b38\u0b2e\u0b5f" },
             { "calendarname.japanese", "\u0b1c\u0b3e\u0b2a\u0b3e\u0b28\u0b3f\u0b1c\u0b4d\u200c \u0b15\u0b4d\u0b5f\u0b3e\u0b32\u0b47\u0b23\u0b4d\u0b21\u0b30\u0b4d\u200c" },
-            { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
-            { "Eras", metaValue_Eras },
             { "japanese.MonthNames", metaValue_MonthNames },
-            { "roc.DayNames", metaValue_DayNames },
             { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
             { "roc.MonthAbbreviations", metaValue_MonthNames },
-            { "islamic.QuarterNames", metaValue_QuarterNames },
             { "long.Eras",
                 new String[] {
                     "\u0b16\u0b4d\u0b30\u0b40\u0b37\u0b4d\u0b1f\u0b2a\u0b42\u0b30\u0b4d\u0b2c",
                     "\u0b16\u0b4d\u0b30\u0b40\u0b37\u0b4d\u0b1f\u0b3e\u0b2c\u0b4d\u0b26",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
-            { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "buddhist.MonthAbbreviations", metaValue_MonthNames },
-            { "field.weekday", "\u0b38. \u0b30 \u0b26\u0b3f\u0b28" },
             { "buddhist.MonthNames", metaValue_MonthNames },
             { "DateTimePatterns",
                 new String[] {
@@ -237,44 +225,90 @@ public class FormatData_or extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
             { "japanese.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "japanese.MonthAbbreviations", metaValue_MonthNames },
             { "buddhist.DayNames", metaValue_DayNames },
             { "field.minute", "\u0b2e\u0b3f\u0b28\u0b3f\u0b1f\u0b4d" },
             { "field.era", "\u0b2f\u0b41\u0b17" },
-            { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
+            { "buddhist.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "field.dayperiod", "\u0b2a\u0b42\u0b30\u0b4d\u0b2c\u0b3e\u0b39\u0b4d\u0b28/\u0b05\u0b2a\u0b30\u0b3e\u0b39\u0b4d\u0b28" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
-            { "japanese.QuarterNames", metaValue_QuarterNames },
-            { "buddhist.QuarterAbbreviations", metaValue_QuarterNames },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "\u0b2e\u0b3f\u0b19\u0b4d\u0b17\u0b4b\u0b13 \u0b15\u0b4d\u0b5f\u0b3e\u0b32\u0b47\u0b23\u0b4d\u0b21\u0b30\u0b4d\u200c" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterNames },
-            { "japanese.DayNames", metaValue_DayNames },
-            { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
-            { "DayNames", metaValue_DayNames },
             { "field.month", "\u0b2e\u0b3e\u0b38" },
-            { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
             { "field.second", "\u0b38\u0b47\u0b15\u0b47\u0b23\u0b4d\u0b21\u0b4d" },
-            { "roc.MonthNames", metaValue_MonthNames },
-            { "field.week", "\u0b38\u0b2a\u0b4d\u0b24\u0b3e\u0b39" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
+            { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "calendarname.islamic", "\u0b07\u0b38\u0b32\u0b3e\u0b2e\u0b3f\u0b15\u0b4d\u200c \u0b15\u0b4d\u0b5f\u0b3e\u0b32\u0b47\u0b23\u0b4d\u0b21\u0b30\u0b4d\u200c" },
+            { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "buddhist.TimePatterns", metaValue_TimePatterns },
+            { "standalone.MonthAbbreviations", metaValue_MonthNames },
+            { "timezone.regionFormat", "{0} \u0b38\u0b2e\u0b5f" },
+            { "long.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "{one:0' '\u0b39\u0b1c\u0b3e\u0b30 other:0' '\u0b39\u0b1c\u0b3e\u0b30}",
+                    "{one:00' '\u0b39\u0b1c\u0b3e\u0b30 other:00' '\u0b39\u0b1c\u0b3e\u0b30}",
+                    "{one:000' '\u0b39\u0b1c\u0b3e\u0b30 other:000' '\u0b39\u0b1c\u0b3e\u0b30}",
+                    "{one:0' '\u0b28\u0b3f\u0b5f\u0b41\u0b24 other:0' '\u0b28\u0b3f\u0b5f\u0b41\u0b24}",
+                    "{one:00' '\u0b28\u0b3f\u0b5f\u0b41\u0b24 other:00' '\u0b28\u0b3f\u0b5f\u0b41\u0b24}",
+                    "{one:000' '\u0b28\u0b3f\u0b5f\u0b41\u0b24 other:000' '\u0b28\u0b3f\u0b5f\u0b41\u0b24}",
+                    "{one:0' '\u0b36\u0b39\u0b15\u0b4b\u0b1f\u0b3f other:0' '\u0b36\u0b39\u0b15\u0b4b\u0b1f\u0b3f}",
+                    "{one:00' '\u0b36\u0b39\u0b15\u0b4b\u0b1f\u0b3f other:00' '\u0b36\u0b39\u0b15\u0b4b\u0b1f\u0b3f}",
+                    "{one:000' '\u0b36\u0b39\u0b15\u0b4b\u0b1f\u0b3f other:000' '\u0b36\u0b39\u0b15\u0b4b\u0b1f\u0b3f}",
+                    "{one:0' '\u0b32\u0b15\u0b4d\u0b37\u0b15\u0b4b\u0b1f\u0b3f other:0' '\u0b32\u0b15\u0b4d\u0b37\u0b15\u0b4b\u0b1f\u0b3f}",
+                    "{one:00' '\u0b32\u0b15\u0b4d\u0b37\u0b15\u0b4b\u0b1f\u0b3f other:00' '\u0b32\u0b15\u0b4d\u0b37\u0b15\u0b4b\u0b1f\u0b3f}",
+                    "{one:000' '\u0b32\u0b15\u0b4d\u0b37\u0b15\u0b4b\u0b1f\u0b3f other:000' '\u0b32\u0b15\u0b4d\u0b37\u0b15\u0b4b\u0b1f\u0b3f}",
+                }
+            },
+            { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
+            { "standalone.QuarterNames", metaValue_QuarterNames },
+            { "japanese.MonthNarrows", metaValue_MonthNarrows },
+            { "islamic.QuarterAbbreviations", metaValue_QuarterNames },
+            { "roc.DayAbbreviations", metaValue_DayAbbreviations },
+            { "standalone.DayNarrows", metaValue_DayNarrows },
+            { "orya.NumberPatterns",
                 new String[] {
                     "#,##,##0.###",
                     "\u00a4#,##0.00",
                     "#,##0%",
+                    "",
                 }
             },
-            { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "islamic.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
+            { "TimePatterns", metaValue_TimePatterns },
+            { "islamic.DayNarrows", metaValue_DayNarrows },
+            { "field.zone", "\u0b38\u0b2e\u0b5f \u0b15\u0b4d\u0b37\u0b47\u0b24\u0b4d\u0b30" },
+            { "japanese.QuarterAbbreviations", metaValue_QuarterNames },
+            { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "Eras", metaValue_Eras },
+            { "roc.DayNames", metaValue_DayNames },
+            { "islamic.QuarterNames", metaValue_QuarterNames },
+            { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "field.weekday", "\u0b38. \u0b30 \u0b26\u0b3f\u0b28" },
+            { "japanese.MonthAbbreviations", metaValue_MonthNames },
+            { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
+            { "japanese.QuarterNames", metaValue_QuarterNames },
+            { "buddhist.QuarterAbbreviations", metaValue_QuarterNames },
+            { "japanese.DayNames", metaValue_DayNames },
+            { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
+            { "DayNames", metaValue_DayNames },
+            { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "roc.MonthNames", metaValue_MonthNames },
+            { "field.week", "\u0b38\u0b2a\u0b4d\u0b24\u0b3e\u0b39" },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
             { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
-            { "calendarname.islamic", "\u0b07\u0b38\u0b32\u0b3e\u0b2e\u0b3f\u0b15\u0b4d\u200c \u0b15\u0b4d\u0b5f\u0b3e\u0b32\u0b47\u0b23\u0b4d\u0b21\u0b30\u0b4d\u200c" },
             { "roc.DayNarrows", metaValue_DayNarrows },
             { "orya.NumberElements",
                 new String[] {
@@ -289,9 +323,11 @@ public class FormatData_or extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
-            { "roc.AmPmMarkers", metaValue_roc_AmPmMarkers },
+            { "roc.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "short.CompactNumberPatterns",
@@ -299,18 +335,18 @@ public class FormatData_or extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u0b39",
-                    "00\u0b39",
-                    "000\u0b39",
-                    "0\u0b28\u0b3f",
-                    "00\u0b28\u0b3f",
-                    "000\u0b28\u0b3f",
-                    "0\u0b2c\u0b3f",
-                    "00\u0b2c\u0b3f",
-                    "000\u0b2c\u0b3f",
-                    "0\u0b1f\u0b4d\u0b30\u0b3f",
-                    "00\u0b1f\u0b4d\u0b30\u0b3f",
-                    "000\u0b1f\u0b4d\u0b30\u0b3f",
+                    "{one:0\u0b39 other:0\u0b39}",
+                    "{one:00\u0b39 other:00\u0b39}",
+                    "{one:000\u0b39 other:000\u0b39}",
+                    "{one:0\u0b28\u0b3f other:0\u0b28\u0b3f}",
+                    "{one:00\u0b28\u0b3f other:00\u0b28\u0b3f}",
+                    "{one:000\u0b28\u0b3f other:000\u0b28\u0b3f}",
+                    "{one:0\u0b2c\u0b3f other:0\u0b2c\u0b3f}",
+                    "{one:00\u0b2c\u0b3f other:00\u0b2c\u0b3f}",
+                    "{one:000\u0b2c\u0b3f other:000\u0b2c\u0b3f}",
+                    "{one:0\u0b1f\u0b4d\u0b30\u0b3f other:0\u0b1f\u0b4d\u0b30\u0b3f}",
+                    "{one:00\u0b1f\u0b4d\u0b30\u0b3f other:00\u0b1f\u0b4d\u0b30\u0b3f}",
+                    "{one:000\u0b1f\u0b4d\u0b30\u0b3f other:000\u0b1f\u0b4d\u0b30\u0b3f}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -328,40 +364,21 @@ public class FormatData_or extends ListResourceBundle {
             { "MonthAbbreviations", metaValue_MonthNames },
             { "standalone.DayNames", metaValue_DayNames },
             { "field.hour", "\u0b18\u0b23\u0b4d\u0b1f\u0b3e" },
-            { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
-            { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "calendarname.buddhist", "\u0b2c\u0b4c\u0b26\u0b4d\u0b27\u0b27\u0b30\u0b4d\u0b2e\u0b3e\u0b32\u0b2e\u0b4d\u0b2c\u0b40\u0b19\u0b4d\u0b15 \u0b15\u0b4d\u0b5f\u0b3e\u0b32\u0b47\u0b23\u0b4d\u0b21\u0b30\u0b4d\u200c" },
             { "standalone.MonthNames", metaValue_MonthNames },
-            { "standalone.MonthAbbreviations", metaValue_MonthNames },
-            { "timezone.regionFormat", "{0} \u0b38\u0b2e\u0b5f" },
-            { "long.CompactNumberPatterns",
+            { "latn.NumberPatterns",
                 new String[] {
-                    "",
-                    "",
-                    "",
-                    "0 \u0b39\u0b1c\u0b3e\u0b30",
-                    "00 \u0b39\u0b1c\u0b3e\u0b30",
-                    "000 \u0b39\u0b1c\u0b3e\u0b30",
-                    "0 \u0b28\u0b3f\u0b5f\u0b41\u0b24",
-                    "00 \u0b28\u0b3f\u0b5f\u0b41\u0b24",
-                    "000 \u0b28\u0b3f\u0b5f\u0b41\u0b24",
-                    "0 \u0b36\u0b39\u0b15\u0b4b\u0b1f\u0b3f",
-                    "00 \u0b36\u0b39\u0b15\u0b4b\u0b1f\u0b3f",
-                    "000 \u0b36\u0b39\u0b15\u0b4b\u0b1f\u0b3f",
-                    "0 \u0b32\u0b15\u0b4d\u0b37\u0b15\u0b4b\u0b1f\u0b3f",
-                    "00 \u0b32\u0b15\u0b4d\u0b37\u0b15\u0b4b\u0b1f\u0b3f",
-                    "000 \u0b32\u0b15\u0b4d\u0b37\u0b15\u0b4b\u0b1f\u0b3f",
+                    "#,##,##0.###",
+                    "\u00a4#,##0.00",
+                    "#,##0%",
+                    "\u00a4#,##0.00;(\u00a4#,##0.00)",
                 }
             },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
-            { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
-            { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
             { "QuarterAbbreviations", metaValue_QuarterNames },
-            { "standalone.QuarterNames", metaValue_QuarterNames },
-            { "japanese.MonthNarrows", metaValue_MonthNarrows },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
         return data;
