@@ -162,12 +162,22 @@ public class FormatData_pl extends ListResourceBundle {
                "p.n.e.",
                "n.e.",
             };
+        final String[] metaValue_TimePatterns = new String[] {
+               "HH:mm:ss zzzz",
+               "HH:mm:ss z",
+               "HH:mm:ss",
+               "HH:mm",
+            };
         final String[] metaValue_buddhist_QuarterNarrows = new String[] {
                "1",
                "2",
                "3",
                "4",
             };
+        final String[] metaValue_buddhist_AmPmMarkers = new String[] {
+               "AM",
+               "PM",
+            };
         final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
                "BC",
                "e.b.",
@@ -184,10 +194,6 @@ public class FormatData_pl extends ListResourceBundle {
                "d MMM y GGGG",
                "dd.MM.y GGGG",
             };
-        final String[] metaValue_roc_AmPmMarkers = new String[] {
-               "AM",
-               "PM",
-            };
         final String[] metaValue_java_time_roc_long_Eras = new String[] {
                "przed ROC",
                "ROC",
@@ -201,6 +207,7 @@ public class FormatData_pl extends ListResourceBundle {
             { "MonthNames", metaValue_MonthNames },
             { "field.year", "rok" },
             { "calendarname.islamic-umalqura", "kalendarz islamski (Umm al-Kura)" },
+            { "japanese.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -208,6 +215,7 @@ public class FormatData_pl extends ListResourceBundle {
             { "roc.MonthNarrows", metaValue_MonthNarrows },
             { "calendarname.islamic-civil", "kalendarz islamski (metoda obliczeniowa)" },
             { "islamic.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "japanese.TimePatterns", metaValue_TimePatterns },
             { "narrow.Eras", metaValue_Eras },
             { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "timezone.regionFormat.standard", "{0} (czas standardowy)" },
@@ -221,6 +229,7 @@ public class FormatData_pl extends ListResourceBundle {
                     "naszej ery",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -246,6 +255,8 @@ public class FormatData_pl extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -253,6 +264,7 @@ public class FormatData_pl extends ListResourceBundle {
             { "buddhist.DayNames", metaValue_DayNames },
             { "field.minute", "minuta" },
             { "field.era", "era" },
+            { "buddhist.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "field.dayperiod", "rano / po po\u0142udniu / wieczorem" },
             { "standalone.MonthNarrows",
                 new String[] {
@@ -288,6 +300,7 @@ public class FormatData_pl extends ListResourceBundle {
                     "",
                 }
             },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "kalendarz Republiki Chi\u0144skiej" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -296,18 +309,12 @@ public class FormatData_pl extends ListResourceBundle {
             { "field.second", "sekunda" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "calendarname.islamic", "kalendarz islamski (metoda wzrokowa)" },
+            { "calendarname.islamic", "kalendarz muzu\u0142ma\u0144ski" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "java.time.roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
             { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "timezone.regionFormat", "czas: {0}" },
             { "long.CompactNumberPatterns",
@@ -315,18 +322,18 @@ public class FormatData_pl extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 tysi\u0105c",
-                    "00 tysi\u0105c",
-                    "000 tysi\u0105c",
-                    "0 milion",
-                    "00 milion",
-                    "000 milion",
-                    "0 miliard",
-                    "00 miliard",
-                    "000 miliard",
-                    "0 bilion",
-                    "00 bilion",
-                    "000 bilion",
+                    "{one:0' 'tysi\u0105c few:0' 'tysi\u0105ce many:0' 'tysi\u0119cy other:0' 'tysi\u0105ca}",
+                    "{one:00' 'tysi\u0105c few:00' 'tysi\u0105ce many:00' 'tysi\u0119cy other:00' 'tysi\u0105ca}",
+                    "{one:000' 'tysi\u0105c few:000' 'tysi\u0105ce many:000' 'tysi\u0119cy other:000' 'tysi\u0105ca}",
+                    "{one:0' 'milion few:0' 'miliony many:0' 'milion\u00f3w other:0' 'miliona}",
+                    "{one:00' 'milion few:00' 'miliony many:00' 'milion\u00f3w other:00' 'miliona}",
+                    "{one:000' 'milion few:000' 'miliony many:000' 'milion\u00f3w other:000' 'miliona}",
+                    "{one:0' 'miliard few:0' 'miliardy many:0' 'miliard\u00f3w other:0' 'miliarda}",
+                    "{one:00' 'miliard few:00' 'miliardy many:00' 'miliard\u00f3w other:00' 'miliarda}",
+                    "{one:000' 'miliard few:000' 'miliardy many:000' 'miliard\u00f3w other:000' 'miliarda}",
+                    "{one:0' 'bilion few:0' 'biliony many:0' 'bilion\u00f3w other:0' 'biliona}",
+                    "{one:00' 'bilion few:00' 'biliony many:00' 'bilion\u00f3w other:00' 'biliona}",
+                    "{one:000' 'bilion few:000' 'biliony many:000' 'bilion\u00f3w other:000' 'biliona}",
                 }
             },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -347,8 +354,9 @@ public class FormatData_pl extends ListResourceBundle {
                     "S",
                 }
             },
+            { "islamic.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
-            { "islamic.AmPmMarkers", metaValue_roc_AmPmMarkers },
+            { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
             { "java.time.roc.Eras", metaValue_java_time_roc_Eras },
             { "field.zone", "strefa czasowa" },
@@ -376,7 +384,7 @@ public class FormatData_pl extends ListResourceBundle {
             { "buddhist.QuarterNames", metaValue_QuarterNames },
             { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "roc.DayNarrows", metaValue_DayNarrows },
-            { "roc.AmPmMarkers", metaValue_roc_AmPmMarkers },
+            { "roc.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "short.CompactNumberPatterns",
@@ -384,18 +392,18 @@ public class FormatData_pl extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0tys'.'",
-                    "00\u00a0tys'.'",
-                    "000\u00a0tys'.'",
-                    "0\u00a0mln",
-                    "00\u00a0mln",
-                    "000\u00a0mln",
-                    "0\u00a0mld",
-                    "00\u00a0mld",
-                    "000\u00a0mld",
-                    "0\u00a0bln",
-                    "00\u00a0bln",
-                    "000\u00a0bln",
+                    "{one:0\u00a0tys'.' few:0\u00a0tys'.' many:0\u00a0tys'.' other:0\u00a0tys'.'}",
+                    "{one:00\u00a0tys'.' few:00\u00a0tys'.' many:00\u00a0tys'.' other:00\u00a0tys'.'}",
+                    "{one:000\u00a0tys'.' few:000\u00a0tys'.' many:000\u00a0tys'.' other:000\u00a0tys'.'}",
+                    "{one:0\u00a0mln few:0\u00a0mln many:0\u00a0mln other:0\u00a0mln}",
+                    "{one:00\u00a0mln few:00\u00a0mln many:00\u00a0mln other:00\u00a0mln}",
+                    "{one:000\u00a0mln few:000\u00a0mln many:000\u00a0mln other:000\u00a0mln}",
+                    "{one:0\u00a0mld few:0\u00a0mld many:0\u00a0mld other:0\u00a0mld}",
+                    "{one:00\u00a0mld few:00\u00a0mld many:00\u00a0mld other:00\u00a0mld}",
+                    "{one:000\u00a0mld few:000\u00a0mld many:000\u00a0mld other:000\u00a0mld}",
+                    "{one:0\u00a0bln few:0\u00a0bln many:0\u00a0bln other:0\u00a0bln}",
+                    "{one:00\u00a0bln few:00\u00a0bln many:00\u00a0bln other:00\u00a0bln}",
+                    "{one:000\u00a0bln few:000\u00a0bln many:000\u00a0bln other:000\u00a0bln}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -410,6 +418,7 @@ public class FormatData_pl extends ListResourceBundle {
                 }
             },
             { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
+            { "islamic.TimePatterns", metaValue_TimePatterns },
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.DayNames", metaValue_DayNames },
             { "field.hour", "godzina" },
@@ -448,9 +457,18 @@ public class FormatData_pl extends ListResourceBundle {
                     "",
                 }
             },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0%",
+                    "#,##0.00\u00a0\u00a4;(#,##0.00\u00a0\u00a4)",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
+            { "roc.TimePatterns", metaValue_TimePatterns },
             { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
