@@ -78,7 +78,7 @@ public class FormatData_ps extends ListResourceBundle {
                "\u0645\u06cd",
                "\u062c\u0648\u0646",
                "\u062c\u0648\u0644\u0627\u06cc",
-               "\u0627\u06af\u0633\u062a",
+               "\u0627\u06ab\u0633\u062a",
                "\u0633\u06d0\u067e\u062a\u0645\u0628\u0631",
                "\u0627\u06a9\u062a\u0648\u0628\u0631",
                "\u0646\u0648\u0645\u0628\u0631",
@@ -173,6 +173,8 @@ public class FormatData_ps extends ListResourceBundle {
                     "\u0609",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
@@ -181,7 +183,7 @@ public class FormatData_ps extends ListResourceBundle {
             { "standalone.QuarterAbbreviations", metaValue_QuarterNames },
             { "roc.QuarterNames", metaValue_QuarterNames },
             { "roc.MonthNarrows", metaValue_MonthNarrows },
-            { "calendarname.islamic-civil", "\u062f \u0627\u0633\u0644\u0627\u0645\u064a \u062c\u0646\u062a\u0631\u064a (\u062c\u062f\u0648\u0644\u064a\u060c \u062f \u0645\u062f\u0646\u064a \u0639\u0635\u0631)" },
+            { "calendarname.islamic-civil", "\u0627\u0633\u0644\u0627\u0645\u064a \u062c\u0646\u062a\u0631\u064a (\u062c\u062f\u0648\u0644\u064a\u060c \u0645\u062f\u0646\u064a \u0639\u0635\u0631)" },
             { "islamic.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
             { "narrow.Eras",
@@ -194,7 +196,7 @@ public class FormatData_ps extends ListResourceBundle {
             { "timezone.regionFormat.standard", "{0} \u0645\u0639\u06cc\u0627\u0631\u06cc \u0648\u062e\u062a" },
             { "DefaultNumberingSystem", "arabext" },
             { "japanese.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
-            { "calendarname.japanese", "\u062f \u062c\u0627\u067e\u0627\u0646\u064a \u062c\u0646\u062a\u0631\u064a" },
+            { "calendarname.japanese", "\u062c\u0627\u067e\u0627\u0646\u064a \u062c\u0646\u062a\u0631\u064a" },
             { "japanese.MonthNames", metaValue_MonthNames },
             { "standalone.DayAbbreviations", metaValue_DayNames },
             { "roc.MonthAbbreviations", metaValue_MonthNames },
@@ -205,6 +207,7 @@ public class FormatData_ps extends ListResourceBundle {
                     "\u0644\u0647 \u0645\u06cc\u0644\u0627\u062f \u0685\u062e\u0647 \u0648\u0631\u0648\u0633\u062a\u0647",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthNames },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -230,6 +233,8 @@ public class FormatData_ps extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -242,34 +247,36 @@ public class FormatData_ps extends ListResourceBundle {
             { "islamic.MonthNames",
                 new String[] {
                     "\u0645\u062d\u0631\u0645",
-                    "\u062f \u0635\u0641\u0631\u06d0 \u062f",
+                    "\u0635\u0641\u0631",
                     "\u0631\u0628\u064a\u0639",
                     "\u0631\u0628\u064a\u0639 II",
                     "\u062c\u0645\u0627\u0639\u0647",
                     "\u062c\u0645\u0648\u0645\u0627 II",
-                    "\u0631\u0627\u062c\u0627\u0628",
+                    "\u0631\u062c\u0628",
                     "\u0634\u0639\u0628\u0627\u0646",
                     "\u0631\u0645\u0636\u0627\u0646",
                     "\u0634\u0648\u0627\u0644",
-                    "\u062f\u0627\u0644\u0642\u0627\u0639\u062f\u0647",
-                    "\u062d\u0644\u0627\u0644 \u062d\u062c",
+                    "\u0630\u064a \u0627\u0644\u0642\u0639\u062f\u0647",
+                    "\u0630\u064a \u0627\u0644\u062d\u062c",
                     "",
                 }
             },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "\u0645\u0646\u06af\u0648\u0648 \u062c\u0646\u062a\u0631\u064a" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterNames },
             { "islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "field.month", "\u0645\u064a\u0627\u0634\u062a" },
-            { "field.second", "\u062b\u0627\u0646\u064a\u0647" },
-            { "DayAbbreviations", metaValue_DayNames },
-            { "NumberPatterns",
+            { "arabext.NumberPatterns",
                 new String[] {
                     "#,##0.###",
                     "#,##0.00\u00a0\u00a4",
                     "#,##0%",
+                    "",
                 }
             },
+            { "field.second", "\u062b\u0627\u0646\u064a\u0647" },
+            { "DayAbbreviations", metaValue_DayNames },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u0627\u0633\u0644\u0627\u0645\u064a \u062c\u0646\u062a\u0631\u064a" },
             { "japanese.narrow.AmPmMarkers", metaValue_AmPmMarkers },
@@ -283,7 +290,7 @@ public class FormatData_ps extends ListResourceBundle {
                     "\u0645\u06cd",
                     "\u062c\u0648\u0646",
                     "\u062c\u0648\u0644\u0627\u06cc",
-                    "\u0627\u06af\u0633\u062a",
+                    "\u0627\u06ab\u0633\u062a",
                     "\u0633\u067e\u062a\u0645\u0628\u0631",
                     "\u0627\u06a9\u062a\u0648\u0628\u0631",
                     "\u0646\u0648\u0645\u0628\u0631",
@@ -297,18 +304,18 @@ public class FormatData_ps extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0K",
-                    "00K",
-                    "000K",
-                    "0M",
-                    "00M",
-                    "000M",
-                    "0G",
-                    "00G",
-                    "000G",
-                    "0T",
-                    "00T",
-                    "000T",
+                    "{one:0K other:0K}",
+                    "{one:00K other:00K}",
+                    "{one:000K other:000K}",
+                    "{one:0M other:0M}",
+                    "{one:00M other:00M}",
+                    "{one:000M other:000M}",
+                    "{one:0G other:0G}",
+                    "{one:00G other:00G}",
+                    "{one:000G other:000G}",
+                    "{one:0T other:0T}",
+                    "{one:00T other:00T}",
+                    "{one:000T other:000T}",
                 }
             },
             { "roc.narrow.AmPmMarkers", metaValue_AmPmMarkers },
@@ -350,6 +357,7 @@ public class FormatData_ps extends ListResourceBundle {
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
             { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
+            { "roc.DayNarrows", metaValue_buddhist_DayNarrows },
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
@@ -358,18 +366,18 @@ public class FormatData_ps extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0K",
-                    "00K",
-                    "000K",
-                    "0M",
-                    "00M",
-                    "000M",
-                    "0B",
-                    "00B",
-                    "000G",
-                    "0T",
-                    "00T",
-                    "000T",
+                    "{one:0K other:0K}",
+                    "{one:00K other:00K}",
+                    "{one:000K other:000K}",
+                    "{one:0M other:0M}",
+                    "{one:00M other:00M}",
+                    "{one:000M other:000M}",
+                    "{one:0B other:0B}",
+                    "{one:00B other:00B}",
+                    "{one:000G other:000B}",
+                    "{one:0T other:0T}",
+                    "{one:00T other:00T}",
+                    "{one:000T other:000T}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -390,17 +398,17 @@ public class FormatData_ps extends ListResourceBundle {
             { "islamic.MonthAbbreviations",
                 new String[] {
                     "\u0645\u062d\u0631\u0645",
-                    "\u0635\u0641\u0631\u0647",
+                    "\u0635\u0641\u0631",
                     "\u0631\u0628\u064a\u0639",
                     "\u0631\u0628\u064a\u0639 II",
-                    "\u062c\u0645\u0627\u0639\u0647",
-                    "\u062c\u0645\u0648\u0645\u0627 II",
-                    "\u0631\u0627\u062c\u0627\u0628",
+                    "\u062c\u0645\u0627\u062f \u06f1",
+                    "\u062c\u0645\u0627\u062f \u06f2",
+                    "\u0631\u062c\u0628",
                     "\u0634\u0639\u0628\u0627\u0646",
                     "\u0631\u0645\u0636\u0627\u0646",
                     "\u0634\u0648\u0627\u0644",
                     "\u062f\u0627\u0644\u0642\u0627\u0639\u062f\u0647",
-                    "\u062d\u0644\u0627\u0644 \u062d\u062c",
+                    "\u0630\u064a \u0627\u0644\u062d\u062c",
                     "",
                 }
             },
@@ -415,7 +423,7 @@ public class FormatData_ps extends ListResourceBundle {
                     "\u0645\u06cd",
                     "\u062c\u0648\u0646",
                     "\u062c\u0648\u0644\u0627\u06cc",
-                    "\u0627\u06af\u0633\u062a",
+                    "\u0627\u06ab\u0633\u062a",
                     "\u0633\u067e\u062a\u0645\u0628\u0631",
                     "\u0627\u06a9\u062a\u0648\u0628\u0631",
                     "\u0646\u0648\u0645\u0628\u0631",
@@ -423,6 +431,14 @@ public class FormatData_ps extends ListResourceBundle {
                     "",
                 }
             },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0%",
+                    "\u00a4#,##0.00;(\u00a4#,##0.00)",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_buddhist_DayNarrows },
             { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "QuarterNames", metaValue_QuarterNames },
