@@ -86,18 +86,18 @@ public class FormatData_pt extends ListResourceBundle {
                "",
             };
         final String[] metaValue_MonthAbbreviations = new String[] {
-               "jan",
-               "fev",
-               "mar",
-               "abr",
-               "mai",
-               "jun",
-               "jul",
-               "ago",
-               "set",
-               "out",
-               "nov",
-               "dez",
+               "jan.",
+               "fev.",
+               "mar.",
+               "abr.",
+               "mai.",
+               "jun.",
+               "jul.",
+               "ago.",
+               "set.",
+               "out.",
+               "nov.",
+               "dez.",
                "",
             };
         final String[] metaValue_MonthNarrows = new String[] {
@@ -125,13 +125,13 @@ public class FormatData_pt extends ListResourceBundle {
                "s\u00e1bado",
             };
         final String[] metaValue_DayAbbreviations = new String[] {
-               "dom",
-               "seg",
-               "ter",
-               "qua",
-               "qui",
-               "sex",
-               "s\u00e1b",
+               "dom.",
+               "seg.",
+               "ter.",
+               "qua.",
+               "qui.",
+               "sex.",
+               "s\u00e1b.",
             };
         final String[] metaValue_DayNarrows = new String[] {
                "D",
@@ -158,12 +158,22 @@ public class FormatData_pt extends ListResourceBundle {
                "a.C.",
                "d.C.",
             };
+        final String[] metaValue_TimePatterns = new String[] {
+               "HH:mm:ss zzzz",
+               "HH:mm:ss z",
+               "HH:mm:ss",
+               "HH:mm",
+            };
         final String[] metaValue_buddhist_QuarterNarrows = new String[] {
                "1",
                "2",
                "3",
                "4",
             };
+        final String[] metaValue_buddhist_AmPmMarkers = new String[] {
+               "AM",
+               "PM",
+            };
         final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
                "BC",
                "EB",
@@ -184,10 +194,6 @@ public class FormatData_pt extends ListResourceBundle {
                "d MMM y GGGG",
                "dd/MM/y G",
             };
-        final String[] metaValue_japanese_narrow_AmPmMarkers = new String[] {
-               "AM",
-               "PM",
-            };
         final String[] metaValue_java_time_roc_long_Eras = new String[] {
                "Antes da R.C.",
                "Minguo",
@@ -197,6 +203,7 @@ public class FormatData_pt extends ListResourceBundle {
             { "MonthNames", metaValue_MonthNames },
             { "field.year", "ano" },
             { "calendarname.islamic-umalqura", "Calend\u00e1rio Isl\u00e2mico (Umm al-Qura)" },
+            { "japanese.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "java.time.japanese.DatePatterns",
                 new String[] {
@@ -210,7 +217,8 @@ public class FormatData_pt extends ListResourceBundle {
             { "roc.QuarterNames", metaValue_QuarterNames },
             { "roc.MonthNarrows", metaValue_MonthNarrows },
             { "calendarname.islamic-civil", "Calend\u00e1rio Civil Isl\u00e2mico" },
-            { "islamic.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "islamic.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
+            { "japanese.TimePatterns", metaValue_TimePatterns },
             { "narrow.Eras", metaValue_Eras },
             { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "timezone.regionFormat.standard", "Hor\u00e1rio Padr\u00e3o: {0}" },
@@ -224,6 +232,7 @@ public class FormatData_pt extends ListResourceBundle {
                     "depois de Cristo",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -248,6 +257,8 @@ public class FormatData_pt extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -262,8 +273,10 @@ public class FormatData_pt extends ListResourceBundle {
             { "buddhist.DayNames", metaValue_DayNames },
             { "field.minute", "minuto" },
             { "field.era", "era" },
+            { "buddhist.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "field.dayperiod", "AM/PM" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "Calend\u00e1rio da Rep\u00fablica da China" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -272,18 +285,12 @@ public class FormatData_pt extends ListResourceBundle {
             { "field.second", "segundo" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "\u00a4\u00a0#,##0.00",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "Calend\u00e1rio Isl\u00e2mico" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "java.time.roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
-            { "japanese.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "japanese.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
+            { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "timezone.regionFormat", "Hor\u00e1rio {0}" },
             { "long.CompactNumberPatterns",
@@ -291,35 +298,37 @@ public class FormatData_pt extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 mil",
-                    "00 mil",
-                    "000 mil",
-                    "0 milh\u00e3o",
-                    "00 milh\u00e3o",
-                    "000 milh\u00e3o",
-                    "0 bilh\u00e3o",
-                    "00 bilh\u00e3o",
-                    "000 bilh\u00e3o",
-                    "0 trilh\u00e3o",
-                    "00 trilh\u00e3o",
-                    "000 trilh\u00e3o",
+                    "{one:0' 'mil other:0' 'mil}",
+                    "{one:00' 'mil other:00' 'mil}",
+                    "{one:000' 'mil other:000' 'mil}",
+                    "{one:0' 'milh\u00e3o other:0' 'milh\u00f5es}",
+                    "{one:00' 'milh\u00e3o other:00' 'milh\u00f5es}",
+                    "{one:000' 'milh\u00e3o other:000' 'milh\u00f5es}",
+                    "{one:0' 'bilh\u00e3o other:0' 'bilh\u00f5es}",
+                    "{one:00' 'bilh\u00e3o other:00' 'bilh\u00f5es}",
+                    "{one:000' 'bilh\u00e3o other:000' 'bilh\u00f5es}",
+                    "{one:0' 'trilh\u00e3o other:0' 'trilh\u00f5es}",
+                    "{one:00' 'trilh\u00e3o other:00' 'trilh\u00f5es}",
+                    "{one:000' 'trilh\u00e3o other:000' 'trilh\u00f5es}",
                 }
             },
             { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
-            { "roc.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "roc.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "standalone.QuarterNames", metaValue_QuarterNames },
             { "japanese.MonthNarrows", metaValue_MonthNarrows },
             { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.DayNarrows", metaValue_DayNarrows },
             { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
+            { "islamic.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
-            { "islamic.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
             { "java.time.roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.zone", "fuso hor\u00e1rio" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
+            { "buddhist.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "Eras", metaValue_Eras },
             { "roc.DayNames", metaValue_DayNames },
             { "islamic.QuarterNames", metaValue_QuarterNames },
@@ -341,7 +350,7 @@ public class FormatData_pt extends ListResourceBundle {
             { "buddhist.QuarterNames", metaValue_QuarterNames },
             { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "roc.DayNarrows", metaValue_DayNarrows },
-            { "roc.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "roc.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "short.CompactNumberPatterns",
@@ -349,18 +358,18 @@ public class FormatData_pt extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0mil",
-                    "00\u00a0mil",
-                    "000\u00a0mil",
-                    "0\u00a0mi",
-                    "00\u00a0mi",
-                    "000\u00a0mi",
-                    "0\u00a0bi",
-                    "00\u00a0bi",
-                    "000\u00a0bi",
-                    "0\u00a0tri",
-                    "00\u00a0tri",
-                    "000\u00a0tri",
+                    "{one:0\u00a0mil other:0\u00a0mil}",
+                    "{one:00\u00a0mil other:00\u00a0mil}",
+                    "{one:000\u00a0mil other:000\u00a0mil}",
+                    "{one:0\u00a0mi other:0\u00a0mi}",
+                    "{one:00\u00a0mi other:00\u00a0mi}",
+                    "{one:000\u00a0mi other:000\u00a0mi}",
+                    "{one:0\u00a0bi other:0\u00a0bi}",
+                    "{one:00\u00a0bi other:00\u00a0bi}",
+                    "{one:000\u00a0bi other:000\u00a0bi}",
+                    "{one:0\u00a0tri other:0\u00a0tri}",
+                    "{one:00\u00a0tri other:00\u00a0tri}",
+                    "{one:000\u00a0tri other:000\u00a0tri}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -375,14 +384,24 @@ public class FormatData_pt extends ListResourceBundle {
                 }
             },
             { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
+            { "islamic.TimePatterns", metaValue_TimePatterns },
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.DayNames", metaValue_DayNames },
             { "field.hour", "hora" },
             { "calendarname.buddhist", "Calend\u00e1rio Budista" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "\u00a4\u00a0#,##0.00",
+                    "#,##0%",
+                    "\u00a4\u00a0#,##0.00",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
+            { "roc.TimePatterns", metaValue_TimePatterns },
             { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
