@@ -168,6 +168,12 @@ public class FormatData_ro extends ListResourceBundle {
                "\u00ee.Hr.",
                "d.Hr.",
             };
+        final String[] metaValue_TimePatterns = new String[] {
+               "HH:mm:ss zzzz",
+               "HH:mm:ss z",
+               "HH:mm:ss",
+               "HH:mm",
+            };
         final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
                "BC",
                "era budist\u0103",
@@ -218,6 +224,7 @@ public class FormatData_ro extends ListResourceBundle {
             { "roc.MonthNarrows", metaValue_MonthNarrows },
             { "calendarname.islamic-civil", "calendar islamic civil" },
             { "islamic.narrow.AmPmMarkers", metaValue_AmPmMarkers },
+            { "japanese.TimePatterns", metaValue_TimePatterns },
             { "narrow.Eras", metaValue_Eras },
             { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
@@ -260,6 +267,8 @@ public class FormatData_ro extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -280,18 +289,12 @@ public class FormatData_ro extends ListResourceBundle {
             { "field.second", "secund\u0103" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0\u00a0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "calendar islamic" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "java.time.roc.narrow.Eras", metaValue_java_time_roc_Eras },
             { "japanese.narrow.AmPmMarkers", metaValue_AmPmMarkers },
+            { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "timezone.regionFormat", "Ora din {0}" },
             { "long.CompactNumberPatterns",
@@ -299,18 +302,18 @@ public class FormatData_ro extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 mie",
-                    "00 mie",
-                    "000 mie",
-                    "0 milion",
-                    "00 milion",
-                    "000 milion",
-                    "0 miliard",
-                    "00 miliard",
-                    "000 miliard",
-                    "0 trilion",
-                    "00 trilion",
-                    "000 trilion",
+                    "{one:0' 'mie few:0' 'mii other:0' 'de' 'mii}",
+                    "{one:00' 'mie few:00' 'mii other:00' 'de' 'mii}",
+                    "{one:000' 'mie few:000' 'mii other:000' 'de' 'mii}",
+                    "{one:0' 'milion few:0' 'milioane other:0' 'de' 'milioane}",
+                    "{one:00' 'milion few:00' 'milioane other:00' 'de' 'milioane}",
+                    "{one:000' 'milion few:000' 'milioane other:000' 'de' 'milioane}",
+                    "{one:0' 'miliard few:0' 'miliarde other:0' 'de' 'miliarde}",
+                    "{one:00' 'miliard few:00' 'miliarde other:00' 'de' 'miliarde}",
+                    "{one:000' 'miliard few:000' 'miliarde other:000' 'de' 'miliarde}",
+                    "{one:0' 'trilion few:0' 'trilioane other:0' 'de' 'trilioane}",
+                    "{one:00' 'trilion few:00' 'trilioane other:00' 'de' 'trilioane}",
+                    "{one:000' 'trilion few:000' 'trilioane other:000' 'de' 'trilioane}",
                 }
             },
             { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
@@ -323,6 +326,7 @@ public class FormatData_ro extends ListResourceBundle {
             { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
+            { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
             { "java.time.roc.Eras", metaValue_java_time_roc_Eras },
             { "field.zone", "fus orar" },
@@ -372,18 +376,18 @@ public class FormatData_ro extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0K",
-                    "00\u00a0K",
-                    "000\u00a0K",
-                    "0\u00a0mil'.'",
-                    "00\u00a0mil'.'",
-                    "000\u00a0mil'.'",
-                    "0\u00a0mld'.'",
-                    "00\u00a0mld'.'",
-                    "000\u00a0mld'.'",
-                    "0\u00a0tril'.'",
-                    "00\u00a0tril'.'",
-                    "000\u00a0tril'.'",
+                    "{one:0\u00a0K few:0\u00a0K other:0\u00a0K}",
+                    "{one:00\u00a0K few:00\u00a0K other:00\u00a0K}",
+                    "{one:000\u00a0K few:000\u00a0K other:000\u00a0K}",
+                    "{one:0\u00a0mil'.' few:0\u00a0mil'.' other:0\u00a0mil'.'}",
+                    "{one:00\u00a0mil'.' few:00\u00a0mil'.' other:00\u00a0mil'.'}",
+                    "{one:000\u00a0mil'.' few:000\u00a0mil'.' other:000\u00a0mil'.'}",
+                    "{one:0\u00a0mld'.' few:0\u00a0mld'.' other:0\u00a0mld'.'}",
+                    "{one:00\u00a0mld'.' few:00\u00a0mld'.' other:00\u00a0mld'.'}",
+                    "{one:000\u00a0mld'.' few:000\u00a0mld'.' other:000\u00a0mld'.'}",
+                    "{one:0\u00a0tril'.' few:0\u00a0tril'.' other:0\u00a0tril'.'}",
+                    "{one:00\u00a0tril'.' few:00\u00a0tril'.' other:00\u00a0tril'.'}",
+                    "{one:000\u00a0tril'.' few:000\u00a0tril'.' other:000\u00a0tril'.'}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -398,16 +402,26 @@ public class FormatData_ro extends ListResourceBundle {
                 }
             },
             { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
+            { "islamic.TimePatterns", metaValue_TimePatterns },
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.DayNames", metaValue_DayNames },
             { "field.hour", "or\u0103" },
             { "islamic.narrow.Eras", metaValue_java_time_islamic_Eras },
             { "calendarname.buddhist", "calendar budist" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0\u00a0%",
+                    "#,##0.00\u00a0\u00a4;(#,##0.00\u00a0\u00a4)",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
+            { "roc.TimePatterns", metaValue_TimePatterns },
             { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
