@@ -205,6 +205,7 @@ public class FormatData_sah extends ListResourceBundle {
             { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "long.Eras", metaValue_long_Eras },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -230,6 +231,8 @@ public class FormatData_sah extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "\u0447\u044b\u044b\u04bb\u044b\u043b\u0430\u00a0\u0431\u0443\u043e\u0442\u0430\u0445",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -240,19 +243,13 @@ public class FormatData_sah extends ListResourceBundle {
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "\u042d\u0418/\u042d\u041a" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "field.month", "\u042b\u0439" },
             { "field.second", "\u0421\u04e9\u043a\u04af\u04af\u043d\u0434\u044d" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u0418\u0441\u043b\u0430\u0430\u043c \u0445\u0430\u043b\u0430\u043d\u0434\u0430\u0430\u0440\u0430" },
             { "japanese.narrow.AmPmMarkers", metaValue_AmPmMarkers },
@@ -263,18 +260,18 @@ public class FormatData_sah extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 \u0442\u044b\u04bb\u044b\u044b\u043d\u0447\u0430",
-                    "00 \u0442\u044b\u04bb\u044b\u044b\u043d\u0447\u0430",
-                    "000 \u0442\u044b\u04bb\u044b\u044b\u043d\u0447\u0430",
-                    "0 \u043c\u04e9\u043b\u04af\u0439\u04af\u04e9\u043d",
-                    "00 \u043c\u04e9\u043b\u04af\u0439\u04af\u04e9\u043d",
-                    "000 \u043c\u04e9\u043b\u04af\u0439\u04af\u04e9\u043d",
-                    "0 \u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434",
-                    "00 \u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434",
-                    "000 \u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434",
-                    "0 \u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d",
-                    "00 \u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d",
-                    "000 \u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d",
+                    "{other:0' '\u0442\u044b\u04bb\u044b\u044b\u043d\u0447\u0430}",
+                    "{other:00' '\u0442\u044b\u04bb\u044b\u044b\u043d\u0447\u0430}",
+                    "{other:000' '\u0442\u044b\u04bb\u044b\u044b\u043d\u0447\u0430}",
+                    "{other:0' '\u043c\u04e9\u043b\u04af\u0439\u04af\u04e9\u043d}",
+                    "{other:00' '\u043c\u04e9\u043b\u04af\u0439\u04af\u04e9\u043d}",
+                    "{other:000' '\u043c\u04e9\u043b\u04af\u0439\u04af\u04e9\u043d}",
+                    "{other:0' '\u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434}",
+                    "{other:00' '\u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434}",
+                    "{other:000' '\u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434}",
+                    "{other:0' '\u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d}",
+                    "{other:00' '\u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d}",
+                    "{other:000' '\u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d}",
                 }
             },
             { "roc.narrow.AmPmMarkers", metaValue_AmPmMarkers },
@@ -319,18 +316,18 @@ public class FormatData_sah extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0\u0442\u044b\u04bb'.'",
-                    "00\u00a0\u0442\u044b\u04bb'.'",
-                    "000\u00a0\u0442\u044b\u04bb'.'",
-                    "0\u00a0\u043c\u04e9\u043b",
-                    "00\u00a0\u043c\u04e9\u043b",
-                    "000\u00a0\u043c\u04e9\u043b",
-                    "0\u00a0\u043c\u043b\u0440\u0434",
-                    "00\u00a0\u043c\u043b\u0440\u0434",
-                    "000\u00a0\u043c\u043b\u0440\u0434",
-                    "0\u00a0\u0442\u0440\u043b\u043d",
-                    "00\u00a0\u0442\u0440\u043b\u043d",
-                    "000\u00a0\u0442\u0440\u043b\u043d",
+                    "{other:0\u00a0\u0442\u044b\u04bb'.'}",
+                    "{other:00\u00a0\u0442\u044b\u04bb'.'}",
+                    "{other:000\u00a0\u0442\u044b\u04bb'.'}",
+                    "{other:0\u00a0\u043c\u04e9\u043b}",
+                    "{other:00\u00a0\u043c\u04e9\u043b}",
+                    "{other:000\u00a0\u043c\u04e9\u043b}",
+                    "{other:0\u00a0\u043c\u043b\u0440\u0434}",
+                    "{other:00\u00a0\u043c\u043b\u0440\u0434}",
+                    "{other:000\u00a0\u043c\u043b\u0440\u0434}",
+                    "{other:0\u00a0\u0442\u0440\u043b\u043d}",
+                    "{other:00\u00a0\u0442\u0440\u043b\u043d}",
+                    "{other:000\u00a0\u0442\u0440\u043b\u043d}",
                 }
             },
             { "DatePatterns",
@@ -364,6 +361,14 @@ public class FormatData_sah extends ListResourceBundle {
                     "",
                 }
             },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0%",
+                    "#,##0.00\u00a0\u00a4",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
