@@ -200,6 +200,7 @@ public class FormatData_sd extends ListResourceBundle {
                     "\u0639\u064a\u0633\u0648\u064a \u06a9\u0627\u0646 \u067e\u0647\u0631\u064a\u0646",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthNames },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -225,6 +226,8 @@ public class FormatData_sd extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -235,6 +238,7 @@ public class FormatData_sd extends ListResourceBundle {
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "\u0635\u0628\u062d/\u0634\u0627\u0645" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "\u0645\u0646\u06af\u0648\u0648 \u06aa\u0626\u0644\u064a\u0646\u068a\u0631" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -242,13 +246,6 @@ public class FormatData_sd extends ListResourceBundle {
             { "field.second", "\u0633\u064a\u06aa\u0646\u068a" },
             { "DayAbbreviations", metaValue_DayNames },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "\u00a4\u00a0#,##0.00",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u0627\u0633\u0644\u0627\u0645\u064a \u06aa\u0626\u0644\u064a\u0646\u068a\u0631" },
             { "japanese.narrow.AmPmMarkers", metaValue_AmPmMarkers },
@@ -260,18 +257,18 @@ public class FormatData_sd extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 \u06be\u0632\u0627\u0631",
-                    "00 \u06be\u0632\u0627\u0631",
-                    "000K",
-                    "0M",
-                    "00M",
-                    "000M",
-                    "0G",
-                    "00G",
-                    "000G",
-                    "0T",
-                    "00T",
-                    "000T",
+                    "{one:0' '\u06be\u0632\u0627\u0631 other:0' '\u06be\u0632\u0627\u0631}",
+                    "{one:00' '\u06be\u0632\u0627\u0631 other:00' '\u0647\u0632\u0627\u0631}",
+                    "{one:000' '\u0647\u0632\u0627\u0631 other:000' '\u0647\u0632\u0627\u0631}",
+                    "{one:0' '\u0645\u0644\u064a\u0646 other:0' '\u0645\u0644\u064a\u0646}",
+                    "{one:00' '\u0645\u0644\u064a\u0646 other:00' '\u0645\u0644\u064a\u0646}",
+                    "{one:000' '\u0645\u0644\u064a\u0646 other:000' '\u0645\u0644\u064a\u0646}",
+                    "{one:0' '\u0628\u0644\u064a\u0646 other:0' '\u0628\u0644\u064a\u0646}",
+                    "{one:00' '\u0628\u0644\u064a\u0646 other:00' '\u0628\u0644\u064a\u0646}",
+                    "{one:000' '\u0628\u0644\u064a\u0646 other:000' '\u0628\u0644\u064a\u0646}",
+                    "{one:0' '\u067d\u0631\u0644\u064a\u0646 other:0' '\u067d\u0631\u0644\u064a\u0646}",
+                    "{one:00' '\u067d\u0631\u0644\u064a\u0646 other:00' '\u067d\u0631\u0644\u064a\u0646}",
+                    "{one:000' '\u067d\u0631\u0644\u064a\u0646 other:000' '\u067d\u0631\u0644\u064a\u0646}",
                 }
             },
             { "roc.narrow.AmPmMarkers", metaValue_AmPmMarkers },
@@ -316,18 +313,18 @@ public class FormatData_sd extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0K",
-                    "00K",
-                    "000K",
-                    "0M",
-                    "00M",
-                    "000M",
-                    "0G",
-                    "00G",
-                    "000G",
-                    "0T",
-                    "00T",
-                    "000T",
+                    "{one:0K other:0K}",
+                    "{one:00K other:00K}",
+                    "{one:000K other:000K}",
+                    "{one:0M other:0M}",
+                    "{one:00M other:00M}",
+                    "{one:000M other:000M}",
+                    "{one:0B other:0B}",
+                    "{one:00B other:00B}",
+                    "{one:000B other:000B}",
+                    "{one:0T other:0T}",
+                    "{one:00T other:00T}",
+                    "{one:000T other:000T}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -347,6 +344,14 @@ public class FormatData_sd extends ListResourceBundle {
             { "field.hour", "\u06aa\u0644\u0627\u06aa" },
             { "calendarname.buddhist", "\u067b\u068c \u068c\u0631\u0645 \u062c\u0648 \u06aa\u0626\u0644\u064a\u0646\u068a\u0631" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "\u00a4\u00a0#,##0.00",
+                    "#,##0%",
+                    "\u00a4\u00a0#,##0.00",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
