@@ -218,6 +218,7 @@ public class FormatData_si extends ListResourceBundle {
                     "\u0d9a\u0dca\u200d\u0dbb\u0dd2\u0dc3\u0dca\u0dad\u0dd4 \u0dc0\u0dbb\u0dca\u0dc2",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -243,6 +244,8 @@ public class FormatData_si extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -253,6 +256,7 @@ public class FormatData_si extends ListResourceBundle {
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "\u0db4\u0dd9.\u0dc0/\u0db4.\u0dc0" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "\u0db8\u0dd2\u0db1\u0dca\u0d9c\u0dcf \u0daf\u0dd2\u0db1 \u0daf\u0dbb\u0dca\u0dc1\u0db1\u0dba" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -260,13 +264,6 @@ public class FormatData_si extends ListResourceBundle {
             { "field.second", "\u0dad\u0dad\u0dca\u0db4\u0dbb\u0dba" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "\u00a4#,##0.00",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u0d89\u0dc3\u0dca\u0dbd\u0dcf\u0db8\u0dd3\u0dba \u0daf\u0dd2\u0db1 \u0daf\u0dbb\u0dca\u0dc1\u0db1\u0dba" },
             { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -294,18 +291,18 @@ public class FormatData_si extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "\u0daf\u0dc4\u0dc3 0",
-                    "\u0daf\u0dc4\u0dc3 00",
-                    "\u0daf\u0dc4\u0dc3 000",
-                    "\u0db8\u0dd2\u0dbd\u0dd2\u0dba\u0db1 0",
-                    "\u0db8\u0dd2\u0dbd\u0dd2\u0dba\u0db1 00",
-                    "\u0db8\u0dd2\u0dbd\u0dd2\u0dba\u0db1 000",
-                    "\u0db6\u0dd2\u0dbd\u0dd2\u0dba\u0db1 0",
-                    "\u0db6\u0dd2\u0dbd\u0dd2\u0dba\u0db1 00",
-                    "\u0db6\u0dd2\u0dbd\u0dd2\u0dba\u0db1 000",
-                    "\u0da7\u0dca\u200d\u0dbb\u0dd2\u0dbd\u0dd2\u0dba\u0db1 0",
-                    "\u0da7\u0dca\u200d\u0dbb\u0dd2\u0dbd\u0dd2\u0dba\u0db1 00",
-                    "\u0da7\u0dca\u200d\u0dbb\u0dd2\u0dbd\u0dd2\u0dba\u0db1 000",
+                    "{one:\u0daf\u0dc4\u0dc3' '0 other:\u0daf\u0dc4\u0dc3' '0}",
+                    "{one:\u0daf\u0dc4\u0dc3' '00 other:\u0daf\u0dc4\u0dc3' '00}",
+                    "{one:\u0daf\u0dc4\u0dc3' '000 other:\u0daf\u0dc4\u0dc3' '000}",
+                    "{one:\u0db8\u0dd2\u0dbd\u0dd2\u0dba\u0db1' '0 other:\u0db8\u0dd2\u0dbd\u0dd2\u0dba\u0db1' '0}",
+                    "{one:\u0db8\u0dd2\u0dbd\u0dd2\u0dba\u0db1' '00 other:\u0db8\u0dd2\u0dbd\u0dd2\u0dba\u0db1' '00}",
+                    "{one:\u0db8\u0dd2\u0dbd\u0dd2\u0dba\u0db1' '000 other:\u0db8\u0dd2\u0dbd\u0dd2\u0dba\u0db1' '000}",
+                    "{one:\u0db6\u0dd2\u0dbd\u0dd2\u0dba\u0db1' '0 other:\u0db6\u0dd2\u0dbd\u0dd2\u0dba\u0db1' '0}",
+                    "{one:\u0db6\u0dd2\u0dbd\u0dd2\u0dba\u0db1' '00 other:\u0db6\u0dd2\u0dbd\u0dd2\u0dba\u0db1' '00}",
+                    "{one:\u0db6\u0dd2\u0dbd\u0dd2\u0dba\u0db1' '000 other:\u0db6\u0dd2\u0dbd\u0dd2\u0dba\u0db1' '000}",
+                    "{one:\u0da7\u0dca\u200d\u0dbb\u0dd2\u0dbd\u0dd2\u0dba\u0db1' '0 other:\u0da7\u0dca\u200d\u0dbb\u0dd2\u0dbd\u0dd2\u0dba\u0db1' '0}",
+                    "{one:\u0da7\u0dca\u200d\u0dbb\u0dd2\u0dbd\u0dd2\u0dba\u0db1' '00 other:\u0da7\u0dca\u200d\u0dbb\u0dd2\u0dbd\u0dd2\u0dba\u0db1' '00}",
+                    "{one:\u0da7\u0dca\u200d\u0dbb\u0dd2\u0dbd\u0dd2\u0dba\u0db1' '000 other:\u0da7\u0dca\u200d\u0dbb\u0dd2\u0dbd\u0dd2\u0dba\u0db1' '000}",
                 }
             },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -351,18 +348,18 @@ public class FormatData_si extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "\u0daf0",
-                    "\u0daf00",
-                    "\u0daf000",
-                    "\u0db8\u0dd20",
-                    "\u0db8\u0dd200",
-                    "\u0db8\u0dd2000",
-                    "\u0db6\u0dd20",
-                    "\u0db6\u0dd200",
-                    "\u0db6\u0dd2000",
-                    "\u0da7\u0dca\u200d\u0dbb\u0dd20",
-                    "\u0da7\u0dca\u200d\u0dbb\u0dd200",
-                    "\u0da7\u0dca\u200d\u0dbb\u0dd2000",
+                    "{one:\u0daf0 other:\u0daf0}",
+                    "{one:\u0daf00 other:\u0daf00}",
+                    "{one:\u0daf000 other:\u0daf000}",
+                    "{one:\u0db8\u0dd20 other:\u0db8\u0dd20}",
+                    "{one:\u0db8\u0dd200 other:\u0db8\u0dd200}",
+                    "{one:\u0db8\u0dd2000 other:\u0db8\u0dd2000}",
+                    "{one:\u0db6\u0dd20 other:\u0db6\u0dd20}",
+                    "{one:\u0db6\u0dd200 other:\u0db6\u0dd200}",
+                    "{one:\u0db6\u0dd2000 other:\u0db6\u0dd2000}",
+                    "{one:\u0da7\u0dca\u200d\u0dbb\u0dd20 other:\u0da7\u0dca\u200d\u0dbb\u0dd20}",
+                    "{one:\u0da7\u0dca\u200d\u0dbb\u0dd200 other:\u0da7\u0dca\u200d\u0dbb\u0dd200}",
+                    "{one:\u0da7\u0dca\u200d\u0dbb\u0dd2000 other:\u0da7\u0dca\u200d\u0dbb\u0dd2000}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -382,6 +379,14 @@ public class FormatData_si extends ListResourceBundle {
             { "field.hour", "\u0db4\u0dd0\u0dba" },
             { "calendarname.buddhist", "\u0db6\u0ddc\u0daf\u0dd4 \u0daf\u0dd2\u0db1 \u0daf\u0dbb\u0dca\u0dc1\u0db1\u0dba" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "\u00a4#,##0.00",
+                    "#,##0%",
+                    "\u00a4#,##0.00;(\u00a4#,##0.00)",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
