@@ -174,6 +174,10 @@ public class FormatData_sk extends ListResourceBundle {
                "AM",
                "PM",
             };
+        final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
+               "BC",
+               "BE",
+            };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
                "EEEE, d. M. y G",
                "d. M. y G",
@@ -190,12 +194,17 @@ public class FormatData_sk extends ListResourceBundle {
                "pred ROC",
                "ROC",
             };
+        final String[] metaValue_java_time_islamic_long_Eras = new String[] {
+               "",
+               "AH",
+            };
         final String metaValue_calendarname_gregorian = "gregori\u00e1nsky kalend\u00e1r";
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
             { "field.year", "rok" },
             { "calendarname.islamic-umalqura", "islamsk\u00fd kalend\u00e1r (Umm al-Qura)" },
             { "japanese.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
+            { "buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "standalone.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
             { "roc.QuarterNames", metaValue_QuarterNames },
@@ -209,12 +218,14 @@ public class FormatData_sk extends ListResourceBundle {
             { "japanese.MonthNames", metaValue_MonthNames },
             { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "java.time.islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "long.Eras",
                 new String[] {
                     "pred Kristom",
                     "po Kristovi",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -239,6 +250,8 @@ public class FormatData_sk extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -266,21 +279,16 @@ public class FormatData_sk extends ListResourceBundle {
                     "",
                 }
             },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "\u010d\u00ednsky republik\u00e1nsky kalend\u00e1r" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
+            { "islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "field.month", "mesiac" },
             { "roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.second", "sekunda" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0\u00a0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "islamsk\u00fd kalend\u00e1r" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
@@ -294,27 +302,30 @@ public class FormatData_sk extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 tis\u00edc",
-                    "00 tis\u00edc",
-                    "000 tis\u00edc",
-                    "0 mili\u00f3n",
-                    "00 mili\u00f3nov",
-                    "000 mili\u00f3nov",
-                    "0 miliarda",
-                    "00 mili\u00e1rd",
-                    "000 mili\u00e1rd",
-                    "0 bili\u00f3n",
-                    "00 bili\u00f3nov",
-                    "000 bili\u00f3nov",
+                    "{one:0' 'tis\u00edc few:0' 'tis\u00edce many:0' 'tis\u00edca other:0' 'tis\u00edc}",
+                    "{one:00' 'tis\u00edc few:00' 'tis\u00edc many:00' 'tis\u00edca other:00' 'tis\u00edc}",
+                    "{one:000' 'tis\u00edc few:000' 'tis\u00edc many:000' 'tis\u00edca other:000' 'tis\u00edc}",
+                    "{one:0' 'mili\u00f3n few:0' 'mili\u00f3ny many:0' 'mili\u00f3na other:0' 'mili\u00f3nov}",
+                    "{one:00' 'mili\u00f3nov few:00' 'mili\u00f3nov many:00' 'mili\u00f3na other:00' 'mili\u00f3nov}",
+                    "{one:000' 'mili\u00f3nov few:000' 'mili\u00f3nov many:000' 'mili\u00f3na other:000' 'mili\u00f3nov}",
+                    "{one:0' 'miliarda few:0' 'miliardy many:0' 'miliardy other:0' 'mili\u00e1rd}",
+                    "{one:00' 'mili\u00e1rd few:00' 'mili\u00e1rd many:00' 'miliardy other:00' 'mili\u00e1rd}",
+                    "{one:000' 'mili\u00e1rd few:000' 'mili\u00e1rd many:000' 'miliardy other:000' 'mili\u00e1rd}",
+                    "{one:0' 'bili\u00f3n few:0' 'bili\u00f3ny many:0' 'bili\u00f3na other:0' 'bili\u00f3nov}",
+                    "{one:00' 'bili\u00f3nov few:00' 'bili\u00f3nov many:00' 'bili\u00f3na other:00' 'bili\u00f3nov}",
+                    "{one:000' 'bili\u00f3nov few:000' 'bili\u00f3nov many:000' 'bili\u00f3na other:000' 'bili\u00f3nov}",
                 }
             },
             { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
+            { "roc.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "standalone.QuarterNames", metaValue_QuarterNames },
             { "japanese.MonthNarrows", metaValue_MonthNarrows },
             { "islamic.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.DayNarrows", metaValue_DayNarrows },
+            { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "islamic.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
+            { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
             { "java.time.roc.Eras", metaValue_java_time_roc_long_Eras },
@@ -329,18 +340,23 @@ public class FormatData_sk extends ListResourceBundle {
             { "field.weekday", "de\u0148 t\u00fd\u017ed\u0148a" },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
+            { "islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
+            { "java.time.islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.QuarterNames", metaValue_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
+            { "java.time.buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "japanese.DayNames", metaValue_DayNames },
             { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNames", metaValue_DayNames },
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.MonthNames", metaValue_MonthNames },
+            { "buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "field.week", "t\u00fd\u017ede\u0148" },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
             { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "roc.DayNarrows", metaValue_DayNarrows },
+            { "roc.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "short.CompactNumberPatterns",
@@ -348,21 +364,22 @@ public class FormatData_sk extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0tis'.'",
-                    "00\u00a0tis'.'",
-                    "000\u00a0tis'.'",
-                    "0\u00a0mil'.'",
-                    "00\u00a0mil'.'",
-                    "000\u00a0mil'.'",
-                    "0\u00a0mld'.'",
-                    "00\u00a0mld'.'",
-                    "000\u00a0mld'.'",
-                    "0\u00a0bil'.'",
-                    "00\u00a0bil'.'",
-                    "000\u00a0bil'.'",
+                    "{one:0\u00a0tis'.' few:0\u00a0tis'.' many:0\u00a0tis'.' other:0\u00a0tis'.'}",
+                    "{one:00\u00a0tis'.' few:00\u00a0tis'.' many:00\u00a0tis'.' other:00\u00a0tis'.'}",
+                    "{one:000\u00a0tis'.' few:000\u00a0tis'.' many:000\u00a0tis'.' other:000\u00a0tis'.'}",
+                    "{one:0\u00a0mil'.' few:0\u00a0mil'.' many:0\u00a0mil'.' other:0\u00a0mil'.'}",
+                    "{one:00\u00a0mil'.' few:00\u00a0mil'.' many:00\u00a0mil'.' other:00\u00a0mil'.'}",
+                    "{one:000\u00a0mil'.' few:000\u00a0mil'.' many:000\u00a0mil'.' other:000\u00a0mil'.'}",
+                    "{one:0\u00a0mld'.' few:0\u00a0mld'.' many:0\u00a0mld'.' other:0\u00a0mld'.'}",
+                    "{one:00\u00a0mld'.' few:00\u00a0mld'.' many:00\u00a0mld'.' other:00\u00a0mld'.'}",
+                    "{one:000\u00a0mld'.' few:000\u00a0mld'.' many:000\u00a0mld'.' other:000\u00a0mld'.'}",
+                    "{one:0\u00a0bil'.' few:0\u00a0bil'.' many:0\u00a0bil'.' other:0\u00a0bil'.'}",
+                    "{one:00\u00a0bil'.' few:00\u00a0bil'.' many:00\u00a0bil'.' other:00\u00a0bil'.'}",
+                    "{one:000\u00a0bil'.' few:000\u00a0bil'.' many:000\u00a0bil'.' other:000\u00a0bil'.'}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
+            { "java.time.buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "DatePatterns",
                 new String[] {
                     "EEEE d. MMMM y",
@@ -393,6 +410,7 @@ public class FormatData_sk extends ListResourceBundle {
                     "",
                 }
             },
+            { "islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "calendarname.buddhist", "buddhistick\u00fd kalend\u00e1r" },
             { "standalone.MonthNames",
                 new String[] {
@@ -411,7 +429,16 @@ public class FormatData_sk extends ListResourceBundle {
                     "",
                 }
             },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0\u00a0%",
+                    "#,##0.00\u00a0\u00a4;(#,##0.00\u00a0\u00a4)",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
+            { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
