@@ -166,6 +166,12 @@ public class FormatData_sl extends ListResourceBundle {
                "pr. Kr.",
                "po Kr.",
             };
+        final String[] metaValue_TimePatterns = new String[] {
+               "HH:mm:ss zzzz",
+               "HH:mm:ss z",
+               "HH:mm:ss",
+               "HH:mm",
+            };
         final String[] metaValue_buddhist_QuarterNarrows = new String[] {
                "1",
                "2",
@@ -214,6 +220,7 @@ public class FormatData_sl extends ListResourceBundle {
             { "roc.MonthNarrows", metaValue_MonthNarrows },
             { "calendarname.islamic-civil", "islamski civilni koledar" },
             { "islamic.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "japanese.TimePatterns", metaValue_TimePatterns },
             { "narrow.Eras", metaValue_Eras },
             { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
@@ -229,6 +236,7 @@ public class FormatData_sl extends ListResourceBundle {
                     "po Kristusu",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -254,6 +262,8 @@ public class FormatData_sl extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -264,6 +274,7 @@ public class FormatData_sl extends ListResourceBundle {
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "dop/pop" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "koledar Minguo" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -272,18 +283,12 @@ public class FormatData_sl extends ListResourceBundle {
             { "field.second", "sekunda" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0\u00a0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "islamski koledar" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "java.time.roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
             { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "timezone.regionFormat", "{0} \u010das" },
             { "long.CompactNumberPatterns",
@@ -291,18 +296,18 @@ public class FormatData_sl extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 tiso\u010d",
-                    "00 tiso\u010d",
-                    "000 tiso\u010d",
-                    "0 milijon",
-                    "00 milijon",
-                    "000 milijon",
-                    "0 milijarda",
-                    "00 milijarda",
-                    "000 milijarda",
-                    "0 bilijon",
-                    "00 bilijon",
-                    "000 bilijon",
+                    "{one:0' 'tiso\u010d two:0' 'tiso\u010d few:0' 'tiso\u010d other:0' 'tiso\u010d}",
+                    "{one:00' 'tiso\u010d two:00' 'tiso\u010d few:00' 'tiso\u010d other:00' 'tiso\u010d}",
+                    "{one:000' 'tiso\u010d two:000' 'tiso\u010d few:000' 'tiso\u010d other:000' 'tiso\u010d}",
+                    "{one:0' 'milijon two:0' 'milijona few:0' 'milijone other:0' 'milijonov}",
+                    "{one:00' 'milijon two:00' 'milijona few:00' 'milijoni other:00' 'milijonov}",
+                    "{one:000' 'milijon two:000' 'milijona few:000' 'milijoni other:000' 'milijonov}",
+                    "{one:0' 'milijarda two:0' 'milijardi few:0' 'milijarde other:0' 'milijard}",
+                    "{one:00' 'milijarda two:00' 'milijardi few:00' 'milijarde other:00' 'milijard}",
+                    "{one:000' 'milijarda two:000' 'milijardi few:000' 'milijarde other:000' 'milijard}",
+                    "{one:0' 'bilijon two:0' 'bilijona few:0' 'bilijoni other:0' 'bilijonov}",
+                    "{one:00' 'bilijon two:00' 'bilijona few:00' 'bilijoni other:00' 'bilijonov}",
+                    "{one:000' 'bilijon two:000' 'bilijona few:000' 'bilijoni other:000' 'bilijonov}",
                 }
             },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -315,6 +320,7 @@ public class FormatData_sl extends ListResourceBundle {
             { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
+            { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
             { "java.time.roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.zone", "\u010dasovni pas" },
@@ -353,18 +359,18 @@ public class FormatData_sl extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0tis'.'",
-                    "00\u00a0tis'.'",
-                    "000\u00a0tis'.'",
-                    "0\u00a0mio'.'",
-                    "00\u00a0mio'.'",
-                    "000\u00a0mio'.'",
-                    "0\u00a0mrd'.'",
-                    "00\u00a0mrd'.'",
-                    "000\u00a0mrd'.'",
-                    "0\u00a0bil'.'",
-                    "00\u00a0bil'.'",
-                    "000\u00a0bil'.'",
+                    "{one:0\u00a0tis'.' two:0\u00a0tis'.' few:0\u00a0tis'.' other:0\u00a0tis'.'}",
+                    "{one:00\u00a0tis'.' two:00\u00a0tis'.' few:00\u00a0tis'.' other:00\u00a0tis'.'}",
+                    "{one:000\u00a0tis'.' two:000\u00a0tis'.' few:000\u00a0tis'.' other:000\u00a0tis'.'}",
+                    "{one:0\u00a0mio'.' two:0\u00a0mio'.' few:0\u00a0mio'.' other:0\u00a0mio'.'}",
+                    "{one:00\u00a0mio'.' two:00\u00a0mio'.' few:00\u00a0mio'.' other:00\u00a0mio'.'}",
+                    "{one:000\u00a0mio'.' two:000\u00a0mio'.' few:000\u00a0mio'.' other:000\u00a0mio'.'}",
+                    "{one:0\u00a0mrd'.' two:0\u00a0mrd'.' few:0\u00a0mrd'.' other:0\u00a0mrd'.'}",
+                    "{one:00\u00a0mrd'.' two:00\u00a0mrd'.' few:00\u00a0mrd'.' other:00\u00a0mrd'.'}",
+                    "{one:000\u00a0mrd'.' two:000\u00a0mrd'.' few:000\u00a0mrd'.' other:000\u00a0mrd'.'}",
+                    "{one:0\u00a0bil'.' two:0\u00a0bil'.' few:0\u00a0bil'.' other:0\u00a0bil'.'}",
+                    "{one:00\u00a0bil'.' two:00\u00a0bil'.' few:00\u00a0bil'.' other:00\u00a0bil'.'}",
+                    "{one:000\u00a0bil'.' two:000\u00a0bil'.' few:000\u00a0bil'.' other:000\u00a0bil'.'}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -379,14 +385,24 @@ public class FormatData_sl extends ListResourceBundle {
                 }
             },
             { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
+            { "islamic.TimePatterns", metaValue_TimePatterns },
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.DayNames", metaValue_DayNames },
             { "field.hour", "ura" },
             { "calendarname.buddhist", "budisti\u010dni koledar" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0\u00a0%",
+                    "#,##0.00\u00a0\u00a4;(#,##0.00\u00a0\u00a4)",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
+            { "roc.TimePatterns", metaValue_TimePatterns },
             { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
