@@ -168,6 +168,12 @@ public class FormatData_sr extends ListResourceBundle {
                "a",
                "p",
             };
+        final String[] metaValue_TimePatterns = new String[] {
+               "HH:mm:ss zzzz",
+               "HH:mm:ss z",
+               "HH:mm:ss",
+               "HH:mm",
+            };
         final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
                "BC",
                "\u0411\u0415",
@@ -229,6 +235,7 @@ public class FormatData_sr extends ListResourceBundle {
             { "roc.MonthNarrows", metaValue_MonthNarrows },
             { "calendarname.islamic-civil", "\u0418\u0441\u043b\u0430\u043c\u0441\u043a\u0438 \u0446\u0438\u0432\u0438\u043b\u043d\u0438 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440" },
             { "islamic.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "japanese.TimePatterns", metaValue_TimePatterns },
             { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "narrow.Eras",
                 new String[] {
@@ -276,6 +283,8 @@ public class FormatData_sr extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -322,36 +331,30 @@ public class FormatData_sr extends ListResourceBundle {
             { "field.second", "\u0441\u0435\u043a\u0443\u043d\u0434" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u0438\u0441\u043b\u0430\u043c\u0441\u043a\u0438 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "java.time.roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
             { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "long.CompactNumberPatterns",
                 new String[] {
                     "",
                     "",
                     "",
-                    "0 \u0445\u0438\u0459\u0430\u0434\u0430",
-                    "00 \u0445\u0438\u0459\u0430\u0434\u0430",
-                    "000 \u0445\u0438\u0459\u0430\u0434\u0430",
-                    "0 \u043c\u0438\u043b\u0438\u043e\u043d",
-                    "00 \u043c\u0438\u043b\u0438\u043e\u043d",
-                    "000 \u043c\u0438\u043b\u0438\u043e\u043d",
-                    "0 \u043c\u0438\u043b\u0438\u0458\u0430\u0440\u0434\u0430",
-                    "00 \u043c\u0438\u043b\u0438\u0458\u0430\u0440\u0434\u0430",
-                    "000 \u043c\u0438\u043b\u0438\u0458\u0430\u0440\u0434\u0430",
-                    "0 \u0431\u0438\u043b\u0438\u043e\u043d",
-                    "00 \u0431\u0438\u043b\u0438\u043e\u043d",
-                    "000 \u0431\u0438\u043b\u0438\u043e\u043d",
+                    "{one:0' '\u0445\u0438\u0459\u0430\u0434\u0430 few:0' '\u0445\u0438\u0459\u0430\u0434\u0435 other:0' '\u0445\u0438\u0459\u0430\u0434\u0430}",
+                    "{one:00' '\u0445\u0438\u0459\u0430\u0434\u0430 few:00' '\u0445\u0438\u0459\u0430\u0434\u0435 other:00' '\u0445\u0438\u0459\u0430\u0434\u0430}",
+                    "{one:000' '\u0445\u0438\u0459\u0430\u0434\u0430 few:000' '\u0445\u0438\u0459\u0430\u0434\u0435 other:000' '\u0445\u0438\u0459\u0430\u0434\u0430}",
+                    "{one:0' '\u043c\u0438\u043b\u0438\u043e\u043d few:0' '\u043c\u0438\u043b\u0438\u043e\u043d\u0430 other:0' '\u043c\u0438\u043b\u0438\u043e\u043d\u0430}",
+                    "{one:00' '\u043c\u0438\u043b\u0438\u043e\u043d few:00' '\u043c\u0438\u043b\u0438\u043e\u043d\u0430 other:00' '\u043c\u0438\u043b\u0438\u043e\u043d\u0430}",
+                    "{one:000' '\u043c\u0438\u043b\u0438\u043e\u043d few:000' '\u043c\u0438\u043b\u0438\u043e\u043d\u0430 other:000' '\u043c\u0438\u043b\u0438\u043e\u043d\u0430}",
+                    "{one:0' '\u043c\u0438\u043b\u0438\u0458\u0430\u0440\u0434\u0430 few:0' '\u043c\u0438\u043b\u0438\u0458\u0430\u0440\u0434\u0435 other:0' '\u043c\u0438\u043b\u0438\u0458\u0430\u0440\u0434\u0438}",
+                    "{one:00' '\u043c\u0438\u043b\u0438\u0458\u0430\u0440\u0434\u0430 few:00' '\u043c\u0438\u043b\u0438\u0458\u0430\u0440\u0434\u0435 other:00' '\u043c\u0438\u043b\u0438\u0458\u0430\u0440\u0434\u0438}",
+                    "{one:000' '\u043c\u0438\u043b\u0438\u0458\u0430\u0440\u0434\u0430 few:000' '\u043c\u0438\u043b\u0438\u0458\u0430\u0440\u0434\u0435 other:000' '\u043c\u0438\u043b\u0438\u0458\u0430\u0440\u0434\u0438}",
+                    "{one:0' '\u0431\u0438\u043b\u0438\u043e\u043d few:0' '\u0431\u0438\u043b\u0438\u043e\u043d\u0430 other:0' '\u0431\u0438\u043b\u0438\u043e\u043d\u0430}",
+                    "{one:00' '\u0431\u0438\u043b\u0438\u043e\u043d few:00' '\u0431\u0438\u043b\u0438\u043e\u043d\u0430 other:00' '\u0431\u0438\u043b\u0438\u043e\u043d\u0430}",
+                    "{one:000' '\u0431\u0438\u043b\u0438\u043e\u043d few:000' '\u0431\u0438\u043b\u0438\u043e\u043d\u0430 other:000' '\u0431\u0438\u043b\u0438\u043e\u043d\u0430}",
                 }
             },
             { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
@@ -364,6 +367,7 @@ public class FormatData_sr extends ListResourceBundle {
             { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
+            { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
             { "java.time.roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.zone", "\u0432\u0440\u0435\u043c\u0435\u043d\u0441\u043a\u0430 \u0437\u043e\u043d\u0430" },
@@ -411,18 +415,18 @@ public class FormatData_sr extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0\u0445\u0438\u0459'.'",
-                    "00\u00a0\u0445\u0438\u0459'.'",
-                    "000\u00a0\u0445\u0438\u0459'.'",
-                    "0\u00a0\u043c\u0438\u043b'.'",
-                    "00\u00a0\u043c\u0438\u043b'.'",
-                    "000\u00a0\u043c\u0438\u043b'.'",
-                    "0\u00a0\u043c\u043b\u0440\u0434'.'",
-                    "00\u00a0\u043c\u043b\u0440\u0434'.'",
-                    "000\u00a0\u043c\u043b\u0440\u0434'.'",
-                    "0\u00a0\u0431\u0438\u043b'.'",
-                    "00\u00a0\u0431\u0438\u043b'.'",
-                    "000\u00a0\u0431\u0438\u043b'.'",
+                    "{one:0\u00a0\u0445\u0438\u0459'.' few:0\u00a0\u0445\u0438\u0459'.' other:0\u00a0\u0445\u0438\u0459'.'}",
+                    "{one:00\u00a0\u0445\u0438\u0459'.' few:00\u00a0\u0445\u0438\u0459'.' other:00\u00a0\u0445\u0438\u0459'.'}",
+                    "{one:000\u00a0\u0445\u0438\u0459'.' few:000\u00a0\u0445\u0438\u0459'.' other:000\u00a0\u0445\u0438\u0459'.'}",
+                    "{one:0\u00a0\u043c\u0438\u043b'.' few:0\u00a0\u043c\u0438\u043b'.' other:0\u00a0\u043c\u0438\u043b'.'}",
+                    "{one:00\u00a0\u043c\u0438\u043b'.' few:00\u00a0\u043c\u0438\u043b'.' other:00\u00a0\u043c\u0438\u043b'.'}",
+                    "{one:000\u00a0\u043c\u0438\u043b'.' few:000\u00a0\u043c\u0438\u043b'.' other:000\u00a0\u043c\u0438\u043b'.'}",
+                    "{one:0\u00a0\u043c\u043b\u0440\u0434'.' few:0\u00a0\u043c\u043b\u0440\u0434'.' other:0\u00a0\u043c\u043b\u0440\u0434'.'}",
+                    "{one:00\u00a0\u043c\u043b\u0440\u0434'.' few:00\u00a0\u043c\u043b\u0440\u0434'.' other:00\u00a0\u043c\u043b\u0440\u0434'.'}",
+                    "{one:000\u00a0\u043c\u043b\u0440\u0434'.' few:000\u00a0\u043c\u043b\u0440\u0434'.' other:000\u00a0\u043c\u043b\u0440\u0434'.'}",
+                    "{one:0\u00a0\u0431\u0438\u043b'.' few:0\u00a0\u0431\u0438\u043b'.' other:0\u00a0\u0431\u0438\u043b'.'}",
+                    "{one:00\u00a0\u0431\u0438\u043b'.' few:00\u00a0\u0431\u0438\u043b'.' other:00\u00a0\u0431\u0438\u043b'.'}",
+                    "{one:000\u00a0\u0431\u0438\u043b'.' few:000\u00a0\u0431\u0438\u043b'.' other:000\u00a0\u0431\u0438\u043b'.'}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -437,16 +441,26 @@ public class FormatData_sr extends ListResourceBundle {
                 }
             },
             { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
+            { "islamic.TimePatterns", metaValue_TimePatterns },
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.DayNames", metaValue_DayNames },
             { "field.hour", "\u0441\u0430\u0442" },
             { "islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "calendarname.buddhist", "\u0431\u0443\u0434\u0438\u0441\u0442\u0438\u0447\u043a\u0438 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0%",
+                    "#,##0.00\u00a0\u00a4;(#,##0.00\u00a0\u00a4)",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
+            { "roc.TimePatterns", metaValue_TimePatterns },
             { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "japanese.Eras", metaValue_java_time_japanese_Eras },
             { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
