@@ -168,6 +168,12 @@ public class FormatData_sr_Latn extends ListResourceBundle {
                "a",
                "p",
             };
+        final String[] metaValue_TimePatterns = new String[] {
+               "HH:mm:ss zzzz",
+               "HH:mm:ss z",
+               "HH:mm:ss",
+               "HH:mm",
+            };
         final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
                "BC",
                "BE",
@@ -229,6 +235,7 @@ public class FormatData_sr_Latn extends ListResourceBundle {
             { "roc.MonthNarrows", metaValue_MonthNarrows },
             { "calendarname.islamic-civil", "Islamski civilni kalendar" },
             { "islamic.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "japanese.TimePatterns", metaValue_TimePatterns },
             { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "narrow.Eras",
                 new String[] {
@@ -276,6 +283,8 @@ public class FormatData_sr_Latn extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -322,36 +331,30 @@ public class FormatData_sr_Latn extends ListResourceBundle {
             { "field.second", "sekund" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "islamski kalendar" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "java.time.roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
             { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "long.CompactNumberPatterns",
                 new String[] {
                     "",
                     "",
                     "",
-                    "0 hiljada",
-                    "00 hiljada",
-                    "000 hiljada",
-                    "0 milion",
-                    "00 milion",
-                    "000 milion",
-                    "0 milijarda",
-                    "00 milijarda",
-                    "000 milijarda",
-                    "0 bilion",
-                    "00 bilion",
-                    "000 bilion",
+                    "{one:0' 'hiljada few:0' 'hiljade other:0' 'hiljada}",
+                    "{one:00' 'hiljada few:00' 'hiljade other:00' 'hiljada}",
+                    "{one:000' 'hiljada few:000' 'hiljade other:000' 'hiljada}",
+                    "{one:0' 'milion few:0' 'miliona other:0' 'miliona}",
+                    "{one:00' 'milion few:00' 'miliona other:00' 'miliona}",
+                    "{one:000' 'milion few:000' 'miliona other:000' 'miliona}",
+                    "{one:0' 'milijarda few:0' 'milijarde other:0' 'milijardi}",
+                    "{one:00' 'milijarda few:00' 'milijarde other:00' 'milijardi}",
+                    "{one:000' 'milijarda few:000' 'milijarde other:000' 'milijardi}",
+                    "{one:0' 'bilion few:0' 'biliona other:0' 'biliona}",
+                    "{one:00' 'bilion few:00' 'biliona other:00' 'biliona}",
+                    "{one:000' 'bilion few:000' 'biliona other:000' 'biliona}",
                 }
             },
             { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
@@ -364,6 +367,7 @@ public class FormatData_sr_Latn extends ListResourceBundle {
             { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
+            { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
             { "java.time.roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.zone", "vremenska zona" },
@@ -411,18 +415,18 @@ public class FormatData_sr_Latn extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0hilj'.'",
-                    "00\u00a0hilj'.'",
-                    "000\u00a0hilj'.'",
-                    "0\u00a0mil'.'",
-                    "00\u00a0mil'.'",
-                    "000\u00a0mil'.'",
-                    "0\u00a0mlrd'.'",
-                    "00\u00a0mlrd'.'",
-                    "000\u00a0mlrd'.'",
-                    "0\u00a0bil'.'",
-                    "00\u00a0bil'.'",
-                    "000\u00a0bil'.'",
+                    "{one:0\u00a0hilj'.' few:0\u00a0hilj'.' other:0\u00a0hilj'.'}",
+                    "{one:00\u00a0hilj'.' few:00\u00a0hilj'.' other:00\u00a0hilj'.'}",
+                    "{one:000\u00a0hilj'.' few:000\u00a0hilj'.' other:000\u00a0hilj'.'}",
+                    "{one:0\u00a0mil'.' few:0\u00a0mil'.' other:0\u00a0mil'.'}",
+                    "{one:00\u00a0mil'.' few:00\u00a0mil'.' other:00\u00a0mil'.'}",
+                    "{one:000\u00a0mil'.' few:000\u00a0mil'.' other:000\u00a0mil'.'}",
+                    "{one:0\u00a0mlrd'.' few:0\u00a0mlrd'.' other:0\u00a0mlrd'.'}",
+                    "{one:00\u00a0mlrd'.' few:00\u00a0mlrd'.' other:00\u00a0mlrd'.'}",
+                    "{one:000\u00a0mlrd'.' few:000\u00a0mlrd'.' other:000\u00a0mlrd'.'}",
+                    "{one:0\u00a0bil'.' few:0\u00a0bil'.' other:0\u00a0bil'.'}",
+                    "{one:00\u00a0bil'.' few:00\u00a0bil'.' other:00\u00a0bil'.'}",
+                    "{one:000\u00a0bil'.' few:000\u00a0bil'.' other:000\u00a0bil'.'}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -437,16 +441,26 @@ public class FormatData_sr_Latn extends ListResourceBundle {
                 }
             },
             { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
+            { "islamic.TimePatterns", metaValue_TimePatterns },
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.DayNames", metaValue_DayNames },
             { "field.hour", "sat" },
             { "islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "calendarname.buddhist", "budisti\u010dki kalendar" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0%",
+                    "#,##0.00\u00a0\u00a4;(#,##0.00\u00a0\u00a4)",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
+            { "roc.TimePatterns", metaValue_TimePatterns },
             { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "japanese.Eras", metaValue_java_time_japanese_Eras },
             { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
