@@ -168,6 +168,12 @@ public class FormatData_sv extends ListResourceBundle {
                "HH:mm:ss",
                "HH:mm",
             };
+        final String[] metaValue_DateTimePatterns = new String[] {
+               "{1} {0}",
+               "{1} {0}",
+               "{1} {0}",
+               "{1} {0}",
+            };
         final String[] metaValue_buddhist_QuarterNarrows = new String[] {
                "1",
                "2",
@@ -178,6 +184,10 @@ public class FormatData_sv extends ListResourceBundle {
                "BC",
                "Buddhistisk era",
             };
+        final String[] metaValue_java_time_buddhist_Eras = new String[] {
+               "BC",
+               "BE",
+            };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
                "EEEE d MMMM y G",
                "d MMMM y G",
@@ -190,6 +200,22 @@ public class FormatData_sv extends ListResourceBundle {
                "d MMM y GGGG",
                "GGGG y-MM-dd",
             };
+        final String[] metaValue_java_time_japanese_long_Eras = new String[] {
+               "efter Kristus",
+               "Meiji",
+               "Taish\u014d",
+               "Sh\u014dwa",
+               "Heisei",
+               "Reiwa",
+            };
+        final String[] metaValue_java_time_japanese_Eras = new String[] {
+               "e.Kr.",
+               "Meiji",
+               "Taish\u014d",
+               "Sh\u014dwa",
+               "Heisei",
+               "Reiwa",
+            };
         final String[] metaValue_java_time_roc_long_Eras = new String[] {
                "f\u00f6re Republiken Kina",
                "Minguo",
@@ -206,7 +232,17 @@ public class FormatData_sv extends ListResourceBundle {
                "",
                "efter Hirja",
             };
+        final String[] metaValue_java_time_islamic_Eras = new String[] {
+               "",
+               "AH",
+            };
         final String metaValue_calendarname_gregorian = "gregoriansk kalender";
+        final String[] metaValue_arabext_NumberPatterns = new String[] {
+               "#,##0.###",
+               "\u00a4\u00a0#,##0.00",
+               "#,##0%",
+               "",
+            };
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
             { "field.year", "\u00e5r" },
@@ -224,9 +260,12 @@ public class FormatData_sv extends ListResourceBundle {
                     "\u0609",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
+            { "buddhist.narrow.Eras", metaValue_java_time_buddhist_Eras },
             { "AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -244,23 +283,18 @@ public class FormatData_sv extends ListResourceBundle {
             { "japanese.MonthNames", metaValue_MonthNames },
             { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "java.time.islamic.narrow.Eras", metaValue_java_time_islamic_Eras },
             { "long.Eras",
                 new String[] {
                     "f\u00f6re Kristus",
                     "efter Kristus",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
-            { "DateTimePatterns",
-                new String[] {
-                    "{1} {0}",
-                    "{1} {0}",
-                    "{1} {0}",
-                    "{1} {0}",
-                }
-            },
+            { "DateTimePatterns", metaValue_DateTimePatterns },
             { "narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "latn.NumberElements",
                 new String[] {
@@ -275,12 +309,15 @@ public class FormatData_sv extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
             { "japanese.DatePatterns", metaValue_buddhist_DatePatterns },
             { "buddhist.DayNames", metaValue_DayNames },
             { "field.minute", "minut" },
+            { "japanese.long.Eras", metaValue_java_time_japanese_long_Eras },
             { "field.era", "era" },
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "fm/em" },
@@ -302,6 +339,7 @@ public class FormatData_sv extends ListResourceBundle {
                     "",
                 }
             },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "arab.NumberElements",
                 new String[] {
                     "\u066b",
@@ -315,23 +353,21 @@ public class FormatData_sv extends ListResourceBundle {
                     "\u0609\u200f",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "calendarname.roc", "kinesiska republikens kalender" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "islamic.Eras", metaValue_java_time_islamic_Eras },
             { "field.month", "m\u00e5nad" },
+            { "arabext.NumberPatterns", metaValue_arabext_NumberPatterns },
+            { "java.time.japanese.long.Eras", metaValue_java_time_japanese_long_Eras },
             { "roc.Eras", metaValue_java_time_roc_Eras },
             { "field.second", "sekund" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0\u00a0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "islamisk kalender" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
@@ -345,18 +381,18 @@ public class FormatData_sv extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 tusen",
-                    "00 tusen",
-                    "000 tusen",
-                    "0 miljon",
-                    "00 miljon",
-                    "000 miljoner",
-                    "0 miljard",
-                    "00 miljarder",
-                    "000 miljarder",
-                    "0 biljon",
-                    "00 biljoner",
-                    "000 biljoner",
+                    "{one:0' 'tusen other:0' 'tusen}",
+                    "{one:00' 'tusen other:00' 'tusen}",
+                    "{one:000' 'tusen other:000' 'tusen}",
+                    "{one:0' 'miljon other:0' 'miljoner}",
+                    "{one:00' 'miljon other:00' 'miljoner}",
+                    "{one:000' 'miljoner other:000' 'miljoner}",
+                    "{one:0' 'miljard other:0' 'miljarder}",
+                    "{one:00' 'miljarder other:00' 'miljarder}",
+                    "{one:000' 'miljarder other:000' 'miljarder}",
+                    "{one:0' 'biljon other:0' 'biljoner}",
+                    "{one:00' 'biljoner other:00' 'biljoner}",
+                    "{one:000' 'biljoner other:000' 'biljoner}",
                 }
             },
             { "roc.narrow.AmPmMarkers", metaValue_AmPmMarkers },
@@ -383,6 +419,8 @@ public class FormatData_sv extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "islamic.DayNarrows", metaValue_DayNarrows },
@@ -390,6 +428,14 @@ public class FormatData_sv extends ListResourceBundle {
             { "field.zone", "tidszon" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.narrow.Eras", metaValue_java_time_roc_narrow_Eras },
+            { "arab.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0%",
+                    "",
+                }
+            },
             { "buddhist.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "Eras", metaValue_Eras },
@@ -401,14 +447,19 @@ public class FormatData_sv extends ListResourceBundle {
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
             { "islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
+            { "java.time.islamic.Eras", metaValue_java_time_islamic_Eras },
+            { "fullwide.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "japanese.QuarterNames", metaValue_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "java.time.buddhist.Eras", metaValue_java_time_buddhist_Eras },
             { "timezone.hourFormat", "+HH:mm;\u2212HH:mm" },
             { "japanese.DayNames", metaValue_DayNames },
             { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNames", metaValue_DayNames },
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "java.time.japanese.Eras", metaValue_java_time_japanese_Eras },
             { "roc.MonthNames", metaValue_MonthNames },
+            { "buddhist.Eras", metaValue_java_time_buddhist_Eras },
             { "field.week", "vecka" },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
@@ -422,21 +473,22 @@ public class FormatData_sv extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0tn",
-                    "00\u00a0tn",
-                    "000\u00a0tn",
-                    "0\u00a0mn",
-                    "00\u00a0mn",
-                    "000\u00a0mn",
-                    "0\u00a0md",
-                    "00\u00a0md",
-                    "000\u00a0md",
-                    "0\u00a0bn",
-                    "00\u00a0bn",
-                    "000\u00a0bn",
+                    "{one:0\u00a0tn other:0\u00a0tn}",
+                    "{one:00\u00a0tn other:00\u00a0tn}",
+                    "{one:000\u00a0tn other:000\u00a0tn}",
+                    "{one:0\u00a0mn other:0\u00a0mn}",
+                    "{one:00\u00a0mn other:00\u00a0mn}",
+                    "{one:000\u00a0mn other:000\u00a0mn}",
+                    "{one:0\u00a0md other:0\u00a0md}",
+                    "{one:00\u00a0md other:00\u00a0md}",
+                    "{one:000\u00a0md other:000\u00a0md}",
+                    "{one:0\u00a0bn other:0\u00a0bn}",
+                    "{one:00\u00a0bn other:00\u00a0bn}",
+                    "{one:000\u00a0bn other:000\u00a0bn}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
+            { "java.time.buddhist.narrow.Eras", metaValue_java_time_buddhist_Eras },
             { "timezone.regionFormat.daylight", "{0} (sommartid)" },
             { "DatePatterns",
                 new String[] {
@@ -448,17 +500,28 @@ public class FormatData_sv extends ListResourceBundle {
             },
             { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
             { "islamic.TimePatterns", metaValue_TimePatterns },
+            { "japanese.DateTimePatterns", metaValue_DateTimePatterns },
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.DayNames", metaValue_DayNames },
             { "field.hour", "timme" },
+            { "islamic.narrow.Eras", metaValue_java_time_islamic_Eras },
             { "calendarname.buddhist", "buddistisk kalender" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0\u00a0%",
+                    "#,##0.00\u00a0\u00a4",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
             { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "japanese.Eras", metaValue_java_time_japanese_Eras },
             { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
