@@ -174,6 +174,14 @@ public class FormatData_te extends ListResourceBundle {
                "3",
                "4",
             };
+        final String[] metaValue_buddhist_AmPmMarkers = new String[] {
+               "AM",
+               "PM",
+            };
+        final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
+               "BC",
+               "BE",
+            };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
                "EEEE d MMMM y G",
                "d MMMM y G",
@@ -186,19 +194,21 @@ public class FormatData_te extends ListResourceBundle {
                "d MMM y GGGG",
                "dd-MM-y G",
             };
-        final String[] metaValue_roc_AmPmMarkers = new String[] {
-               "AM",
-               "PM",
-            };
         final String[] metaValue_java_time_roc_long_Eras = new String[] {
                "R.O.C. \u0c2a\u0c42\u0c30\u0c4d\u0c35\u0c02",
+               "R.O.C.",
+            };
+        final String[] metaValue_java_time_islamic_long_Eras = new String[] {
                "",
+               "AH",
             };
         final String metaValue_calendarname_gregorian = "\u0c17\u0c4d\u0c30\u0c47\u0c17\u0c4b\u0c30\u0c3f\u0c2f\u0c28\u0c4d \u0c15\u0c4d\u0c2f\u0c3e\u0c32\u0c46\u0c02\u0c21\u0c30\u0c4d";
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
             { "field.year", "\u0c38\u0c02\u0c35\u0c24\u0c4d\u0c38\u0c30\u0c02" },
             { "calendarname.islamic-umalqura", "\u0c07\u0c38\u0c4d\u0c32\u0c3e\u0c2e\u0c3f\u0c15\u0c4d \u0c15\u0c4d\u0c2f\u0c3e\u0c32\u0c46\u0c02\u0c21\u0c30\u0c4d (\u0c09\u0c2e\u0c4d \u0c05\u0c32\u0c4d-\u0c16\u0c41\u0c30\u0c3e)" },
+            { "japanese.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
+            { "buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.QuarterNames", metaValue_QuarterNames },
@@ -213,12 +223,14 @@ public class FormatData_te extends ListResourceBundle {
             { "japanese.MonthNames", metaValue_MonthNames },
             { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "java.time.islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "long.Eras",
                 new String[] {
                     "\u0c15\u0c4d\u0c30\u0c40\u0c38\u0c4d\u0c24\u0c41 \u0c2a\u0c42\u0c30\u0c4d\u0c35\u0c02",
                     "\u0c15\u0c4d\u0c30\u0c40\u0c38\u0c4d\u0c24\u0c41 \u0c36\u0c15\u0c02",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -244,6 +256,8 @@ public class FormatData_te extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -251,23 +265,19 @@ public class FormatData_te extends ListResourceBundle {
             { "buddhist.DayNames", metaValue_DayNames },
             { "field.minute", "\u0c28\u0c3f\u0c2e\u0c3f\u0c37\u0c2e\u0c41" },
             { "field.era", "\u0c2f\u0c41\u0c17\u0c02" },
+            { "buddhist.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "field.dayperiod", "AM/PM" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "\u0c2e\u0c3f\u0c02\u0c17\u0c4d\u0c2f\u0c42 \u0c15\u0c4d\u0c2f\u0c3e\u0c32\u0c46\u0c02\u0c21\u0c30\u0c4d" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "field.month", "\u0c28\u0c46\u0c32" },
             { "roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.second", "\u0c38\u0c46\u0c15\u0c28\u0c41" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##,##0.###",
-                    "\u00a4#,##,##0.00",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u0c07\u0c38\u0c4d\u0c32\u0c3e\u0c2e\u0c3f\u0c15\u0c4d \u0c15\u0c4d\u0c2f\u0c3e\u0c32\u0c46\u0c02\u0c21\u0c30\u0c4d" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
@@ -281,18 +291,18 @@ public class FormatData_te extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 \u0c35\u0c47\u0c2f\u0c3f",
-                    "00 \u0c35\u0c47\u0c32\u0c41",
-                    "000 \u0c35\u0c47\u0c32\u0c41",
-                    "0 \u0c2e\u0c3f\u0c32\u0c3f\u0c2f\u0c28\u0c4d",
-                    "00 \u0c2e\u0c3f\u0c32\u0c3f\u0c2f\u0c28\u0c4d\u0c32\u0c41",
-                    "000 \u0c2e\u0c3f\u0c32\u0c3f\u0c2f\u0c28\u0c4d\u0c32\u0c41",
-                    "0 \u0c2c\u0c3f\u0c32\u0c3f\u0c2f\u0c28\u0c4d",
-                    "00 \u0c2c\u0c3f\u0c32\u0c3f\u0c2f\u0c28\u0c4d\u0c32\u0c41",
-                    "000 \u0c2c\u0c3f\u0c32\u0c3f\u0c2f\u0c28\u0c4d\u0c32\u0c41",
-                    "0 \u0c1f\u0c4d\u0c30\u0c3f\u0c32\u0c3f\u0c2f\u0c28\u0c4d",
-                    "00 \u0c1f\u0c4d\u0c30\u0c3f\u0c32\u0c3f\u0c2f\u0c28\u0c4d\u0c32\u0c41",
-                    "000 \u0c1f\u0c4d\u0c30\u0c3f\u0c32\u0c3f\u0c2f\u0c28\u0c4d\u0c32\u0c41",
+                    "{one:0' '\u0c35\u0c47\u0c2f\u0c3f other:0' '\u0c35\u0c47\u0c32\u0c41}",
+                    "{one:00' '\u0c35\u0c47\u0c32\u0c41 other:00' '\u0c35\u0c47\u0c32\u0c41}",
+                    "{one:000' '\u0c35\u0c47\u0c32\u0c41 other:000' '\u0c35\u0c47\u0c32\u0c41}",
+                    "{one:0' '\u0c2e\u0c3f\u0c32\u0c3f\u0c2f\u0c28\u0c4d other:0' '\u0c2e\u0c3f\u0c32\u0c3f\u0c2f\u0c28\u0c4d\u0c32\u0c41}",
+                    "{one:00' '\u0c2e\u0c3f\u0c32\u0c3f\u0c2f\u0c28\u0c4d\u0c32\u0c41 other:00' '\u0c2e\u0c3f\u0c32\u0c3f\u0c2f\u0c28\u0c4d\u0c32\u0c41}",
+                    "{one:000' '\u0c2e\u0c3f\u0c32\u0c3f\u0c2f\u0c28\u0c4d\u0c32\u0c41 other:000' '\u0c2e\u0c3f\u0c32\u0c3f\u0c2f\u0c28\u0c4d\u0c32\u0c41}",
+                    "{one:0' '\u0c2c\u0c3f\u0c32\u0c3f\u0c2f\u0c28\u0c4d other:0' '\u0c2c\u0c3f\u0c32\u0c3f\u0c2f\u0c28\u0c4d\u0c32\u0c41}",
+                    "{one:00' '\u0c2c\u0c3f\u0c32\u0c3f\u0c2f\u0c28\u0c4d\u0c32\u0c41 other:00' '\u0c2c\u0c3f\u0c32\u0c3f\u0c2f\u0c28\u0c4d\u0c32\u0c41}",
+                    "{one:000' '\u0c2c\u0c3f\u0c32\u0c3f\u0c2f\u0c28\u0c4d\u0c32\u0c41 other:000' '\u0c2c\u0c3f\u0c32\u0c3f\u0c2f\u0c28\u0c4d\u0c32\u0c41}",
+                    "{one:0' '\u0c1f\u0c4d\u0c30\u0c3f\u0c32\u0c3f\u0c2f\u0c28\u0c4d other:0' '\u0c1f\u0c4d\u0c30\u0c3f\u0c32\u0c3f\u0c2f\u0c28\u0c4d\u0c32\u0c41}",
+                    "{one:00' '\u0c1f\u0c4d\u0c30\u0c3f\u0c32\u0c3f\u0c2f\u0c28\u0c4d\u0c32\u0c41 other:00' '\u0c1f\u0c4d\u0c30\u0c3f\u0c32\u0c3f\u0c2f\u0c28\u0c4d\u0c32\u0c41}",
+                    "{one:000' '\u0c1f\u0c4d\u0c30\u0c3f\u0c32\u0c3f\u0c2f\u0c28\u0c4d\u0c32\u0c41 other:000' '\u0c1f\u0c4d\u0c30\u0c3f\u0c32\u0c3f\u0c2f\u0c28\u0c4d\u0c32\u0c41}",
                 }
             },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -302,13 +312,23 @@ public class FormatData_te extends ListResourceBundle {
             { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.DayNarrows", metaValue_DayNarrows },
-            { "islamic.AmPmMarkers", metaValue_roc_AmPmMarkers },
+            { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
+            { "islamic.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
+            { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
             { "java.time.roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.zone", "\u0c38\u0c2e\u0c2f \u0c2e\u0c02\u0c21\u0c32\u0c3f" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
+            { "telu.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "\u00a4#,##,##0.00",
+                    "#,##0%",
+                    "",
+                }
+            },
             { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "Eras", metaValue_Eras },
             { "roc.DayNames", metaValue_DayNames },
@@ -317,8 +337,11 @@ public class FormatData_te extends ListResourceBundle {
             { "field.weekday", "\u0c35\u0c3e\u0c30\u0c02\u0c32\u0c4b \u0c30\u0c4b\u0c1c\u0c41" },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
+            { "islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
+            { "java.time.islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.QuarterNames", metaValue_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "java.time.buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "telu.NumberElements",
                 new String[] {
                     ".",
@@ -332,6 +355,8 @@ public class FormatData_te extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "japanese.DayNames", metaValue_DayNames },
@@ -339,12 +364,13 @@ public class FormatData_te extends ListResourceBundle {
             { "DayNames", metaValue_DayNames },
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.MonthNames", metaValue_MonthNames },
+            { "buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "field.week", "\u0c35\u0c3e\u0c30\u0c2e\u0c41" },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
             { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "roc.DayNarrows", metaValue_DayNarrows },
-            { "roc.AmPmMarkers", metaValue_roc_AmPmMarkers },
+            { "roc.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "short.CompactNumberPatterns",
@@ -352,21 +378,22 @@ public class FormatData_te extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u0c35\u0c47",
-                    "00\u0c35\u0c47",
-                    "000\u0c35\u0c47",
-                    "0\u0c2e\u0c3f",
-                    "00\u0c2e\u0c3f",
-                    "000\u0c2e\u0c3f",
-                    "0\u0c2c\u0c3f",
-                    "00\u0c2c\u0c3f",
-                    "000\u0c2c\u0c3f",
-                    "0\u0c1f\u0c4d\u0c30\u0c3f",
-                    "00\u0c1f\u0c4d\u0c30\u0c3f",
-                    "000\u0c1f\u0c4d\u0c30\u0c3f",
+                    "{one:0\u0c35\u0c47 other:0\u0c35\u0c47}",
+                    "{one:00\u0c35\u0c47 other:00\u0c35\u0c47}",
+                    "{one:000\u0c35\u0c47 other:000\u0c35\u0c47}",
+                    "{one:0\u0c2e\u0c3f other:0\u0c2e\u0c3f}",
+                    "{one:00\u0c2e\u0c3f other:00\u0c2e\u0c3f}",
+                    "{one:000\u0c2e\u0c3f other:000\u0c2e\u0c3f}",
+                    "{one:0\u0c2c\u0c3f other:0\u0c2c\u0c3f}",
+                    "{one:00\u0c2c\u0c3f other:00\u0c2c\u0c3f}",
+                    "{one:000\u0c2c\u0c3f other:000\u0c2c\u0c3f}",
+                    "{one:0\u0c1f\u0c4d\u0c30\u0c3f other:0\u0c1f\u0c4d\u0c30\u0c3f}",
+                    "{one:00\u0c1f\u0c4d\u0c30\u0c3f other:00\u0c1f\u0c4d\u0c30\u0c3f}",
+                    "{one:000\u0c1f\u0c4d\u0c30\u0c3f other:000\u0c1f\u0c4d\u0c30\u0c3f}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
+            { "java.time.buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "timezone.regionFormat.daylight", "{0} \u0c2a\u0c17\u0c1f\u0c3f \u0c35\u0c46\u0c32\u0c41\u0c24\u0c41\u0c30\u0c41 \u0c38\u0c2e\u0c2f\u0c02" },
             { "DatePatterns",
                 new String[] {
@@ -398,9 +425,19 @@ public class FormatData_te extends ListResourceBundle {
                     "",
                 }
             },
+            { "islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "calendarname.buddhist", "\u0c2c\u0c41\u0c26\u0c4d\u0c27\u0c41\u0c32 \u0c15\u0c4d\u0c2f\u0c3e\u0c32\u0c46\u0c02\u0c21\u0c30\u0c4d\u200c" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##,##0.###",
+                    "\u00a4#,##,##0.00",
+                    "#,##0%",
+                    "\u00a4#,##0.00;(\u00a4#,##0.00)",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
+            { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
