@@ -151,6 +151,12 @@ public class FormatData_th extends ListResourceBundle {
                "HH:mm:ss",
                "HH:mm",
             };
+        final String[] metaValue_DateTimePatterns = new String[] {
+               "{1} {0}",
+               "{1} {0}",
+               "{1} {0}",
+               "{1} {0}",
+            };
         final String[] metaValue_buddhist_QuarterNarrows = new String[] {
                "1",
                "2",
@@ -231,17 +237,11 @@ public class FormatData_th extends ListResourceBundle {
                     "\u0e04\u0e23\u0e34\u0e2a\u0e15\u0e4c\u0e28\u0e31\u0e01\u0e23\u0e32\u0e0a",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
-            { "DateTimePatterns",
-                new String[] {
-                    "{1} {0}",
-                    "{1} {0}",
-                    "{1} {0}",
-                    "{1} {0}",
-                }
-            },
+            { "DateTimePatterns", metaValue_DateTimePatterns },
             { "narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "latn.NumberElements",
                 new String[] {
@@ -256,6 +256,8 @@ public class FormatData_th extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthAbbreviations },
@@ -291,6 +293,7 @@ public class FormatData_th extends ListResourceBundle {
                     "",
                 }
             },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "\u0e1b\u0e0f\u0e34\u0e17\u0e34\u0e19\u0e44\u0e15\u0e49\u0e2b\u0e27\u0e31\u0e19" },
             { "islamic.DatePatterns",
                 new String[] {
@@ -308,13 +311,6 @@ public class FormatData_th extends ListResourceBundle {
             { "field.second", "\u0e27\u0e34\u0e19\u0e32\u0e17\u0e35" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "\u00a4#,##0.00",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns",
                 new String[] {
                     "EEEE\u0e17\u0e35\u0e48 d MMMM \u0e1b\u0e35GGGG\u0e17\u0e35\u0e48 y",
@@ -335,18 +331,18 @@ public class FormatData_th extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 \u0e1e\u0e31\u0e19",
-                    "0 \u0e2b\u0e21\u0e37\u0e48\u0e19",
-                    "0 \u0e41\u0e2a\u0e19",
-                    "0 \u0e25\u0e49\u0e32\u0e19",
-                    "00 \u0e25\u0e49\u0e32\u0e19",
-                    "000 \u0e25\u0e49\u0e32\u0e19",
-                    "0 \u0e1e\u0e31\u0e19\u0e25\u0e49\u0e32\u0e19",
-                    "0 \u0e2b\u0e21\u0e37\u0e48\u0e19\u0e25\u0e49\u0e32\u0e19",
-                    "0 \u0e41\u0e2a\u0e19\u0e25\u0e49\u0e32\u0e19",
-                    "0 \u0e25\u0e49\u0e32\u0e19\u0e25\u0e49\u0e32\u0e19",
-                    "00 \u0e25\u0e49\u0e32\u0e19\u0e25\u0e49\u0e32\u0e19",
-                    "000 \u0e25\u0e49\u0e32\u0e19\u0e25\u0e49\u0e32\u0e19",
+                    "{other:0' '\u0e1e\u0e31\u0e19}",
+                    "{other:0' '\u0e2b\u0e21\u0e37\u0e48\u0e19}",
+                    "{other:0' '\u0e41\u0e2a\u0e19}",
+                    "{other:0' '\u0e25\u0e49\u0e32\u0e19}",
+                    "{other:00' '\u0e25\u0e49\u0e32\u0e19}",
+                    "{other:000' '\u0e25\u0e49\u0e32\u0e19}",
+                    "{other:0' '\u0e1e\u0e31\u0e19\u0e25\u0e49\u0e32\u0e19}",
+                    "{other:0' '\u0e2b\u0e21\u0e37\u0e48\u0e19\u0e25\u0e49\u0e32\u0e19}",
+                    "{other:0' '\u0e41\u0e2a\u0e19\u0e25\u0e49\u0e32\u0e19}",
+                    "{other:0' '\u0e25\u0e49\u0e32\u0e19\u0e25\u0e49\u0e32\u0e19}",
+                    "{other:00' '\u0e25\u0e49\u0e32\u0e19\u0e25\u0e49\u0e32\u0e19}",
+                    "{other:000' '\u0e25\u0e49\u0e32\u0e19\u0e25\u0e49\u0e32\u0e19}",
                 }
             },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -428,18 +424,18 @@ public class FormatData_th extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0K",
-                    "00K",
-                    "000K",
-                    "0M",
-                    "00M",
-                    "000M",
-                    "0B",
-                    "00B",
-                    "000B",
-                    "0T",
-                    "00T",
-                    "000T",
+                    "{other:0K}",
+                    "{other:00K}",
+                    "{other:000K}",
+                    "{other:0M}",
+                    "{other:00M}",
+                    "{other:000M}",
+                    "{other:0B}",
+                    "{other:00B}",
+                    "{other:000B}",
+                    "{other:0T}",
+                    "{other:00T}",
+                    "{other:000T}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -455,6 +451,7 @@ public class FormatData_th extends ListResourceBundle {
             },
             { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
             { "islamic.TimePatterns", metaValue_TimePatterns },
+            { "japanese.DateTimePatterns", metaValue_DateTimePatterns },
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.DayNames", metaValue_DayNames },
             { "field.hour", "\u0e0a\u0e31\u0e48\u0e27\u0e42\u0e21\u0e07" },
@@ -478,6 +475,14 @@ public class FormatData_th extends ListResourceBundle {
             { "islamic.narrow.Eras", metaValue_java_time_islamic_Eras },
             { "calendarname.buddhist", "\u0e1b\u0e0f\u0e34\u0e17\u0e34\u0e19\u0e1e\u0e38\u0e17\u0e18" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "\u00a4#,##0.00",
+                    "#,##0%",
+                    "\u00a4#,##0.00;(\u00a4#,##0.00)",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
