@@ -230,6 +230,7 @@ public class FormatData_tk extends ListResourceBundle {
                     "Isadan so\u0148",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -255,6 +256,8 @@ public class FormatData_tk extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "san\u00a0d\u00e4l",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -265,6 +268,7 @@ public class FormatData_tk extends ListResourceBundle {
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "g\u00fcnortadan \u00f6\u0148/g\u00fcnortadan so\u0148" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "Minguo senenamasy" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -272,13 +276,6 @@ public class FormatData_tk extends ListResourceBundle {
             { "field.second", "sekunt" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0\u00a0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "Hijri-kamary senenamasy" },
             { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -306,18 +303,18 @@ public class FormatData_tk extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 m\u00fc\u0148",
-                    "00 m\u00fc\u0148",
-                    "000 m\u00fc\u0148",
-                    "0 million",
-                    "00 million",
-                    "000 million",
-                    "0 milliard",
-                    "00 milliard",
-                    "000 milliard",
-                    "0 trillion",
-                    "00 trillion",
-                    "000 trillion",
+                    "{one:0' 'm\u00fc\u0148 other:0' 'm\u00fc\u0148}",
+                    "{one:00' 'm\u00fc\u0148 other:00' 'm\u00fc\u0148}",
+                    "{one:000' 'm\u00fc\u0148 other:000' 'm\u00fc\u0148}",
+                    "{one:0' 'million other:0' 'million}",
+                    "{one:00' 'million other:00' 'million}",
+                    "{one:000' 'million other:000' 'million}",
+                    "{one:0' 'milliard other:0' 'milliard}",
+                    "{one:00' 'milliard other:00' 'milliard}",
+                    "{one:000' 'milliard other:000' 'milliard}",
+                    "{one:0' 'trillion other:0' 'trillion}",
+                    "{one:00' 'trillion other:00' 'trillion}",
+                    "{one:000' 'trillion other:000' 'trillion}",
                 }
             },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -362,18 +359,18 @@ public class FormatData_tk extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0m\u00fc\u0148",
-                    "00\u00a0m\u00fc\u0148",
-                    "000\u00a0m\u00fc\u0148",
-                    "0\u00a0mln",
-                    "00\u00a0mln",
-                    "000\u00a0mln",
-                    "0\u00a0mlrd",
-                    "00\u00a0mlrd",
-                    "000\u00a0mlrd",
-                    "0\u00a0trln",
-                    "00\u00a0trln",
-                    "000\u00a0trln",
+                    "{one:0\u00a0m\u00fc\u0148 other:0\u00a0m\u00fc\u0148}",
+                    "{one:00\u00a0m\u00fc\u0148 other:00\u00a0m\u00fc\u0148}",
+                    "{one:000\u00a0m\u00fc\u0148 other:000\u00a0m\u00fc\u0148}",
+                    "{one:0\u00a0mln other:0\u00a0mln}",
+                    "{one:00\u00a0mln other:00\u00a0mln}",
+                    "{one:000\u00a0mln other:000\u00a0mln}",
+                    "{one:0\u00a0mlrd other:0\u00a0mlrd}",
+                    "{one:00\u00a0mlrd other:00\u00a0mlrd}",
+                    "{one:000\u00a0mlrd other:000\u00a0mlrd}",
+                    "{one:0\u00a0trln other:0\u00a0trln}",
+                    "{one:00\u00a0trln other:00\u00a0trln}",
+                    "{one:000\u00a0trln other:000\u00a0trln}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -419,6 +416,14 @@ public class FormatData_tk extends ListResourceBundle {
                     "",
                 }
             },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0\u00a0%",
+                    "#,##0.00\u00a0\u00a4",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
