@@ -236,6 +236,7 @@ public class FormatData_ug extends ListResourceBundle {
                     "\u0645\u0649\u0644\u0627\u062f\u0649\u064a\u06d5",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthNames },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -261,6 +262,8 @@ public class FormatData_ug extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "japanese.DatePatterns",
@@ -277,6 +280,7 @@ public class FormatData_ug extends ListResourceBundle {
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "\u0686\u06c8\u0634\u062a\u0649\u0646 \u0628\u06c7\u0631\u06c7\u0646/\u0686\u06c8\u0634\u062a\u0649\u0646 \u0643\u06d0\u064a\u0649\u0646" },
             { "islamic.MonthNames", metaValue_islamic_MonthNames },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "\u0645\u0649\u0646\u06af\u0648 \u064a\u0649\u0644\u0646\u0627\u0645\u06d5\u0633\u0649" },
             { "islamic.DatePatterns",
                 new String[] {
@@ -293,13 +297,6 @@ public class FormatData_ug extends ListResourceBundle {
             { "field.second", "\u0633\u06d0\u0643\u06c7\u0646\u062a" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "\u00a4#,##0.00",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u0626\u0649\u0633\u0644\u0627\u0645 \u06be\u0649\u062c\u0631\u0649\u064a\u06d5 \u064a\u0649\u0644\u0646\u0627\u0645\u06d5\u0633\u0649" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
@@ -313,18 +310,18 @@ public class FormatData_ug extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 \u0645\u0649\u06ad",
-                    "00 \u0645\u0649\u06ad",
-                    "000 \u0645\u0649\u06ad",
-                    "0 \u0645\u0649\u0644\u064a\u0648\u0646",
-                    "00 \u0645\u0649\u0644\u064a\u0648\u0646",
-                    "000 \u0645\u0649\u0644\u064a\u0648\u0646",
-                    "0 \u0645\u0649\u0644\u064a\u0627\u0631\u062f",
-                    "00 \u0645\u0649\u0644\u064a\u0627\u0631\u062f",
-                    "000 \u0645\u0649\u0644\u064a\u0627\u0631\u062f",
-                    "0 \u062a\u0649\u0631\u0649\u0644\u064a\u0648\u0646",
-                    "00 \u062a\u0649\u0631\u0649\u0644\u064a\u0648\u0646",
-                    "000 \u062a\u0649\u0631\u0649\u0644\u064a\u0648\u0646",
+                    "{one:0' '\u0645\u0649\u06ad other:0' '\u0645\u0649\u06ad}",
+                    "{one:00' '\u0645\u0649\u06ad other:00' '\u0645\u0649\u06ad}",
+                    "{one:000' '\u0645\u0649\u06ad other:000' '\u0645\u0649\u06ad}",
+                    "{one:0' '\u0645\u0649\u0644\u064a\u0648\u0646 other:0' '\u0645\u0649\u0644\u064a\u0648\u0646}",
+                    "{one:00' '\u0645\u0649\u0644\u064a\u0648\u0646 other:00' '\u0645\u0649\u0644\u064a\u0648\u0646}",
+                    "{one:000' '\u0645\u0649\u0644\u064a\u0648\u0646 other:000' '\u0645\u0649\u0644\u064a\u0648\u0646}",
+                    "{one:0' '\u0645\u0649\u0644\u064a\u0627\u0631\u062f other:0' '\u0645\u0649\u0644\u064a\u0627\u0631\u062f}",
+                    "{one:00' '\u0645\u0649\u0644\u064a\u0627\u0631\u062f other:00' '\u0645\u0649\u0644\u064a\u0627\u0631\u062f}",
+                    "{one:000' '\u0645\u0649\u0644\u064a\u0627\u0631\u062f other:000' '\u0645\u0649\u0644\u064a\u0627\u0631\u062f}",
+                    "{one:0' '\u062a\u0649\u0631\u0649\u0644\u064a\u0648\u0646 other:0' '\u062a\u0649\u0631\u0649\u0644\u064a\u0648\u0646}",
+                    "{one:00' '\u062a\u0649\u0631\u0649\u0644\u064a\u0648\u0646 other:00' '\u062a\u0649\u0631\u0649\u0644\u064a\u0648\u0646}",
+                    "{one:000' '\u062a\u0649\u0631\u0649\u0644\u064a\u0648\u0646 other:000' '\u062a\u0649\u0631\u0649\u0644\u064a\u0648\u0646}",
                 }
             },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -382,18 +379,18 @@ public class FormatData_ug extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u0645\u0649\u06ad",
-                    "00\u0645\u0649\u06ad",
-                    "000\u0645\u0649\u06ad",
-                    "0\u0645\u0649\u0644\u064a\u0648\u0646",
-                    "00\u0645\u0649\u0644\u064a\u0648\u0646",
-                    "000\u0645\u0649\u0644\u064a\u0648\u0646",
-                    "0\u0645\u0649\u0644\u064a\u0627\u0631\u062f",
-                    "00\u0645\u0649\u0644\u064a\u0627\u0631\u062f",
-                    "000\u0645\u0649\u0644\u064a\u0627\u0631\u062f",
-                    "0T",
-                    "00T",
-                    "000T",
+                    "{one:0\u0645\u0649\u06ad other:0\u0645\u0649\u06ad}",
+                    "{one:00\u0645\u0649\u06ad other:00\u0645\u0649\u06ad}",
+                    "{one:000\u0645\u0649\u06ad other:000\u0645\u0649\u06ad}",
+                    "{one:0\u0645\u0649\u0644\u064a\u0648\u0646 other:0\u0645\u0649\u0644\u064a\u0648\u0646}",
+                    "{one:00\u0645\u0649\u0644\u064a\u0648\u0646 other:00\u0645\u0649\u0644\u064a\u0648\u0646}",
+                    "{one:000\u0645\u0649\u0644\u064a\u0648\u0646 other:000\u0645\u0649\u0644\u064a\u0648\u0646}",
+                    "{one:0\u0645\u0649\u0644\u064a\u0627\u0631\u062f other:0\u0645\u0649\u0644\u064a\u0627\u0631\u062f}",
+                    "{one:00\u0645\u0649\u0644\u064a\u0627\u0631\u062f other:00\u0645\u0649\u0644\u064a\u0627\u0631\u062f}",
+                    "{one:000\u0645\u0649\u0644\u064a\u0627\u0631\u062f other:000\u0645\u0649\u0644\u064a\u0627\u0631\u062f}",
+                    "{one:0T other:0T}",
+                    "{one:00T other:00T}",
+                    "{one:000T other:000T}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -416,6 +413,14 @@ public class FormatData_ug extends ListResourceBundle {
             { "islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "calendarname.buddhist", "\u0628\u06c7\u062f\u062f\u0627 \u064a\u0649\u0644\u0646\u0627\u0645\u06d5\u0633\u0649" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "\u00a4#,##0.00",
+                    "#,##0%",
+                    "\u00a4#,##0.00;(\u00a4#,##0.00)",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
