@@ -186,6 +186,10 @@ public class FormatData_uz extends ListResourceBundle {
                "d-MMM, y (GGGG)",
                "dd.MM.y (G)",
             };
+        final String[] metaValue_java_time_islamic_long_Eras = new String[] {
+               "",
+               "Hijriy yil",
+            };
         final String metaValue_calendarname_gregorian = "grigorian taqvimi";
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
@@ -203,6 +207,8 @@ public class FormatData_uz extends ListResourceBundle {
                     "\u0609",
                     "\u221e",
                     "son\u00a0emas",
+                    "",
+                    "",
                 }
             },
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
@@ -220,12 +226,14 @@ public class FormatData_uz extends ListResourceBundle {
             { "japanese.MonthNames", metaValue_MonthNames },
             { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "java.time.islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "long.Eras",
                 new String[] {
                     "miloddan avvalgi",
                     "milodiy",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -251,6 +259,8 @@ public class FormatData_uz extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "son\u00a0emas",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -265,33 +275,36 @@ public class FormatData_uz extends ListResourceBundle {
                 new String[] {
                     "Muharram",
                     "Safar",
-                    "Robi\u02bc ul-avval",
-                    "Robi\u02bc ul-oxir",
+                    "Robi\u2019 ul-avval",
+                    "Robi\u2019 ul-oxir",
                     "Jumad ul-avval",
                     "Jumad ul-oxir",
                     "Rajab",
-                    "Sha\u02bcbon",
+                    "Sha\u2019bon",
                     "Ramazon",
                     "Shavvol",
-                    "Zul-qa\u02bcda",
+                    "Zul-qa\u2019da",
                     "Zul-hijja",
                     "",
                 }
             },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "Mingo taqvimi" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "field.month", "oy" },
-            { "field.second", "soniya" },
-            { "DayAbbreviations", metaValue_DayAbbreviations },
-            { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
+            { "arabext.NumberPatterns",
                 new String[] {
                     "#,##0.###",
                     "#,##0.00\u00a0\u00a4",
                     "#,##0%",
+                    "",
                 }
             },
+            { "field.second", "soniya" },
+            { "DayAbbreviations", metaValue_DayAbbreviations },
+            { "DayNarrows", metaValue_DayNarrows },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "islomiy taqvim" },
             { "japanese.narrow.AmPmMarkers", metaValue_AmPmMarkers },
@@ -318,18 +331,18 @@ public class FormatData_uz extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 ming",
-                    "00 ming",
-                    "000 ming",
-                    "0 million",
-                    "00 million",
-                    "000 million",
-                    "0 milliard",
-                    "00 milliard",
-                    "000 milliard",
-                    "0 trillion",
-                    "00 trillion",
-                    "000 trillion",
+                    "{one:0' 'ming other:0' 'ming}",
+                    "{one:00' 'ming other:00' 'ming}",
+                    "{one:000' 'ming other:000' 'ming}",
+                    "{one:0' 'million other:0' 'million}",
+                    "{one:00' 'million other:00' 'million}",
+                    "{one:000' 'million other:000' 'million}",
+                    "{one:0' 'milliard other:0' 'milliard}",
+                    "{one:00' 'milliard other:00' 'milliard}",
+                    "{one:000' 'milliard other:000' 'milliard}",
+                    "{one:0' 'trillion other:0' 'trillion}",
+                    "{one:00' 'trillion other:00' 'trillion}",
+                    "{one:000' 'trillion other:000' 'trillion}",
                 }
             },
             { "roc.narrow.AmPmMarkers", metaValue_AmPmMarkers },
@@ -354,6 +367,8 @@ public class FormatData_uz extends ListResourceBundle {
             { "field.weekday", "hafta kuni" },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
+            { "islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
+            { "java.time.islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.QuarterNames", metaValue_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "japanese.DayNames", metaValue_DayNames },
@@ -374,18 +389,18 @@ public class FormatData_uz extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0ming",
-                    "00\u00a0ming",
-                    "000\u00a0ming",
-                    "0\u00a0mln",
-                    "00\u00a0mln",
-                    "000\u00a0mln",
-                    "0\u00a0mlrd",
-                    "00\u00a0mlrd",
-                    "000\u00a0mlrd",
-                    "0\u00a0trln",
-                    "00\u00a0trln",
-                    "000\u00a0trln",
+                    "{one:0\u00a0ming other:0\u00a0ming}",
+                    "{one:00\u00a0ming other:00\u00a0ming}",
+                    "{one:000\u00a0ming other:000\u00a0ming}",
+                    "{one:0\u00a0mln other:0\u00a0mln}",
+                    "{one:00\u00a0mln other:00\u00a0mln}",
+                    "{one:000\u00a0mln other:000\u00a0mln}",
+                    "{one:0\u00a0mlrd other:0\u00a0mlrd}",
+                    "{one:00\u00a0mlrd other:00\u00a0mlrd}",
+                    "{one:000\u00a0mlrd other:000\u00a0mlrd}",
+                    "{one:0\u00a0trln other:0\u00a0trln}",
+                    "{one:00\u00a0trln other:00\u00a0trln}",
+                    "{one:000\u00a0trln other:000\u00a0trln}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -402,6 +417,24 @@ public class FormatData_uz extends ListResourceBundle {
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.DayNames", metaValue_DayNames },
             { "field.hour", "soat" },
+            { "islamic.MonthAbbreviations",
+                new String[] {
+                    "Muh.",
+                    "Saf.",
+                    "Rob. avv.",
+                    "Rob. ox.",
+                    "Jum. avv.",
+                    "Jum. ox.",
+                    "Raj.",
+                    "Sha.",
+                    "Ram.",
+                    "Shav.",
+                    "Zul-q.",
+                    "Zul-h.",
+                    "",
+                }
+            },
+            { "islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "calendarname.buddhist", "buddizm taqvimi" },
             { "standalone.MonthNames",
                 new String[] {
@@ -420,7 +453,16 @@ public class FormatData_uz extends ListResourceBundle {
                     "",
                 }
             },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0%",
+                    "#,##0.00\u00a0\u00a4",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
+            { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
