@@ -203,6 +203,8 @@ public class FormatData_uz_Cyrl extends ListResourceBundle {
                     "\u0609",
                     "\u221e",
                     "\u04b3\u0430\u049b\u0438\u049b\u0438\u0439\u00a0\u0441\u043e\u043d\u00a0\u044d\u043c\u0430\u0441",
+                    "",
+                    "",
                 }
             },
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
@@ -226,6 +228,7 @@ public class FormatData_uz_Cyrl extends ListResourceBundle {
                     "\u043c\u0438\u043b\u043e\u0434\u0438\u0439",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -251,6 +254,8 @@ public class FormatData_uz_Cyrl extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "\u04b3\u0430\u049b\u0438\u049b\u0438\u0439\u00a0\u0441\u043e\u043d\u00a0\u044d\u043c\u0430\u0441",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -261,19 +266,21 @@ public class FormatData_uz_Cyrl extends ListResourceBundle {
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "\u041a\u0443\u043d \u0432\u0430\u049b\u0442\u0438" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "field.month", "\u041e\u0439" },
-            { "field.second", "\u0421\u043e\u043d\u0438\u044f" },
-            { "DayAbbreviations", metaValue_DayAbbreviations },
-            { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
+            { "arabext.NumberPatterns",
                 new String[] {
                     "#,##0.###",
                     "#,##0.00\u00a0\u00a4",
                     "#,##0%",
+                    "",
                 }
             },
+            { "field.second", "\u0421\u043e\u043d\u0438\u044f" },
+            { "DayAbbreviations", metaValue_DayAbbreviations },
+            { "DayNarrows", metaValue_DayNarrows },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "japanese.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
@@ -284,18 +291,18 @@ public class FormatData_uz_Cyrl extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 \u043c\u0438\u043d\u0433",
-                    "00 \u043c\u0438\u043d\u0433",
-                    "000 \u043c\u0438\u043d\u0433",
-                    "0 \u043c\u0438\u043b\u043b\u0438\u043e\u043d",
-                    "00 \u043c\u0438\u043b\u043b\u0438\u043e\u043d",
-                    "000 \u043c\u0438\u043b\u043b\u0438\u043e\u043d",
-                    "0 \u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434",
-                    "00 \u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434",
-                    "000 \u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434",
-                    "0 \u0442\u0440\u0438\u043b\u0438\u043e\u043d",
-                    "00 \u0442\u0440\u0438\u043b\u0438\u043e\u043d",
-                    "000 \u0442\u0440\u0438\u043b\u0438\u043e\u043d",
+                    "{one:0' '\u043c\u0438\u043d\u0433 other:0' '\u043c\u0438\u043d\u0433}",
+                    "{one:00' '\u043c\u0438\u043d\u0433 other:00' '\u043c\u0438\u043d\u0433}",
+                    "{one:000' '\u043c\u0438\u043d\u0433 other:000' '\u043c\u0438\u043d\u0433}",
+                    "{one:0' '\u043c\u0438\u043b\u043b\u0438\u043e\u043d other:0' '\u043c\u0438\u043b\u043b\u0438\u043e\u043d}",
+                    "{one:00' '\u043c\u0438\u043b\u043b\u0438\u043e\u043d other:00' '\u043c\u0438\u043b\u043b\u0438\u043e\u043d}",
+                    "{one:000' '\u043c\u0438\u043b\u043b\u0438\u043e\u043d other:000' '\u043c\u0438\u043b\u043b\u0438\u043e\u043d}",
+                    "{one:0' '\u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434 other:0' '\u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434}",
+                    "{one:00' '\u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434 other:00' '\u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434}",
+                    "{one:000' '\u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434 other:000' '\u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434}",
+                    "{one:0' '\u0442\u0440\u0438\u043b\u0438\u043e\u043d other:0' '\u0442\u0440\u0438\u043b\u0438\u043e\u043d}",
+                    "{one:00' '\u0442\u0440\u0438\u043b\u0438\u043e\u043d other:00' '\u0442\u0440\u0438\u043b\u0438\u043e\u043d}",
+                    "{one:000' '\u0442\u0440\u0438\u043b\u0438\u043e\u043d other:000' '\u0442\u0440\u0438\u043b\u0438\u043e\u043d}",
                 }
             },
             { "roc.narrow.AmPmMarkers", metaValue_AmPmMarkers },
@@ -340,18 +347,18 @@ public class FormatData_uz_Cyrl extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u043c\u0438\u043d\u0433",
-                    "00\u043c\u0438\u043d\u0433",
-                    "000\u043c\u0438\u043d\u0433",
-                    "0\u043c\u043b\u043d",
-                    "00\u043c\u043b\u043d",
-                    "000\u043c\u043b\u043d",
-                    "0\u043c\u043b\u0440\u0434",
-                    "00\u043c\u043b\u0440\u0434",
-                    "000\u043c\u043b\u0440\u0434",
-                    "0\u0442\u0440\u043b\u043d",
-                    "00\u0442\u0440\u043b\u043d",
-                    "000\u0442\u0440\u043b\u043d",
+                    "{one:0\u043c\u0438\u043d\u0433 other:0\u043c\u0438\u043d\u0433}",
+                    "{one:00\u043c\u0438\u043d\u0433 other:00\u043c\u0438\u043d\u0433}",
+                    "{one:000\u043c\u0438\u043d\u0433 other:000\u043c\u0438\u043d\u0433}",
+                    "{one:0\u043c\u043b\u043d other:0\u043c\u043b\u043d}",
+                    "{one:00\u043c\u043b\u043d other:00\u043c\u043b\u043d}",
+                    "{one:000\u043c\u043b\u043d other:000\u043c\u043b\u043d}",
+                    "{one:0\u043c\u043b\u0440\u0434 other:0\u043c\u043b\u0440\u0434}",
+                    "{one:00\u043c\u043b\u0440\u0434 other:00\u043c\u043b\u0440\u0434}",
+                    "{one:000\u043c\u043b\u0440\u0434 other:000\u043c\u043b\u0440\u0434}",
+                    "{one:0\u0442\u0440\u043b\u043d other:0\u0442\u0440\u043b\u043d}",
+                    "{one:00\u0442\u0440\u043b\u043d other:00\u0442\u0440\u043b\u043d}",
+                    "{one:000\u0442\u0440\u043b\u043d other:000\u0442\u0440\u043b\u043d}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -370,6 +377,14 @@ public class FormatData_uz_Cyrl extends ListResourceBundle {
             { "standalone.DayNames", metaValue_DayNames },
             { "field.hour", "\u0421\u043e\u0430\u0442" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0%",
+                    "#,##0.00\u00a0\u00a4",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
