@@ -158,6 +158,10 @@ public class FormatData_yo extends ListResourceBundle {
                "\u00c0\u00e1r\u1ecd\u0300",
                "\u1ecc\u0300s\u00e1n",
             };
+        final String[] metaValue_Eras = new String[] {
+               "BCE",
+               "AD",
+            };
         final String[] metaValue_TimePatterns = new String[] {
                "HH:mm:ss zzzz",
                "H:mm:ss z",
@@ -184,14 +188,15 @@ public class FormatData_yo extends ListResourceBundle {
             { "AmPmMarkers", metaValue_AmPmMarkers },
             { "timezone.gmtFormat", "WAT{0}" },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "standalone.QuarterAbbreviations", metaValue_QuarterNames },
             { "roc.QuarterNames", metaValue_QuarterNames },
             { "roc.MonthNarrows", metaValue_MonthNarrows },
             { "islamic.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
+            { "narrow.Eras", metaValue_Eras },
             { "abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "timezone.regionFormat.standard", "{0} \u00ccl\u00e0n\u00e0 \u00c0k\u00f3k\u00f2" },
             { "japanese.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
+            { "calendarname.japanese", "K\u00e0l\u1eb9\u0300\u0144d\u00e0 ti J\u00e0p\u00e1n\u00f9" },
             { "timezone.gmtZeroFormat", "WAT" },
             { "japanese.MonthNames", metaValue_MonthNames },
             { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
@@ -228,6 +233,8 @@ public class FormatData_yo extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -239,20 +246,14 @@ public class FormatData_yo extends ListResourceBundle {
             { "field.dayperiod", "\u00c0\u00e1r\u1ecd\u0300/\u1ecd\u0300s\u00e1n" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
             { "japanese.QuarterNarrows", metaValue_QuarterNarrows },
+            { "calendarname.roc", "K\u00e0l\u1eb9\u0300\u0144d\u00e0 Minguo" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "roc.QuarterAbbreviations", metaValue_QuarterNames },
             { "field.month", "Os\u00f9" },
             { "field.second", "\u00ccs\u1eb9\u0301j\u00fa \u00c0\u00e0y\u00e1" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "\u00a4#,##0.00",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "calendarname.islamic", "K\u00e0l\u1eb9\u0300\u0144d\u00e0 L\u00e1r\u00fab\u00e1w\u00e1" },
             { "japanese.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations",
@@ -272,21 +273,39 @@ public class FormatData_yo extends ListResourceBundle {
                     "",
                 }
             },
-            { "timezone.regionFormat", "{0} \u00ccgb\u00e0" },
+            { "timezone.regionFormat", "\u00ccgb\u00e0 {0}" },
+            { "long.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "{other:0' '\u1eb9gb\u1eb9\u0300r\u00fan}",
+                    "{other:00' '\u1eb9gb\u1eb9\u0300r\u00fan}",
+                    "{other:000' '\u1eb9gb\u1eb9\u0300r\u00fan}",
+                    "{other:0' 'm\u00edl\u00ed\u1ecd\u0300n\u00f9}",
+                    "{other:00' 'm\u00edl\u00ed\u1ecd\u0300n\u00f9}",
+                    "{other:000' 'm\u00edl\u00ed\u1ecd\u0300n\u00f9}",
+                    "{other:0' 'bil\u00ed\u1ecd\u0300n\u00f9}",
+                    "{other:00' 'bil\u00ed\u1ecd\u0300n\u00f9}",
+                    "{other:000' 'bil\u00ed\u1ecd\u0300n\u00f9}",
+                    "{other:0' 'tirili\u1ecd\u0300n\u00f9}",
+                    "{other:00' 'tirili\u1ecd\u0300n\u00f9}",
+                    "{other:000' 'tirili\u1ecd\u0300n\u00f9}",
+                }
+            },
             { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "standalone.QuarterNames", metaValue_QuarterNames },
             { "japanese.MonthNarrows", metaValue_MonthNarrows },
-            { "islamic.QuarterAbbreviations", metaValue_QuarterNames },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.DayNarrows", metaValue_DayNarrows },
             { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
             { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
             { "field.zone", "Agb\u00e8gb\u00e8 \u00e0k\u00f3k\u00f2" },
-            { "japanese.QuarterAbbreviations", metaValue_QuarterNames },
             { "buddhist.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
+            { "Eras", metaValue_Eras },
             { "roc.DayNames", metaValue_DayNames },
             { "islamic.QuarterNames", metaValue_QuarterNames },
             { "QuarterNarrows", metaValue_QuarterNarrows },
@@ -304,7 +323,6 @@ public class FormatData_yo extends ListResourceBundle {
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
             { "japanese.QuarterNames", metaValue_QuarterNames },
-            { "buddhist.QuarterAbbreviations", metaValue_QuarterNames },
             { "japanese.DayNames", metaValue_DayNames },
             { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNames", metaValue_DayNames },
@@ -343,6 +361,7 @@ public class FormatData_yo extends ListResourceBundle {
                 }
             },
             { "field.hour", "W\u00e1k\u00e0t\u00ed" },
+            { "calendarname.buddhist", "K\u00e0l\u1eb9\u0300\u0144d\u00e0 Buddhist" },
             { "standalone.MonthNames",
                 new String[] {
                     "\u1e62\u1eb9\u0301r\u1eb9\u0301",
@@ -360,6 +379,14 @@ public class FormatData_yo extends ListResourceBundle {
                     "",
                 }
             },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "\u00a4#,##0.00",
+                    "#,##0%",
+                    "\u00a4#,##0.00;(\u00a4#,##0.00)",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
