@@ -202,18 +202,18 @@ public class FormatData_yue extends ListResourceBundle {
                "",
                "",
                "",
-               "0",
-               "0\u842c",
-               "00\u842c",
-               "000\u842c",
-               "0000\u842c",
-               "0\u5104",
-               "00\u5104",
-               "000\u5104",
-               "0000\u5104",
-               "0\u5146",
-               "00\u5146",
-               "000\u5146",
+               "{other:0}",
+               "{other:0\u842c}",
+               "{other:00\u842c}",
+               "{other:000\u842c}",
+               "{other:0000\u842c}",
+               "{other:0\u5104}",
+               "{other:00\u5104}",
+               "{other:000\u5104}",
+               "{other:0000\u5104}",
+               "{other:0\u5146}",
+               "{other:00\u5146}",
+               "{other:000\u5146}",
             };
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
@@ -240,6 +240,7 @@ public class FormatData_yue extends ListResourceBundle {
             { "roc.MonthAbbreviations", metaValue_MonthNames },
             { "java.time.islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "long.Eras", metaValue_long_Eras },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthNames },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -258,6 +259,8 @@ public class FormatData_yue extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "\u975e\u6578\u503c",
+                    "",
+                    "",
                 }
             },
             { "japanese.DatePatterns", metaValue_buddhist_DatePatterns },
@@ -268,6 +271,7 @@ public class FormatData_yue extends ListResourceBundle {
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "\u4e0a\u5348/\u4e0b\u5348" },
             { "islamic.MonthNames", metaValue_islamic_MonthNames },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "\u6c11\u570b\u66c6" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterNames },
@@ -278,13 +282,6 @@ public class FormatData_yue extends ListResourceBundle {
             { "field.second", "\u79d2" },
             { "DayAbbreviations", metaValue_DayNames },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "\u00a4#,##0.00",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns",
                 new String[] {
                     "GGGGy\u5e74M\u6708d\u65e5 EEEE",
@@ -314,12 +311,37 @@ public class FormatData_yue extends ListResourceBundle {
             { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
             { "java.time.roc.Eras", metaValue_java_time_roc_long_Eras },
+            { "hanidec.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "\u00a4#,##0.00",
+                    "#,##0%",
+                    "",
+                }
+            },
             { "field.zone", "\u6642\u5340" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterNames },
             { "roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
             { "buddhist.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "Eras", metaValue_long_Eras },
+            { "hanidec.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "0",
+                    "#",
+                    "-",
+                    "E",
+                    "\u2030",
+                    "\u221e",
+                    "NaN",
+                    "",
+                    "",
+                }
+            },
             { "roc.DayNames", metaValue_DayNames },
             { "islamic.QuarterNames", metaValue_QuarterNames },
             { "islamic.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
@@ -376,6 +398,14 @@ public class FormatData_yue extends ListResourceBundle {
             { "islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "calendarname.buddhist", "\u4f5b\u66c6" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "\u00a4#,##0.00",
+                    "#,##0%",
+                    "\u00a4#,##0.00;(\u00a4#,##0.00)",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
