@@ -214,18 +214,18 @@ public class FormatData_yue_Hans extends ListResourceBundle {
                "",
                "",
                "",
-               "0",
-               "0\u4e07",
-               "00\u4e07",
-               "000\u4e07",
-               "0000\u4e07",
-               "0\u4ebf",
-               "00\u4ebf",
-               "000\u4ebf",
-               "0000\u4ebf",
-               "0\u5146",
-               "00\u5146",
-               "000\u5146",
+               "{other:0}",
+               "{other:0\u4e07}",
+               "{other:00\u4e07}",
+               "{other:000\u4e07}",
+               "{other:0000\u4e07}",
+               "{other:0\u4ebf}",
+               "{other:00\u4ebf}",
+               "{other:000\u4ebf}",
+               "{other:0000\u4ebf}",
+               "{other:0\u5146}",
+               "{other:00\u5146}",
+               "{other:000\u5146}",
             };
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
@@ -258,6 +258,7 @@ public class FormatData_yue_Hans extends ListResourceBundle {
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "java.time.islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "long.Eras", metaValue_long_Eras },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -276,6 +277,8 @@ public class FormatData_yue_Hans extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "\u975e\u6570\u503c",
+                    "",
+                    "",
                 }
             },
             { "japanese.DatePatterns",
@@ -293,6 +296,7 @@ public class FormatData_yue_Hans extends ListResourceBundle {
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "\u4e0a\u5348/\u4e0b\u5348" },
             { "islamic.MonthNames", metaValue_islamic_MonthNames },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "\u6c11\u56fd\u5386" },
             { "islamic.DatePatterns",
                 new String[] {
@@ -310,13 +314,6 @@ public class FormatData_yue_Hans extends ListResourceBundle {
             { "field.second", "\u79d2" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "\u00a4#,##0.00",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns",
                 new String[] {
                     "GGGGy\u5e74M\u6708d\u65e5EEEE",
@@ -346,12 +343,37 @@ public class FormatData_yue_Hans extends ListResourceBundle {
             { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
             { "java.time.roc.Eras", metaValue_java_time_roc_long_Eras },
+            { "hanidec.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "\u00a4#,##0.00",
+                    "#,##0%",
+                    "",
+                }
+            },
             { "field.zone", "\u65f6\u533a" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterNames },
             { "roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
             { "buddhist.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "Eras", metaValue_long_Eras },
+            { "hanidec.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "0",
+                    "#",
+                    "-",
+                    "E",
+                    "\u2030",
+                    "\u221e",
+                    "NaN",
+                    "",
+                    "",
+                }
+            },
             { "roc.DayNames", metaValue_DayNames },
             { "islamic.QuarterNames", metaValue_QuarterNames },
             { "islamic.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
@@ -428,6 +450,14 @@ public class FormatData_yue_Hans extends ListResourceBundle {
             { "islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "calendarname.buddhist", "\u4f5b\u5386" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "\u00a4#,##0.00",
+                    "#,##0%",
+                    "\u00a4#,##0.00;(\u00a4#,##0.00)",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
