@@ -48,11 +48,12 @@ public class CLDRBaseLocaleDataMetaInfo implements LocaleDataMetaInfo {
              new String[] {
                  "", "az-Arab", "az-Cyrl", "blt-Latn", "bm-Nkoo", "bs-Cyrl", "byn-Latn", 
                  "cu-Glag", "dje-Arab", "dyo-Arab", "en-Dsrt", "en-Shaw", "ff-Adlm", 
-                 "ff-Arab", "ha-Arab", "iu-Latn", "kk-Arab", "ku-Arab", "ky-Arab", 
-                 "ky-Latn", "ml-Arab", "mn-Mong", "ms-Arab", "pa-Arab", "sd-Deva", 
-                 "sd-Khoj", "sd-Sind", "shi-Latn", "so-Arab", "sr-Latn", "sw-Arab", 
-                 "tg-Arab", "ug-Cyrl", "uz-Arab", "uz-Cyrl", "vai-Latn", "wo-Arab", 
-                 "yo-Arab", "yue-Hans", "zh-Hant", 
+                 "ff-Arab", "ha-Arab", "hi-Latn", "iu-Latn", "kk-Arab", "ks-Deva", 
+                 "ku-Arab", "ky-Arab", "ky-Latn", "ml-Arab", "mn-Mong", "mni-Mtei", 
+                 "ms-Arab", "pa-Arab", "sat-Deva", "sd-Deva", "sd-Khoj", "sd-Sind", 
+                 "shi-Latn", "so-Arab", "sr-Latn", "sw-Arab", "tg-Arab", "ug-Cyrl", 
+                 "uz-Arab", "uz-Cyrl", "vai-Latn", "wo-Arab", "yo-Arab", "yue-Hans", 
+                 "zh-Hant", 
              });
         parentLocalesMap.put(Locale.forLanguageTag("en-001"),
              new String[] {
@@ -82,141 +83,146 @@ public class CLDRBaseLocaleDataMetaInfo implements LocaleDataMetaInfo {
                  "", "en-AT", "en-BE", "en-CH", "en-DE", "en-DK", "en-FI", "en-NL", 
                  "en-SE", "en-SI", 
              });
-                languageAliasMap.put("pa-PK", "pa-Arab-PK");
-                languageAliasMap.put("mwj", "vaj");
-                languageAliasMap.put("tdu", "dtp");
-                languageAliasMap.put("aa-SAAHO", "ssy");
-                languageAliasMap.put("ha-Latn-GH", "ha-GH");
-                languageAliasMap.put("pmc", "huw");
-                languageAliasMap.put("lmm", "rmx");
-                languageAliasMap.put("ccq", "rki");
-                languageAliasMap.put("nad", "xny");
-                languageAliasMap.put("sca", "hle");
-                languageAliasMap.put("uok", "ema");
-                languageAliasMap.put("scc", "sr");
-                languageAliasMap.put("skk", "oyb");
-                languageAliasMap.put("puz", "pub");
-                languageAliasMap.put("sgn-CH-DE", "sgg");
-                languageAliasMap.put("tmp", "tyj");
-                languageAliasMap.put("pmu", "phr");
-                languageAliasMap.put("yos", "zom");
-                languageAliasMap.put("bjd", "drl");
-                languageAliasMap.put("gti", "nyc");
-                languageAliasMap.put("scr", "hr");
-                languageAliasMap.put("ktr", "dtp");
-                languageAliasMap.put("tne", "kak");
-                languageAliasMap.put("tnf", "fa-af");
-                languageAliasMap.put("i-klingon", "tlh");
-                languageAliasMap.put("zh-min-nan", "nan");
-                languageAliasMap.put("zh-guoyu", "zh");
-                languageAliasMap.put("i-pwn", "pwn");
-                languageAliasMap.put("i-mingo", "see-x-i-mingo");
-                languageAliasMap.put("cmk", "xch");
-                languageAliasMap.put("ayx", "nun");
-                languageAliasMap.put("sgn-BE-NL", "vgt");
-                languageAliasMap.put("zh-MO", "zh-Hant-MO");
-                languageAliasMap.put("guv", "duz");
-                languageAliasMap.put("myt", "mry");
-                languageAliasMap.put("oun", "vaj");
-                languageAliasMap.put("ky-Cyrl-KG", "ky-KG");
-                languageAliasMap.put("aam", "aas");
-                languageAliasMap.put("jw", "jv");
-                languageAliasMap.put("ms-Latn-MY", "ms-MY");
-                languageAliasMap.put("sr-ME", "sr-Latn-ME");
-                languageAliasMap.put("i-navajo", "nv");
-                languageAliasMap.put("sh", "sr-Latn");
-                languageAliasMap.put("ncp", "kdz");
-                languageAliasMap.put("ppa", "bfy");
-                languageAliasMap.put("uz-UZ", "uz-Latn-UZ");
-                languageAliasMap.put("zh-TW", "zh-Hant-TW");
-                languageAliasMap.put("cnr", "sr-ME");
-                languageAliasMap.put("mn-Cyrl-MN", "mn-MN");
-                languageAliasMap.put("i-default", "en-x-i-default");
-                languageAliasMap.put("kvs", "gdj");
-                languageAliasMap.put("shi-MA", "shi-Tfng-MA");
-                languageAliasMap.put("nts", "pij");
-                languageAliasMap.put("ha-Latn-NE", "ha-NE");
-                languageAliasMap.put("thc", "tpo");
-                languageAliasMap.put("ha-Latn-NG", "ha-NG");
-                languageAliasMap.put("ibi", "opa");
-                languageAliasMap.put("sgn-BE-FR", "sfb");
-                languageAliasMap.put("ppr", "lcq");
-                languageAliasMap.put("art-lojban", "jbo");
-                languageAliasMap.put("i-lux", "lb");
-                languageAliasMap.put("vai-LR", "vai-Vaii-LR");
-                languageAliasMap.put("i-enochian", "und-x-i-enochian");
-                languageAliasMap.put("gfx", "vaj");
-                languageAliasMap.put("tl", "fil");
-                languageAliasMap.put("ybd", "rki");
-                languageAliasMap.put("zh-hakka", "hak");
-                languageAliasMap.put("i-ami", "ami");
-                languageAliasMap.put("kwq", "yam");
-                languageAliasMap.put("ug-Arab-CN", "ug-CN");
-                languageAliasMap.put("thx", "oyb");
-                languageAliasMap.put("kgc", "tdf");
-                languageAliasMap.put("zh-xiang", "hsn");
-                languageAliasMap.put("koj", "kwv");
-                languageAliasMap.put("kk-Cyrl-KZ", "kk-KZ");
-                languageAliasMap.put("coy", "pij");
-                languageAliasMap.put("jeg", "oyb");
-                languageAliasMap.put("kgh", "kml");
-                languageAliasMap.put("lii", "raq");
-                languageAliasMap.put("zh-CN", "zh-Hans-CN");
-                languageAliasMap.put("ggn", "gvr");
-                languageAliasMap.put("mst", "mry");
-                languageAliasMap.put("tie", "ras");
-                languageAliasMap.put("xia", "acn");
-                languageAliasMap.put("i-tay", "tay");
-                languageAliasMap.put("kxe", "tvd");
-                languageAliasMap.put("drh", "mn");
-                languageAliasMap.put("yue-HK", "yue-Hant-HK");
-                languageAliasMap.put("mo", "ro");
-                languageAliasMap.put("bs-BA", "bs-Latn-BA");
-                languageAliasMap.put("drw", "fa-af");
-                languageAliasMap.put("sr-XK", "sr-Cyrl-XK");
-                languageAliasMap.put("hrr", "jal");
-                languageAliasMap.put("adp", "dz");
-                languageAliasMap.put("i-tsu", "tsu");
-                languageAliasMap.put("aue", "ktz");
-                languageAliasMap.put("zh-SG", "zh-Hans-SG");
-                languageAliasMap.put("ilw", "gal");
-                languageAliasMap.put("pry", "prt");
-                languageAliasMap.put("xba", "cax");
-                languageAliasMap.put("nnx", "ngv");
-                languageAliasMap.put("ks-Arab-IN", "ks-IN");
-                languageAliasMap.put("az-AZ", "az-Latn-AZ");
-                languageAliasMap.put("cel-gaulish", "xtg-x-cel-gaulish");
-                languageAliasMap.put("cqu", "quh");
-                languageAliasMap.put("tsf", "taj");
-                languageAliasMap.put("bgm", "bcg");
-                languageAliasMap.put("yma", "lrr");
-                languageAliasMap.put("zh-min", "nan-x-zh-min");
-                languageAliasMap.put("meg", "cir");
-                languageAliasMap.put("xsj", "suj");
-                languageAliasMap.put("xkh", "waw");
-                languageAliasMap.put("tkk", "twm");
-                languageAliasMap.put("pa-IN", "pa-Guru-IN");
-                languageAliasMap.put("yuu", "yug");
-                languageAliasMap.put("kzj", "dtp");
-                languageAliasMap.put("gav", "dev");
-                languageAliasMap.put("pcr", "adx");
-                languageAliasMap.put("ymt", "mtm");
-                languageAliasMap.put("tzm-Latn-MA", "tzm-MA");
-                languageAliasMap.put("i-bnn", "bnn");
-                languageAliasMap.put("i-tao", "tao");
-                languageAliasMap.put("kzt", "dtp");
-                languageAliasMap.put("sr-BA", "sr-Cyrl-BA");
-                languageAliasMap.put("uz-AF", "uz-Arab-AF");
-                languageAliasMap.put("zh-HK", "zh-Hant-HK");
-                languageAliasMap.put("sr-RS", "sr-Cyrl-RS");
-                languageAliasMap.put("krm", "bmf");
-                languageAliasMap.put("ms-Latn-SG", "ms-SG");
-                languageAliasMap.put("cjr", "mom");
-                languageAliasMap.put("ms-Latn-BN", "ms-BN");
-                languageAliasMap.put("i-hak", "hak");
-                languageAliasMap.put("yue-CN", "yue-Hans-CN");
-                languageAliasMap.put("cka", "cmr");
-                languageAliasMap.put("tlw", "weo");
+        languageAliasMap.put("pa-PK", "pa-Arab-PK");
+        languageAliasMap.put("mwj", "vaj");
+        languageAliasMap.put("tdu", "dtp");
+        languageAliasMap.put("aa-SAAHO", "ssy");
+        languageAliasMap.put("ha-Latn-GH", "ha-GH");
+        languageAliasMap.put("pmc", "huw");
+        languageAliasMap.put("lmm", "rmx");
+        languageAliasMap.put("ccq", "rki");
+        languageAliasMap.put("nad", "xny");
+        languageAliasMap.put("sca", "hle");
+        languageAliasMap.put("uok", "ema");
+        languageAliasMap.put("scc", "sr");
+        languageAliasMap.put("skk", "oyb");
+        languageAliasMap.put("puz", "pub");
+        languageAliasMap.put("sgn-CH-DE", "sgg");
+        languageAliasMap.put("tmp", "tyj");
+        languageAliasMap.put("pmu", "phr");
+        languageAliasMap.put("yos", "zom");
+        languageAliasMap.put("bjd", "drl");
+        languageAliasMap.put("gti", "nyc");
+        languageAliasMap.put("scr", "hr");
+        languageAliasMap.put("ktr", "dtp");
+        languageAliasMap.put("tne", "kak");
+        languageAliasMap.put("tnf", "fa-af");
+        languageAliasMap.put("myd", "aog");
+        languageAliasMap.put("i-klingon", "tlh");
+        languageAliasMap.put("zh-min-nan", "nan");
+        languageAliasMap.put("zh-guoyu", "zh");
+        languageAliasMap.put("i-pwn", "pwn");
+        languageAliasMap.put("i-mingo", "see-x-i-mingo");
+        languageAliasMap.put("cmk", "xch");
+        languageAliasMap.put("ayx", "nun");
+        languageAliasMap.put("sgn-BE-NL", "vgt");
+        languageAliasMap.put("zh-MO", "zh-Hant-MO");
+        languageAliasMap.put("guv", "duz");
+        languageAliasMap.put("myt", "mry");
+        languageAliasMap.put("oun", "vaj");
+        languageAliasMap.put("ky-Cyrl-KG", "ky-KG");
+        languageAliasMap.put("aam", "aas");
+        languageAliasMap.put("jw", "jv");
+        languageAliasMap.put("ms-Latn-MY", "ms-MY");
+        languageAliasMap.put("sr-ME", "sr-Latn-ME");
+        languageAliasMap.put("i-navajo", "nv");
+        languageAliasMap.put("sh", "sr-Latn");
+        languageAliasMap.put("ncp", "kdz");
+        languageAliasMap.put("ppa", "bfy");
+        languageAliasMap.put("uz-UZ", "uz-Latn-UZ");
+        languageAliasMap.put("zh-TW", "zh-Hant-TW");
+        languageAliasMap.put("cnr", "sr-ME");
+        languageAliasMap.put("mn-Cyrl-MN", "mn-MN");
+        languageAliasMap.put("i-default", "en-x-i-default");
+        languageAliasMap.put("kvs", "gdj");
+        languageAliasMap.put("shi-MA", "shi-Tfng-MA");
+        languageAliasMap.put("nts", "pij");
+        languageAliasMap.put("ha-Latn-NE", "ha-NE");
+        languageAliasMap.put("thc", "tpo");
+        languageAliasMap.put("ha-Latn-NG", "ha-NG");
+        languageAliasMap.put("ibi", "opa");
+        languageAliasMap.put("sgn-BE-FR", "sfb");
+        languageAliasMap.put("ppr", "lcq");
+        languageAliasMap.put("asd", "snz");
+        languageAliasMap.put("art-lojban", "jbo");
+        languageAliasMap.put("i-lux", "lb");
+        languageAliasMap.put("vai-LR", "vai-Vaii-LR");
+        languageAliasMap.put("i-enochian", "und-x-i-enochian");
+        languageAliasMap.put("gfx", "vaj");
+        languageAliasMap.put("tl", "fil");
+        languageAliasMap.put("ybd", "rki");
+        languageAliasMap.put("zh-hakka", "hak");
+        languageAliasMap.put("i-ami", "ami");
+        languageAliasMap.put("kwq", "yam");
+        languageAliasMap.put("ug-Arab-CN", "ug-CN");
+        languageAliasMap.put("thx", "oyb");
+        languageAliasMap.put("kgc", "tdf");
+        languageAliasMap.put("zh-xiang", "hsn");
+        languageAliasMap.put("koj", "kwv");
+        languageAliasMap.put("kk-Cyrl-KZ", "kk-KZ");
+        languageAliasMap.put("coy", "pij");
+        languageAliasMap.put("jeg", "oyb");
+        languageAliasMap.put("kgh", "kml");
+        languageAliasMap.put("lii", "raq");
+        languageAliasMap.put("zh-CN", "zh-Hans-CN");
+        languageAliasMap.put("dit", "dif");
+        languageAliasMap.put("ggn", "gvr");
+        languageAliasMap.put("mst", "mry");
+        languageAliasMap.put("tie", "ras");
+        languageAliasMap.put("xia", "acn");
+        languageAliasMap.put("i-tay", "tay");
+        languageAliasMap.put("kxe", "tvd");
+        languageAliasMap.put("drh", "mn");
+        languageAliasMap.put("yue-HK", "yue-Hant-HK");
+        languageAliasMap.put("mo", "ro");
+        languageAliasMap.put("bs-BA", "bs-Latn-BA");
+        languageAliasMap.put("drw", "fa-af");
+        languageAliasMap.put("sr-XK", "sr-Cyrl-XK");
+        languageAliasMap.put("hrr", "jal");
+        languageAliasMap.put("adp", "dz");
+        languageAliasMap.put("i-tsu", "tsu");
+        languageAliasMap.put("aue", "ktz");
+        languageAliasMap.put("nns", "nbr");
+        languageAliasMap.put("zh-SG", "zh-Hans-SG");
+        languageAliasMap.put("ilw", "gal");
+        languageAliasMap.put("pry", "prt");
+        languageAliasMap.put("xba", "cax");
+        languageAliasMap.put("nnx", "ngv");
+        languageAliasMap.put("ks-Arab-IN", "ks-IN");
+        languageAliasMap.put("az-AZ", "az-Latn-AZ");
+        languageAliasMap.put("cel-gaulish", "xtg-x-cel-gaulish");
+        languageAliasMap.put("cqu", "quh");
+        languageAliasMap.put("tsf", "taj");
+        languageAliasMap.put("bgm", "bcg");
+        languageAliasMap.put("yma", "lrr");
+        languageAliasMap.put("zh-min", "nan-x-zh-min");
+        languageAliasMap.put("meg", "cir");
+        languageAliasMap.put("xsj", "suj");
+        languageAliasMap.put("xkh", "waw");
+        languageAliasMap.put("tkk", "twm");
+        languageAliasMap.put("pa-IN", "pa-Guru-IN");
+        languageAliasMap.put("yuu", "yug");
+        languageAliasMap.put("kzj", "dtp");
+        languageAliasMap.put("gav", "dev");
+        languageAliasMap.put("pcr", "adx");
+        languageAliasMap.put("ymt", "mtm");
+        languageAliasMap.put("tzm-Latn-MA", "tzm-MA");
+        languageAliasMap.put("i-bnn", "bnn");
+        languageAliasMap.put("i-tao", "tao");
+        languageAliasMap.put("kzt", "dtp");
+        languageAliasMap.put("sr-BA", "sr-Cyrl-BA");
+        languageAliasMap.put("uz-AF", "uz-Arab-AF");
+        languageAliasMap.put("zh-HK", "zh-Hant-HK");
+        languageAliasMap.put("sr-RS", "sr-Cyrl-RS");
+        languageAliasMap.put("krm", "bmf");
+        languageAliasMap.put("ms-Latn-SG", "ms-SG");
+        languageAliasMap.put("cjr", "mom");
+        languageAliasMap.put("llo", "ngt");
+        languageAliasMap.put("ms-Latn-BN", "ms-BN");
+        languageAliasMap.put("i-hak", "hak");
+        languageAliasMap.put("yue-CN", "yue-Hans-CN");
+        languageAliasMap.put("cka", "cmr");
+        languageAliasMap.put("tlw", "weo");
     }
 
     private static class TZCanonicalIDMapHolder {
