@@ -84,7 +84,6 @@ public class CurrencyNames_ar extends OpenListResourceBundle {
             { "BAM", "BAM" },
             { "BBD", "BBD" },
             { "BDT", "BDT" },
-            { "BGL", "BGL" },
             { "BGN", "BGN" },
             { "BHD", "\u062f.\u0628.\u200f" },
             { "BIF", "BIF" },
@@ -116,6 +115,7 @@ public class CurrencyNames_ar extends OpenListResourceBundle {
             { "ETB", "ETB" },
             { "FJD", "FJD" },
             { "FKP", "FKP" },
+            { "GBP", "UK\u00a3" },
             { "GEL", "GEL" },
             { "GHS", "GHS" },
             { "GIP", "GIP" },
@@ -127,6 +127,7 @@ public class CurrencyNames_ar extends OpenListResourceBundle {
             { "HRK", "HRK" },
             { "HTG", "HTG" },
             { "HUF", "HUF" },
+            { "IDR", "IDR" },
             { "IQD", "\u062f.\u0639.\u200f" },
             { "IRR", "\u0631.\u0625." },
             { "ISK", "ISK" },
@@ -135,6 +136,7 @@ public class CurrencyNames_ar extends OpenListResourceBundle {
             { "KES", "KES" },
             { "KGS", "KGS" },
             { "KHR", "KHR" },
+            { "KMF", "KMF" },
             { "KPW", "KPW" },
             { "KWD", "\u062f.\u0643.\u200f" },
             { "KYD", "KYD" },
@@ -143,7 +145,6 @@ public class CurrencyNames_ar extends OpenListResourceBundle {
             { "LBP", "\u0644.\u0644.\u200f" },
             { "LKR", "LKR" },
             { "LRD", "LRD" },
-            { "LSL", "LSL" },
             { "LYD", "\u062f.\u0644.\u200f" },
             { "MAD", "\u062f.\u0645.\u200f" },
             { "MDL", "MDL" },
@@ -168,6 +169,7 @@ public class CurrencyNames_ar extends OpenListResourceBundle {
             { "PEN", "PEN" },
             { "PGK", "PGK" },
             { "PHP", "PHP" },
+            { "PKR", "PKR" },
             { "PLN", "PLN" },
             { "PYG", "PYG" },
             { "QAR", "\u0631.\u0642.\u200f" },
@@ -210,7 +212,6 @@ public class CurrencyNames_ar extends OpenListResourceBundle {
             { "XXX", "***" },
             { "YER", "\u0631.\u064a.\u200f" },
             { "ZAR", "ZAR" },
-            { "ZMK", "ZMK" },
             { "ZMW", "ZMW" },
             { "adp", "\u0628\u064a\u0633\u062a\u0627 \u0623\u0646\u062f\u0648\u0631\u064a" },
             { "aed", "\u062f\u0631\u0647\u0645 \u0625\u0645\u0627\u0631\u0627\u062a\u064a" },
