@@ -71,9 +71,147 @@ public class CurrencyNames_az extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
         final Object[][] data = new Object[][] {
+            { "AED", "AED" },
+            { "AFN", "AFN" },
+            { "ALL", "ALL" },
+            { "AMD", "AMD" },
+            { "ANG", "ANG" },
+            { "AOA", "AOA" },
+            { "ARS", "ARS" },
+            { "AWG", "AWG" },
             { "AZN", "\u20bc" },
+            { "BAM", "BAM" },
+            { "BBD", "BBD" },
+            { "BDT", "BDT" },
+            { "BGN", "BGN" },
+            { "BHD", "BHD" },
+            { "BIF", "BIF" },
+            { "BMD", "BMD" },
+            { "BND", "BND" },
+            { "BOB", "BOB" },
+            { "BSD", "BSD" },
+            { "BTN", "BTN" },
+            { "BWP", "BWP" },
+            { "BYN", "BYN" },
+            { "BYR", "BYR" },
+            { "BZD", "BZD" },
+            { "CDF", "CDF" },
+            { "CHF", "CHF" },
+            { "CLP", "CLP" },
+            { "CNH", "CNH" },
+            { "COP", "COP" },
+            { "CRC", "CRC" },
+            { "CUC", "CUC" },
+            { "CUP", "CUP" },
+            { "CVE", "CVE" },
+            { "CZK", "CZK" },
+            { "DJF", "DJF" },
+            { "DKK", "DKK" },
+            { "DOP", "DOP" },
+            { "DZD", "DZD" },
+            { "EGP", "EGP" },
+            { "ERN", "ERN" },
+            { "ETB", "ETB" },
+            { "FJD", "FJD" },
+            { "FKP", "FKP" },
+            { "GEL", "GEL" },
+            { "GHS", "GHS" },
+            { "GIP", "GIP" },
+            { "GMD", "GMD" },
+            { "GNF", "GNF" },
+            { "GTQ", "GTQ" },
+            { "GYD", "GYD" },
+            { "HNL", "HNL" },
+            { "HRK", "HRK" },
+            { "HTG", "HTG" },
+            { "HUF", "HUF" },
+            { "IDR", "IDR" },
+            { "IQD", "IQD" },
+            { "IRR", "IRR" },
+            { "ISK", "ISK" },
+            { "JMD", "JMD" },
+            { "JOD", "JOD" },
+            { "KES", "KES" },
+            { "KGS", "KGS" },
+            { "KHR", "KHR" },
+            { "KMF", "KMF" },
+            { "KPW", "KPW" },
+            { "KWD", "KWD" },
+            { "KYD", "KYD" },
+            { "KZT", "KZT" },
+            { "LAK", "LAK" },
+            { "LBP", "LBP" },
+            { "LKR", "LKR" },
+            { "LRD", "LRD" },
+            { "LTL", "LTL" },
+            { "LVL", "LVL" },
+            { "LYD", "LYD" },
+            { "MAD", "MAD" },
+            { "MDL", "MDL" },
+            { "MGA", "MGA" },
+            { "MKD", "MKD" },
+            { "MMK", "MMK" },
+            { "MNT", "MNT" },
+            { "MOP", "MOP" },
+            { "MRO", "MRO" },
             { "MRU", "MRU" },
+            { "MUR", "MUR" },
+            { "MVR", "MVR" },
+            { "MWK", "MWK" },
+            { "MYR", "MYR" },
+            { "MZN", "MZN" },
+            { "NAD", "NAD" },
+            { "NGN", "NGN" },
+            { "NIO", "NIO" },
+            { "NOK", "NOK" },
+            { "NPR", "NPR" },
+            { "OMR", "OMR" },
+            { "PAB", "PAB" },
+            { "PEN", "PEN" },
+            { "PGK", "PGK" },
+            { "PHP", "PHP" },
+            { "PKR", "PKR" },
+            { "PLN", "PLN" },
+            { "PYG", "PYG" },
+            { "QAR", "QAR" },
+            { "RON", "RON" },
+            { "RSD", "RSD" },
+            { "RUB", "RUB" },
+            { "RWF", "RWF" },
+            { "SAR", "SAR" },
+            { "SBD", "SBD" },
+            { "SCR", "SCR" },
+            { "SDG", "SDG" },
+            { "SEK", "SEK" },
+            { "SGD", "SGD" },
+            { "SHP", "SHP" },
+            { "SLL", "SLL" },
+            { "SOS", "SOS" },
+            { "SRD", "SRD" },
+            { "SSP", "SSP" },
+            { "STD", "STD" },
+            { "STN", "STN" },
+            { "SYP", "SYP" },
+            { "SZL", "SZL" },
             { "THB", "\u0e3f" },
+            { "TJS", "TJS" },
+            { "TMT", "TMT" },
+            { "TND", "TND" },
+            { "TOP", "TOP" },
+            { "TRY", "TRY" },
+            { "TTD", "TTD" },
+            { "TZS", "TZS" },
+            { "UAH", "UAH" },
+            { "UGX", "UGX" },
+            { "UYU", "UYU" },
+            { "UZS", "UZS" },
+            { "VEF", "VEF" },
+            { "VES", "VES" },
+            { "VUV", "VUV" },
+            { "WST", "WST" },
+            { "YER", "YER" },
+            { "ZAR", "ZAR" },
+            { "ZMW", "ZMW" },
             { "adp", "Andora Pesetas\u0131" },
             { "aed", "Birl\u0259\u015fmi\u015f \u018fr\u0259b \u018fmirlikl\u0259ri Dirh\u0259mi" },
             { "afa", "\u018ffqan\u0131stan \u018ffqanisi (1927\u20132002)" },
@@ -116,7 +254,7 @@ public class CurrencyNames_az extends OpenListResourceBundle {
             { "brl", "Braziliya Real\u0131" },
             { "brn", "Braziliya kruzado novas\u0131" },
             { "brr", "Braziliya kruzeyrosu" },
-            { "bsd", "Bahama Dollar\u0131" },
+            { "bsd", "Baham Dollar\u0131" },
             { "btn", "Butan Nqultrumu" },
             { "buk", "Burmis Kyat\u0131" },
             { "bwp", "Botsvana Pulas\u0131" },
@@ -160,12 +298,12 @@ public class CurrencyNames_az extends OpenListResourceBundle {
             { "fjd", "Fici Dollar\u0131" },
             { "fkp", "Folklend Adalar\u0131 Funtu" },
             { "frf", "Frans\u0131z Markas\u0131" },
-            { "gbp", "Britaniya Funt" },
+            { "gbp", "Britaniya Funtu" },
             { "gek", "G\u00fcrc\u00fcstan Kupon Lariti" },
             { "gel", "G\u00fcrc\u00fcstan Larisi" },
             { "ghc", "Qana Sedisi (1979\u20132007)" },
             { "ghs", "Qana Sedisi" },
-            { "gip", "Gibraltar Funtu" },
+            { "gip", "C\u0259b\u0259li-Tariq Funtu" },
             { "gmd", "Qambiya Dalasisi" },
             { "gnf", "Qvineya Frank\u0131" },
             { "gns", "Qvineya Sulisi" },
@@ -196,7 +334,7 @@ public class CurrencyNames_az extends OpenListResourceBundle {
             { "jod", "\u0130ordaniya Dinar\u0131" },
             { "jpy", "Yaponiya Yeni" },
             { "kes", "Keniya \u015eillinqi" },
-            { "kgs", "K\u0131r\u011f\u0131z\u0131stan Somu" },
+            { "kgs", "Q\u0131r\u011f\u0131z\u0131stan Somu" },
             { "khr", "Kamboca Rieli" },
             { "kmf", "Komor Frank\u0131" },
             { "kpw", "\u015eimali Koreya Vonu" },
