@@ -80,17 +80,17 @@ public class CurrencyNames_bs_Cyrl extends OpenListResourceBundle {
             { "adp", "\u0410\u043d\u0434\u043e\u0440\u0441\u043a\u0430 \u043f\u0435\u0437\u0435\u0442\u0430" },
             { "aed", "\u0423\u0458\u0435\u0434\u0438\u045a\u0435\u043d\u0438 \u0430\u0440\u0430\u043f\u0441\u043a\u0438 \u0435\u043c\u0438\u0440\u0430\u0442\u0438 \u0434\u0438\u0440\u0445\u0430\u043c" },
             { "afa", "\u0410\u0432\u0433\u0430\u043d\u0438\u0441\u0442\u0430\u043d\u0441\u043a\u0438 \u0430\u0432\u0433\u0430\u043d (1927\u20132002)" },
-            { "afn", "\u0410\u0432\u0433\u0430\u043d\u0438\u0441\u0442\u0430\u043d\u0441\u043a\u0438 \u0430\u0432\u0433\u0430\u043d" },
+            { "afn", "\u0410\u0444\u0433\u0430\u043d\u0438\u0441\u0442\u0430\u043d\u0441\u043a\u0438 \u0430\u0444\u0433\u0430\u043d\u0438" },
             { "all", "\u0410\u043b\u0431\u0430\u043d\u0441\u043a\u0438 \u043b\u0435\u043a" },
-            { "amd", "\u0408\u0435\u0440\u043c\u0435\u043d\u0441\u043a\u0438 \u0434\u0440\u0430\u043c" },
+            { "amd", "\u0410\u0440\u043c\u0435\u043d\u0441\u043a\u0438 \u0434\u0440\u0430\u043c" },
             { "ang", "\u0425\u043e\u043b\u0430\u043d\u0434\u0441\u043a\u0438 \u0430\u043d\u0442\u0438\u043b\u0438 \u0433\u0438\u043b\u0434\u0435\u0440" },
-            { "aoa", "\u0430\u043d\u0433\u043e\u043b\u0441\u043a\u0430 \u043a\u0432\u0430\u043d\u0437\u0430" },
+            { "aoa", "\u0410\u043d\u0433\u043e\u043b\u0441\u043a\u0430 \u043a\u0432\u0430\u043d\u0437\u0430" },
             { "aok", "\u0430\u043d\u0433\u043e\u043b\u0438\u0458\u0441\u043a\u0430 \u043a\u0432\u0430\u043d\u0437\u0430 (1977\u20131990)" },
             { "aon", "\u0410\u043d\u0433\u043e\u043b\u0438\u0458\u0441\u043a\u0430 \u043d\u043e\u0432\u0430 \u043a\u0432\u0430\u043d\u0437\u0430 (1990\u20132000)" },
             { "aor", "\u0410\u043d\u0433\u043e\u043b\u0441\u043a\u0430 \u043a\u0432\u0430\u043d\u0437\u0430 \u0440\u0435\u0430\u0452\u0443\u0441\u0442\u0430\u0434\u043e (1995\u20131999)" },
             { "ara", "\u0410\u0440\u0433\u0435\u043d\u0442\u0438\u043d\u0441\u043a\u0438 \u0430\u0443\u0441\u0442\u0440\u0430\u043b" },
             { "arp", "\u0430\u0440\u0433\u0435\u043d\u0442\u0438\u043d\u0441\u043a\u0438 \u043f\u0435\u0437\u043e (1983\u20131985)" },
-            { "ars", "\u0430\u0440\u0433\u0435\u043d\u0442\u0438\u043d\u0441\u043a\u0438 \u043f\u0435\u0437\u043e" },
+            { "ars", "\u0410\u0440\u0433\u0435\u043d\u0442\u0438\u043d\u0441\u043a\u0438 \u043f\u0435\u0437\u043e\u0441" },
             { "ats", "\u0410\u0443\u0441\u0442\u0440\u0438\u0458\u0441\u043a\u0438 \u0448\u0438\u043b\u0438\u043d\u0433" },
             { "aud", "\u0410\u0443\u0441\u0442\u0440\u0430\u043b\u0438\u0458\u0441\u043a\u0438 \u0434\u043e\u043b\u0430\u0440" },
             { "awg", "\u0410\u0440\u0443\u0431\u0430\u043d\u0441\u043a\u0438 \u0444\u043b\u043e\u0440\u0438\u043d" },
@@ -98,7 +98,7 @@ public class CurrencyNames_bs_Cyrl extends OpenListResourceBundle {
             { "azn", "\u0410\u0437\u0435\u0440\u0431\u0435\u0458\u045f\u0430\u043d\u0441\u043a\u0438 \u043c\u0430\u043d\u0430\u0442" },
             { "bad", "\u0411\u043e\u0441\u0430\u043d\u0441\u043a\u043e-\u0425\u0435\u0440\u0446\u0435\u0433\u043e\u0432\u0430\u0447\u043a\u0438 \u0434\u0438\u043d\u0430\u0440" },
             { "bam", "\u041a\u043e\u043d\u0432\u0435\u0440\u0442\u0438\u0431\u0438\u043b\u043d\u0430 \u043c\u0430\u0440\u043a\u0430" },
-            { "bbd", "\u0411\u0430\u0440\u0431\u0430\u0434\u043e\u0448\u043a\u0438 \u0434\u043e\u043b\u0430\u0440" },
+            { "bbd", "\u0411\u0430\u0440\u0431\u0430\u0434\u043e\u0441\u043a\u0438 \u0434\u043e\u043b\u0430\u0440" },
             { "bdt", "\u0411\u0430\u043d\u0433\u043b\u0430\u0434\u0435\u0448\u043a\u0430 \u0442\u0430\u043a\u0430" },
             { "bec", "\u0411\u0435\u043b\u0433\u0438\u0458\u0441\u043a\u0438 \u0444\u0440\u0430\u043d\u0430\u043a (\u043a\u043e\u043d\u0432\u0435\u0440\u0442\u0438\u0431\u0438\u043b\u043d\u0438)" },
             { "bef", "\u0411\u0435\u043b\u0433\u0438\u0458\u0441\u043a\u0438 \u0444\u0440\u0430\u043d\u0430\u043a" },
@@ -109,13 +109,13 @@ public class CurrencyNames_bs_Cyrl extends OpenListResourceBundle {
             { "bif", "\u0411\u0443\u0440\u0443\u043d\u0434\u0441\u043a\u0438 \u0444\u0440\u0430\u043d\u0430\u043a" },
             { "bmd", "\u0411\u0435\u0440\u043c\u0443\u0434\u0441\u043a\u0438 \u0434\u043e\u043b\u0430\u0440" },
             { "bnd", "\u0411\u0440\u0443\u043d\u0435\u0458\u0441\u043a\u0438 \u0434\u043e\u043b\u0430\u0440" },
-            { "bob", "\u0411\u043e\u043b\u0438\u0432\u0438\u0458\u0441\u043a\u0438 \u0411\u043e\u043b\u0438\u0432\u0438\u0430\u043d\u043e" },
+            { "bob", "\u0411\u043e\u043b\u0438\u0432\u0438\u0458\u0441\u043a\u0438 \u0431\u043e\u043b\u0438\u0432\u0438\u0430\u043d\u043e" },
             { "bop", "\u0411\u043e\u043b\u0438\u0432\u0438\u0458\u0441\u043a\u0438 \u043f\u0435\u0437\u043e" },
             { "bov", "\u0411\u043e\u043b\u0438\u0432\u0438\u0458\u0441\u043a\u0438 \u043c\u0432\u0434\u043e\u043b" },
             { "brb", "\u0411\u0440\u0430\u0437\u0438\u043b\u0441\u043a\u0438 \u043d\u043e\u0432\u0438 \u043a\u0440\u0443\u0437\u0435\u0438\u0440\u043e (1967\u20131986)" },
             { "brc", "\u0411\u0440\u0430\u0437\u0438\u043b\u0438\u0458\u0441\u043a\u0438 \u043a\u0440\u0443\u0437\u0430\u0434\u043e" },
             { "bre", "\u0411\u0440\u0430\u0437\u0438\u043b\u0441\u043a\u0438 \u043a\u0440\u0443\u0437\u0435\u0438\u0440\u043e (1990\u20131993)" },
-            { "brl", "\u0411\u0440\u0430\u0437\u0438\u043b\u0441\u043a\u0438 \u0420\u0435\u0430\u043b" },
+            { "brl", "\u0411\u0440\u0430\u0437\u0438\u043b\u0441\u043a\u0438 \u0440\u0435\u0430\u043b" },
             { "brn", "\u0411\u0440\u0430\u0437\u0438\u043b\u0438\u0458\u0441\u043a\u0438 \u043d\u043e\u0432\u0438 \u043a\u0440\u0443\u0437\u0430\u0434\u043e" },
             { "brr", "\u0411\u0440\u0430\u0437\u0438\u043b\u0441\u043a\u0438 \u043a\u0440\u0443\u0437\u0435\u0438\u0440\u043e" },
             { "bsd", "\u0411\u0430\u0445\u0430\u043c\u0441\u043a\u0438 \u0434\u043e\u043b\u0430\u0440" },
@@ -125,51 +125,52 @@ public class CurrencyNames_bs_Cyrl extends OpenListResourceBundle {
             { "byb", "\u0411\u0435\u043b\u043e\u0440\u0443\u0441\u043a\u0430 \u043d\u043e\u0432\u0430 \u0440\u0443\u0431\u0459\u0430 (1994\u20131999)" },
             { "byn", "\u0411\u0435\u043b\u043e\u0440\u0443\u0441\u043a\u0430 \u0440\u0443\u0431\u0459\u0430" },
             { "byr", "\u0411\u0435\u043b\u043e\u0440\u0443\u0441\u043a\u0430 \u0440\u0443\u0431\u0459\u0430 (2000\u20132016)" },
-            { "bzd", "\u0411\u0435\u043b\u0438\u0437\u0435 \u0434\u043e\u043b\u0430\u0440" },
+            { "bzd", "\u0411\u0435\u043b\u0438\u0437\u0435\u0430\u043d\u0441\u043a\u0438 \u0434\u043e\u043b\u0430\u0440" },
             { "cad", "\u041a\u0430\u043d\u0430\u0434\u0441\u043a\u0438 \u0434\u043e\u043b\u0430\u0440" },
-            { "cdf", "\u041a\u043e\u043d\u0433\u043e\u043b\u0441\u043a\u0438 \u0444\u0440\u0430\u043d\u0430\u043a" },
+            { "cdf", "\u041a\u043e\u043d\u0433\u043e\u0430\u043d\u0441\u043a\u0438 \u0444\u0440\u0430\u043d\u0430\u043a" },
             { "che", "WIR \u0435\u0432\u0440\u043e" },
             { "chf", "\u0428\u0432\u0430\u0458\u0446\u0430\u0440\u0441\u043a\u0438 \u0444\u0440\u0430\u043d\u0430\u043a" },
             { "chw", "WIR \u0444\u0440\u0430\u043d\u0430\u043a" },
             { "clf", "\u0427\u0438\u043b\u0435\u043e\u0432\u0441\u043a\u0438 \u0443\u043d\u0438\u0434\u0430\u0434\u0435\u0441 \u0441\u0435 \u0444\u043e\u043c\u0435\u043d\u0442\u043e" },
-            { "clp", "\u0427\u0438\u043b\u0435\u0430\u043d\u0441\u043a\u0438 \u043f\u0435\u0437\u043e" },
-            { "cny", "\u041a\u0438\u043d\u0435\u0441\u043a\u0438 \u0458\u0443\u0430\u043d \u0440\u0435\u043d\u043c\u0438\u043d\u0431\u0438" },
-            { "cop", "\u041a\u043e\u043b\u0443\u043c\u0431\u0438\u0458\u0441\u043a\u0438 \u043f\u0435\u0437\u043e" },
+            { "clp", "\u0427\u0438\u043b\u0435\u0430\u043d\u0441\u043a\u0438 \u043f\u0435\u0437\u043e\u0441" },
+            { "cnh", "\u041a\u0438\u043d\u0435\u0441\u043a\u0438 \u0458\u0443\u0430\u043d (\u043e\u0441\u0442\u0440\u0432\u0441\u043a\u0438)" },
+            { "cny", "\u041a\u0438\u043d\u0435\u0441\u043a\u0438 \u0458\u0443\u0430\u043d" },
+            { "cop", "\u041a\u043e\u043b\u0443\u043c\u0431\u0438\u0458\u0441\u043a\u0438 \u043f\u0435\u0437\u043e\u0441" },
             { "cou", "\u0423\u043d\u0438\u0434\u0430\u0434 \u0434\u0435 \u0432\u0430\u043b\u043e\u0440\u0448\u043a\u0438 \u0440\u0435\u0430\u043b" },
             { "crc", "\u041a\u043e\u0441\u0442\u0430\u0440\u0438\u043a\u0430\u043d\u0441\u043a\u0438 \u043a\u043e\u043b\u043e\u043d" },
             { "csd", "\u0421\u0442\u0430\u0440\u0438 \u0441\u0440\u043f\u0441\u043a\u0438 \u0434\u0438\u043d\u0430\u0440" },
             { "csk", "\u0427\u0435\u0445\u043e\u0441\u043b\u043e\u0432\u0430\u0447\u043a\u0430 \u0442\u0432\u0440\u0434\u0430 \u043a\u0440\u0443\u043d\u0430" },
-            { "cuc", "\u043a\u0443\u0431\u0430\u043d\u0441\u043a\u0438 \u043a\u043e\u043d\u0432\u0435\u0440\u0442\u0438\u0431\u0438\u043b\u043d\u0438 \u043f\u0435\u0441\u043e" },
-            { "cup", "\u041a\u0443\u0431\u0430\u043d\u0441\u043a\u0438 \u043f\u0435\u0437\u043e" },
+            { "cuc", "\u043a\u0443\u0431\u0430\u043d\u0441\u043a\u0438 \u043a\u043e\u043d\u0432\u0435\u0440\u0442\u0438\u0431\u0438\u043b\u043d\u0438 \u043f\u0435\u0437\u043e\u0441" },
+            { "cup", "\u041a\u0443\u0431\u0430\u043d\u0441\u043a\u0438 \u043f\u0435\u0437\u043e\u0441" },
             { "cve", "\u0417\u0435\u043b\u0435\u043d\u043e\u0440\u0442\u0441\u043a\u0438 \u0435\u0441\u043a\u0443\u0434\u043e" },
             { "cyp", "\u041a\u0438\u043f\u0430\u0440\u0441\u043a\u0430 \u0444\u0443\u043d\u0442\u0430" },
             { "czk", "\u0427\u0435\u0448\u043a\u0430 \u043a\u0440\u0443\u043d\u0430" },
             { "ddm", "\u0418\u0441\u0442\u043e\u0447\u043d\u043e-\u043d\u0435\u043c\u0430\u0447\u043a\u0430 \u043c\u0430\u0440\u043a\u0430" },
             { "dem", "\u041d\u0435\u043c\u0430\u0447\u043a\u0430 \u043c\u0430\u0440\u043a\u0430" },
-            { "djf", "\u040f\u0438\u0431\u0443\u0442\u0430\u043d\u0441\u043a\u0438 \u0444\u0440\u0430\u043d\u0430\u043a" },
+            { "djf", "\u040f\u0438\u0431\u0443\u0442\u0441\u043a\u0438 \u0444\u0440\u0430\u043d\u0430\u043a" },
             { "dkk", "\u0414\u0430\u043d\u0441\u043a\u0430 \u043a\u0440\u0443\u043d\u0430" },
-            { "dop", "\u0414\u043e\u043c\u0438\u043d\u0438\u043a\u0430\u043d\u0441\u043a\u0438 \u043f\u0435\u0437\u043e" },
+            { "dop", "\u0414\u043e\u043c\u0438\u043d\u0438\u043a\u0430\u043d\u0441\u043a\u0438 \u043f\u0435\u0437\u043e\u0441" },
             { "dzd", "\u0410\u043b\u0436\u0438\u0440\u0441\u043a\u0438 \u0434\u0438\u043d\u0430\u0440" },
             { "ecs", "\u0415\u043a\u0432\u0430\u0434\u043e\u0440\u0441\u043a\u0438 \u0441\u0430\u043a\u0440" },
             { "ecv", "\u0415\u043a\u0432\u0430\u0434\u043e\u0440\u0441\u043a\u0438 \u0443\u043d\u0438\u0434\u0430\u0434 \u0434\u0435 \u0432\u0430\u043b\u043e\u0440 \u043a\u043e\u043d\u0441\u0442\u0430\u043d\u0442\u0435" },
             { "eek", "\u0415\u0441\u0442\u043e\u043d\u0441\u043a\u0430 \u043a\u0440\u043e\u043e\u043d" },
             { "egp", "\u0415\u0433\u0438\u043f\u0430\u0442\u0441\u043a\u0430 \u0444\u0443\u043d\u0442\u0430" },
-            { "ern", "\u0415\u0440\u0438\u0442\u0440\u0435\u0430\u043d\u0441\u043a\u0430 \u043d\u0430\u043a\u0444\u0430" },
+            { "ern", "\u0415\u0440\u0438\u0442\u0440\u0435\u0458\u0441\u043a\u0430 \u043d\u0430\u043a\u0444\u0430" },
             { "esa", "\u0428\u043f\u0430\u043d\u0441\u043a\u0430 \u043f\u0435\u0437\u0435\u0442\u0430 (\u0440\u0430\u0447\u0443\u043d)" },
             { "esb", "\u0428\u043f\u0430\u043d\u0441\u043a\u0430 \u043f\u0435\u0437\u0435\u0442\u0430 (\u043a\u043e\u043d\u0432\u0435\u0440\u0442\u0438\u0431\u0438\u043b\u043d\u0438\u0440\u0430\u0447\u0443\u043d)" },
             { "esp", "\u0428\u043f\u0430\u043d\u0441\u043a\u0430 \u043f\u0435\u0437\u0435\u0442\u0430" },
-            { "etb", "\u0435\u0442\u0438\u043e\u043f\u0438\u0458\u0441\u043a\u0438 \u0431\u0438\u0440" },
+            { "etb", "\u0415\u0442\u0438\u043e\u043f\u0438\u0458\u0441\u043a\u0438 \u0431\u0438\u0440" },
             { "eur", "\u0415\u0432\u0440\u043e" },
             { "fim", "\u0424\u0438\u043d\u0441\u043a\u0430 \u043c\u0430\u0440\u043a\u0430" },
             { "fjd", "\u0424\u0438\u045f\u0438 \u0434\u043e\u043b\u0430\u0440" },
-            { "fkp", "\u0424\u043e\u043a\u043b\u0430\u043d\u0434\u0441\u043a\u0430 \u043e\u0441\u0442\u0440\u0432\u0430 \u0444\u0443\u043d\u0442\u0430" },
+            { "fkp", "\u0424\u043e\u043b\u043a\u043b\u0430\u043d\u0434\u0441\u043a\u0430 \u0444\u0443\u043d\u0442\u0430" },
             { "frf", "\u0424\u0440\u0430\u043d\u0446\u0443\u0441\u043a\u0438 \u0444\u0440\u0430\u043d\u0430\u043a" },
             { "gbp", "\u0411\u0440\u0438\u0442\u0430\u043d\u0441\u043a\u0430 \u0444\u0443\u043d\u0442\u0430" },
             { "gek", "\u0413\u0440\u0443\u0437\u0438\u0458\u0441\u043a\u0438 \u043a\u0443\u043f\u043e\u043d \u043b\u0430\u0440\u0438\u0442" },
             { "gel", "\u0413\u0440\u0443\u0437\u0438\u0458\u0441\u043a\u0438 \u043b\u0430\u0440\u0438" },
             { "ghc", "\u0413\u0430\u043d\u0441\u043a\u0438 \u0446\u0435\u0434\u0438 (1979\u20132007)" },
             { "ghs", "\u0413\u0430\u043d\u0441\u043a\u0438 \u0446\u0435\u0434\u0438" },
-            { "gip", "\u0413\u0438\u0431\u0440\u0430\u043b\u0442\u0430\u0448\u043a\u0430 \u0444\u0443\u043d\u0442\u0430" },
+            { "gip", "\u0413\u0438\u0431\u0440\u0430\u043b\u0442\u0430\u0441\u043a\u0430 \u0444\u0443\u043d\u0442\u0430" },
             { "gmd", "\u0413\u0430\u043c\u0431\u0438\u0458\u0441\u043a\u0438 \u0434\u0430\u043b\u0430\u0441\u0438" },
             { "gnf", "\u0413\u0432\u0438\u043d\u0435\u0458\u0441\u043a\u0438 \u0444\u0440\u0430\u043d\u0430\u043a" },
             { "gns", "\u0413\u0432\u0438\u043d\u0435\u0458\u0441\u043a\u0438 \u0441\u0438\u043b\u0438" },
@@ -178,21 +179,21 @@ public class CurrencyNames_bs_Cyrl extends OpenListResourceBundle {
             { "gtq", "\u0413\u0432\u0430\u0442\u0435\u043c\u0430\u043b\u0441\u043a\u0438 \u043a\u0432\u0435\u0446\u0430\u043b" },
             { "gwe", "\u043f\u043e\u0440\u0442\u0443\u0433\u0430\u043b\u0441\u043a\u0430 \u0433\u0432\u0438\u043d\u0435\u0458\u0430 \u0435\u0441\u043a\u0443\u0434\u043e" },
             { "gwp", "\u0413\u0432\u0438\u043d\u0435\u0458\u0430 \u0411\u0438\u0441\u0430\u043e \u041f\u0435\u0437\u043e" },
-            { "gyd", "\u0413\u0443\u0458\u0430\u043d\u0441\u043a\u0438 \u0434\u043e\u043b\u0430\u0440" },
+            { "gyd", "\u0413\u0432\u0430\u0458\u0430\u043d\u0441\u043a\u0438 \u0434\u043e\u043b\u0430\u0440" },
             { "hkd", "\u0425\u043e\u043d\u0433\u043a\u043e\u043d\u0448\u043a\u0438 \u0434\u043e\u043b\u0430\u0440" },
             { "hnl", "\u0425\u043e\u043d\u0434\u0443\u0440\u0430\u0448\u043a\u0430 \u043b\u0435\u043c\u043f\u0438\u0440\u0430" },
             { "hrd", "\u0425\u0440\u0432\u0430\u0442\u0441\u043a\u0438 \u0434\u0438\u043d\u0430\u0440" },
             { "hrk", "\u0425\u0440\u0432\u0430\u0442\u0441\u043a\u0430 \u043a\u0443\u043d\u0430" },
             { "htg", "\u0425\u0430\u0438\u045b\u0430\u043d\u0441\u043a\u0438 \u0433\u0443\u0440\u0434" },
             { "huf", "\u041c\u0430\u0452\u0430\u0440\u0441\u043a\u0430 \u0444\u043e\u0440\u0438\u043d\u0442\u0430" },
-            { "idr", "\u0418\u043d\u0434\u043e\u043d\u0435\u0437\u0438\u0458\u0441\u043a\u0430 \u0440\u0443\u043f\u0438\u0430" },
+            { "idr", "\u0418\u043d\u0434\u043e\u043d\u0435\u0436\u0430\u043d\u0441\u043a\u0430 \u0440\u0443\u043f\u0438\u0458\u0430" },
             { "iep", "\u0418\u0440\u0441\u043a\u0430 \u0444\u0443\u043d\u0442\u0430" },
             { "ilp", "\u0418\u0437\u0440\u0430\u0435\u043b\u0441\u043a\u0430 \u0444\u0443\u043d\u0442\u0430" },
             { "ilr", "\u0441\u0442\u0430\u0440\u0438 \u0438\u0437\u0440\u0430\u0435\u043b\u0441\u043a\u0438 \u0448\u0435\u043a\u0435\u043b\u0438" },
             { "ils", "\u0418\u0437\u0440\u0430\u0435\u043b\u0441\u043a\u0438 \u043d\u043e\u0432\u0438 \u0448\u0435\u043a\u0435\u043b" },
-            { "inr", "\u0418\u043d\u0434\u0438\u0458\u0441\u043a\u0438 \u0420\u0443\u043f\u0438" },
+            { "inr", "\u0418\u043d\u0434\u0438\u0458\u0441\u043a\u0430 \u0440\u0443\u043f\u0438\u0458\u0430" },
             { "iqd", "\u0418\u0440\u0430\u0447\u043a\u0438 \u0434\u0438\u043d\u0430\u0440" },
-            { "irr", "\u0418\u0440\u0430\u043d\u0441\u043a\u0438 \u0440\u0438\u0430\u043b" },
+            { "irr", "\u0418\u0440\u0430\u043d\u0441\u043a\u0438 \u0440\u0438\u0458\u0430\u043b" },
             { "isj", "\u0441\u0442\u0430\u0440\u0430 \u0438\u0441\u043b\u0430\u043d\u0434\u0441\u043a\u0430 \u043a\u0440\u0443\u043d\u0430" },
             { "isk", "\u0418\u0441\u043b\u0430\u043d\u0434\u0441\u043a\u0430 \u043a\u0440\u0443\u043d\u0430" },
             { "itl", "\u0418\u0442\u0430\u043b\u0438\u0458\u0430\u043d\u0441\u043a\u0430 \u043b\u0438\u0440\u0430" },
@@ -201,16 +202,16 @@ public class CurrencyNames_bs_Cyrl extends OpenListResourceBundle {
             { "jpy", "\u0408\u0430\u043f\u0430\u043d\u0441\u043a\u0438 \u0458\u0435\u043d" },
             { "kes", "\u041a\u0435\u043d\u0438\u0458\u0441\u043a\u0438 \u0448\u0438\u043b\u0438\u043d\u0433" },
             { "kgs", "\u041a\u0438\u0440\u0433\u0438\u0441\u0442\u0430\u043d\u0441\u043a\u0438 \u0441\u043e\u043c" },
-            { "khr", "\u041a\u0430\u043c\u0431\u043e\u045f\u0438\u0458\u0441\u043a\u0438 \u0440\u0438\u0435\u043b" },
+            { "khr", "\u041a\u0430\u043c\u0431\u043e\u045f\u0430\u043d\u0441\u043a\u0438 \u0440\u0438\u0458\u0435\u043b" },
             { "kmf", "\u041a\u043e\u043c\u043e\u0440\u0441\u043a\u0438 \u0444\u0440\u0430\u043d\u0430\u043a" },
             { "kpw", "\u0421\u0435\u0432\u0435\u0440\u043d\u043e\u043a\u043e\u0440\u0435\u0458\u0441\u043a\u0438 \u0432\u043e\u043d" },
-            { "krw", "\u0408\u0443\u0436\u043d\u043e\u043a\u043e\u0440\u0435\u0458\u0441\u043a\u0438 \u0412\u043e\u043d" },
+            { "krw", "\u0408\u0443\u0436\u043d\u043e\u043a\u043e\u0440\u0435\u0458\u0441\u043a\u0438 \u0432\u043e\u043d" },
             { "kwd", "\u041a\u0443\u0432\u0430\u0458\u0442\u0441\u043a\u0438 \u0434\u0438\u043d\u0430\u0440" },
-            { "kyd", "\u041a\u0430\u0458\u043c\u0430\u043d\u0441\u043a\u0430 \u043e\u0441\u0442\u0440\u0432\u0430 \u0434\u043e\u043b\u0430\u0440" },
-            { "kzt", "\u041a\u0430\u0437\u0430\u0445\u0441\u0442\u0430\u043d\u0441\u043a\u0438 \u0442\u0435\u043d\u045f" },
-            { "lak", "\u041b\u0430\u043e\u0448\u043a\u0438 \u043a\u0438\u043f" },
-            { "lbp", "\u041b\u0435\u0431\u0430\u043d\u0441\u043a\u0430 \u0444\u0443\u043d\u0442\u0430" },
-            { "lkr", "\u0428\u0440\u0438\u043b\u0430\u043d\u043a\u0430\u043d\u0441\u043a\u0438 \u0440\u0443\u043f\u0438" },
+            { "kyd", "\u041a\u0430\u0458\u043c\u0430\u043d\u0441\u043a\u0438 \u0434\u043e\u043b\u0430\u0440" },
+            { "kzt", "\u041a\u0430\u0437\u0430\u0445\u0441\u0442\u0430\u043d\u0441\u043a\u0438 \u0442\u0435\u043d\u0433\u0435" },
+            { "lak", "\u041b\u0430\u043e\u0441\u043a\u0438 \u043a\u0438\u043f" },
+            { "lbp", "\u041b\u0438\u0431\u0430\u043d\u0441\u043a\u0430 \u0444\u0443\u043d\u0442\u0430" },
+            { "lkr", "\u0428\u0440\u0438\u043b\u0430\u043d\u043a\u0430\u043d\u0441\u043a\u0430 \u0440\u0443\u043f\u0438\u0458\u0430" },
             { "lrd", "\u041b\u0438\u0431\u0435\u0440\u0438\u0458\u0441\u043a\u0438 \u0434\u043e\u043b\u0430\u0440" },
             { "lsl", "\u041b\u0435\u0441\u043e\u0442\u043e \u043b\u043e\u0442\u0438" },
             { "ltl", "\u041b\u0438\u0442\u0432\u0430\u043d\u0441\u043a\u0438 \u043b\u0438\u0442\u0430\u0441" },
@@ -223,88 +224,89 @@ public class CurrencyNames_bs_Cyrl extends OpenListResourceBundle {
             { "lyd", "\u041b\u0438\u0431\u0438\u0458\u0441\u043a\u0438 \u0434\u0438\u043d\u0430\u0440" },
             { "mad", "\u041c\u0430\u0440\u043e\u043a\u0430\u043d\u0441\u043a\u0438 \u0434\u0438\u0440\u0445\u0430\u043c" },
             { "maf", "\u041c\u0430\u0440\u043e\u043a\u0430\u043d\u0441\u043a\u0438 \u0444\u0440\u0430\u043d\u0430\u043a" },
-            { "mdl", "\u041c\u043e\u043b\u0434\u043e\u0432\u0441\u043a\u0438 \u0459\u0443" },
-            { "mga", "\u041c\u0430\u043b\u0430\u0433\u0430\u0441\u0438\u0458\u0441\u043a\u0438 \u0430\u0440\u0438\u0430\u0440\u0438" },
+            { "mdl", "\u041c\u043e\u043b\u0434\u0430\u0432\u0441\u043a\u0438 \u043b\u0435\u0458" },
+            { "mga", "\u041c\u0430\u0434\u0430\u0433\u0430\u0441\u043a\u0430\u0440\u0441\u043a\u0438 \u0430\u0440\u0438\u0458\u0430\u0440\u0438" },
             { "mgf", "\u041c\u0430\u043b\u0430\u0433\u0430\u0441\u0438\u0458\u0441\u043a\u0438 \u0444\u0440\u0430\u043d\u0430\u043a" },
             { "mkd", "\u041c\u0430\u043a\u0435\u0434\u043e\u043d\u0441\u043a\u0438 \u0434\u0435\u043d\u0430\u0440" },
             { "mlf", "\u041c\u0430\u043b\u0438\u0458\u0430\u043d\u0441\u043a\u0438 \u0444\u0440\u0430\u043d\u0430\u043a" },
-            { "mmk", "\u041c\u0458\u0430\u043d\u043c\u0430\u0448\u043a\u0438 \u043a\u0458\u0430\u0442" },
+            { "mmk", "\u041c\u0438\u0458\u0430\u043d\u043c\u0430\u0440\u0441\u043a\u0438 \u043a\u0458\u0430\u0442" },
             { "mnt", "\u041c\u043e\u043d\u0433\u043e\u043b\u0441\u043a\u0438 \u0442\u0443\u0433\u0440\u0438\u043a" },
-            { "mop", "\u041c\u0430\u043a\u0430\u043d\u0438\u0448\u043a\u0430 \u043f\u0430\u0442\u0430\u043a\u0430" },
+            { "mop", "\u041c\u0430\u043a\u0430\u043e\u0441\u043a\u0430 \u043f\u0430\u0442\u0430\u043a\u0430" },
             { "mro", "\u041c\u0430\u0443\u0440\u0438\u0442\u0430\u043d\u0438\u0458\u0441\u043a\u0430 \u0443\u0433\u0432\u0438\u0458\u0430 (1973\u20132017)" },
-            { "mru", "\u041c\u0430\u0443\u0440\u0438\u0442\u0430\u043d\u0438\u0458\u0441\u043a\u0430 \u0443\u0433\u0432\u0438\u0458\u0430" },
+            { "mru", "\u041c\u0430\u0443\u0440\u0438\u0442\u0430\u043d\u0441\u043a\u0430 \u043e\u0433\u0438\u0458\u0430" },
             { "mtl", "\u041c\u0430\u043b\u0442\u0435\u0448\u043a\u0430 \u043b\u0438\u0440\u0430" },
             { "mtp", "\u041c\u0430\u043b\u0442\u0435\u0448\u043a\u0430 \u0444\u0443\u043d\u0442\u0430" },
-            { "mur", "\u041c\u0430\u0443\u0440\u0438\u0446\u0438\u0458\u0441\u043a\u0438 \u0440\u0443\u043f\u0438" },
-            { "mvr", "\u041c\u0430\u043b\u0434\u0438\u0432\u0438\u0458\u0441\u043a\u0430 \u0440\u0443\u0444\u0438\u0458\u0430" },
+            { "mur", "\u041c\u0430\u0443\u0440\u0438\u0446\u0438\u0458\u0441\u043a\u0430 \u0440\u0443\u043f\u0438\u0458\u0430" },
+            { "mvr", "\u041c\u0430\u043b\u0434\u0438\u0432\u0441\u043a\u0430 \u0440\u0443\u0444\u0438\u0458\u0430" },
             { "mwk", "\u041c\u0430\u043b\u0430\u0432\u0438\u0458\u0441\u043a\u0430 \u043a\u0432\u0430\u0447\u0430" },
-            { "mxn", "\u041c\u0435\u043a\u0441\u0438\u0447\u043a\u0438 \u043f\u0435\u0437\u043e" },
+            { "mxn", "\u041c\u0435\u043a\u0441\u0438\u0447\u043a\u0438 \u043f\u0435\u0437\u043e\u0441" },
             { "mxp", "\u041c\u0435\u043a\u0441\u0438\u0447\u043a\u0438 \u0441\u0440\u0435\u0431\u0440\u043d\u0438 \u043f\u0435\u0437\u043e (1861\u20131992)" },
             { "mxv", "\u041c\u0435\u043a\u0441\u0438\u0447\u043a\u0438 \u0443\u043d\u0438\u0434\u0430\u0434 \u0434\u0435 \u0438\u043d\u0432\u0435\u0440\u0441\u0438\u043e\u043d (UDI)" },
-            { "myr", "\u041c\u0430\u043b\u0435\u0437\u0438\u0458\u0441\u043a\u0438 \u0440\u0438\u043d\u0433\u0433\u0438\u0442" },
+            { "myr", "\u041c\u0430\u043b\u0435\u0437\u0438\u0458\u0441\u043a\u0438 \u0440\u0438\u043d\u0433\u0438\u0442" },
             { "mze", "\u041c\u043e\u0437\u0430\u043c\u0431\u0438\u0458\u0441\u043a\u0438 \u0435\u0441\u043a\u0443\u0434\u043e" },
             { "mzm", "\u0421\u0442\u0430\u0440\u0438 \u043c\u043e\u0437\u0430\u043c\u0431\u0438\u0458\u0441\u043a\u0438 \u043c\u0435\u0442\u0438\u043a\u0430\u043b" },
             { "mzn", "\u041c\u043e\u0437\u0430\u043c\u0431\u0438\u0458\u0441\u043a\u0438 \u043c\u0435\u0442\u0438\u043a\u0430\u043b" },
-            { "nad", "\u043d\u0430\u043c\u0431\u0438\u0458\u0441\u043a\u0438 \u0434\u043e\u043b\u0430\u0440" },
+            { "nad", "\u041d\u0430\u043c\u0438\u0431\u0438\u0458\u0441\u043a\u0438 \u0434\u043e\u043b\u0430\u0440" },
             { "ngn", "\u041d\u0438\u0433\u0435\u0440\u0438\u0458\u0441\u043a\u0430 \u043d\u0430\u0438\u0440\u0430" },
             { "nic", "\u041d\u0438\u043a\u0430\u0440\u0430\u0433\u0432\u0430\u043d\u0441\u043a\u0430 \u043a\u043e\u0440\u0434\u043e\u0431\u0430" },
             { "nio", "\u041d\u0438\u043a\u0430\u0440\u0430\u0433\u0432\u0430\u043d\u0441\u043a\u0430 \u0437\u043b\u0430\u0442\u043d\u0430 \u043a\u043e\u0440\u0434\u043e\u0431\u0430" },
             { "nlg", "\u0425\u043e\u043b\u0430\u043d\u0434\u0441\u043a\u0438 \u0433\u0443\u043b\u0434\u0435\u043d" },
             { "nok", "\u041d\u043e\u0440\u0432\u0435\u0448\u043a\u0430 \u043a\u0440\u0443\u043d\u0430" },
-            { "npr", "\u041d\u0435\u043f\u0430\u043b\u0441\u043a\u0438 \u0440\u0443\u043f\u0438" },
+            { "npr", "\u041d\u0435\u043f\u0430\u043b\u0441\u043a\u0430 \u0440\u0443\u043f\u0438\u0458\u0430" },
             { "nzd", "\u041d\u043e\u0432\u043e\u0437\u0435\u043b\u0430\u043d\u0434\u0441\u043a\u0438 \u0434\u043e\u043b\u0430\u0440" },
             { "omr", "\u041e\u043c\u0430\u043d\u0441\u043a\u0438 \u0440\u0438\u0458\u0430\u043b" },
             { "pab", "\u041f\u0430\u043d\u0430\u043c\u0441\u043a\u0430 \u0431\u0430\u043b\u0431\u043e\u0430" },
             { "pei", "\u041f\u0435\u0440\u0443\u0430\u043d\u0441\u043a\u0438 \u0438\u043d\u0442\u0438" },
             { "pen", "\u041f\u0435\u0440\u0443\u0430\u043d\u0441\u043a\u0438 \u0441\u043e\u043b" },
             { "pes", "\u041f\u0435\u0440\u0443\u0430\u043d\u0441\u043a\u0438 \u0441\u043e\u043b (1863\u20131965)" },
-            { "pgk", "\u041f\u0430\u043f\u0443\u0430 \u043d\u043e\u0432\u043e-\u0433\u0432\u0438\u043d\u0435\u0458\u0448\u043a\u0430 \u043a\u0438\u043d\u0430" },
-            { "php", "\u0424\u0438\u043b\u0438\u043f\u0438\u043d\u0441\u043a\u0438 \u043f\u0435\u0437\u043e" },
-            { "pkr", "\u041f\u0430\u043a\u0438\u0441\u0442\u0430\u043d\u0441\u043a\u0438 \u0440\u0443\u043f\u0438" },
+            { "pgk", "\u041f\u0430\u043f\u0443\u0430\u043d\u0441\u043a\u0430 \u043a\u0438\u043d\u0430" },
+            { "php", "\u0424\u0438\u043b\u0438\u043f\u0438\u043d\u0441\u043a\u0438 \u043f\u0435\u0437\u043e\u0441" },
+            { "pkr", "\u041f\u0430\u043a\u0438\u0441\u0442\u0430\u043d\u0441\u043a\u0430 \u0440\u0443\u043f\u0438\u0458\u0430" },
             { "pln", "\u041f\u043e\u0459\u0441\u043a\u0438 \u0437\u043b\u043e\u0442" },
             { "plz", "\u041f\u043e\u0459\u0441\u043a\u0438 \u0437\u043b\u043e\u0442\u0438 (1950\u20131995)" },
             { "pte", "\u041f\u043e\u0440\u0442\u0443\u0433\u0430\u043b\u0441\u043a\u0438 \u0435\u0441\u043a\u0443\u0434\u043e" },
-            { "pyg", "\u041f\u0430\u0440\u0430\u0433\u0432\u0430\u0458\u0441\u043a\u0438 \u0433\u0443\u0430\u0440\u043d\u0438" },
-            { "qar", "\u041a\u0430\u0442\u0430\u0440\u0448\u043a\u0438 \u0440\u0438\u0458\u0430\u043b" },
+            { "pyg", "\u041f\u0430\u0440\u0430\u0433\u0432\u0430\u0458\u0441\u043a\u0438 \u0433\u0432\u0430\u0440\u0430\u043d\u0438" },
+            { "qar", "\u041a\u0430\u0442\u0430\u0440\u0441\u043a\u0438 \u0440\u0438\u0458\u0430\u043b" },
             { "rhd", "\u0420\u043e\u0434\u0435\u0458\u0441\u043a\u0438\u0434\u043e\u043b\u0430\u0440" },
             { "rol", "\u0421\u0442\u0430\u0440\u0438 \u0440\u0443\u043c\u0443\u043d\u0441\u043a\u0438 \u0459\u0443" },
-            { "ron", "\u0420\u0443\u043c\u0443\u043d\u0441\u043a\u0438 \u043b\u0435\u0443" },
+            { "ron", "\u0420\u0443\u043c\u0443\u043d\u0441\u043a\u0438 \u043b\u0435\u0458" },
             { "rsd", "\u0421\u0440\u043f\u0441\u043a\u0438 \u0434\u0438\u043d\u0430\u0440" },
             { "rub", "\u0420\u0443\u0441\u043a\u0430 \u0440\u0443\u0431\u0459\u0430" },
             { "rur", "\u0420\u0443\u0441\u043a\u0430 \u0440\u0443\u0431\u0459\u0430 (1991\u20131998)" },
-            { "rwf", "\u0420\u0443\u0430\u043d\u0434\u0430\u043d\u0441\u043a\u0438 \u0444\u0440\u0430\u043d\u0430\u043a" },
+            { "rwf", "\u0420\u0443\u0430\u043d\u0434\u0441\u043a\u0438 \u0444\u0440\u0430\u043d\u0430\u043a" },
             { "sar", "\u0421\u0430\u0443\u0434\u0438\u0458\u0441\u043a\u0438 \u0440\u0438\u0458\u0430\u043b" },
-            { "sbd", "\u0421\u043e\u043b\u043e\u043c\u043e\u043d\u0441\u043a\u043e-\u043e\u0441\u0442\u0440\u0432\u0441\u043a\u0438 \u0434\u043e\u043b\u0430\u0440" },
+            { "sbd", "\u0421\u043e\u043b\u043e\u043c\u043e\u043d\u0441\u043a\u0438 \u0434\u043e\u043b\u0430\u0440" },
             { "scr", "\u0421\u0435\u0458\u0448\u0435\u043b\u0441\u043a\u0430 \u0440\u0443\u043f\u0438\u0458\u0430" },
             { "sdd", "\u0421\u0442\u0430\u0440\u0438 \u0441\u0443\u0434\u0430\u043d\u0441\u043a\u0438 \u0434\u0438\u043d\u0430\u0440" },
             { "sdg", "\u0421\u0443\u0434\u0430\u043d\u0441\u043a\u0430 \u0444\u0443\u043d\u0442\u0430" },
             { "sdp", "\u0421\u0442\u0430\u0440\u0430 \u0441\u0443\u0434\u0430\u043d\u0441\u043a\u0430 \u0444\u0443\u043d\u0442\u0430" },
             { "sek", "\u0428\u0432\u0435\u0434\u0441\u043a\u0430 \u043a\u0440\u0443\u043d\u0430" },
             { "sgd", "\u0421\u0438\u043d\u0433\u0430\u043f\u0443\u0440\u0441\u043a\u0438 \u0434\u043e\u043b\u0430\u0440" },
-            { "shp", "\u0421\u0432. \u0458\u0435\u043b\u0435\u043d\u0441\u043a\u0430 \u0444\u0443\u043d\u0442\u0430" },
+            { "shp", "\u0421\u0432\u0435\u0442\u0430 \u0408\u0435\u043b\u0435\u043d\u0430 \u0444\u0443\u043d\u0442\u0430" },
             { "sit", "\u0421\u043b\u043e\u0432\u0435\u043d\u0430\u0447\u043a\u0438 \u0442\u043e\u043b\u0430\u0440" },
             { "skk", "\u0421\u043b\u043e\u0432\u0430\u0447\u043a\u0430 \u043a\u0440\u0443\u043d\u0430" },
-            { "sll", "\u0421\u0438\u0458\u0435\u0440\u0430-\u043b\u0435\u043e\u043d\u0448\u043a\u0438 \u043b\u0435\u043e\u043d\u0435" },
-            { "sos", "\u0421\u041e\u043c\u0430\u043b\u0438\u0458\u0441\u043a\u0438 \u0448\u0438\u043b\u0438\u043d\u0433" },
-            { "srd", "\u0421\u0423\u0440\u0438\u043d\u0430\u043c\u0441\u043a\u0438 \u0434\u043e\u043b\u0430\u0440" },
+            { "sll", "\u0421\u0438\u0458\u0435\u0440\u0430\u043b\u0435\u043e\u043d\u0441\u043a\u0438 \u043b\u0435\u043e\u043d\u0435" },
+            { "sos", "\u0421\u043e\u043c\u0430\u043b\u0438\u0458\u0441\u043a\u0438 \u0448\u0438\u043b\u0438\u043d\u0433" },
+            { "srd", "\u0421\u0443\u0440\u0438\u043d\u0430\u043c\u0441\u043a\u0438 \u0434\u043e\u043b\u0430\u0440" },
             { "srg", "\u0421\u0443\u0440\u0438\u043d\u0430\u043c\u0441\u043a\u0438 \u0433\u0438\u043b\u0434\u0435\u0440" },
+            { "ssp", "\u0408\u0443\u0436\u043d\u043e\u0441\u0443\u0434\u0430\u043d\u0441\u043a\u0430 \u0444\u0443\u043d\u0442\u0430" },
             { "std", "\u0421\u0430\u043e \u0422\u043e\u043c\u0435 \u0438 \u041f\u0440\u0438\u043d\u0446\u0438\u043f\u0435 \u0434\u043e\u0431\u0440\u0430 (1977\u20132017)" },
             { "stn", "\u0421\u0430\u043e \u0422\u043e\u043c\u0435 \u0438 \u041f\u0440\u0438\u043d\u0446\u0438\u043f\u0435 \u0434\u043e\u0431\u0440\u0430" },
             { "sur", "\u0421\u043e\u0432\u0458\u0435\u0442\u0441\u043a\u0430 \u0440\u0443\u0431\u0459\u0430" },
             { "svc", "\u0421\u0430\u043b\u0432\u0430\u0434\u043e\u0440\u0441\u043a\u0438 \u043a\u043e\u043b\u043e\u043d" },
             { "syp", "\u0421\u0438\u0440\u0438\u0458\u0441\u043a\u0430 \u0444\u0443\u043d\u0442\u0430" },
-            { "szl", "\u0421\u0432\u0430\u0437\u0438 \u043b\u0438\u043b\u0430\u043d\u0433\u0435\u043d\u0438" },
-            { "thb", "\u0422\u0430\u0438 \u0431\u0430\u0445\u0442" },
+            { "szl", "\u0421\u0432\u0430\u0437\u0438\u043b\u0435\u043d\u0434\u0441\u043a\u0438 \u043b\u0438\u043b\u0430\u043d\u0433\u0435\u043d\u0438" },
+            { "thb", "\u0422\u0430\u0458\u0441\u043a\u0438 \u0431\u0430\u0445\u0442" },
             { "tjr", "\u0422\u0430\u045f\u0438\u0445\u0438\u0441\u0442\u0430\u043d\u0441\u043a\u0430 \u0440\u0443\u0431\u0459\u0430" },
-            { "tjs", "\u0422\u0430\u0459\u0438\u0445\u0438\u0441\u0442\u0430\u043d\u0441\u043a\u0438 \u0441\u043e\u043c\u043e\u043d\u0438" },
+            { "tjs", "\u0422\u0430\u045f\u0438\u043a\u0438\u0441\u0442\u0430\u043d\u0441\u043a\u0438 \u0441\u043e\u043c\u043e\u043d\u0438" },
             { "tmm", "\u0422\u0443\u0440\u043a\u043c\u0435\u043d\u0438\u0441\u0442\u0430\u043d\u0441\u043a\u0438 \u043c\u0430\u043d\u0430\u0442 (1993\u20132009)" },
             { "tmt", "\u0422\u0443\u0440\u043a\u043c\u0435\u043d\u0438\u0441\u0442\u0430\u043d\u0441\u043a\u0438 \u043c\u0430\u043d\u0430\u0442" },
-            { "tnd", "\u0422\u0443\u043d\u0438\u0437\u0438\u0458\u0441\u043a\u0438 \u0434\u043e\u043b\u0430\u0440" },
-            { "top", "\u0422\u043e\u043d\u0433\u043e\u043d\u0448\u043a\u0430 \u041f\u0430\u043d\u0433\u0430" },
+            { "tnd", "\u0422\u0443\u043d\u0438\u0441\u043a\u0438 \u0434\u0438\u043d\u0430\u0440" },
+            { "top", "\u0422\u043e\u043d\u0433\u043e\u0430\u043d\u0441\u043a\u0430 \u043f\u0430\u043d\u0433\u0430" },
             { "tpe", "\u0422\u0438\u043c\u043e\u0440\u0448\u043a\u0438 \u0435\u0441\u043a\u0443\u0434\u043e" },
             { "trl", "\u0421\u0442\u0430\u0440\u0430 \u0442\u0443\u0440\u0441\u043a\u0430 \u043b\u0438\u0440\u0430" },
             { "try", "\u0422\u0443\u0440\u0441\u043a\u0430 \u043b\u0438\u0440\u0430" },
-            { "ttd", "\u0422\u0440\u0438\u043d\u0438\u0434\u0430\u0434 \u0442\u043e\u0431\u0430\u0433\u043e\u0448\u043a\u0438 \u0434\u043e\u043b\u0430\u0440" },
+            { "ttd", "\u0422\u0440\u0438\u043d\u0438\u0434\u0430\u0434-\u0442\u043e\u0431\u0430\u0433\u043e\u0448\u043a\u0438 \u0434\u043e\u043b\u0430\u0440" },
             { "twd", "\u041d\u043e\u0432\u0438 \u0442\u0430\u0458\u0432\u0430\u043d\u0441\u043a\u0438 \u0434\u043e\u043b\u0430\u0440" },
             { "tzs", "\u0422\u0430\u043d\u0437\u0430\u043d\u0438\u0458\u0441\u043a\u0438 \u0448\u0438\u043b\u0438\u043d\u0433" },
             { "uah", "\u0423\u043a\u0440\u0430\u0458\u0438\u043d\u0441\u043a\u0430 \u0445\u0440\u0438\u0432\u045a\u0430" },
@@ -316,7 +318,7 @@ public class CurrencyNames_bs_Cyrl extends OpenListResourceBundle {
             { "uss", "\u0421\u0410\u0414 \u0434\u043e\u043b\u0430\u0440 (\u0438\u0441\u0442\u0438 \u0434\u0430\u043d)" },
             { "uyi", "\u0423\u0440\u0443\u0433\u0432\u0430\u0458\u0441\u043a\u0438 \u043f\u0435\u0437\u043e \u0435\u043d \u0443\u043d\u0438\u0434\u0430\u0434\u0435\u0441 \u0438\u043d\u0434\u0435\u043a\u0441\u0430\u0434\u0430\u0441" },
             { "uyp", "\u0423\u0440\u0443\u0433\u0432\u0430\u0458\u0441\u043a\u0438 \u043f\u0435\u0437\u043e (1975\u20131993)" },
-            { "uyu", "\u0423\u0440\u0443\u0433\u0432\u0430\u0458\u0441\u043a\u0438 \u043f\u0435\u0437\u043e" },
+            { "uyu", "\u0423\u0440\u0443\u0433\u0432\u0430\u0458\u0441\u043a\u0438 \u043f\u0435\u0437\u043e\u0441" },
             { "uzs", "\u0423\u0437\u0431\u0435\u043a\u0438\u0441\u0442\u0430\u043d\u0441\u043a\u0438 \u0441\u043e\u043c" },
             { "veb", "\u0412\u0435\u043d\u0435\u0446\u0443\u0435\u043b\u0430\u043d\u0441\u043a\u0438 \u0431\u043e\u043b\u0438\u0432\u0430\u0440 (1871\u20132008)" },
             { "vef", "\u0412\u0435\u043d\u0435\u0446\u0443\u0435\u043b\u0430\u043d\u0441\u043a\u0438 \u0431\u043e\u043b\u0438\u0432\u0430\u0440 (2008\u20132018)" },
@@ -344,12 +346,12 @@ public class CurrencyNames_bs_Cyrl extends OpenListResourceBundle {
             { "xts", "\u041a\u043e\u0434 \u0442\u0435\u0441\u0442\u0438\u0440\u0430\u043d\u0435 \u0432\u0430\u043b\u0443\u0442\u0435" },
             { "xxx", "\u041d\u0435\u043f\u043e\u0437\u043d\u0430\u0442\u0430 \u0438\u043b\u0438 \u043d\u0435\u0432\u0430\u0436\u0435\u045b\u0430 \u0432\u0430\u043b\u0443\u0442\u0430" },
             { "ydd", "\u0408\u0435\u043c\u0435\u043d\u0441\u043a\u0438 \u0434\u0438\u043d\u0430\u0440" },
-            { "yer", "\u0408\u0435\u043c\u0435\u043d\u0441\u043a\u0438 \u0440\u0438\u0430\u043b" },
+            { "yer", "\u0408\u0435\u043c\u0435\u043d\u0441\u043a\u0438 \u0440\u0438\u0458\u0430\u043b" },
             { "yud", "\u0408\u0443\u0433\u043e\u0441\u043b\u043e\u0432\u0435\u043d\u0441\u043a\u0438 \u0442\u0432\u0440\u0434\u0438 \u0434\u0438\u043d\u0430\u0440" },
             { "yum", "\u0408\u0443\u0433\u043e\u0441\u043b\u043e\u0432\u0435\u043d\u0441\u043a\u0438 \u043d\u043e\u0432\u0438 \u0434\u0438\u043d\u0430\u0440" },
             { "yun", "\u0408\u0443\u0433\u043e\u0441\u043b\u043e\u0432\u0435\u043d\u0441\u043a\u0438 \u043a\u043e\u043d\u0432\u0435\u0440\u0442\u0438\u0431\u0438\u043b\u043d\u0438 \u0434\u0438\u043d\u0430\u0440" },
             { "zal", "\u0408\u0443\u0436\u043d\u043e-\u0430\u0444\u0440\u0438\u0447\u043a\u0438 \u0440\u0430\u043d\u0434 (\u0444\u0438\u043d\u0430\u043d\u0441\u0438\u0458\u0441\u043a\u0438)" },
-            { "zar", "\u0408\u0443\u0436\u043d\u043e-\u0430\u0444\u0440\u0438\u0447\u043a\u0438 \u0440\u0430\u043d\u0434" },
+            { "zar", "\u0408\u0443\u0436\u043d\u043e\u0430\u0444\u0440\u0438\u0447\u043a\u0438 \u0440\u0430\u043d\u0434" },
             { "zmk", "\u0417\u0430\u043c\u0431\u0438\u0458\u0441\u043a\u0430 \u043a\u0432\u0430\u0447\u0430 (1968\u20132012)" },
             { "zmw", "\u0417\u0430\u043c\u0431\u0438\u0458\u0441\u043a\u0430 \u043a\u0432\u0430\u0447\u0430" },
             { "zrn", "\u0417\u0430\u0438\u0440\u0441\u043a\u0438 \u043d\u043e\u0432\u0438 \u0437\u0430\u0438\u0440" },
