@@ -71,19 +71,155 @@ public class CurrencyNames_ca extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
         final Object[][] data = new Object[][] {
+            { "AED", "AED" },
+            { "AFN", "AFN" },
+            { "ALL", "ALL" },
+            { "AMD", "AMD" },
+            { "ANG", "ANG" },
+            { "AOA", "AOA" },
+            { "ARS", "ARS" },
             { "AUD", "AU$" },
+            { "AWG", "AWG" },
+            { "AZN", "AZN" },
+            { "BAM", "BAM" },
+            { "BBD", "BBD" },
+            { "BDT", "BDT" },
+            { "BGN", "BGN" },
+            { "BHD", "BHD" },
+            { "BIF", "BIF" },
+            { "BMD", "BMD" },
+            { "BND", "BND" },
+            { "BOB", "BOB" },
             { "BRL", "BRL" },
+            { "BSD", "BSD" },
+            { "BTN", "BTN" },
+            { "BWP", "BWP" },
+            { "BYN", "BYN" },
+            { "BYR", "BYR" },
+            { "BZD", "BZD" },
             { "CAD", "CAD" },
+            { "CDF", "CDF" },
+            { "CHF", "CHF" },
+            { "CLP", "CLP" },
             { "CNH", "CNH" },
             { "CNY", "CNY" },
+            { "COP", "COP" },
+            { "CRC", "CRC" },
+            { "CUC", "CUC" },
+            { "CUP", "CUP" },
+            { "CVE", "CVE" },
+            { "CZK", "CZK" },
+            { "DJF", "DJF" },
+            { "DKK", "DKK" },
+            { "DOP", "DOP" },
+            { "DZD", "DZD" },
+            { "EGP", "EGP" },
+            { "ERN", "ERN" },
             { "ESP", "\u20a7" },
+            { "ETB", "ETB" },
+            { "FJD", "FJD" },
+            { "FKP", "FKP" },
+            { "GEL", "GEL" },
+            { "GHS", "GHS" },
+            { "GIP", "GIP" },
+            { "GMD", "GMD" },
+            { "GNF", "GNF" },
+            { "GTQ", "GTQ" },
+            { "GYD", "GYD" },
+            { "HNL", "HNL" },
+            { "HRK", "HRK" },
+            { "HTG", "HTG" },
+            { "HUF", "HUF" },
+            { "IDR", "IDR" },
+            { "IQD", "IQD" },
+            { "IRR", "IRR" },
+            { "ISK", "ISK" },
+            { "JMD", "JMD" },
+            { "JOD", "JOD" },
+            { "JPY", "\u00a5" },
+            { "KES", "KES" },
+            { "KGS", "KGS" },
+            { "KHR", "KHR" },
+            { "KMF", "KMF" },
+            { "KPW", "KPW" },
+            { "KWD", "KWD" },
+            { "KYD", "KYD" },
+            { "KZT", "KZT" },
+            { "LAK", "LAK" },
+            { "LBP", "LBP" },
+            { "LKR", "LKR" },
+            { "LRD", "LRD" },
+            { "LYD", "LYD" },
+            { "MAD", "MAD" },
+            { "MDL", "MDL" },
+            { "MGA", "MGA" },
+            { "MKD", "MKD" },
+            { "MMK", "MMK" },
+            { "MNT", "MNT" },
+            { "MOP", "MOP" },
+            { "MRO", "MRO" },
+            { "MRU", "MRU" },
+            { "MUR", "MUR" },
+            { "MVR", "MVR" },
+            { "MWK", "MWK" },
             { "MXN", "MXN" },
+            { "MYR", "MYR" },
+            { "MZN", "MZN" },
+            { "NAD", "NAD" },
+            { "NGN", "NGN" },
+            { "NIO", "NIO" },
+            { "NOK", "NOK" },
+            { "NPR", "NPR" },
+            { "OMR", "OMR" },
+            { "PAB", "PAB" },
+            { "PEN", "PEN" },
+            { "PGK", "PGK" },
+            { "PHP", "PHP" },
+            { "PKR", "PKR" },
+            { "PLN", "PLN" },
+            { "PYG", "PYG" },
+            { "QAR", "QAR" },
+            { "RON", "RON" },
+            { "RSD", "RSD" },
+            { "RUB", "RUB" },
+            { "RWF", "RWF" },
+            { "SAR", "SAR" },
+            { "SBD", "SBD" },
+            { "SCR", "SCR" },
+            { "SDG", "SDG" },
+            { "SEK", "SEK" },
+            { "SGD", "SGD" },
+            { "SHP", "SHP" },
+            { "SLL", "SLL" },
+            { "SOS", "SOS" },
+            { "SRD", "SRD" },
+            { "SSP", "SSP" },
+            { "STD", "STD" },
             { "STN", "STN" },
+            { "SYP", "SYP" },
+            { "SZL", "SZL" },
             { "THB", "\u0e3f" },
+            { "TJS", "TJS" },
+            { "TMT", "TMT" },
+            { "TND", "TND" },
+            { "TOP", "TOP" },
+            { "TRY", "TRY" },
+            { "TTD", "TTD" },
+            { "TZS", "TZS" },
+            { "UAH", "UAH" },
+            { "UGX", "UGX" },
             { "USD", "USD" },
+            { "UYU", "UYU" },
+            { "UZS", "UZS" },
+            { "VEF", "VEF" },
             { "VES", "VES" },
+            { "VUV", "VUV" },
+            { "WST", "WST" },
             { "XCD", "XCD" },
             { "XXX", "XXX" },
+            { "YER", "YER" },
+            { "ZAR", "ZAR" },
+            { "ZMW", "ZMW" },
             { "adp", "pesseta andorrana" },
             { "aed", "d\u00edrham de la UEA" },
             { "afa", "afgani afgan\u00e8s (1927\u20132002)" },
@@ -315,7 +451,7 @@ public class CurrencyNames_ca extends OpenListResourceBundle {
             { "stn", "dobra de S\u00e3o Tom\u00e9 i Pr\u00edncipe" },
             { "sur", "ruble sovi\u00e8tic" },
             { "svc", "colon salvadorenc" },
-            { "syp", "lliura s\u00edria" },
+            { "syp", "lliura siriana" },
             { "szl", "lilangeni swazi" },
             { "thb", "baht tailand\u00e8s" },
             { "tjr", "ruble tadjik" },
