@@ -72,6 +72,7 @@ public class CurrencyNames_fr extends OpenListResourceBundle {
     protected final Object[][] getContents() {
         final Object[][] data = new Object[][] {
             { "AED", "AED" },
+            { "AFN", "AFN" },
             { "ALL", "ALL" },
             { "AMD", "AMD" },
             { "ANG", "ANG" },
@@ -81,8 +82,11 @@ public class CurrencyNames_fr extends OpenListResourceBundle {
             { "AWG", "AWG" },
             { "AZN", "AZN" },
             { "BAM", "BAM" },
+            { "BBD", "BBD" },
+            { "BDT", "BDT" },
             { "BEF", "FB" },
             { "BGN", "BGN" },
+            { "BHD", "BHD" },
             { "BIF", "BIF" },
             { "BMD", "$BM" },
             { "BND", "$BN" },
@@ -91,19 +95,26 @@ public class CurrencyNames_fr extends OpenListResourceBundle {
             { "BTN", "BTN" },
             { "BWP", "BWP" },
             { "BYN", "BYN" },
+            { "BYR", "BYR" },
             { "BZD", "$BZ" },
             { "CAD", "$CA" },
             { "CDF", "CDF" },
+            { "CHF", "CHF" },
             { "CLP", "$CL" },
             { "CNH", "CNH" },
             { "CNY", "CNY" },
             { "COP", "$CO" },
             { "CRC", "CRC" },
             { "CUC", "CUC" },
+            { "CUP", "CUP" },
+            { "CVE", "CVE" },
             { "CYP", "\u00a3CY" },
             { "CZK", "CZK" },
             { "DJF", "DJF" },
+            { "DKK", "DKK" },
             { "DOP", "DOP" },
+            { "DZD", "DZD" },
+            { "EGP", "EGP" },
             { "ERN", "ERN" },
             { "ETB", "ETB" },
             { "FJD", "$FJ" },
@@ -111,7 +122,10 @@ public class CurrencyNames_fr extends OpenListResourceBundle {
             { "FRF", "F" },
             { "GBP", "\u00a3GB" },
             { "GEL", "GEL" },
+            { "GHS", "GHS" },
             { "GIP", "\u00a3GI" },
+            { "GMD", "GMD" },
+            { "GNF", "GNF" },
             { "GTQ", "GTQ" },
             { "GYD", "GYD" },
             { "HKD", "HKD" },
@@ -119,10 +133,12 @@ public class CurrencyNames_fr extends OpenListResourceBundle {
             { "HRK", "HRK" },
             { "HTG", "HTG" },
             { "HUF", "HUF" },
+            { "IDR", "IDR" },
             { "IEP", "\u00a3IE" },
             { "ILP", "\u00a3IL" },
             { "IQD", "IQD" },
             { "IRR", "IRR" },
+            { "ISK", "ISK" },
             { "ITL", "\u20a4IT" },
             { "JMD", "JMD" },
             { "JOD", "JOD" },
@@ -131,26 +147,45 @@ public class CurrencyNames_fr extends OpenListResourceBundle {
             { "KGS", "KGS" },
             { "KHR", "KHR" },
             { "KMF", "KMF" },
+            { "KPW", "KPW" },
             { "KWD", "KWD" },
             { "KYD", "KYD" },
             { "KZT", "KZT" },
             { "LAK", "LAK" },
             { "LBP", "\u00a3LB" },
+            { "LKR", "LKR" },
+            { "LRD", "LRD" },
+            { "LTL", "LTL" },
+            { "LVL", "LVL" },
+            { "LYD", "LYD" },
+            { "MAD", "MAD" },
             { "MDL", "MDL" },
             { "MGA", "MGA" },
             { "MKD", "MKD" },
+            { "MMK", "MMK" },
+            { "MNT", "MNT" },
+            { "MOP", "MOP" },
+            { "MRO", "MRO" },
             { "MRU", "MRU" },
             { "MTP", "\u00a3MT" },
             { "MUR", "MUR" },
+            { "MVR", "MVR" },
             { "MWK", "MWK" },
             { "MXN", "$MX" },
+            { "MYR", "MYR" },
             { "MZN", "MZN" },
             { "NAD", "$NA" },
+            { "NGN", "NGN" },
             { "NIO", "NIO" },
+            { "NOK", "NOK" },
+            { "NPR", "NPR" },
             { "NZD", "$NZ" },
             { "OMR", "OMR" },
             { "PAB", "PAB" },
+            { "PEN", "PEN" },
+            { "PGK", "PGK" },
             { "PHP", "PHP" },
+            { "PKR", "PKR" },
             { "PLN", "PLN" },
             { "PYG", "PYG" },
             { "QAR", "QAR" },
@@ -162,13 +197,22 @@ public class CurrencyNames_fr extends OpenListResourceBundle {
             { "SAR", "SAR" },
             { "SBD", "$SB" },
             { "SCR", "SCR" },
+            { "SDG", "SDG" },
+            { "SEK", "SEK" },
             { "SGD", "$SG" },
+            { "SHP", "SHP" },
+            { "SLL", "SLL" },
             { "SOS", "SOS" },
             { "SRD", "$SR" },
+            { "SSP", "SSP" },
+            { "STD", "STD" },
             { "STN", "STN" },
             { "SYP", "SYP" },
             { "SZL", "SZL" },
+            { "THB", "THB" },
+            { "TJS", "TJS" },
             { "TMT", "TMT" },
+            { "TND", "TND" },
             { "TOP", "TOP" },
             { "TRY", "TRY" },
             { "TTD", "$TT" },
@@ -182,7 +226,7 @@ public class CurrencyNames_fr extends OpenListResourceBundle {
             { "VEF", "VEF" },
             { "VES", "VES" },
             { "VUV", "VUV" },
-            { "WST", "WS$" },
+            { "WST", "$WS" },
             { "XCD", "XCD" },
             { "XPF", "FCFP" },
             { "YER", "YER" },
