@@ -70,290 +70,412 @@ import sun.util.resources.OpenListResourceBundle;
 public class CurrencyNames_ga extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
-        final String metaValue_CNH = "CNH";
         final Object[][] data = new Object[][] {
-            { "mwk", "Kwacha na Mal\u00e1ive" },
+            { "ADP", "ADP" },
+            { "AFA", "AFA" },
+            { "ALK", "ALK" },
+            { "AOK", "AOK" },
+            { "AON", "AON" },
+            { "AOR", "AOR" },
+            { "ARA", "ARA" },
+            { "ARL", "ARL" },
+            { "ARM", "ARM" },
+            { "ARP", "ARP" },
+            { "ATS", "ATS" },
+            { "AZM", "AZM" },
+            { "BAD", "BAD" },
+            { "BAN", "BAN" },
+            { "BEC", "BEC" },
+            { "BEF", "BEF" },
+            { "BEL", "BEL" },
+            { "BGL", "BGL" },
+            { "BGO", "BGO" },
+            { "BOL", "BOL" },
+            { "BOP", "BOP" },
+            { "BOV", "BOV" },
+            { "BRB", "BRB" },
+            { "BRC", "BRC" },
+            { "BRE", "BRE" },
+            { "BRN", "BRN" },
+            { "BRR", "BRR" },
+            { "BRZ", "BRZ" },
+            { "BUK", "BUK" },
+            { "BYB", "BYB" },
+            { "BYR", "BYR" },
+            { "CLE", "CLE" },
+            { "CLF", "CLF" },
+            { "COU", "COU" },
+            { "CSD", "CSD" },
+            { "CSK", "CSK" },
+            { "CYP", "CYP" },
+            { "DDM", "DDM" },
+            { "DEM", "DEM" },
+            { "ECS", "ECS" },
+            { "ECV", "ECV" },
+            { "EEK", "EEK" },
+            { "ESA", "ESA" },
+            { "ESB", "ESB" },
+            { "ESP", "ESP" },
+            { "FIM", "FIM" },
+            { "FRF", "FRF" },
+            { "GEK", "GEK" },
+            { "GHC", "GHC" },
+            { "GNS", "GNS" },
+            { "GQE", "GQE" },
+            { "GRD", "GRD" },
+            { "GWE", "GWE" },
+            { "GWP", "GWP" },
+            { "HRD", "HRD" },
+            { "IEP", "IEP" },
+            { "ILP", "ILP" },
+            { "ITL", "ITL" },
+            { "JPY", "\u00a5" },
+            { "KRH", "KRH" },
+            { "KRO", "KRO" },
+            { "LSL", "LSL" },
+            { "LTL", "LTL" },
+            { "LTT", "LTT" },
+            { "LUC", "LUC" },
+            { "LUF", "LUF" },
+            { "LVL", "LVL" },
+            { "LVR", "LVR" },
+            { "MAF", "MAF" },
+            { "MGF", "MGF" },
+            { "MKN", "MKN" },
+            { "MLF", "MLF" },
+            { "MRO", "MRO" },
+            { "MTL", "MTL" },
+            { "MTP", "MTP" },
+            { "MVP", "MVP" },
+            { "MXP", "MXP" },
+            { "MXV", "MXV" },
+            { "MZE", "MZE" },
+            { "MZM", "MZM" },
+            { "NIC", "NIC" },
+            { "NLG", "NLG" },
+            { "PEI", "PEI" },
+            { "PES", "PES" },
+            { "PLZ", "PLZ" },
+            { "PTE", "PTE" },
+            { "ROL", "ROL" },
+            { "RUR", "RUR" },
+            { "SDD", "SDD" },
+            { "SDP", "SDP" },
+            { "SIT", "SIT" },
+            { "SKK", "SKK" },
+            { "SRG", "SRG" },
+            { "STD", "STD" },
+            { "SUR", "SUR" },
+            { "SVC", "SVC" },
+            { "THB", "\u0e3f" },
+            { "TJR", "TJR" },
+            { "TMM", "TMM" },
+            { "TPE", "TPE" },
+            { "TRL", "TRL" },
+            { "UAK", "UAK" },
+            { "UGS", "UGS" },
+            { "USD", "$" },
+            { "USN", "USN" },
+            { "USS", "USS" },
+            { "UYP", "UYP" },
+            { "VEB", "VEB" },
+            { "VEF", "VEF" },
+            { "VES", "VES" },
+            { "VNN", "VNN" },
+            { "XAG", "XAG" },
+            { "XAU", "XAU" },
+            { "XBA", "XBA" },
+            { "XBB", "XBB" },
+            { "XBC", "XBC" },
+            { "XBD", "XBD" },
+            { "XDR", "XDR" },
+            { "XEU", "XEU" },
+            { "XFO", "XFO" },
+            { "XFU", "XFU" },
+            { "XPD", "XPD" },
+            { "XPT", "XPT" },
+            { "XRE", "XRE" },
+            { "XSU", "XSU" },
+            { "XXX", "XXX" },
+            { "YDD", "YDD" },
+            { "YUD", "YUD" },
+            { "YUM", "YUM" },
+            { "YUN", "YUN" },
+            { "YUR", "YUR" },
+            { "ZAL", "ZAL" },
+            { "ZMK", "ZMK" },
+            { "ZRN", "ZRN" },
+            { "ZRZ", "ZRZ" },
+            { "ZWD", "ZWD" },
+            { "adp", "Peseta And\u00f3ra" },
+            { "aed", "Dirham Aontas na n\u00c9im\u00edr\u00edochta\u00ed Arabacha" },
+            { "afa", "Afgain\u00ed (1927\u20132002)" },
+            { "afn", "Afghani na hAfganast\u00e1ine" },
+            { "alk", "Lek na hAlb\u00e1ine (1946\u20131965)" },
+            { "all", "Lek na hAlb\u00e1ine" },
+            { "amd", "Dram na hAirm\u00e9ine" },
+            { "ang", "Gildear Aintill\u00ed na h\u00cdsilt\u00edre" },
+            { "aoa", "Kwanza Ang\u00f3la" },
+            { "aok", "Kwanza Ang\u00f3lach (1977\u20131990)" },
             { "aon", "Kwanza Nua Ang\u00f3lach (1990\u20132000)" },
-            { "bad", "D\u00ednear Bhoisnia-Heirseagaiv\u00e9in (1992\u20131994)" },
             { "aor", "Kwanza Reajustado Ang\u00f3lach (1995\u20131999)" },
-            { "mga", "Ariary Mhadagascar" },
-            { "nic", "C\u00f3rdoba Nicearagua (1988\u20131991)" },
-            { "fim", "Markka Fionnlannach" },
-            { "STN", "STN" },
-            { "dem", "Deutsche Mark" },
-            { "mgf", "Franc Madagascar" },
+            { "ara", "Austral Airgint\u00edneach" },
+            { "arm", "Peso na hAirgint\u00edne (1881\u20131970)" },
+            { "arp", "Peso na hAirgint\u00edne (1983\u20131985)" },
+            { "ars", "Peso na hAirgint\u00edne" },
+            { "ats", "Scilling na hOstaire" },
+            { "aud", "Dollar na hAstr\u00e1ile" },
+            { "awg", "Fl\u00f3ir\u00edn Ar\u00faba" },
+            { "azm", "Manat na hAsarbaise\u00e1ine (1993\u20132006)" },
+            { "azn", "Manat na hAsarbaise\u00e1ine" },
+            { "bad", "D\u00ednear Bhoisnia-Heirseagaiv\u00e9in (1992\u20131994)" },
             { "bam", "Marg Inmhalartaithe na Boisnia-Heirseagaiv\u00e9ine" },
-            { "egp", "Punt na h\u00c9igipte" },
-            { "ssp", "Punt na S\u00fad\u00e1ine Theas" },
-            { "brc", "Cruzado na Brasa\u00edle (1986\u20131989)" },
+            { "bbd", "Dollar Bharbad\u00f3s" },
+            { "bdt", "Taka na Banglaid\u00e9ise" },
+            { "bec", "Franc na Beilge (inmhalartaithe)" },
+            { "bef", "Franc Beilgeach" },
+            { "bel", "Franc na Beilge (airgeadais)" },
+            { "bgl", "Lev Crua na Bulg\u00e1ire" },
+            { "bgn", "Lev na Bulg\u00e1ire" },
+            { "bgo", "Lev na Bulg\u00e1ire (1879\u20131952)" },
+            { "bhd", "Dinar Bhair\u00e9in" },
+            { "bif", "Franc na Bur\u00faine" },
+            { "bmd", "Dollar Bheirmi\u00fada" },
+            { "bnd", "Dollar Bhr\u00fain\u00e9" },
+            { "bob", "Boliviano" },
+            { "bop", "Peso na Bolaive" },
+            { "bov", "Mvdol na Bolaive" },
             { "brb", "Cruzeiro Nua na Brasa\u00edle (1967\u20131986)" },
+            { "brc", "Cruzado na Brasa\u00edle (1986\u20131989)" },
             { "bre", "Cruzeiro na Brasa\u00edle (1990\u20131993)" },
-            { "nio", "C\u00f3rdoba Nicearagua" },
-            { "nzd", "Dollar na Nua-Sh\u00e9alainne" },
             { "brl", "Real na Brasa\u00edle" },
             { "brn", "Cruzado Nua na Brasa\u00edle (1989\u20131990)" },
-            { "ugs", "Scilling Uganda (1966\u20131987)" },
-            { "fjd", "Dollar Fhids\u00ed" },
-            { "mxn", "Peso Mheicsiceo" },
-            { "std", "Dobra S\u00e3o Tom\u00e9 agus Pr\u00edncipe (1977\u20132017)" },
             { "brr", "Cruzeiro na Brasa\u00edle (1993\u20131994)" },
-            { "lvl", "Lats na Laitvia" },
-            { "scr", "R\u00faip\u00ed na S\u00e9is\u00e9al" },
-            { "cdf", "Franc an Chong\u00f3" },
-            { "mxp", "Peso Airgid Mheicsiceo (1861\u20131992)" },
-            { "zal", "Rand na hAfraice Theas (airgead\u00fail)" },
-            { "bbd", "Dollar Bharbad\u00f3s" },
-            { "hnl", "Lempira Hond\u00faras" },
-            { "ugx", "Scilling Uganda" },
-            { "lvr", "LVR" },
-            { "mxv", "MXV" },
-            { "zar", "Rand na hAfraice Theas" },
             { "brz", "Cruzeiro na Brasa\u00edle (1942\u20131967)" },
-            { "stn", "Dobra S\u00e3o Tom\u00e9 agus Pr\u00edncipe" },
-            { "cuc", "Peso Inmhalartaithe Ch\u00faba" },
             { "bsd", "Dollar na mBah\u00e1ma\u00ed" },
-            { "sdd", "Dinar na S\u00fad\u00e1ine (1992\u20132007)" },
-            { "sdg", "Punt na S\u00fad\u00e1ine" },
-            { "zrn", "Zaire Nua S\u00e1\u00edreach" },
-            { "iqd", "Dinar na hIar\u00e1ice" },
-            { "sdp", "Punt na S\u00fad\u00e1ine (1957\u20131998)" },
-            { "cup", "Peso Ch\u00faba" },
-            { "gmd", "Dalasi na Gaimbia" },
-            { "twd", "Dollar Nua na T\u00e9av\u00e1ine" },
-            { "rsd", "Dinar na Seirbia" },
-            { "zrz", "Zaire S\u00e1\u00edreach" },
-            { "myr", "Ringgit na Malaeisia" },
-            { "fkp", "Punt Oile\u00e1in Fh\u00e1clainne" },
-            { "uyp", "Peso Uragua (1975\u20131993)" },
-            { "xof", "Franc CFA Iarthar na hAfraice" },
-            { "THB", "\u0e3f" },
-            { "uyu", "Peso Uragua" },
-            { "ara", "Austral Airgint\u00edneach" },
-            { "sur", "R\u00fabal an Aontais Sh\u00f3iv\u00e9adaigh" },
-            { "cve", "Escudo Rinn Verde" },
-            { "omr", "Rial \u00d3man" },
-            { "kes", "Scilling na C\u00e9inia" },
-            { "sek", "Cor\u00f3in na Sualainne" },
-            { "mze", "Escudo M\u00f3saimb\u00edce" },
-            { "arm", "Peso na hAirgint\u00edne (1881\u20131970)" },
             { "btn", "Ngultrum na B\u00fat\u00e1ine" },
-            { "arp", "Peso na hAirgint\u00edne (1983\u20131985)" },
-            { "gnf", "Franc na Guine" },
-            { "mzn", "Metical Mh\u00f3saimb\u00edc" },
-            { "mzm", "Metical M\u00f3saimb\u00edce" },
-            { "svc", "Col\u00f3n na Salvad\u00f3ire" },
-            { "ars", "Peso na hAirgint\u00edne" },
-            { "qar", "Riyal Chatar" },
-            { "irr", "Rial na hIar\u00e1ine" },
-            { "nlg", "Guilder \u00cdsilt\u00edreach" },
-            { "gns", "Syli Guine" },
-            { "xpd", "Pallaidiam" },
-            { "thb", "Baht na T\u00e9alainne" },
-            { "uzs", "Sum na h\u00daisb\u00e9iceast\u00e1ine" },
-            { "xpf", "Franc CFP" },
-            { "bdt", "Taka na Banglaid\u00e9ise" },
-            { "lyd", "Dinar na Libia" },
             { "buk", "Kyat Bhurma" },
-            { "kwd", "Dinar Chu\u00e1it" },
-            { "xpt", "Platanam" },
-            { "rub", "R\u00fabal na R\u00faise" },
-            { "isk", "Kr\u00f3na na h\u00cdoslainne" },
-            { "bec", "BEC" },
-            { "bef", "Franc Beilgeach" },
-            { "mkd", "Denar na Macad\u00f3ine" },
-            { "bel", "BEL" },
-            { "rur", "R\u00fabal na R\u00faise (1991\u20131998)" },
-            { "dzd", "Dinar na hAilg\u00e9ire" },
-            { "pab", "Balboa Phanama" },
-            { "sgd", "Dollar Shingeap\u00f3r" },
-            { "kgs", "Som na Cirgeast\u00e1ine" },
-            { "hrd", "D\u00ednear na Cr\u00f3ite" },
-            { "xaf", "Franc CFA na hAfraice L\u00e1ir" },
-            { "xag", "Airgead" },
-            { "chf", "Franc na hEilv\u00e9ise" },
-            { "hrk", "Kuna na Cr\u00f3ite" },
-            { "itl", "Lira na hIod\u00e1ile" },
-            { "ats", "ATS" },
-            { "djf", "Franc Djibouti" },
-            { "mlf", "Franc Mhail\u00ed" },
-            { "adp", "Peseta And\u00f3ra" },
-            { "tzs", "Scilling na Tans\u00e1ine" },
-            { "vnd", "Dong V\u00edtneam" },
-            { "xau", "\u00d3r" },
-            { "aud", "Dollar na hAstr\u00e1ile" },
-            { "khr", "Riel na Camb\u00f3ide" },
-            { "idr", "Rupiah na hIndin\u00e9ise" },
-            { "xba", "Aonad Ilchodach Eorpach" },
-            { "kyd", "Dollar Oile\u00e1in Cayman" },
-            { "vnn", "Dong V\u00edtneam (1978\u20131985)" },
-            { "xbc", "Aonad Cuntais Eorpach (XBC)" },
-            { "ydd", "D\u00ednear \u00c9imin" },
-            { "xbb", "Aonad Airgeada\u00edochta Eorpach" },
             { "bwp", "Pula na Botsu\u00e1ine" },
-            { "gqe", "Ekwele Guineana na Guine Me\u00e1nchiorcla\u00ed" },
-            { "shp", "Punt San H\u00e9ilin" },
-            { "cyp", "Punt na Cipire" },
-            { "xbd", "Aonad Cuntais Eorpach (XBD)" },
-            { "tjs", "Somoni na T\u00e1ids\u00edceast\u00e1ine" },
-            { "tjr", "R\u00fabal na T\u00e1ids\u00edceast\u00e1ine" },
-            { "rwf", "Franc Ruanda" },
-            { "aed", "Dirham Aontas na n\u00c9im\u00edr\u00edochta\u00ed Arabacha" },
-            { "dkk", "Cor\u00f3in na Danmhairge" },
-            { "bgl", "Lev Crua na Bulg\u00e1ire" },
-            { "zwd", "Dollar Siomb\u00e1bach (1980\u20132008)" },
-            { "bgn", "Lev na Bulg\u00e1ire" },
-            { "yud", "D\u00ednear Crua I\u00fagslavach (1966\u20131990)" },
-            { "mmk", "Kyat Mhaenmar" },
-            { "bgo", "Lev na Bulg\u00e1ire (1879\u20131952)" },
-            { "nok", "Cor\u00f3in na hIorua" },
-            { "syp", "Punt na Siria" },
-            { "yum", "D\u00ednear Nua I\u00fagslavach (1994\u20132002)" },
-            { "lkr", "R\u00faip\u00ed Shr\u00ed Lanca" },
-            { "yun", "YUN" },
-            { "czk", "Koruna Phoblacht na Seice" },
-            { "iep", "Punt \u00c9ireannach" },
-            { "grd", "Drachma Gr\u00e9agach" },
-            { "xcd", "Dollar na Cairibe Thoir" },
-            { "htg", "Gourde H\u00e1\u00edt\u00ed" },
-            { "afa", "Afgain\u00ed (1927\u20132002)" },
-            { "bhd", "Dinar Bhair\u00e9in" },
-            { "sit", "Tolar na Sl\u00f3iv\u00e9ine" },
-            { "pte", "Escudo na Portaing\u00e9ile" },
-            { "kzt", "Tenge na Casacst\u00e1ine" },
-            { "szl", "Lilangeni na Suasalainne" },
-            { "yer", "Rial \u00c9imin" },
-            { "afn", "Afghani na hAfganast\u00e1ine" },
             { "byb", "R\u00fabal Nua na Bealar\u00faise (1994\u20131999)" },
-            { "awg", "Fl\u00f3ir\u00edn Ar\u00faba" },
-            { "npr", "R\u00faip\u00ed Neipeal" },
-            { "mnt", "Tugrik na Mong\u00f3ile" },
-            { "gbp", "Punt Steirling" },
             { "byn", "R\u00fabal na Bealar\u00faise" },
-            { "huf", "Forint na hUng\u00e1ire" },
             { "byr", "R\u00fabal na Bealar\u00faise (2000\u20132016)" },
-            { "bif", "Franc na Bur\u00faine" },
-            { "xdr", "Cearta Speisialta Tarraingthe" },
             { "bzd", "Dollar na Beil\u00edse" },
-            { "mop", "Pataca Mhacao" },
-            { "nad", "Dollar na Namaibe" },
-            { "skk", "Koruna na Sl\u00f3vaice" },
-            { "pei", "Inti Pheiri\u00fa" },
-            { "tmm", "Manat na Tuircm\u00e9anast\u00e1ine (1993\u20132009)" },
-            { "pen", "Sol Pheiri\u00fa" },
-            { "wst", "Tala Sham\u00f3" },
-            { "tmt", "Manat na Tuircm\u00e9anast\u00e1ine" },
-            { "frf", "FRF" },
-            { "clf", "Unidades de Fomento na Sile" },
-            { "cle", "Escudo na Sile" },
-            { "pes", "Sol Pheiri\u00fa (1863\u20131965)" },
-            { "gtq", "Quetzal Ghuatamala" },
-            { "clp", "Peso na Sile" },
-            { "xeu", "Aonad Airgeadra Eorpach" },
-            { "tnd", "Dinar na T\u00fain\u00e9ise" },
-            { "sll", "Leone Shiarra Leon" },
-            { "CNH", metaValue_CNH },
-            { "xfo", "Franc \u00d3r Francach" },
-            { "dop", "Peso na Poblachta Doiminic\u00ed" },
-            { "kmf", "Franc Oile\u00e1in Chom\u00f3ra" },
-            { "xfu", "UIC-Franc Francach" },
-            { "gek", "Kupon Larit na Gr\u00faise" },
-            { "gel", "Lari na Seoirsia" },
-            { "MRU", "MRU" },
-            { "mad", "Dirham Mharac\u00f3" },
-            { "maf", "Franc Mharac\u00f3" },
-            { "azn", "Manat na hAsarbaise\u00e1ine" },
-            { "top", "Pa\u02bbanga Thonga" },
-            { "azm", "Manat na hAsarbaise\u00e1ine (1993\u20132006)" },
-            { "pgk", "Kina Nua-Ghuine Phapua" },
-            { "XXX", "XXX" },
-            { "cnh", metaValue_CNH },
-            { "uah", "Hryvnia na h\u00dacr\u00e1ine" },
-            { "uak", "Karbovanets \u00dacr\u00e1nach" },
-            { "ern", "Nakfa na hEiritr\u00e9" },
-            { "USD", "$" },
-            { "tpe", "Escudo T\u00edom\u00f3ir" },
-            { "mro", "Ouguiya na M\u00e1rat\u00e1ine (1973\u20132017)" },
-            { "cny", "Yuan na S\u00edne" },
-            { "mru", "Ouguiya na M\u00e1rat\u00e1ine" },
-            { "gwe", "Escudo na Guine Portaing\u00e9ala\u00ed" },
-            { "bmd", "Dollar Bheirmi\u00fada" },
-            { "php", "Peso na nOile\u00e1n Filip\u00edneach" },
-            { "xxx", "Airgeadra Anaithnid" },
-            { "pyg", "Guaran\u00ed Pharagua" },
-            { "jmd", "Dollar na hIam\u00e1ice" },
-            { "gwp", "Peso Guine-Bhissau" },
-            { "esp", "Peseta na Sp\u00e1inne" },
-            { "cop", "Peso na Col\u00f3ime" },
-            { "usd", "Dollar S.A.M." },
-            { "usn", "Dollar S.A.M. (an ch\u00e9ad l\u00e1 eile)" },
-            { "etb", "Birr na hAet\u00f3ipe" },
-            { "veb", "Bol\u00edvar Veinis\u00e9ala (1871\u20132008)" },
-            { "ecs", "Sucre Eacuad\u00f3ir" },
-            { "uss", "Dollar S.A.M. (an l\u00e1 c\u00e9anna)" },
-            { "sos", "Scilling na Som\u00e1ile" },
-            { "vef", "Bol\u00edvar Veinis\u00e9ala (2008\u20132018)" },
-            { "vuv", "Vatu Vanuat\u00fa" },
-            { "lak", "Kip Laos" },
-            { "bnd", "Dollar Bhr\u00fain\u00e9" },
-            { "ecv", "Unidad de Valor Constante (UVC) Eacuad\u00f3ir" },
-            { "zmk", "Kwacha Saimbiach (1968\u20132012)" },
-            { "lrd", "Dollar na Lib\u00e9ire" },
-            { "all", "Lek na hAlb\u00e1ine" },
-            { "alk", "Lek na hAlb\u00e1ine (1946\u20131965)" },
-            { "ghc", "Cedi Gh\u00e1na (1979\u20132007)" },
-            { "mtl", "Lira Mh\u00e1lta" },
-            { "ves", "Bol\u00edvar Veinis\u00e9ala" },
-            { "zmw", "Kwacha na Saimbia" },
-            { "mtp", "Punt Mh\u00e1lta" },
-            { "ilp", "Punt Iosraelach" },
-            { "trl", "Lira na Tuirce (1922\u20132005)" },
-            { "ils", "Seiceal Nua Iosrael" },
-            { "ghs", "Cedi Gh\u00e1na" },
-            { "gyd", "Dollar na Gu\u00e1ine" },
-            { "kpw", "Won na C\u00f3ir\u00e9 Thuaidh" },
-            { "bob", "Boliviano" },
-            { "mdl", "Leu na Mold\u00f3ive" },
-            { "amd", "Dram na hAirm\u00e9ine" },
-            { "try", "Lira na Tuirce" },
-            { "lbp", "Punt na Liob\u00e1ine" },
-            { "jod", "Dinar na hIord\u00e1ine" },
-            { "hkd", "Dollar Hong Cong" },
-            { "bop", "Peso na Bolaive" },
-            { "eur", "Euro" },
-            { "lsl", "Loti Leos\u00f3ta" },
             { "cad", "Dollar Cheanada" },
-            { "bov", "Mvdol na Bolaive" },
-            { "eek", "Kroon na hEast\u00f3ine" },
-            { "mur", "R\u00faip\u00ed Oile\u00e1n Mhuir\u00eds" },
-            { "rol", "Leu na R\u00f3m\u00e1ine (1952\u20132006)" },
-            { "gip", "Punt Ghiobr\u00e1ltar" },
-            { "ron", "Leu na R\u00f3m\u00e1ine" },
-            { "JPY", "\u00a5" },
-            { "ngn", "Naira na Nig\u00e9ire" },
+            { "cdf", "Franc an Chong\u00f3" },
+            { "chf", "Franc na hEilv\u00e9ise" },
+            { "cle", "Escudo na Sile" },
+            { "clf", "Unidades de Fomento na Sile" },
+            { "clp", "Peso na Sile" },
+            { "cny", "Yuan na S\u00edne" },
+            { "cop", "Peso na Col\u00f3ime" },
             { "crc", "Col\u00f3n Ch\u00f3sta R\u00edce" },
-            { "pkr", "R\u00faip\u00ed na Pacast\u00e1ine" },
-            { "ang", "Gildear Aintill\u00ed na h\u00cdsilt\u00edre" },
-            { "srd", "Dollar Shuranam" },
-            { "ltl", "Litas na Liotu\u00e1ine" },
-            { "sar", "Riyal na hAraibe S\u00e1da\u00ed" },
-            { "ttd", "Dollar Oile\u00e1n na Tr\u00edon\u00f3ide agus Tob\u00e1ga" },
-            { "mvp", "R\u00faip\u00ed Oile\u00e1in Mhaild\u00edve" },
-            { "mvr", "Rufiyaa Oile\u00e1in Mhaild\u00edve" },
-            { "srg", "Gildear Shuranam" },
-            { "ddm", "DDM" },
-            { "inr", "R\u00faip\u00ed na hIndia" },
-            { "ltt", "Talonas Liotu\u00e1nach" },
-            { "krw", "Won na C\u00f3ir\u00e9 Theas" },
-            { "aoa", "Kwanza Ang\u00f3la" },
-            { "jpy", "Yen na Seap\u00e1ine" },
-            { "pln", "Zloty na Polainne" },
-            { "sbd", "Dollar Oile\u00e1in Sholom\u00f3n" },
             { "csd", "Dinar na Seirbia (2002\u20132006)" },
             { "csk", "Koruna Crua na Seicsl\u00f3vaice" },
-            { "luc", "LUC" },
-            { "aok", "Kwanza Ang\u00f3lach (1977\u20131990)" },
+            { "cuc", "Peso Inmhalartaithe Ch\u00faba" },
+            { "cup", "Peso Ch\u00faba" },
+            { "cve", "Escudo Rinn Verde" },
+            { "cyp", "Punt na Cipire" },
+            { "czk", "Koruna Phoblacht na Seice" },
+            { "ddm", "Marc Ghearm\u00e1in an Oirthir" },
+            { "dem", "Deutsche Mark" },
+            { "djf", "Franc Djibouti" },
+            { "dkk", "Cor\u00f3in na Danmhairge" },
+            { "dop", "Peso na Poblachta Doiminic\u00ed" },
+            { "dzd", "Dinar na hAilg\u00e9ire" },
+            { "ecs", "Sucre Eacuad\u00f3ir" },
+            { "ecv", "Unidad de Valor Constante (UVC) Eacuad\u00f3ir" },
+            { "eek", "Kroon na hEast\u00f3ine" },
+            { "egp", "Punt na h\u00c9igipte" },
+            { "ern", "Nakfa na hEiritr\u00e9" },
+            { "esp", "Peseta na Sp\u00e1inne" },
+            { "etb", "Birr na hAet\u00f3ipe" },
+            { "eur", "Euro" },
+            { "fim", "Markka Fionnlannach" },
+            { "fjd", "Dollar Fhids\u00ed" },
+            { "fkp", "Punt Oile\u00e1in Fh\u00e1clainne" },
+            { "gbp", "Punt Steirling" },
+            { "gek", "Kupon Larit na Gr\u00faise" },
+            { "gel", "Lari na Seoirsia" },
+            { "ghc", "Cedi Gh\u00e1na (1979\u20132007)" },
+            { "ghs", "Cedi Gh\u00e1na" },
+            { "gip", "Punt Ghiobr\u00e1ltar" },
+            { "gmd", "Dalasi na Gaimbia" },
+            { "gnf", "Franc na Guine" },
+            { "gns", "Syli Guine" },
+            { "gqe", "Ekwele Guineana na Guine Me\u00e1nchiorcla\u00ed" },
+            { "grd", "Drachma Gr\u00e9agach" },
+            { "gtq", "Quetzal Ghuatamala" },
+            { "gwe", "Escudo na Guine Portaing\u00e9ala\u00ed" },
+            { "gwp", "Peso Guine-Bhissau" },
+            { "gyd", "Dollar na Gu\u00e1ine" },
+            { "hkd", "Dollar Hong Cong" },
+            { "hnl", "Lempira Hond\u00faras" },
+            { "hrd", "D\u00ednear na Cr\u00f3ite" },
+            { "hrk", "Kuna na Cr\u00f3ite" },
+            { "htg", "Gourde H\u00e1\u00edt\u00ed" },
+            { "huf", "Forint na hUng\u00e1ire" },
+            { "idr", "Rupiah na hIndin\u00e9ise" },
+            { "iep", "Punt \u00c9ireannach" },
+            { "ilp", "Punt Iosraelach" },
+            { "ils", "Seiceal Nua Iosrael" },
+            { "inr", "R\u00faip\u00ed na hIndia" },
+            { "iqd", "Dinar na hIar\u00e1ice" },
+            { "irr", "Rial na hIar\u00e1ine" },
+            { "isk", "Kr\u00f3na na h\u00cdoslainne" },
+            { "itl", "Lira na hIod\u00e1ile" },
+            { "jmd", "Dollar na hIam\u00e1ice" },
+            { "jod", "Dinar na hIord\u00e1ine" },
+            { "jpy", "Yen na Seap\u00e1ine" },
+            { "kes", "Scilling na C\u00e9inia" },
+            { "kgs", "Som na Cirgeast\u00e1ine" },
+            { "khr", "Riel na Camb\u00f3ide" },
+            { "kmf", "Franc Oile\u00e1in Chom\u00f3ra" },
+            { "kpw", "Won na C\u00f3ir\u00e9 Thuaidh" },
+            { "krw", "Won na C\u00f3ir\u00e9 Theas" },
+            { "kwd", "Dinar Chu\u00e1it" },
+            { "kyd", "Dollar Oile\u00e1in Cayman" },
+            { "kzt", "Tenge na Casacst\u00e1ine" },
+            { "lak", "Kip Laos" },
+            { "lbp", "Punt na Liob\u00e1ine" },
+            { "lkr", "R\u00faip\u00ed Shr\u00ed Lanca" },
+            { "lrd", "Dollar na Lib\u00e9ire" },
+            { "lsl", "Loti Leos\u00f3ta" },
+            { "ltl", "Litas na Liotu\u00e1ine" },
+            { "ltt", "Talonas Liotu\u00e1nach" },
             { "luf", "Franc Lucsamburg" },
+            { "lvl", "Lats na Laitvia" },
+            { "lyd", "Dinar na Libia" },
+            { "mad", "Dirham Mharac\u00f3" },
+            { "maf", "Franc Mharac\u00f3" },
+            { "mdl", "Leu na Mold\u00f3ive" },
+            { "mga", "Ariary Mhadagascar" },
+            { "mgf", "Franc Madagascar" },
+            { "mkd", "Denar na Macad\u00f3ine" },
+            { "mlf", "Franc Mhail\u00ed" },
+            { "mmk", "Kyat Mhaenmar" },
+            { "mnt", "Tugrik na Mong\u00f3ile" },
+            { "mop", "Pataca Mhacao" },
+            { "mro", "Ouguiya na M\u00e1rat\u00e1ine (1973\u20132017)" },
+            { "mru", "Ouguiya na M\u00e1rat\u00e1ine" },
+            { "mtl", "Lira Mh\u00e1lta" },
+            { "mtp", "Punt Mh\u00e1lta" },
+            { "mur", "R\u00faip\u00ed Oile\u00e1n Mhuir\u00eds" },
+            { "mvp", "R\u00faip\u00ed Oile\u00e1in Mhaild\u00edve" },
+            { "mvr", "Rufiyaa Oile\u00e1in Mhaild\u00edve" },
+            { "mwk", "Kwacha na Mal\u00e1ive" },
+            { "mxn", "Peso Mheicsiceo" },
+            { "mxp", "Peso Airgid Mheicsiceo (1861\u20131992)" },
+            { "myr", "Ringgit na Malaeisia" },
+            { "mze", "Escudo M\u00f3saimb\u00edce" },
+            { "mzm", "Metical M\u00f3saimb\u00edce" },
+            { "mzn", "Metical Mh\u00f3saimb\u00edc" },
+            { "nad", "Dollar na Namaibe" },
+            { "ngn", "Naira na Nig\u00e9ire" },
+            { "nic", "C\u00f3rdoba Nicearagua (1988\u20131991)" },
+            { "nio", "C\u00f3rdoba Nicearagua" },
+            { "nlg", "Guilder \u00cdsilt\u00edreach" },
+            { "nok", "Cor\u00f3in na hIorua" },
+            { "npr", "R\u00faip\u00ed Neipeal" },
+            { "nzd", "Dollar na Nua-Sh\u00e9alainne" },
+            { "omr", "Rial \u00d3man" },
+            { "pab", "Balboa Phanama" },
+            { "pei", "Inti Pheiri\u00fa" },
+            { "pen", "Sol Pheiri\u00fa" },
+            { "pes", "Sol Pheiri\u00fa (1863\u20131965)" },
+            { "pgk", "Kina Nua-Ghuine Phapua" },
+            { "php", "Peso na nOile\u00e1n Filip\u00edneach" },
+            { "pkr", "R\u00faip\u00ed na Pacast\u00e1ine" },
+            { "pln", "Zloty na Polainne" },
             { "plz", "Zloty Polannach (1950\u20131995)" },
+            { "pte", "Escudo na Portaing\u00e9ile" },
+            { "pyg", "Guaran\u00ed Pharagua" },
+            { "qar", "Riyal Chatar" },
+            { "rol", "Leu na R\u00f3m\u00e1ine (1952\u20132006)" },
+            { "ron", "Leu na R\u00f3m\u00e1ine" },
+            { "rsd", "Dinar na Seirbia" },
+            { "rub", "R\u00fabal na R\u00faise" },
+            { "rur", "R\u00fabal na R\u00faise (1991\u20131998)" },
+            { "rwf", "Franc Ruanda" },
+            { "sar", "Riyal na hAraibe S\u00e1da\u00ed" },
+            { "sbd", "Dollar Oile\u00e1in Sholom\u00f3n" },
+            { "scr", "R\u00faip\u00ed na S\u00e9is\u00e9al" },
+            { "sdd", "Dinar na S\u00fad\u00e1ine (1992\u20132007)" },
+            { "sdg", "Punt na S\u00fad\u00e1ine" },
+            { "sdp", "Punt na S\u00fad\u00e1ine (1957\u20131998)" },
+            { "sek", "Cor\u00f3in na Sualainne" },
+            { "sgd", "Dollar Shingeap\u00f3r" },
+            { "shp", "Punt San H\u00e9ilin" },
+            { "sit", "Tolar na Sl\u00f3iv\u00e9ine" },
+            { "skk", "Koruna na Sl\u00f3vaice" },
+            { "sll", "Leone Shiarra Leon" },
+            { "sos", "Scilling na Som\u00e1ile" },
+            { "srd", "Dollar Shuranam" },
+            { "srg", "Gildear Shuranam" },
+            { "ssp", "Punt na S\u00fad\u00e1ine Theas" },
+            { "std", "Dobra S\u00e3o Tom\u00e9 agus Pr\u00edncipe (1977\u20132017)" },
+            { "stn", "Dobra S\u00e3o Tom\u00e9 agus Pr\u00edncipe" },
+            { "sur", "R\u00fabal an Aontais Sh\u00f3iv\u00e9adaigh" },
+            { "svc", "Col\u00f3n na Salvad\u00f3ire" },
+            { "syp", "Punt na Siria" },
+            { "szl", "Lilangeni na Suasalainne" },
+            { "thb", "Baht na T\u00e9alainne" },
+            { "tjr", "R\u00fabal na T\u00e1ids\u00edceast\u00e1ine" },
+            { "tjs", "Somoni na T\u00e1ids\u00edceast\u00e1ine" },
+            { "tmm", "Manat na Tuircm\u00e9anast\u00e1ine (1993\u20132009)" },
+            { "tmt", "Manat na Tuircm\u00e9anast\u00e1ine" },
+            { "tnd", "Dinar na T\u00fain\u00e9ise" },
+            { "top", "Pa\u02bbanga Thonga" },
+            { "tpe", "Escudo T\u00edom\u00f3ir" },
+            { "trl", "Lira na Tuirce (1922\u20132005)" },
+            { "try", "Lira na Tuirce" },
+            { "ttd", "Dollar Oile\u00e1n na Tr\u00edon\u00f3ide agus Tob\u00e1ga" },
+            { "twd", "Dollar Nua na T\u00e9av\u00e1ine" },
+            { "tzs", "Scilling na Tans\u00e1ine" },
+            { "uah", "Hryvnia na h\u00dacr\u00e1ine" },
+            { "uak", "Karbovanets \u00dacr\u00e1nach" },
+            { "ugs", "Scilling Uganda (1966\u20131987)" },
+            { "ugx", "Scilling Uganda" },
+            { "usd", "Dollar S.A.M." },
+            { "usn", "Dollar S.A.M. (an ch\u00e9ad l\u00e1 eile)" },
+            { "uss", "Dollar S.A.M. (an l\u00e1 c\u00e9anna)" },
+            { "uyp", "Peso Uragua (1975\u20131993)" },
+            { "uyu", "Peso Uragua" },
+            { "uzs", "Sum na h\u00daisb\u00e9iceast\u00e1ine" },
+            { "veb", "Bol\u00edvar Veinis\u00e9ala (1871\u20132008)" },
+            { "vef", "Bol\u00edvar Veinis\u00e9ala (2008\u20132018)" },
+            { "ves", "Bol\u00edvar Veinis\u00e9ala" },
+            { "vnd", "Dong V\u00edtneam" },
+            { "vnn", "Dong V\u00edtneam (1978\u20131985)" },
+            { "vuv", "Vatu Vanuat\u00fa" },
+            { "wst", "Tala Sham\u00f3" },
+            { "xaf", "Franc CFA na hAfraice L\u00e1ir" },
+            { "xag", "Airgead" },
+            { "xau", "\u00d3r" },
+            { "xba", "Aonad Ilchodach Eorpach" },
+            { "xbb", "Aonad Airgeada\u00edochta Eorpach" },
+            { "xbc", "Aonad Cuntais Eorpach (XBC)" },
+            { "xbd", "Aonad Cuntais Eorpach (XBD)" },
+            { "xcd", "Dollar na Cairibe Thoir" },
+            { "xdr", "Cearta Speisialta Tarraingthe" },
+            { "xeu", "Aonad Airgeadra Eorpach" },
+            { "xfo", "Franc \u00d3r Francach" },
+            { "xfu", "UIC-Franc Francach" },
+            { "xof", "Franc CFA Iarthar na hAfraice" },
+            { "xpd", "Pallaidiam" },
+            { "xpf", "Franc CFP" },
+            { "xpt", "Platanam" },
+            { "xxx", "Airgeadra Anaithnid" },
+            { "ydd", "D\u00ednear \u00c9imin" },
+            { "yer", "Rial \u00c9imin" },
+            { "yud", "D\u00ednear Crua I\u00fagslavach (1966\u20131990)" },
+            { "yum", "D\u00ednear Nua I\u00fagslavach (1994\u20132002)" },
+            { "zal", "Rand na hAfraice Theas (airgead\u00fail)" },
+            { "zar", "Rand na hAfraice Theas" },
+            { "zmk", "Kwacha Saimbiach (1968\u20132012)" },
+            { "zmw", "Kwacha na Saimbia" },
+            { "zrn", "Zaire Nua S\u00e1\u00edreach" },
+            { "zrz", "Zaire S\u00e1\u00edreach" },
+            { "zwd", "Dollar Siomb\u00e1bach (1980\u20132008)" },
         };
         return data;
     }
