@@ -71,25 +71,306 @@ public class CurrencyNames_hr extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
         final Object[][] data = new Object[][] {
+            { "ADP", "ADP" },
+            { "AED", "AED" },
+            { "AFA", "AFA" },
+            { "AFN", "AFN" },
+            { "ALK", "ALK" },
+            { "ALL", "ALL" },
+            { "AMD", "AMD" },
+            { "ANG", "ANG" },
+            { "AOA", "AOA" },
+            { "AOK", "AOK" },
+            { "AON", "AON" },
+            { "AOR", "AOR" },
+            { "ARA", "ARA" },
+            { "ARL", "ARL" },
+            { "ARM", "ARM" },
+            { "ARP", "ARP" },
+            { "ARS", "ARS" },
+            { "ATS", "ATS" },
             { "AUD", "AUD" },
+            { "AWG", "AWG" },
+            { "AZM", "AZM" },
+            { "AZN", "AZN" },
+            { "BAD", "BAD" },
+            { "BAM", "BAM" },
+            { "BAN", "BAN" },
+            { "BBD", "BBD" },
+            { "BDT", "BDT" },
+            { "BEC", "BEC" },
+            { "BEF", "BEF" },
+            { "BEL", "BEL" },
+            { "BGL", "BGL" },
+            { "BGM", "BGM" },
+            { "BGN", "BGN" },
+            { "BGO", "BGO" },
+            { "BHD", "BHD" },
+            { "BIF", "BIF" },
+            { "BMD", "BMD" },
+            { "BND", "BND" },
+            { "BOB", "BOB" },
+            { "BOL", "BOL" },
+            { "BOP", "BOP" },
+            { "BOV", "BOV" },
+            { "BRB", "BRB" },
+            { "BRC", "BRC" },
+            { "BRE", "BRE" },
             { "BRL", "BRL" },
+            { "BRN", "BRN" },
+            { "BRR", "BRR" },
+            { "BRZ", "BRZ" },
+            { "BSD", "BSD" },
+            { "BTN", "BTN" },
+            { "BUK", "BUK" },
+            { "BWP", "BWP" },
+            { "BYB", "BYB" },
+            { "BYN", "BYN" },
+            { "BYR", "BYR" },
+            { "BZD", "BZD" },
             { "CAD", "CAD" },
+            { "CDF", "CDF" },
+            { "CHE", "CHE" },
+            { "CHF", "CHF" },
+            { "CHW", "CHW" },
+            { "CLE", "CLE" },
+            { "CLF", "CLF" },
+            { "CLP", "CLP" },
+            { "CNH", "CNH" },
+            { "CNX", "CNX" },
             { "CNY", "CNY" },
+            { "COP", "COP" },
+            { "COU", "COU" },
+            { "CRC", "CRC" },
+            { "CSD", "CSD" },
+            { "CSK", "CSK" },
+            { "CUC", "CUC" },
+            { "CUP", "CUP" },
+            { "CVE", "CVE" },
+            { "CYP", "CYP" },
+            { "CZK", "CZK" },
+            { "DDM", "DDM" },
+            { "DEM", "DEM" },
+            { "DJF", "DJF" },
+            { "DKK", "DKK" },
+            { "DOP", "DOP" },
+            { "DZD", "DZD" },
+            { "ECS", "ECS" },
+            { "ECV", "ECV" },
+            { "EEK", "EEK" },
+            { "EGP", "EGP" },
+            { "ERN", "ERN" },
+            { "ESA", "ESA" },
+            { "ESB", "ESB" },
+            { "ESP", "ESP" },
+            { "ETB", "ETB" },
             { "EUR", "EUR" },
+            { "FIM", "FIM" },
+            { "FJD", "FJD" },
+            { "FKP", "FKP" },
+            { "FRF", "FRF" },
             { "GBP", "GBP" },
+            { "GEK", "GEK" },
+            { "GEL", "GEL" },
+            { "GHC", "GHC" },
+            { "GHS", "GHS" },
+            { "GIP", "GIP" },
+            { "GMD", "GMD" },
+            { "GNF", "GNF" },
+            { "GNS", "GNS" },
+            { "GQE", "GQE" },
+            { "GRD", "GRD" },
+            { "GTQ", "GTQ" },
+            { "GWE", "GWE" },
+            { "GWP", "GWP" },
+            { "GYD", "GYD" },
             { "HKD", "HKD" },
+            { "HNL", "HNL" },
+            { "HRD", "HRD" },
+            { "HRK", "HRK" },
+            { "HTG", "HTG" },
+            { "HUF", "HUF" },
+            { "IDR", "IDR" },
+            { "IEP", "IEP" },
+            { "ILP", "ILP" },
+            { "ILR", "ILR" },
             { "ILS", "ILS" },
             { "INR", "INR" },
+            { "IQD", "IQD" },
+            { "IRR", "IRR" },
+            { "ISJ", "ISJ" },
+            { "ISK", "ISK" },
+            { "ITL", "ITL" },
+            { "JMD", "JMD" },
+            { "JOD", "JOD" },
             { "JPY", "JPY" },
+            { "KES", "KES" },
+            { "KGS", "KGS" },
+            { "KHR", "KHR" },
+            { "KMF", "KMF" },
+            { "KPW", "KPW" },
+            { "KRH", "KRH" },
+            { "KRO", "KRO" },
             { "KRW", "KRW" },
+            { "KWD", "KWD" },
+            { "KYD", "KYD" },
+            { "KZT", "KZT" },
+            { "LAK", "LAK" },
+            { "LBP", "LBP" },
+            { "LKR", "LKR" },
+            { "LRD", "LRD" },
+            { "LSL", "LSL" },
+            { "LTL", "LTL" },
+            { "LTT", "LTT" },
+            { "LUC", "LUC" },
+            { "LUF", "LUF" },
+            { "LUL", "LUL" },
+            { "LVL", "LVL" },
+            { "LVR", "LVR" },
+            { "LYD", "LYD" },
+            { "MAD", "MAD" },
+            { "MAF", "MAF" },
+            { "MCF", "MCF" },
+            { "MDC", "MDC" },
+            { "MDL", "MDL" },
+            { "MGA", "MGA" },
+            { "MGF", "MGF" },
+            { "MKD", "MKD" },
+            { "MKN", "MKN" },
+            { "MLF", "MLF" },
+            { "MMK", "MMK" },
+            { "MNT", "MNT" },
+            { "MOP", "MOP" },
+            { "MRO", "MRO" },
+            { "MRU", "MRU" },
+            { "MTL", "MTL" },
+            { "MTP", "MTP" },
+            { "MUR", "MUR" },
+            { "MVP", "MVP" },
+            { "MVR", "MVR" },
+            { "MWK", "MWK" },
             { "MXN", "MXN" },
+            { "MXP", "MXP" },
+            { "MXV", "MXV" },
+            { "MYR", "MYR" },
+            { "MZE", "MZE" },
+            { "MZM", "MZM" },
+            { "MZN", "MZN" },
+            { "NAD", "NAD" },
+            { "NGN", "NGN" },
+            { "NIC", "NIC" },
+            { "NIO", "NIO" },
+            { "NLG", "NLG" },
+            { "NOK", "NOK" },
+            { "NPR", "NPR" },
             { "NZD", "NZD" },
+            { "OMR", "OMR" },
+            { "PAB", "PAB" },
+            { "PEI", "PEI" },
+            { "PEN", "PEN" },
+            { "PES", "PES" },
+            { "PGK", "PGK" },
+            { "PHP", "PHP" },
+            { "PKR", "PKR" },
+            { "PLN", "PLN" },
+            { "PLZ", "PLZ" },
+            { "PTE", "PTE" },
+            { "PYG", "PYG" },
+            { "QAR", "QAR" },
+            { "RHD", "RHD" },
+            { "ROL", "ROL" },
+            { "RON", "RON" },
+            { "RSD", "RSD" },
+            { "RUB", "RUB" },
+            { "RUR", "RUR" },
+            { "RWF", "RWF" },
+            { "SAR", "SAR" },
+            { "SBD", "SBD" },
+            { "SCR", "SCR" },
+            { "SDD", "SDD" },
+            { "SDG", "SDG" },
+            { "SDP", "SDP" },
+            { "SEK", "SEK" },
+            { "SGD", "SGD" },
+            { "SHP", "SHP" },
+            { "SIT", "SIT" },
+            { "SKK", "SKK" },
+            { "SLL", "SLL" },
+            { "SOS", "SOS" },
+            { "SRD", "SRD" },
+            { "SRG", "SRG" },
+            { "SSP", "SSP" },
+            { "STD", "STD" },
+            { "STN", "STN" },
+            { "SUR", "SUR" },
+            { "SVC", "SVC" },
+            { "SYP", "SYP" },
+            { "SZL", "SZL" },
+            { "THB", "THB" },
+            { "TJR", "TJR" },
+            { "TJS", "TJS" },
+            { "TMM", "TMM" },
+            { "TMT", "TMT" },
+            { "TND", "TND" },
+            { "TOP", "TOP" },
+            { "TPE", "TPE" },
+            { "TRL", "TRL" },
+            { "TRY", "TRY" },
+            { "TTD", "TTD" },
             { "TWD", "TWD" },
+            { "TZS", "TZS" },
+            { "UAH", "UAH" },
+            { "UAK", "UAK" },
+            { "UGS", "UGS" },
+            { "UGX", "UGX" },
             { "USD", "USD" },
+            { "USN", "USN" },
+            { "USS", "USS" },
+            { "UYI", "UYI" },
+            { "UYP", "UYP" },
+            { "UYU", "UYU" },
+            { "UZS", "UZS" },
+            { "VEB", "VEB" },
+            { "VEF", "VEF" },
+            { "VES", "VES" },
             { "VND", "VND" },
+            { "VNN", "VNN" },
+            { "VUV", "VUV" },
+            { "WST", "WST" },
+            { "XAG", "XAG" },
+            { "XAU", "XAU" },
+            { "XBA", "XBA" },
+            { "XBB", "XBB" },
+            { "XBC", "XBC" },
+            { "XBD", "XBD" },
             { "XCD", "XCD" },
+            { "XDR", "XDR" },
+            { "XEU", "XEU" },
+            { "XFO", "XFO" },
+            { "XFU", "XFU" },
+            { "XPD", "XPD" },
             { "XPF", "XPF" },
+            { "XPT", "XPT" },
+            { "XRE", "XRE" },
+            { "XSU", "XSU" },
+            { "XTS", "XTS" },
+            { "XUA", "XUA" },
             { "XXX", "XXX" },
+            { "YDD", "YDD" },
+            { "YER", "YER" },
+            { "YUD", "YUD" },
+            { "YUM", "YUM" },
+            { "YUN", "YUN" },
+            { "YUR", "YUR" },
+            { "ZAL", "ZAL" },
+            { "ZAR", "ZAR" },
+            { "ZMK", "ZMK" },
+            { "ZMW", "ZMW" },
+            { "ZRN", "ZRN" },
+            { "ZRZ", "ZRZ" },
+            { "ZWD", "ZWD" },
+            { "ZWL", "ZWL" },
+            { "ZWR", "ZWR" },
             { "adp", "andorska pezeta" },
             { "aed", "UAE dirham" },
             { "afa", "afganistanski afgani (1927.\u20132002.)" },
@@ -143,7 +424,7 @@ public class CurrencyNames_hr extends OpenListResourceBundle {
             { "buk", "burmanski kyat" },
             { "bwp", "bocvanska pula" },
             { "byb", "bjeloruska nova rublja (1994\u20131999)" },
-            { "byn", "bjeloruska rublja" },
+            { "byn", "bjeloruski rubalj" },
             { "byr", "bjeloruska rublja (2000\u20132016)" },
             { "bzd", "belizeanski dolar" },
             { "cad", "kanadski dolar" },
@@ -224,7 +505,7 @@ public class CurrencyNames_hr extends OpenListResourceBundle {
             { "jpy", "japanski jen" },
             { "kes", "kenijski \u0161iling" },
             { "kgs", "kirgiski som" },
-            { "khr", "kambo\u0111anski rijal" },
+            { "khr", "kambod\u017eanski rijal" },
             { "kmf", "komorski franak" },
             { "kpw", "sjevernokorejski won" },
             { "krh", "ju\u017enokorejski hvan" },
@@ -250,7 +531,7 @@ public class CurrencyNames_hr extends OpenListResourceBundle {
             { "maf", "marokanski franak" },
             { "mdc", "moldavski kupon" },
             { "mdl", "moldavski lej" },
-            { "mga", "madagaskarski ariary" },
+            { "mga", "malga\u0161ki arijari" },
             { "mgf", "madagaskarski franak" },
             { "mkd", "makedonski denar" },
             { "mkn", "stari makedonski denar" },
@@ -298,10 +579,10 @@ public class CurrencyNames_hr extends OpenListResourceBundle {
             { "rol", "starorumunjski lek" },
             { "ron", "rumunjski lej" },
             { "rsd", "srpski dinar" },
-            { "rub", "ruska rublja" },
+            { "rub", "ruski rubalj" },
             { "rur", "ruska rublja (1991.\u20131998.)" },
             { "rwf", "ruandski franak" },
-            { "sar", "saudijski rial" },
+            { "sar", "saudijski rijal" },
             { "sbd", "solmonskooto\u010dni dolar" },
             { "scr", "sej\u0161elska rupija" },
             { "sdd", "sudanski dinar" },
@@ -376,7 +657,7 @@ public class CurrencyNames_hr extends OpenListResourceBundle {
             { "xua", "obra\u010dunska jedinica ADB" },
             { "xxx", "nepoznata valuta" },
             { "ydd", "jemenski dinar" },
-            { "yer", "jemenski rial" },
+            { "yer", "jemenski rijal" },
             { "yud", "jugoslavenski \u010dvrsti dinar" },
             { "yum", "jugoslavenski novi dinar" },
             { "yun", "jugoslavenski konvertibilni dinar" },
