@@ -86,6 +86,7 @@ public class CurrencyNames_kk extends OpenListResourceBundle {
             { "BGN", "BGN" },
             { "BHD", "BHD" },
             { "BIF", "BIF" },
+            { "BMD", "BMD" },
             { "BND", "BND" },
             { "BOB", "BOB" },
             { "BSD", "BSD" },
@@ -97,6 +98,7 @@ public class CurrencyNames_kk extends OpenListResourceBundle {
             { "CDF", "CDF" },
             { "CHF", "CHF" },
             { "CLP", "CLP" },
+            { "CNH", "CNH" },
             { "COP", "COP" },
             { "CRC", "CRC" },
             { "CUC", "CUC" },
@@ -150,7 +152,6 @@ public class CurrencyNames_kk extends OpenListResourceBundle {
             { "MNT", "MNT" },
             { "MOP", "MOP" },
             { "MRO", "MRO" },
-            { "MRU", "MRU" },
             { "MUR", "MUR" },
             { "MVR", "MVR" },
             { "MWK", "MWK" },
@@ -186,7 +187,6 @@ public class CurrencyNames_kk extends OpenListResourceBundle {
             { "SRD", "SRD" },
             { "SSP", "SSP" },
             { "STD", "STD" },
-            { "STN", "STN" },
             { "SYP", "SYP" },
             { "SZL", "SZL" },
             { "THB", "\u0e3f" },
@@ -203,7 +203,6 @@ public class CurrencyNames_kk extends OpenListResourceBundle {
             { "UYU", "UYU" },
             { "UZS", "UZS" },
             { "VEF", "VEF" },
-            { "VES", "VES" },
             { "VUV", "VUV" },
             { "WST", "WST" },
             { "YER", "YER" },
