@@ -71,22 +71,158 @@ public class CurrencyNames_mk extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
         final Object[][] data = new Object[][] {
+            { "AED", "AED" },
+            { "AFN", "AFN" },
+            { "ALL", "ALL" },
+            { "AMD", "AMD" },
+            { "ANG", "ANG" },
+            { "AOA", "AOA" },
+            { "ARS", "ARS" },
             { "AUD", "AUD" },
+            { "AWG", "AWG" },
+            { "AZN", "AZN" },
+            { "BAM", "BAM" },
+            { "BBD", "BBD" },
+            { "BDT", "BDT" },
+            { "BGN", "BGN" },
+            { "BHD", "BHD" },
+            { "BIF", "BIF" },
+            { "BMD", "BMD" },
+            { "BND", "BND" },
+            { "BOB", "BOB" },
+            { "BSD", "BSD" },
+            { "BTN", "BTN" },
+            { "BWP", "BWP" },
+            { "BYN", "BYN" },
+            { "BYR", "BYR" },
+            { "BZD", "BZD" },
+            { "CDF", "CDF" },
+            { "CHF", "CHF" },
+            { "CLP", "CLP" },
             { "CNH", "CNH" },
             { "CNY", "CNY" },
+            { "COP", "COP" },
+            { "CRC", "CRC" },
+            { "CUC", "CUC" },
+            { "CUP", "CUP" },
+            { "CVE", "CVE" },
+            { "CZK", "CZK" },
+            { "DJF", "DJF" },
+            { "DKK", "DKK" },
+            { "DOP", "DOP" },
+            { "DZD", "DZD" },
+            { "EGP", "EGP" },
+            { "ERN", "ERN" },
+            { "ETB", "ETB" },
+            { "FJD", "FJD" },
+            { "FKP", "FKP" },
             { "GBP", "GBP" },
+            { "GEL", "GEL" },
+            { "GHS", "GHS" },
+            { "GIP", "GIP" },
+            { "GMD", "GMD" },
+            { "GNF", "GNF" },
+            { "GTQ", "GTQ" },
+            { "GYD", "GYD" },
             { "HKD", "HKD" },
+            { "HNL", "HNL" },
+            { "HRK", "HRK" },
+            { "HTG", "HTG" },
+            { "HUF", "HUF" },
+            { "IDR", "IDR" },
             { "ILS", "ILS" },
             { "INR", "INR" },
+            { "IQD", "IQD" },
+            { "IRR", "IRR" },
+            { "ISK", "ISK" },
+            { "JMD", "JMD" },
+            { "JOD", "JOD" },
             { "JPY", "JPY" },
+            { "KES", "KES" },
+            { "KGS", "KGS" },
+            { "KHR", "KHR" },
+            { "KMF", "KMF" },
+            { "KPW", "KPW" },
             { "KRW", "KRW" },
-            { "MKD", "\u0434\u0435\u043d" },
+            { "KWD", "KWD" },
+            { "KYD", "KYD" },
+            { "KZT", "KZT" },
+            { "LAK", "LAK" },
+            { "LBP", "LBP" },
+            { "LKR", "LKR" },
+            { "LRD", "LRD" },
+            { "LTL", "LTL" },
+            { "LVL", "LVL" },
+            { "LYD", "LYD" },
+            { "MAD", "MAD" },
+            { "MDL", "MDL" },
+            { "MGA", "MGA" },
+            { "MKD", "\u0434\u0435\u043d." },
+            { "MMK", "MMK" },
+            { "MNT", "MNT" },
+            { "MOP", "MOP" },
+            { "MRO", "MRO" },
             { "MRU", "MRU" },
+            { "MUR", "MUR" },
+            { "MVR", "MVR" },
+            { "MWK", "MWK" },
+            { "MYR", "MYR" },
+            { "MZN", "MZN" },
+            { "NAD", "NAD" },
+            { "NGN", "NGN" },
+            { "NIO", "NIO" },
+            { "NOK", "NOK" },
+            { "NPR", "NPR" },
             { "NZD", "NZD" },
+            { "OMR", "OMR" },
+            { "PAB", "PAB" },
+            { "PEN", "PEN" },
+            { "PGK", "PGK" },
+            { "PHP", "PHP" },
+            { "PKR", "PKR" },
+            { "PLN", "PLN" },
+            { "PYG", "PYG" },
+            { "QAR", "QAR" },
+            { "RON", "RON" },
+            { "RSD", "RSD" },
+            { "RUB", "RUB" },
+            { "RWF", "RWF" },
+            { "SAR", "SAR" },
+            { "SBD", "SBD" },
+            { "SCR", "SCR" },
+            { "SDG", "SDG" },
+            { "SEK", "SEK" },
+            { "SGD", "SGD" },
+            { "SHP", "SHP" },
+            { "SLL", "SLL" },
+            { "SOS", "SOS" },
+            { "SRD", "SRD" },
+            { "SSP", "SSP" },
+            { "STD", "STD" },
             { "STN", "STN" },
+            { "SYP", "SYP" },
+            { "SZL", "SZL" },
+            { "THB", "THB" },
+            { "TJS", "TJS" },
+            { "TMT", "TMT" },
+            { "TND", "TND" },
+            { "TOP", "TOP" },
+            { "TRY", "TRY" },
+            { "TTD", "TTD" },
             { "TWD", "TWD" },
+            { "TZS", "TZS" },
+            { "UAH", "UAH" },
+            { "UGX", "UGX" },
+            { "UYU", "UYU" },
+            { "UZS", "UZS" },
+            { "VEF", "VEF" },
             { "VES", "VES" },
             { "VND", "VND" },
+            { "VUV", "VUV" },
+            { "WST", "WST" },
+            { "YER", "YER" },
+            { "ZAR", "ZAR" },
+            { "ZMW", "ZMW" },
             { "adp", "\u0410\u043d\u0434\u043e\u0440\u0441\u043a\u0430 \u041f\u0435\u0437\u0435\u0442\u0430" },
             { "aed", "\u0414\u0438\u0440\u0445\u0430\u043c \u043d\u0430 \u041e\u0431\u0435\u0434\u0438\u043d\u0435\u0442\u0438 \u0410\u0440\u0430\u043f\u0441\u043a\u0438 \u0415\u043c\u0438\u0440\u0430\u0442\u0438" },
             { "afa", "\u0410\u0432\u0433\u0430\u043d\u0438 (1927\u20132002)" },
@@ -94,7 +230,7 @@ public class CurrencyNames_mk extends OpenListResourceBundle {
             { "all", "\u0410\u043b\u0431\u0430\u043d\u0441\u043a\u0438 \u043b\u0435\u043a" },
             { "amd", "\u0415\u0440\u043c\u0435\u043d\u0441\u043a\u0438 \u0434\u0440\u0430\u043c" },
             { "ang", "\u0425\u043e\u043b\u0430\u043d\u0434\u0441\u043a\u0438 \u0430\u043d\u0442\u0438\u043b\u0441\u043a\u0438 \u0433\u0438\u043b\u0434\u0435\u0440" },
-            { "aoa", "\u0410\u043d\u0433\u043e\u043b\u0441\u043a\u0430 \u041a\u0432\u0430\u043d\u0437\u0430" },
+            { "aoa", "\u0410\u043d\u0433\u043e\u043b\u0441\u043a\u0430 \u043a\u0432\u0430\u043d\u0437\u0430" },
             { "aok", "\u0410\u043d\u0433\u043e\u043b\u0441\u043a\u0430 \u041a\u0432\u0430\u043d\u0437\u0430 (1977\u20131990)" },
             { "aon", "\u0410\u043d\u0433\u043e\u043b\u0441\u043a\u0430 \u043d\u043e\u0432\u0430 \u041a\u0432\u0430\u043d\u0437\u0430 (1990\u20132000)" },
             { "arp", "\u0410\u0440\u0433\u0435\u043d\u0442\u0438\u043d\u0441\u043a\u0438 \u041f\u0435\u0437\u043e\u0441 (1983\u20131985)" },
@@ -104,7 +240,7 @@ public class CurrencyNames_mk extends OpenListResourceBundle {
             { "awg", "\u0410\u0440\u0443\u0431\u0438\u0441\u043a\u0438 \u0444\u043b\u043e\u0440\u0438\u043d" },
             { "azn", "\u0410\u0437\u0435\u0440\u0431\u0435\u0458\u045f\u0430\u043d\u0441\u043a\u0438 \u043c\u0430\u043d\u0430\u0442" },
             { "bad", "\u0411\u043e\u0441\u0430\u043d\u0441\u043a\u043e-\u0425\u0435\u0440\u0446\u0435\u0433\u043e\u0432\u0441\u043a\u0438 \u0414\u0438\u043d\u0430\u0440" },
-            { "bam", "\u0411\u043e\u0441\u0430\u043d\u0441\u043a\u043e-\u0425\u0435\u0440\u0446\u0435\u0433\u043e\u0432\u0441\u043a\u0430 \u043a\u043e\u043d\u0432\u0435\u0440\u0442\u0438\u0431\u0438\u043b\u043d\u0430 \u043c\u0430\u0440\u043a\u0430" },
+            { "bam", "\u0411\u043e\u0441\u0430\u043d\u0441\u043a\u043e-\u0445\u0435\u0440\u0446\u0435\u0433\u043e\u0432\u0441\u043a\u0430 \u043a\u043e\u043d\u0432\u0435\u0440\u0442\u0438\u0431\u0438\u043b\u043d\u0430 \u043c\u0430\u0440\u043a\u0430" },
             { "bbd", "\u0411\u0430\u0440\u0431\u0430\u0434\u043e\u0441\u043a\u0438 \u0434\u043e\u043b\u0430\u0440" },
             { "bdt", "\u0411\u0430\u043d\u0433\u043b\u0430\u0434\u0435\u0448\u043a\u0430 \u0442\u0430\u043a\u0430" },
             { "bec", "\u0411\u0435\u043b\u0433\u0438\u0441\u043a\u0438 \u0424\u0440\u0430\u043d\u043a (\u043a\u043e\u043d\u0432\u0435\u0440\u0442\u0438\u0431\u0438\u043b\u0435\u043d)" },
@@ -124,7 +260,7 @@ public class CurrencyNames_mk extends OpenListResourceBundle {
             { "byb", "\u0411\u0435\u043b\u043e\u0440\u0443\u0441\u043a\u0430 \u043d\u043e\u0432\u0430 \u0440\u0443\u0431\u0459\u0430 (1994\u20131999)" },
             { "byn", "\u0411\u0435\u043b\u043e\u0440\u0443\u0441\u043a\u0430 \u0440\u0443\u0431\u0459\u0430" },
             { "byr", "\u0411\u0435\u043b\u043e\u0440\u0443\u0441\u043a\u0430 \u0440\u0443\u0431\u0459\u0430 (2000\u20132016)" },
-            { "bzd", "\u0411\u0435\u043b\u0438\u0437\u0438\u0441\u043a\u0438 \u0414\u043e\u043b\u0430\u0440" },
+            { "bzd", "\u0411\u0435\u043b\u0438\u0437\u0438\u0441\u043a\u0438 \u0434\u043e\u043b\u0430\u0440" },
             { "cad", "\u041a\u0430\u043d\u0430\u0434\u0441\u043a\u0438 \u0434\u043e\u043b\u0430\u0440" },
             { "cdf", "\u041a\u043e\u043d\u0433\u043e\u043b\u0441\u043a\u0438 \u0444\u0440\u0430\u043d\u043a" },
             { "chf", "\u0428\u0432\u0430\u0458\u0446\u0430\u0440\u0441\u043a\u0438 \u0444\u0440\u0430\u043d\u043a" },
@@ -138,11 +274,11 @@ public class CurrencyNames_mk extends OpenListResourceBundle {
             { "cup", "\u041a\u0443\u0431\u0430\u043d\u0441\u043a\u0438 \u043f\u0435\u0437\u043e\u0441" },
             { "cve", "\u0417\u0435\u043b\u0435\u043d\u043e\u2019\u0440\u0442\u0441\u043a\u0438 \u0435\u0441\u043a\u0443\u0434\u043e" },
             { "cyp", "\u041a\u0438\u043f\u0430\u0440\u0441\u043a\u0430 \u0444\u0443\u043d\u0442\u0430" },
-            { "czk", "\u0427\u0435\u0448\u043a\u0430 \u043a\u043e\u0440\u043e\u043d\u0430" },
+            { "czk", "\u0427\u0435\u0448\u043a\u0430 \u043a\u0440\u0443\u043d\u0430" },
             { "dem", "\u0413\u0435\u0440\u043c\u0430\u043d\u0441\u043a\u0430 \u041c\u0430\u0440\u043a\u0430" },
             { "djf", "\u040f\u0438\u0431\u0443\u0442\u0441\u043a\u0438 \u0444\u0440\u0430\u043d\u043a" },
             { "dkk", "\u0414\u0430\u043d\u0441\u043a\u0430 \u043a\u0440\u0443\u043d\u0430" },
-            { "dop", "\u0414\u043e\u043c\u0438\u043d\u0438\u043a\u0430\u043d\u0441\u043a\u0438 \u041f\u0435\u0437\u043e\u0441" },
+            { "dop", "\u0414\u043e\u043c\u0438\u043d\u0438\u043a\u0430\u043d\u0441\u043a\u0438 \u043f\u0435\u0437\u043e\u0441" },
             { "dzd", "\u0410\u043b\u0436\u0438\u0440\u0441\u043a\u0438 \u0434\u0438\u043d\u0430\u0440" },
             { "egp", "\u0415\u0433\u0438\u043f\u0435\u0442\u0441\u043a\u0430 \u0444\u0443\u043d\u0442\u0430" },
             { "ern", "\u0415\u0440\u0438\u0442\u0440\u0435\u0458\u0441\u043a\u0430 \u043d\u0430\u043a\u0444\u0430" },
@@ -174,7 +310,7 @@ public class CurrencyNames_mk extends OpenListResourceBundle {
             { "iep", "\u0418\u0440\u0441\u043a\u0430 \u0444\u0443\u043d\u0442\u0430" },
             { "ilp", "\u0418\u0437\u0440\u0435\u043b\u0441\u043a\u0430 \u0444\u0443\u043d\u0442\u0430" },
             { "ils", "\u0418\u0437\u0440\u0430\u0435\u043b\u0441\u043a\u0438 \u043d\u043e\u0432 \u0448\u0435\u043a\u0435\u043b" },
-            { "inr", "\u0418\u043d\u0434\u0438\u0458\u0441\u043a\u0430 \u0440\u0443\u043f\u0438\u0458\u0430" },
+            { "inr", "\u0418\u043d\u0434\u0438\u0441\u043a\u0430 \u0440\u0443\u043f\u0438\u0458\u0430" },
             { "iqd", "\u0418\u0440\u0430\u0447\u043a\u0438 \u0434\u0438\u043d\u0430\u0440" },
             { "irr", "\u0418\u0440\u0430\u043d\u0441\u043a\u0438 \u0440\u0438\u0430\u043b" },
             { "isk", "\u0418\u0441\u043b\u0430\u043d\u0434\u0441\u043a\u0430 \u043a\u0440\u043e\u043d\u0430" },
@@ -245,7 +381,7 @@ public class CurrencyNames_mk extends OpenListResourceBundle {
             { "pyg", "\u041f\u0430\u0440\u0430\u0433\u0432\u0430\u0458\u0441\u043a\u0430 \u0433\u0443\u0430\u0440\u0430\u043d\u0430" },
             { "qar", "\u041a\u0430\u0442\u0430\u0440\u0441\u043a\u0438 \u0440\u0438\u0430\u043b" },
             { "rol", "\u0420\u043e\u043c\u0430\u043d\u0441\u043a\u0430 \u043b\u0435\u0438 (1952\u20132006)" },
-            { "ron", "\u0420\u043e\u043c\u0430\u043d\u0441\u043a\u0430 \u043b\u0435\u0438" },
+            { "ron", "\u0420\u043e\u043c\u0430\u043d\u0441\u043a\u0438 \u043b\u0435\u0443" },
             { "rsd", "\u0421\u0440\u043f\u0441\u043a\u0438 \u0434\u0438\u043d\u0430\u0440" },
             { "rub", "\u0420\u0443\u0441\u043a\u0430 \u0440\u0443\u0431\u0459\u0430" },
             { "rur", "\u0420\u0443\u0441\u043a\u0430 \u0440\u0443\u0431\u0459\u0430 (1991\u20131998)" },
@@ -267,7 +403,7 @@ public class CurrencyNames_mk extends OpenListResourceBundle {
             { "srg", "\u0421\u0443\u0440\u0438\u043d\u0430\u043c\u0441\u043a\u0438 \u0433\u0438\u043b\u0434\u0435\u0440" },
             { "ssp", "\u0408\u0443\u0436\u043d\u043e\u0441\u0443\u0434\u0430\u043d\u0441\u043a\u0430 \u0444\u0443\u043d\u0442\u0430" },
             { "std", "\u0414\u043e\u0431\u0440\u0430 \u043d\u0430 \u0421\u0430\u0443\u043d \u0422\u043e\u043c\u0435 \u0438 \u041f\u0440\u0438\u043d\u0441\u0438\u043f (1977\u20132017)" },
-            { "stn", "\u0414\u043e\u0431\u0440\u0430 \u043d\u0430 \u0421\u0430\u0443\u043d \u0422\u043e\u043c\u0435 \u0438 \u041f\u0440\u0438\u043d\u0441\u0438\u043f" },
+            { "stn", "\u0414\u043e\u0431\u0440\u0430 \u043d\u0430 \u0421\u0430\u043e \u0422\u043e\u043c\u0435 \u0438 \u041f\u0440\u0438\u043d\u0441\u0438\u043f\u0435" },
             { "sur", "\u0421\u043e\u0432\u0435\u0442\u0441\u043a\u0430 \u0440\u0443\u0431\u0459\u0430" },
             { "svc", "\u0421\u0430\u043b\u0432\u0430\u0434\u043e\u0440\u0441\u043a\u0438 \u043a\u043e\u043b\u043e\u043d" },
             { "syp", "\u0421\u0438\u0440\u0438\u0458\u0441\u043a\u0430 \u0444\u0443\u043d\u0442\u0430" },
@@ -301,7 +437,7 @@ public class CurrencyNames_mk extends OpenListResourceBundle {
             { "vuv", "\u0412\u0430\u043d\u0430\u0442\u0441\u043a\u0438 \u0432\u0430\u0442\u0443" },
             { "wst", "\u0421\u0430\u043c\u043e\u0430\u043d\u0441\u043a\u0430 \u0442\u0430\u043b\u0430" },
             { "xaf", "\u0426\u0435\u043d\u0442\u0440\u0430\u043b\u043d\u043e\u0430\u0444\u0440\u0438\u043a\u0430\u043d\u0441\u043a\u0438 \u0444\u0440\u0430\u043d\u043a" },
-            { "xcd", "\u0418\u0441\u0442\u043e\u0447\u043d\u043e \u043a\u0430\u0440\u0438\u0431\u0438\u0441\u043a\u0438 \u0434\u043e\u043b\u0430\u0440" },
+            { "xcd", "\u0418\u0441\u0442\u043e\u0447\u043d\u043e \u043a\u0430\u0440\u0438\u043f\u0441\u043a\u0438 \u0434\u043e\u043b\u0430\u0440" },
             { "xof", "\u0417\u0430\u043f\u0430\u0434\u043d\u043e\u0430\u0444\u0440\u0438\u043a\u0430\u043d\u0441\u043a\u0438 \u0444\u0440\u0430\u043d\u043a" },
             { "xpf", "\u0426\u0424\u041f \u0444\u0440\u0430\u043d\u043a" },
             { "xxx", "\u041d\u0435\u043f\u043e\u0437\u043d\u0430\u0442\u0430 \u0432\u0430\u043b\u0443\u0442\u0430" },
