@@ -93,11 +93,14 @@ public class CurrencyNames_my extends OpenListResourceBundle {
             { "BTN", "BTN" },
             { "BWP", "BWP" },
             { "BYN", "BYN" },
+            { "BYR", "BYR" },
             { "BZD", "BZD" },
             { "CDF", "CDF" },
             { "CHF", "CHF" },
             { "CLP", "CLP" },
+            { "CNH", "CNH" },
             { "COP", "COP" },
+            { "CRC", "CRC" },
             { "CUC", "CUC" },
             { "CUP", "CUP" },
             { "CVE", "CVE" },
@@ -184,6 +187,7 @@ public class CurrencyNames_my extends OpenListResourceBundle {
             { "SRD", "SRD" },
             { "SSP", "SSP" },
             { "STD", "STD" },
+            { "STN", "STN" },
             { "SYP", "SYP" },
             { "SZL", "SZL" },
             { "THB", "\u0e3f" },
