@@ -71,63 +71,129 @@ public class CurrencyNames_nl extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
         final Object[][] data = new Object[][] {
+            { "ADP", "ADP" },
             { "AED", "AED" },
+            { "AFA", "AFA" },
             { "AFN", "AFN" },
+            { "ALK", "ALK" },
             { "ALL", "ALL" },
             { "AMD", "AMD" },
             { "ANG", "ANG" },
             { "AOA", "AOA" },
+            { "AOK", "AOK" },
+            { "AON", "AON" },
+            { "AOR", "AOR" },
+            { "ARA", "ARA" },
+            { "ARL", "ARL" },
+            { "ARM", "ARM" },
+            { "ARP", "ARP" },
             { "ARS", "ARS" },
+            { "ATS", "ATS" },
             { "AUD", "AU$" },
+            { "AWG", "AWG" },
+            { "AZM", "AZM" },
             { "AZN", "AZN" },
+            { "BAD", "BAD" },
             { "BAM", "BAM" },
+            { "BAN", "BAN" },
             { "BBD", "BBD" },
             { "BDT", "BDT" },
+            { "BEC", "BEC" },
+            { "BEF", "BEF" },
+            { "BEL", "BEL" },
+            { "BGL", "BGL" },
+            { "BGM", "BGM" },
             { "BGN", "BGN" },
+            { "BGO", "BGO" },
             { "BHD", "BHD" },
             { "BIF", "BIF" },
             { "BMD", "BMD" },
             { "BND", "BND" },
             { "BOB", "BOB" },
+            { "BOL", "BOL" },
+            { "BOP", "BOP" },
+            { "BOV", "BOV" },
+            { "BRB", "BRB" },
+            { "BRC", "BRC" },
+            { "BRE", "BRE" },
+            { "BRN", "BRN" },
+            { "BRR", "BRR" },
+            { "BRZ", "BRZ" },
             { "BSD", "BSD" },
             { "BTN", "BTN" },
+            { "BUK", "BUK" },
             { "BWP", "BWP" },
+            { "BYB", "BYB" },
             { "BYN", "BYN" },
+            { "BYR", "BYR" },
             { "BZD", "BZD" },
             { "CAD", "C$" },
             { "CDF", "CDF" },
+            { "CHE", "CHE" },
             { "CHF", "CHF" },
+            { "CHW", "CHW" },
+            { "CLE", "CLE" },
+            { "CLF", "CLF" },
             { "CLP", "CLP" },
+            { "CNH", "CNH" },
+            { "CNX", "CNX" },
             { "COP", "COP" },
+            { "COU", "COU" },
             { "CRC", "CRC" },
+            { "CSD", "CSD" },
+            { "CSK", "CSK" },
             { "CUC", "CUC" },
             { "CUP", "CUP" },
             { "CVE", "CVE" },
+            { "CYP", "CYP" },
             { "CZK", "CZK" },
+            { "DDM", "DDM" },
+            { "DEM", "DEM" },
             { "DJF", "DJF" },
             { "DKK", "DKK" },
             { "DOP", "DOP" },
             { "DZD", "DZD" },
+            { "ECS", "ECS" },
+            { "ECV", "ECV" },
+            { "EEK", "EEK" },
             { "EGP", "EGP" },
             { "ERN", "ERN" },
+            { "ESA", "ESA" },
+            { "ESB", "ESB" },
+            { "ESP", "ESP" },
             { "ETB", "ETB" },
+            { "FIM", "FIM" },
             { "FJD", "FJ$" },
             { "FKP", "FKP" },
+            { "FRF", "FRF" },
+            { "GEK", "GEK" },
             { "GEL", "GEL" },
+            { "GHC", "GHC" },
             { "GHS", "GHS" },
             { "GIP", "GIP" },
             { "GMD", "GMD" },
             { "GNF", "GNF" },
+            { "GNS", "GNS" },
+            { "GQE", "GQE" },
+            { "GRD", "GRD" },
             { "GTQ", "GTQ" },
+            { "GWE", "GWE" },
+            { "GWP", "GWP" },
             { "GYD", "GYD" },
             { "HNL", "HNL" },
+            { "HRD", "HRD" },
             { "HRK", "HRK" },
             { "HTG", "HTG" },
             { "HUF", "HUF" },
             { "IDR", "IDR" },
+            { "IEP", "IEP" },
+            { "ILP", "ILP" },
+            { "ILR", "ILR" },
             { "IQD", "IQD" },
             { "IRR", "IRR" },
+            { "ISJ", "ISJ" },
             { "ISK", "ISK" },
+            { "ITL", "ITL" },
             { "JMD", "JMD" },
             { "JOD", "JOD" },
             { "KES", "KES" },
@@ -135,6 +201,8 @@ public class CurrencyNames_nl extends OpenListResourceBundle {
             { "KHR", "KHR" },
             { "KMF", "KMF" },
             { "KPW", "KPW" },
+            { "KRH", "KRH" },
+            { "KRO", "KRO" },
             { "KWD", "KWD" },
             { "KYD", "KYD" },
             { "KZT", "KZT" },
@@ -142,76 +210,152 @@ public class CurrencyNames_nl extends OpenListResourceBundle {
             { "LBP", "LBP" },
             { "LKR", "LKR" },
             { "LRD", "LRD" },
+            { "LSL", "LSL" },
+            { "LTL", "LTL" },
+            { "LTT", "LTT" },
+            { "LUC", "LUC" },
+            { "LUF", "LUF" },
+            { "LUL", "LUL" },
+            { "LVL", "LVL" },
+            { "LVR", "LVR" },
             { "LYD", "LYD" },
             { "MAD", "MAD" },
+            { "MAF", "MAF" },
+            { "MCF", "MCF" },
+            { "MDC", "MDC" },
             { "MDL", "MDL" },
             { "MGA", "MGA" },
+            { "MGF", "MGF" },
             { "MKD", "MKD" },
+            { "MKN", "MKN" },
+            { "MLF", "MLF" },
             { "MMK", "MMK" },
             { "MNT", "MNT" },
             { "MOP", "MOP" },
             { "MRO", "MRO" },
             { "MRU", "MRU" },
+            { "MTL", "MTL" },
+            { "MTP", "MTP" },
             { "MUR", "MUR" },
+            { "MVP", "MVP" },
             { "MVR", "MVR" },
             { "MWK", "MWK" },
+            { "MXP", "MXP" },
+            { "MXV", "MXV" },
             { "MYR", "MYR" },
+            { "MZE", "MZE" },
+            { "MZM", "MZM" },
             { "MZN", "MZN" },
             { "NAD", "NAD" },
             { "NGN", "NGN" },
+            { "NIC", "NIC" },
             { "NIO", "NIO" },
+            { "NLG", "NLG" },
             { "NOK", "NOK" },
             { "NPR", "NPR" },
             { "OMR", "OMR" },
             { "PAB", "PAB" },
+            { "PEI", "PEI" },
             { "PEN", "PEN" },
+            { "PES", "PES" },
             { "PGK", "PGK" },
             { "PHP", "PHP" },
             { "PKR", "PKR" },
             { "PLN", "PLN" },
+            { "PLZ", "PLZ" },
+            { "PTE", "PTE" },
             { "PYG", "PYG" },
             { "QAR", "QAR" },
+            { "RHD", "RHD" },
+            { "ROL", "ROL" },
             { "RON", "RON" },
             { "RSD", "RSD" },
             { "RUB", "RUB" },
+            { "RUR", "RUR" },
             { "RWF", "RWF" },
             { "SAR", "SAR" },
             { "SBD", "SI$" },
             { "SCR", "SCR" },
+            { "SDD", "SDD" },
             { "SDG", "SDG" },
+            { "SDP", "SDP" },
             { "SEK", "SEK" },
             { "SGD", "SGD" },
             { "SHP", "SHP" },
+            { "SIT", "SIT" },
+            { "SKK", "SKK" },
             { "SLL", "SLL" },
             { "SOS", "SOS" },
             { "SRD", "SRD" },
+            { "SRG", "SRG" },
             { "SSP", "SSP" },
             { "STD", "STD" },
             { "STN", "STN" },
+            { "SUR", "SUR" },
+            { "SVC", "SVC" },
             { "SYP", "SYP" },
             { "SZL", "SZL" },
             { "THB", "\u0e3f" },
+            { "TJR", "TJR" },
             { "TJS", "TJS" },
+            { "TMM", "TMM" },
             { "TMT", "TMT" },
             { "TND", "TND" },
             { "TOP", "TOP" },
+            { "TPE", "TPE" },
+            { "TRL", "TRL" },
             { "TRY", "TRY" },
             { "TTD", "TTD" },
             { "TZS", "TZS" },
             { "UAH", "UAH" },
+            { "UAK", "UAK" },
+            { "UGS", "UGS" },
             { "UGX", "UGX" },
+            { "USN", "USN" },
+            { "USS", "USS" },
+            { "UYI", "UYI" },
+            { "UYP", "UYP" },
             { "UYU", "UYU" },
-            { "UYW", "UYW" },
             { "UZS", "UZS" },
+            { "VEB", "VEB" },
             { "VEF", "VEF" },
             { "VES", "VES" },
+            { "VNN", "VNN" },
             { "VUV", "VUV" },
             { "WST", "WST" },
+            { "XAG", "XAG" },
+            { "XAU", "XAU" },
+            { "XBA", "XBA" },
+            { "XBB", "XBB" },
+            { "XBC", "XBC" },
+            { "XBD", "XBD" },
+            { "XDR", "XDR" },
+            { "XEU", "XEU" },
+            { "XFO", "XFO" },
+            { "XFU", "XFU" },
+            { "XPD", "XPD" },
             { "XPF", "XPF" },
+            { "XPT", "XPT" },
+            { "XRE", "XRE" },
+            { "XSU", "XSU" },
+            { "XTS", "XTS" },
+            { "XUA", "XUA" },
             { "XXX", "XXX" },
+            { "YDD", "YDD" },
             { "YER", "YER" },
+            { "YUD", "YUD" },
+            { "YUM", "YUM" },
+            { "YUN", "YUN" },
+            { "YUR", "YUR" },
+            { "ZAL", "ZAL" },
             { "ZAR", "ZAR" },
+            { "ZMK", "ZMK" },
             { "ZMW", "ZMW" },
+            { "ZRN", "ZRN" },
+            { "ZRZ", "ZRZ" },
+            { "ZWD", "ZWD" },
+            { "ZWL", "ZWL" },
+            { "ZWR", "ZWR" },
             { "adp", "Andorrese peseta" },
             { "aed", "Verenigde Arabische Emiraten-dirham" },
             { "afa", "Afghani (1927\u20132002)" },
@@ -277,7 +421,7 @@ public class CurrencyNames_nl extends OpenListResourceBundle {
             { "cle", "Chileense escudo" },
             { "clf", "Chileense unidades de fomento" },
             { "clp", "Chileense peso" },
-            { "cnh", "Chinese renminbi (offshore)" },
+            { "cnh", "Chinese yuan (offshore)" },
             { "cnx", "dollar van de Chinese Volksbank" },
             { "cny", "Chinese yuan" },
             { "cop", "Colombiaanse peso" },
