@@ -71,10 +71,28 @@ public class CurrencyNames_pa extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
         final Object[][] data = new Object[][] {
+            { "AED", "AED" },
+            { "AFN", "AFN" },
+            { "ALL", "ALL" },
+            { "AMD", "AMD" },
+            { "ANG", "ANG" },
+            { "AOA", "AOA" },
             { "ARA", "ARA" },
             { "ARL", "ARL" },
             { "ARM", "ARM" },
             { "ARP", "ARP" },
+            { "ARS", "ARS" },
+            { "AWG", "AWG" },
+            { "AZN", "AZN" },
+            { "BAM", "BAM" },
+            { "BBD", "BBD" },
+            { "BDT", "BDT" },
+            { "BGN", "BGN" },
+            { "BHD", "BHD" },
+            { "BIF", "BIF" },
+            { "BMD", "BMD" },
+            { "BND", "BND" },
+            { "BOB", "BOB" },
             { "BOL", "BOL" },
             { "BOP", "BOP" },
             { "BOV", "BOV" },
@@ -84,15 +102,133 @@ public class CurrencyNames_pa extends OpenListResourceBundle {
             { "BRN", "BRN" },
             { "BRR", "BRR" },
             { "BRZ", "BRZ" },
+            { "BSD", "BSD" },
+            { "BTN", "BTN" },
+            { "BWP", "BWP" },
+            { "BYN", "BYN" },
+            { "BYR", "BYR" },
+            { "BZD", "BZD" },
+            { "CDF", "CDF" },
+            { "CHF", "CHF" },
+            { "CLP", "CLP" },
+            { "CNH", "CNH" },
+            { "COP", "COP" },
+            { "CRC", "CRC" },
+            { "CUC", "CUC" },
+            { "CUP", "CUP" },
+            { "CVE", "CVE" },
+            { "CZK", "CZK" },
             { "DEM", "DEM" },
+            { "DJF", "DJF" },
+            { "DKK", "DKK" },
+            { "DOP", "DOP" },
+            { "DZD", "DZD" },
+            { "EGP", "EGP" },
+            { "ERN", "ERN" },
+            { "ETB", "ETB" },
+            { "FJD", "FJD" },
+            { "FKP", "FKP" },
+            { "GEL", "GEL" },
+            { "GHS", "GHS" },
+            { "GIP", "GIP" },
+            { "GMD", "GMD" },
+            { "GNF", "GNF" },
+            { "GTQ", "GTQ" },
+            { "GYD", "GYD" },
+            { "HNL", "HNL" },
+            { "HRK", "HRK" },
+            { "HTG", "HTG" },
+            { "HUF", "HUF" },
+            { "IDR", "IDR" },
             { "ILP", "ILP" },
+            { "IQD", "IQD" },
+            { "IRR", "IRR" },
+            { "ISK", "ISK" },
+            { "JMD", "JMD" },
+            { "JOD", "JOD" },
+            { "KES", "KES" },
+            { "KGS", "KGS" },
+            { "KHR", "KHR" },
+            { "KMF", "KMF" },
+            { "KPW", "KPW" },
+            { "KWD", "KWD" },
+            { "KYD", "KYD" },
+            { "KZT", "KZT" },
+            { "LAK", "LAK" },
+            { "LBP", "LBP" },
+            { "LKR", "LKR" },
+            { "LRD", "LRD" },
+            { "LTL", "LTL" },
+            { "LVL", "LVL" },
+            { "LYD", "LYD" },
+            { "MAD", "MAD" },
+            { "MDL", "MDL" },
+            { "MGA", "MGA" },
+            { "MKD", "MKD" },
+            { "MMK", "MMK" },
+            { "MNT", "MNT" },
+            { "MOP", "MOP" },
+            { "MRO", "MRO" },
+            { "MRU", "MRU" },
+            { "MUR", "MUR" },
+            { "MVR", "MVR" },
+            { "MWK", "MWK" },
+            { "MYR", "MYR" },
+            { "MZN", "MZN" },
+            { "NAD", "NAD" },
+            { "NGN", "NGN" },
+            { "NIO", "NIO" },
+            { "NOK", "NOK" },
+            { "NPR", "NPR" },
+            { "OMR", "OMR" },
+            { "PAB", "PAB" },
+            { "PEN", "PEN" },
+            { "PGK", "PGK" },
+            { "PHP", "PHP" },
+            { "PKR", "PKR" },
+            { "PLN", "PLN" },
+            { "PYG", "PYG" },
+            { "QAR", "QAR" },
+            { "RON", "RON" },
+            { "RSD", "RSD" },
+            { "RUB", "RUB" },
+            { "RWF", "RWF" },
+            { "SAR", "SAR" },
+            { "SBD", "SBD" },
+            { "SCR", "SCR" },
+            { "SDG", "SDG" },
+            { "SEK", "SEK" },
+            { "SGD", "SGD" },
+            { "SHP", "SHP" },
+            { "SLL", "SLL" },
+            { "SOS", "SOS" },
+            { "SRD", "SRD" },
+            { "SSP", "SSP" },
+            { "STD", "STD" },
+            { "STN", "STN" },
             { "SUR", "SUR" },
+            { "SYP", "SYP" },
+            { "SZL", "SZL" },
             { "THB", "\u0e3f" },
+            { "TJS", "TJS" },
+            { "TMT", "TMT" },
+            { "TND", "TND" },
+            { "TOP", "TOP" },
+            { "TRY", "TRY" },
+            { "TTD", "TTD" },
+            { "TZS", "TZS" },
+            { "UAH", "UAH" },
+            { "UGX", "UGX" },
             { "UYI", "UYI" },
             { "UYP", "UYP" },
+            { "UYU", "UYU" },
+            { "UZS", "UZS" },
             { "VEB", "VEB" },
+            { "VEF", "VEF" },
             { "VES", "VES" },
             { "VNN", "VNN" },
+            { "VUV", "VUV" },
+            { "WST", "WST" },
             { "XAG", "XAG" },
             { "XAU", "XAU" },
             { "XBA", "XBA" },
@@ -101,10 +237,13 @@ public class CurrencyNames_pa extends OpenListResourceBundle {
             { "XBD", "XBD" },
             { "XEU", "XEU" },
             { "XXX", "XXX" },
+            { "YER", "YER" },
+            { "ZAR", "ZAR" },
+            { "ZMW", "ZMW" },
             { "aed", "\u0a38\u0a70\u0a2f\u0a41\u0a15\u0a24 \u0a05\u0a30\u0a2c \u0a05\u0a2e\u0a40\u0a30\u0a3e\u0a24 \u0a26\u0a3f\u0a30\u0a39\u0a3e\u0a2e" },
             { "afn", "\u0a05\u0a2b\u0a3c\u0a17\u0a3e\u0a28 \u0a05\u0a2b\u0a3c\u0a17\u0a3e\u0a28\u0a40" },
             { "all", "\u0a05\u0a32\u0a2c\u0a3e\u0a28\u0a40\u0a06\u0a08 \u0a32\u0a47\u0a15" },
-            { "amd", "\u0a05\u0a30\u0a2e\u0a40\u0a28\u0a40\u0a06\u0a08 \u0a26\u0a30\u0a2e" },
+            { "amd", "\u0a05\u0a30\u0a2e\u0a40\u0a28\u0a40\u0a06\u0a08 \u0a26\u0a30\u0a3e\u0a2e" },
             { "ang", "\u0a28\u0a40\u0a26\u0a30\u0a32\u0a48\u0a02\u0a21\u0a38 \u0a10\u0a02\u0a1f\u0a40\u0a32\u0a40\u0a05\u0a28 \u0a17\u0a3f\u0a32\u0a21\u0a30" },
             { "aoa", "\u0a05\u0a70\u0a17\u0a4b\u0a32\u0a3e \u0a15\u0a35\u0a3e\u0a02\u0a1c\u0a3e" },
             { "ara", "\u0a05\u0a30\u0a1c\u0a28\u0a1f\u0a40\u0a28\u0a40 \u0a05\u0a38\u0a1f\u0a30\u0a3e\u0a32" },
@@ -183,7 +322,7 @@ public class CurrencyNames_pa extends OpenListResourceBundle {
             { "inr", "\u0a2d\u0a3e\u0a30\u0a24\u0a40 \u0a30\u0a41\u0a2a\u0a07\u0a06" },
             { "iqd", "\u0a07\u0a30\u0a3e\u0a15\u0a40 \u0a26\u0a3f\u0a28\u0a3e\u0a30" },
             { "irr", "\u0a08\u0a30\u0a3e\u0a28\u0a40 \u0a30\u0a3f\u0a06\u0a32" },
-            { "isk", "\u0a06\u0a08\u0a38\u0a32\u0a48\u0a02\u0a21\u0a3f\u0a15 \u0a15\u0a30\u0a4c\u0a28" },
+            { "isk", "\u0a06\u0a08\u0a38\u0a32\u0a48\u0a02\u0a21\u0a40 \u0a15\u0a30\u0a4b\u0a28\u0a3e" },
             { "jmd", "\u0a1c\u0a2e\u0a3e\u0a07\u0a15\u0a28 \u0a21\u0a3e\u0a32\u0a30" },
             { "jod", "\u0a1c\u0a3e\u0a30\u0a21\u0a28 \u0a26\u0a3f\u0a28\u0a3e\u0a30" },
             { "jpy", "\u0a1c\u0a2a\u0a3e\u0a28\u0a40 \u0a2f\u0a47\u0a28" },
@@ -202,7 +341,7 @@ public class CurrencyNames_pa extends OpenListResourceBundle {
             { "lrd", "\u0a32\u0a3e\u0a08\u0a2c\u0a40\u0a30\u0a40\u0a06\u0a08 \u0a21\u0a3e\u0a32\u0a30" },
             { "ltl", "\u0a32\u0a3f\u0a25\u0a41\u0a06\u0a28\u0a40\u0a06\u0a08 \u0a32\u0a3f\u0a24\u0a3e\u0a38" },
             { "lvl", "\u0a32\u0a3e\u0a1f\u0a35\u0a3f\u0a06\u0a08 \u0a32\u0a3e\u0a1f\u0a38" },
-            { "lyd", "\u0a32\u0a40\u0a2c\u0a40\u0a05\u0a28 \u0a26\u0a3f\u0a28\u0a3e\u0a30" },
+            { "lyd", "\u0a32\u0a40\u0a2c\u0a40\u0a06\u0a08 \u0a26\u0a3f\u0a28\u0a3e\u0a30" },
             { "mad", "\u0a2e\u0a4b\u0a30\u0a71\u0a15\u0a28 \u0a26\u0a3f\u0a30\u0a39\u0a3e\u0a2e" },
             { "mdl", "\u0a2e\u0a4b\u0a32\u0a21\u0a4b\u0a35\u0a28 \u0a32\u0a47\u0a09" },
             { "mga", "\u0a2e\u0a3e\u0a32\u0a3e\u0a17\u0a3e\u0a38\u0a40 \u0a05\u0a30\u0a3e\u0a07\u0a30\u0a40" },
