@@ -71,30 +71,164 @@ public class CurrencyNames_pl extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
         final Object[][] data = new Object[][] {
+            { "AED", "AED" },
+            { "AFN", "AFN" },
+            { "ALL", "ALL" },
+            { "AMD", "AMD" },
+            { "ANG", "ANG" },
+            { "AOA", "AOA" },
+            { "ARS", "ARS" },
             { "AUD", "AUD" },
+            { "AWG", "AWG" },
+            { "AZN", "AZN" },
+            { "BAM", "BAM" },
+            { "BBD", "BBD" },
+            { "BDT", "BDT" },
+            { "BGN", "BGN" },
+            { "BHD", "BHD" },
+            { "BIF", "BIF" },
+            { "BMD", "BMD" },
+            { "BND", "BND" },
+            { "BOB", "BOB" },
+            { "BSD", "BSD" },
+            { "BTN", "BTN" },
+            { "BWP", "BWP" },
+            { "BYN", "BYN" },
+            { "BZD", "BZD" },
             { "CAD", "CAD" },
+            { "CDF", "CDF" },
+            { "CHF", "CHF" },
+            { "CLP", "CLP" },
+            { "CNH", "CNH" },
             { "CNY", "CNY" },
+            { "COP", "COP" },
+            { "CRC", "CRC" },
+            { "CUC", "CUC" },
+            { "CUP", "CUP" },
+            { "CVE", "CVE" },
+            { "CZK", "CZK" },
+            { "DJF", "DJF" },
+            { "DKK", "DKK" },
+            { "DOP", "DOP" },
+            { "DZD", "DZD" },
+            { "EGP", "EGP" },
+            { "ERN", "ERN" },
+            { "ETB", "ETB" },
+            { "FJD", "FJD" },
+            { "FKP", "FKP" },
             { "GBP", "GBP" },
+            { "GEL", "GEL" },
+            { "GHS", "GHS" },
+            { "GIP", "GIP" },
+            { "GMD", "GMD" },
+            { "GNF", "GNF" },
+            { "GTQ", "GTQ" },
+            { "GYD", "GYD" },
             { "HKD", "HKD" },
+            { "HNL", "HNL" },
+            { "HRK", "HRK" },
+            { "HTG", "HTG" },
+            { "HUF", "HUF" },
+            { "IDR", "IDR" },
             { "ILS", "ILS" },
             { "INR", "INR" },
+            { "IQD", "IQD" },
+            { "IRR", "IRR" },
+            { "ISK", "ISK" },
+            { "JMD", "JMD" },
+            { "JOD", "JOD" },
             { "JPY", "JPY" },
+            { "KES", "KES" },
+            { "KGS", "KGS" },
+            { "KHR", "KHR" },
+            { "KMF", "KMF" },
+            { "KPW", "KPW" },
             { "KRW", "KRW" },
+            { "KWD", "KWD" },
+            { "KYD", "KYD" },
+            { "KZT", "KZT" },
+            { "LAK", "LAK" },
+            { "LBP", "LBP" },
+            { "LKR", "LKR" },
+            { "LRD", "LRD" },
+            { "LYD", "LYD" },
+            { "MAD", "MAD" },
+            { "MDL", "MDL" },
+            { "MGA", "MGA" },
+            { "MKD", "MKD" },
+            { "MMK", "MMK" },
+            { "MNT", "MNT" },
+            { "MOP", "MOP" },
+            { "MRU", "MRU" },
+            { "MUR", "MUR" },
+            { "MVR", "MVR" },
+            { "MWK", "MWK" },
             { "MXN", "MXN" },
+            { "MYR", "MYR" },
+            { "MZN", "MZN" },
+            { "NAD", "NAD" },
+            { "NGN", "NGN" },
+            { "NIO", "NIO" },
+            { "NOK", "NOK" },
+            { "NPR", "NPR" },
             { "NZD", "NZD" },
+            { "OMR", "OMR" },
+            { "PAB", "PAB" },
+            { "PEN", "PEN" },
             { "PES", "PES" },
+            { "PGK", "PGK" },
+            { "PHP", "PHP" },
+            { "PKR", "PKR" },
             { "PLN", "z\u0142" },
+            { "PYG", "PYG" },
+            { "QAR", "QAR" },
+            { "RON", "RON" },
+            { "RSD", "RSD" },
+            { "RUB", "RUB" },
+            { "RWF", "RWF" },
+            { "SAR", "SAR" },
+            { "SBD", "SBD" },
+            { "SCR", "SCR" },
+            { "SDG", "SDG" },
+            { "SEK", "SEK" },
+            { "SGD", "SGD" },
+            { "SHP", "SHP" },
+            { "SLL", "SLL" },
+            { "SOS", "SOS" },
+            { "SRD", "SRD" },
+            { "SSP", "SSP" },
+            { "STN", "STN" },
+            { "SYP", "SYP" },
+            { "SZL", "SZL" },
+            { "THB", "THB" },
+            { "TJS", "TJS" },
+            { "TMT", "TMT" },
+            { "TND", "TND" },
+            { "TOP", "TOP" },
+            { "TRY", "TRY" },
+            { "TTD", "TTD" },
             { "TWD", "TWD" },
+            { "TZS", "TZS" },
+            { "UAH", "UAH" },
+            { "UGX", "UGX" },
             { "USD", "USD" },
+            { "UYU", "UYU" },
+            { "UZS", "UZS" },
+            { "VES", "VES" },
             { "VND", "VND" },
+            { "VUV", "VUV" },
+            { "WST", "WST" },
+            { "YER", "YER" },
+            { "ZAR", "ZAR" },
+            { "ZMW", "ZMW" },
             { "adp", "peseta andorska" },
-            { "aed", "dirham arabski" },
+            { "aed", "dirham ZEA" },
             { "afa", "afgani (1927\u20132002)" },
-            { "afn", "afgani" },
+            { "afn", "afgani afga\u0144skie" },
             { "all", "lek alba\u0144ski" },
             { "amd", "dram arme\u0144ski" },
             { "ang", "gulden antylski" },
-            { "aoa", "kwanza angola\u0144ska" },
+            { "aoa", "kwanza angolska" },
             { "aok", "kwanza angola\u0144ska (1977\u20131990)" },
             { "aon", "nowa kwanza angola\u0144ska (1990\u20132000)" },
             { "aor", "kwanza angola\u0144ska Reajustado (1995\u20131999)" },
@@ -121,7 +255,7 @@ public class CurrencyNames_pl extends OpenListResourceBundle {
             { "bif", "frank burundyjski" },
             { "bmd", "dolar bermudzki" },
             { "bnd", "dolar brunejski" },
-            { "bob", "boliviano" },
+            { "bob", "boliviano boliwijskie" },
             { "bop", "peso boliwijskie" },
             { "bov", "mvdol boliwijski" },
             { "brb", "cruzeiro novo brazylijskie (1967\u20131986)" },
@@ -176,7 +310,7 @@ public class CurrencyNames_pl extends OpenListResourceBundle {
             { "gek", "kupon gruzi\u0144ski larit" },
             { "gel", "lari gruzi\u0144skie" },
             { "ghc", "cedi gha\u0144skie (1979\u20132007)" },
-            { "ghs", "cedi gha\u0144ski" },
+            { "ghs", "cedi gha\u0144skie" },
             { "gip", "funt gibraltarski" },
             { "gmd", "dalasi gambijskie" },
             { "gnf", "frank gwinejski" },
@@ -191,7 +325,7 @@ public class CurrencyNames_pl extends OpenListResourceBundle {
             { "hnl", "lempira honduraska" },
             { "hrd", "dinar chorwacki" },
             { "hrk", "kuna chorwacka" },
-            { "htg", "gourde haita\u0144skie" },
+            { "htg", "gourde haita\u0144ski" },
             { "huf", "forint w\u0119gierski" },
             { "idr", "rupia indonezyjska" },
             { "iep", "funt irlandzki" },
@@ -236,7 +370,7 @@ public class CurrencyNames_pl extends OpenListResourceBundle {
             { "mnt", "tugrik mongolski" },
             { "mop", "pataca Makau" },
             { "mro", "ouguiya maureta\u0144ska (1973\u20132017)" },
-            { "mru", "ouguiya maureta\u0144ska" },
+            { "mru", "ugija maureta\u0144ska" },
             { "mtl", "lira malta\u0144ska" },
             { "mtp", "funt malta\u0144ski" },
             { "mur", "rupia maurytyjska" },
@@ -261,7 +395,7 @@ public class CurrencyNames_pl extends OpenListResourceBundle {
             { "pei", "inti peruwia\u0144ski" },
             { "pen", "sol peruwia\u0144ski" },
             { "pes", "sol peruwia\u0144ski (1863\u20131965)" },
-            { "pgk", "kina Papua Nowa Gwinea" },
+            { "pgk", "kina papua\u0144ska" },
             { "php", "peso filipi\u0144skie" },
             { "pkr", "rupia pakista\u0144ska" },
             { "pln", "z\u0142oty polski" },
@@ -284,7 +418,7 @@ public class CurrencyNames_pl extends OpenListResourceBundle {
             { "sdp", "funt suda\u0144ski (1957\u20131998)" },
             { "sek", "korona szwedzka" },
             { "sgd", "dolar singapurski" },
-            { "shp", "funt Wyspy \u015awi\u0119tej Heleny" },
+            { "shp", "funt \u015awi\u0119tej Heleny" },
             { "sit", "tolar s\u0142owe\u0144ski" },
             { "skk", "korona s\u0142owacka" },
             { "sll", "leone sierraleo\u0144ski" },
