@@ -71,8 +71,144 @@ public class CurrencyNames_sd extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
         final Object[][] data = new Object[][] {
+            { "AED", "AED" },
+            { "AFN", "AFN" },
+            { "ALL", "ALL" },
+            { "AMD", "AMD" },
+            { "ANG", "ANG" },
+            { "AOA", "AOA" },
+            { "ARS", "ARS" },
+            { "AWG", "AWG" },
+            { "AZN", "AZN" },
+            { "BAM", "BAM" },
+            { "BBD", "BBD" },
+            { "BDT", "BDT" },
+            { "BGN", "BGN" },
+            { "BHD", "BHD" },
+            { "BIF", "BIF" },
+            { "BMD", "BMD" },
+            { "BND", "BND" },
+            { "BOB", "BOB" },
+            { "BSD", "BSD" },
+            { "BTN", "BTN" },
+            { "BWP", "BWP" },
+            { "BYN", "BYN" },
+            { "BYR", "BYR" },
+            { "BZD", "BZD" },
+            { "CDF", "CDF" },
+            { "CHF", "CHF" },
+            { "CLP", "CLP" },
+            { "CNH", "CNH" },
+            { "COP", "COP" },
+            { "CRC", "CRC" },
+            { "CUC", "CUC" },
+            { "CUP", "CUP" },
+            { "CVE", "CVE" },
+            { "CZK", "CZK" },
+            { "DJF", "DJF" },
+            { "DKK", "DKK" },
+            { "DOP", "DOP" },
+            { "DZD", "DZD" },
+            { "EGP", "EGP" },
+            { "ERN", "ERN" },
+            { "ETB", "ETB" },
+            { "FJD", "FJD" },
+            { "FKP", "FKP" },
+            { "GEL", "GEL" },
+            { "GHS", "GHS" },
+            { "GIP", "GIP" },
+            { "GMD", "GMD" },
+            { "GNF", "GNF" },
+            { "GTQ", "GTQ" },
+            { "GYD", "GYD" },
+            { "HNL", "HNL" },
+            { "HRK", "HRK" },
+            { "HTG", "HTG" },
+            { "HUF", "HUF" },
+            { "IDR", "IDR" },
+            { "IQD", "IQD" },
+            { "IRR", "IRR" },
+            { "ISK", "ISK" },
+            { "JMD", "JMD" },
+            { "JOD", "JOD" },
+            { "KES", "KES" },
+            { "KGS", "KGS" },
+            { "KHR", "KHR" },
+            { "KMF", "KMF" },
+            { "KPW", "KPW" },
+            { "KWD", "KWD" },
+            { "KYD", "KYD" },
+            { "KZT", "KZT" },
+            { "LAK", "LAK" },
+            { "LBP", "LBP" },
+            { "LKR", "LKR" },
+            { "LRD", "LRD" },
+            { "LYD", "LYD" },
+            { "MAD", "MAD" },
+            { "MDL", "MDL" },
+            { "MGA", "MGA" },
+            { "MKD", "MKD" },
+            { "MMK", "MMK" },
+            { "MNT", "MNT" },
+            { "MOP", "MOP" },
+            { "MRO", "MRO" },
+            { "MRU", "MRU" },
+            { "MUR", "MUR" },
+            { "MVR", "MVR" },
+            { "MWK", "MWK" },
+            { "MYR", "MYR" },
+            { "MZN", "MZN" },
+            { "NAD", "NAD" },
+            { "NGN", "NGN" },
+            { "NIO", "NIO" },
+            { "NOK", "NOK" },
+            { "NPR", "NPR" },
+            { "OMR", "OMR" },
+            { "PAB", "PAB" },
+            { "PEN", "PEN" },
+            { "PGK", "PGK" },
+            { "PHP", "PHP" },
             { "PKR", "Rs" },
-            { "VES", "VES" },
+            { "PLN", "PLN" },
+            { "PYG", "PYG" },
+            { "QAR", "QAR" },
+            { "RON", "RON" },
+            { "RSD", "RSD" },
+            { "RUB", "RUB" },
+            { "RWF", "RWF" },
+            { "SAR", "SAR" },
+            { "SBD", "SBD" },
+            { "SCR", "SCR" },
+            { "SDG", "SDG" },
+            { "SEK", "SEK" },
+            { "SGD", "SGD" },
+            { "SHP", "SHP" },
+            { "SLL", "SLL" },
+            { "SOS", "SOS" },
+            { "SRD", "SRD" },
+            { "SSP", "SSP" },
+            { "STD", "STD" },
+            { "STN", "STN" },
+            { "SYP", "SYP" },
+            { "SZL", "SZL" },
+            { "THB", "THB" },
+            { "TJS", "TJS" },
+            { "TMT", "TMT" },
+            { "TND", "TND" },
+            { "TOP", "TOP" },
+            { "TRY", "TRY" },
+            { "TTD", "TTD" },
+            { "TZS", "TZS" },
+            { "UAH", "UAH" },
+            { "UGX", "UGX" },
+            { "UYU", "UYU" },
+            { "UZS", "UZS" },
+            { "VEF", "VEF" },
+            { "VUV", "VUV" },
+            { "WST", "WST" },
+            { "YER", "YER" },
+            { "ZAR", "ZAR" },
+            { "ZMW", "ZMW" },
             { "aed", "\u06af\u068f\u064a\u0644 \u0639\u0631\u0628 \u0627\u0645\u0627\u0631\u0627\u062a \u062f\u0631\u0647\u0645" },
             { "afn", "\u0627\u0641\u063a\u0627\u0646\u064a \u0627\u0641\u063a\u0627\u0646\u064a" },
             { "all", "\u0627\u0644\u0628\u0627\u0646\u064a \u0644\u064a\u06aa" },
@@ -97,7 +233,6 @@ public class CurrencyNames_sd extends OpenListResourceBundle {
             { "btn", "\u0680\u0648\u067d\u0627\u0646\u064a \u06af\u0644\u067d\u0631\u0645" },
             { "bwp", "\u0628\u0648\u0633\u062a\u0648\u0627\u0646\u064a \u067e\u0648\u0644\u0627" },
             { "byn", "\u0628\u06cc\u0644\u0627\u0631\u0648\u0633\u06cc \u0631\u0628\u0644" },
-            { "byr", "BYR" },
             { "bzd", "\u0628\u064a\u0644\u064a\u0632 \u068a\u0627\u0644\u0631" },
             { "cad", "\u06aa\u0626\u064a\u0646\u068a\u064a\u0627\u0626\u064a \u068a\u0627\u0644\u0631" },
             { "cdf", "\u06aa\u0627\u0646\u06af\u0648 \u0641\u0631\u064a\u0646\u06aa" },
