@@ -71,34 +71,171 @@ public class CurrencyNames_sv extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
         final Object[][] data = new Object[][] {
+            { "AED", "AED" },
+            { "AFN", "AFN" },
+            { "ALL", "ALL" },
+            { "AMD", "AMD" },
+            { "ANG", "ANG" },
+            { "AOA", "AOA" },
+            { "ARS", "ARS" },
             { "AUD", "AUD" },
+            { "AWG", "AWG" },
+            { "AZN", "AZN" },
+            { "BAD", "BAD" },
+            { "BAM", "BAM" },
             { "BBD", "Bds$" },
+            { "BDT", "BDT" },
+            { "BGN", "BGN" },
+            { "BHD", "BHD" },
+            { "BIF", "BIF" },
             { "BMD", "BM$" },
+            { "BND", "BND" },
+            { "BOB", "BOB" },
             { "BRL", "BR$" },
             { "BSD", "BS$" },
+            { "BTN", "BTN" },
+            { "BWP", "BWP" },
+            { "BYN", "BYN" },
+            { "BYR", "BYR" },
             { "BZD", "BZ$" },
+            { "CDF", "CDF" },
+            { "CHF", "CHF" },
+            { "CLP", "CLP" },
+            { "CNX", "CNX" },
             { "CNY", "CNY" },
+            { "COP", "COP" },
+            { "CRC", "CRC" },
+            { "CUC", "CUC" },
+            { "CUP", "CUP" },
+            { "CVE", "CVE" },
+            { "CYP", "CYP" },
+            { "CZK", "CZK" },
+            { "DJF", "DJF" },
             { "DKK", "Dkr" },
             { "DOP", "RD$" },
+            { "DZD", "DZD" },
             { "EEK", "Ekr" },
             { "EGP", "EG\u00a3" },
+            { "ERN", "ERN" },
+            { "ETB", "ETB" },
+            { "FJD", "FJD" },
+            { "FKP", "FKP" },
             { "GBP", "GBP" },
+            { "GEL", "GEL" },
+            { "GHS", "GHS" },
+            { "GIP", "GIP" },
+            { "GMD", "GMD" },
+            { "GNF", "GNF" },
+            { "GTQ", "GTQ" },
+            { "GYD", "GYD" },
             { "HKD", "HKD" },
+            { "HNL", "HNL" },
+            { "HRK", "HRK" },
+            { "HTG", "HTG" },
+            { "HUF", "HUF" },
+            { "IDR", "IDR" },
             { "IEP", "IE\u00a3" },
             { "INR", "INR" },
+            { "IQD", "IQD" },
+            { "IRR", "IRR" },
+            { "ISJ", "ISJ" },
             { "ISK", "Ikr" },
+            { "ITL", "ITL" },
             { "JMD", "JM$" },
+            { "JOD", "JOD" },
             { "JPY", "JPY" },
+            { "KES", "KES" },
+            { "KGS", "KGS" },
+            { "KHR", "KHR" },
+            { "KMF", "KMF" },
+            { "KPW", "KPW" },
             { "KRW", "KRW" },
+            { "KWD", "KWD" },
+            { "KYD", "KYD" },
+            { "KZT", "KZT" },
+            { "LAK", "LAK" },
+            { "LBP", "LBP" },
+            { "LKR", "LKR" },
+            { "LRD", "LRD" },
+            { "LVL", "LVL" },
+            { "LYD", "LYD" },
+            { "MAD", "MAD" },
+            { "MDL", "MDL" },
+            { "MGA", "MGA" },
+            { "MKD", "MKD" },
+            { "MKN", "MKN" },
+            { "MMK", "MMK" },
+            { "MNT", "MNT" },
+            { "MOP", "MOP" },
+            { "MRO", "MRO" },
+            { "MTL", "MTL" },
+            { "MUR", "MUR" },
+            { "MVP", "MVP" },
+            { "MVR", "MVR" },
+            { "MWK", "MWK" },
+            { "MYR", "MYR" },
+            { "MZN", "MZN" },
+            { "NAD", "NAD" },
+            { "NGN", "NGN" },
+            { "NIC", "NIC" },
+            { "NIO", "NIO" },
             { "NOK", "Nkr" },
+            { "NPR", "NPR" },
             { "NZD", "NZD" },
+            { "OMR", "OMR" },
+            { "PAB", "PAB" },
+            { "PEN", "PEN" },
+            { "PGK", "PGK" },
+            { "PHP", "PHP" },
+            { "PKR", "PKR" },
+            { "PLN", "PLN" },
+            { "PYG", "PYG" },
+            { "QAR", "QAR" },
+            { "RON", "RON" },
+            { "RSD", "RSD" },
+            { "RUB", "RUB" },
+            { "RWF", "RWF" },
+            { "SAR", "SAR" },
+            { "SBD", "SBD" },
+            { "SCR", "SCR" },
+            { "SDG", "SDG" },
             { "SEK", "kr" },
+            { "SGD", "SGD" },
+            { "SHP", "SHP" },
+            { "SIT", "SIT" },
+            { "SLL", "SLL" },
+            { "SOS", "SOS" },
+            { "SRD", "SRD" },
+            { "SSP", "SSP" },
+            { "STD", "STD" },
+            { "SYP", "SYP" },
+            { "SZL", "SZL" },
+            { "THB", "THB" },
             { "TJR", "TJR" },
+            { "TJS", "TJS" },
+            { "TMT", "TMT" },
+            { "TND", "TND" },
+            { "TOP", "TOP" },
+            { "TRL", "TRL" },
+            { "TRY", "TRY" },
+            { "TTD", "TTD" },
             { "TWD", "TWD" },
+            { "TZS", "TZS" },
+            { "UAH", "UAH" },
+            { "UGX", "UGX" },
+            { "UYU", "UYU" },
+            { "UZS", "UZS" },
+            { "VEF", "VEF" },
             { "VND", "VND" },
+            { "VUV", "VUV" },
+            { "WST", "WST" },
+            { "XTS", "XTS" },
+            { "YER", "YER" },
             { "YUD", "YUD" },
             { "YUM", "YUM" },
             { "YUN", "YUN" },
+            { "ZAR", "ZAR" },
+            { "ZMW", "ZMW" },
             { "adp", "andorransk peseta" },
             { "aed", "F\u00f6renade Arabemiratens dirham" },
             { "afa", "afghani (1927\u20132002)" },
@@ -164,7 +301,7 @@ public class CurrencyNames_sv extends OpenListResourceBundle {
             { "cle", "chilensk escudo (1960\u20131975)" },
             { "clf", "chilensk unidad de fomento" },
             { "clp", "chilensk peso" },
-            { "cnh", "CNH" },
+            { "cnh", "kinesisk yuan (offshore)" },
             { "cnx", "kinesisk dollar" },
             { "cny", "kinesisk yuan" },
             { "cop", "colombiansk peso" },
@@ -341,7 +478,7 @@ public class CurrencyNames_sv extends OpenListResourceBundle {
             { "tmt", "turkmenistansk manat" },
             { "tnd", "tunisisk dinar" },
             { "top", "tongansk pa\u02bbanga" },
-            { "tpe", "timoriansk escudo" },
+            { "tpe", "\u00f6sttimoresisk escudo" },
             { "trl", "turkisk lire (1922\u20132005)" },
             { "try", "turkisk lira" },
             { "ttd", "Trinidad och Tobago-dollar" },
@@ -357,6 +494,7 @@ public class CurrencyNames_sv extends OpenListResourceBundle {
             { "uyi", "uruguayansk peso en unidades indexadas" },
             { "uyp", "uruguayansk peso (1975\u20131993)" },
             { "uyu", "uruguayansk peso" },
+            { "uyw", "uruguayansk indexenhet f\u00f6r nominell l\u00f6n" },
             { "uzs", "uzbekisk sum" },
             { "veb", "venezuelansk bolivar (1871\u20132008)" },
             { "vef", "venezuelansk bol\u00edvar (2008\u20132018)" },
@@ -383,7 +521,7 @@ public class CurrencyNames_sv extends OpenListResourceBundle {
             { "xpt", "platina" },
             { "xre", "RINET-fond" },
             { "xsu", "latinamerikansk sucre" },
-            { "xts", "test-valutakod" },
+            { "xts", "testvalutaenhet" },
             { "xua", "afrikansk kontoenhet" },
             { "xxx", "ok\u00e4nd valuta" },
             { "ydd", "jemenitisk dinar" },
