@@ -71,15 +71,254 @@ public class CurrencyNames_tr extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
         final Object[][] data = new Object[][] {
+            { "ADP", "ADP" },
+            { "AED", "AED" },
+            { "AFN", "AFN" },
+            { "ALL", "ALL" },
+            { "AMD", "AMD" },
+            { "ANG", "ANG" },
+            { "AOA", "AOA" },
+            { "ARA", "ARA" },
+            { "ARL", "ARL" },
+            { "ARM", "ARM" },
+            { "ARP", "ARP" },
+            { "ARS", "ARS" },
+            { "ATS", "ATS" },
             { "AUD", "AU$" },
+            { "AWG", "AWG" },
+            { "AZM", "AZM" },
+            { "AZN", "AZN" },
+            { "BAD", "BAD" },
+            { "BAM", "BAM" },
+            { "BAN", "BAN" },
+            { "BBD", "BBD" },
+            { "BDT", "BDT" },
+            { "BEC", "BEC" },
+            { "BEF", "BEF" },
+            { "BEL", "BEL" },
+            { "BGL", "BGL" },
+            { "BGM", "BGM" },
+            { "BGN", "BGN" },
+            { "BGO", "BGO" },
+            { "BHD", "BHD" },
+            { "BIF", "BIF" },
+            { "BMD", "BMD" },
+            { "BND", "BND" },
+            { "BOB", "BOB" },
+            { "BOL", "BOL" },
+            { "BOP", "BOP" },
+            { "BOV", "BOV" },
+            { "BRB", "BRB" },
+            { "BRC", "BRC" },
+            { "BRE", "BRE" },
+            { "BRN", "BRN" },
+            { "BRR", "BRR" },
+            { "BRZ", "BRZ" },
+            { "BSD", "BSD" },
+            { "BTN", "BTN" },
+            { "BUK", "BUK" },
+            { "BWP", "BWP" },
+            { "BYB", "BYB" },
+            { "BYN", "BYN" },
+            { "BYR", "BYR" },
+            { "BZD", "BZD" },
+            { "CDF", "CDF" },
+            { "CHE", "CHE" },
+            { "CHF", "CHF" },
+            { "CHW", "CHW" },
+            { "CLE", "CLE" },
+            { "CLF", "CLF" },
+            { "CLP", "CLP" },
             { "CNH", "CNH" },
+            { "COP", "COP" },
+            { "COU", "COU" },
+            { "CRC", "CRC" },
+            { "CSD", "CSD" },
+            { "CSK", "CSK" },
+            { "CUC", "CUC" },
+            { "CUP", "CUP" },
+            { "CVE", "CVE" },
+            { "CYP", "CYP" },
+            { "CZK", "CZK" },
+            { "DDM", "DDM" },
+            { "DEM", "DEM" },
+            { "DJF", "DJF" },
+            { "DKK", "DKK" },
             { "DOP", "DOP" },
+            { "DZD", "DZD" },
+            { "ECS", "ECS" },
+            { "ECV", "ECV" },
+            { "EEK", "EEK" },
+            { "EGP", "EGP" },
+            { "ERN", "ERN" },
+            { "ESA", "ESA" },
+            { "ESB", "ESB" },
+            { "ESP", "ESP" },
+            { "ETB", "ETB" },
+            { "FIM", "FIM" },
+            { "FJD", "FJD" },
+            { "FKP", "FKP" },
+            { "FRF", "FRF" },
+            { "GEK", "GEK" },
+            { "GEL", "GEL" },
+            { "GHS", "GHS" },
+            { "GIP", "GIP" },
+            { "GMD", "GMD" },
+            { "GNF", "GNF" },
+            { "GRD", "GRD" },
+            { "GTQ", "GTQ" },
+            { "GYD", "GYD" },
+            { "HNL", "HNL" },
+            { "HRD", "HRD" },
+            { "HRK", "HRK" },
+            { "HTG", "HTG" },
+            { "HUF", "HUF" },
+            { "IDR", "IDR" },
+            { "IEP", "IEP" },
+            { "ILP", "ILP" },
+            { "IQD", "IQD" },
+            { "IRR", "IRR" },
+            { "ISK", "ISK" },
+            { "ITL", "ITL" },
+            { "JMD", "JMD" },
+            { "JOD", "JOD" },
             { "JPY", "\u00a5" },
+            { "KES", "KES" },
+            { "KGS", "KGS" },
+            { "KHR", "KHR" },
+            { "KMF", "KMF" },
+            { "KPW", "KPW" },
+            { "KRH", "KRH" },
+            { "KRO", "KRO" },
+            { "KWD", "KWD" },
+            { "KYD", "KYD" },
+            { "KZT", "KZT" },
+            { "LAK", "LAK" },
+            { "LBP", "LBP" },
+            { "LKR", "LKR" },
+            { "LRD", "LRD" },
+            { "LSL", "LSL" },
+            { "LTL", "LTL" },
+            { "LTT", "LTT" },
+            { "LUC", "LUC" },
+            { "LUF", "LUF" },
+            { "LUL", "LUL" },
+            { "LVL", "LVL" },
+            { "LVR", "LVR" },
+            { "LYD", "LYD" },
+            { "MAD", "MAD" },
+            { "MCF", "MCF" },
+            { "MDC", "MDC" },
+            { "MDL", "MDL" },
+            { "MGA", "MGA" },
+            { "MKD", "MKD" },
+            { "MKN", "MKN" },
+            { "MMK", "MMK" },
+            { "MNT", "MNT" },
+            { "MOP", "MOP" },
+            { "MRO", "MRO" },
+            { "MRU", "MRU" },
+            { "MTL", "MTL" },
+            { "MTP", "MTP" },
+            { "MUR", "MUR" },
+            { "MVR", "MVR" },
+            { "MWK", "MWK" },
+            { "MXP", "MXP" },
+            { "MXV", "MXV" },
+            { "MYR", "MYR" },
+            { "MZN", "MZN" },
+            { "NAD", "NAD" },
+            { "NGN", "NGN" },
+            { "NIC", "NIC" },
+            { "NIO", "NIO" },
+            { "NLG", "NLG" },
+            { "NOK", "NOK" },
+            { "NPR", "NPR" },
+            { "OMR", "OMR" },
+            { "PAB", "PAB" },
+            { "PEI", "PEI" },
+            { "PEN", "PEN" },
+            { "PES", "PES" },
+            { "PGK", "PGK" },
+            { "PHP", "PHP" },
+            { "PKR", "PKR" },
+            { "PLN", "PLN" },
+            { "PLZ", "PLZ" },
+            { "PTE", "PTE" },
+            { "PYG", "PYG" },
+            { "QAR", "QAR" },
+            { "ROL", "ROL" },
+            { "RON", "RON" },
+            { "RSD", "RSD" },
+            { "RUB", "RUB" },
+            { "RUR", "RUR" },
+            { "RWF", "RWF" },
+            { "SAR", "SAR" },
+            { "SBD", "SBD" },
+            { "SCR", "SCR" },
+            { "SDG", "SDG" },
+            { "SEK", "SEK" },
+            { "SGD", "SGD" },
+            { "SHP", "SHP" },
+            { "SIT", "SIT" },
+            { "SKK", "SKK" },
+            { "SLL", "SLL" },
+            { "SOS", "SOS" },
+            { "SRD", "SRD" },
+            { "SRG", "SRG" },
+            { "SSP", "SSP" },
+            { "STD", "STD" },
             { "STN", "STN" },
+            { "SUR", "SUR" },
+            { "SVC", "SVC" },
+            { "SYP", "SYP" },
+            { "SZL", "SZL" },
             { "THB", "\u0e3f" },
+            { "TJR", "TJR" },
+            { "TJS", "TJS" },
+            { "TMM", "TMM" },
+            { "TMT", "TMT" },
+            { "TND", "TND" },
+            { "TOP", "TOP" },
+            { "TPE", "TPE" },
+            { "TRL", "TRL" },
             { "TRY", "\u20ba" },
+            { "TTD", "TTD" },
+            { "TZS", "TZS" },
+            { "UAH", "UAH" },
+            { "UAK", "UAK" },
+            { "UGX", "UGX" },
             { "USD", "$" },
+            { "USN", "USN" },
+            { "USS", "USS" },
+            { "UYI", "UYI" },
+            { "UYP", "UYP" },
+            { "UYU", "UYU" },
+            { "UZS", "UZS" },
+            { "VEB", "VEB" },
+            { "VEF", "VEF" },
             { "VES", "VES" },
+            { "VNN", "VNN" },
+            { "VUV", "VUV" },
+            { "WST", "WST" },
+            { "XAG", "XAG" },
+            { "XAU", "XAU" },
+            { "XEU", "XEU" },
+            { "XPT", "XPT" },
+            { "XRE", "XRE" },
+            { "XSU", "XSU" },
+            { "XTS", "XTS" },
+            { "XUA", "XUA" },
+            { "YDD", "YDD" },
+            { "YER", "YER" },
+            { "YUD", "YUD" },
+            { "YUM", "YUM" },
+            { "YUN", "YUN" },
+            { "YUR", "YUR" },
+            { "ZAR", "ZAR" },
+            { "ZMK", "ZMK" },
+            { "ZMW", "ZMW" },
+            { "ZWR", "ZWR" },
             { "adp", "Andorra Pezetas\u0131" },
             { "aed", "Birle\u015fik Arap Emirlikleri Dirhemi" },
             { "afa", "Afganistan Afganisi (1927\u20132002)" },
@@ -130,7 +369,7 @@ public class CurrencyNames_tr extends OpenListResourceBundle {
             { "brr", "Brezilya Kruzeirosu" },
             { "brz", "Brezilya Kruzeirosu (1942\u20131967)" },
             { "bsd", "Bahama Dolar\u0131" },
-            { "btn", "Bhutan Ngultrumu" },
+            { "btn", "Butan Ngultrumu" },
             { "buk", "Burma Kyat\u0131" },
             { "bwp", "Botsvana Pulas\u0131" },
             { "byb", "Yeni Beyaz Rusya Rublesi (1994\u20131999)" },
@@ -157,7 +396,7 @@ public class CurrencyNames_tr extends OpenListResourceBundle {
             { "cup", "K\u00fcba Pesosu" },
             { "cve", "Cape Verde Esk\u00fcdosu" },
             { "cyp", "G\u00fcney K\u0131br\u0131s Liras\u0131" },
-            { "czk", "\u00c7ek Cumhuriyeti Korunas\u0131" },
+            { "czk", "\u00c7ek Korunas\u0131" },
             { "ddm", "Do\u011fu Alman Mark\u0131" },
             { "dem", "Alman Mark\u0131" },
             { "djf", "Cibuti Frang\u0131" },
@@ -199,7 +438,7 @@ public class CurrencyNames_tr extends OpenListResourceBundle {
             { "hrk", "H\u0131rvatistan Kunas\u0131" },
             { "htg", "Haiti Gurdu" },
             { "huf", "Macar Forinti" },
-            { "idr", "Endonezya Rupiah\u0131" },
+            { "idr", "Endonezya Rupisi" },
             { "iep", "\u0130rlanda Liras\u0131" },
             { "ilp", "\u0130srail Liras\u0131" },
             { "ilr", "\u0130srail \u015eekeli (1980\u20131985)" },
@@ -310,7 +549,7 @@ public class CurrencyNames_tr extends OpenListResourceBundle {
             { "srg", "Surinam Guldeni" },
             { "ssp", "G\u00fcney Sudan Liras\u0131" },
             { "std", "S\u00e3o Tom\u00e9 ve Pr\u00edncipe Dobras\u0131 (1977\u20132017)" },
-            { "stn", "S\u00e3o Tom\u00e9 ve Pr\u00edncipe Dobras\u0131" },
+            { "stn", "Sao Tome ve Principe Dobras\u0131" },
             { "sur", "Sovyet Rublesi" },
             { "svc", "El Salvador Kolonu" },
             { "syp", "Suriye Liras\u0131" },
@@ -346,7 +585,7 @@ public class CurrencyNames_tr extends OpenListResourceBundle {
             { "vnn", "Vietnam Dongu (1978\u20131985)" },
             { "vuv", "Vanuatu Vatusu" },
             { "wst", "Samoa Talas\u0131" },
-            { "xaf", "CFA Frang\u0131 BEAC" },
+            { "xaf", "Orta Afrika CFA Frang\u0131" },
             { "xag", "G\u00fcm\u00fc\u015f" },
             { "xau", "Alt\u0131n" },
             { "xba", "Birle\u015fik Avrupa Birimi" },
@@ -358,7 +597,7 @@ public class CurrencyNames_tr extends OpenListResourceBundle {
             { "xeu", "Avrupa Para Birimi" },
             { "xfo", "Frans\u0131z Alt\u0131n Frang\u0131" },
             { "xfu", "Frans\u0131z UIC-Frang\u0131" },
-            { "xof", "CFA Frang\u0131 BCEAO" },
+            { "xof", "Bat\u0131 Afrika CFA Frang\u0131" },
             { "xpd", "Paladyum" },
             { "xpf", "CFP Frang\u0131" },
             { "xpt", "Platin" },
