@@ -71,9 +71,148 @@ public class CurrencyNames_ur extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
         final Object[][] data = new Object[][] {
+            { "AED", "AED" },
+            { "AFN", "AFN" },
+            { "ALL", "ALL" },
+            { "AMD", "AMD" },
+            { "ANG", "ANG" },
+            { "AOA", "AOA" },
+            { "ARS", "ARS" },
+            { "AWG", "AWG" },
+            { "AZN", "AZN" },
+            { "BAM", "BAM" },
+            { "BBD", "BBD" },
+            { "BDT", "BDT" },
+            { "BGN", "BGN" },
+            { "BHD", "BHD" },
+            { "BIF", "BIF" },
+            { "BMD", "BMD" },
+            { "BND", "BND" },
+            { "BOB", "BOB" },
+            { "BSD", "BSD" },
+            { "BTN", "BTN" },
+            { "BWP", "BWP" },
+            { "BYN", "BYN" },
+            { "BYR", "BYR" },
+            { "BZD", "BZD" },
+            { "CDF", "CDF" },
+            { "CHF", "CHF" },
+            { "CLP", "CLP" },
+            { "CNH", "CNH" },
+            { "COP", "COP" },
+            { "CRC", "CRC" },
+            { "CUC", "CUC" },
+            { "CUP", "CUP" },
+            { "CVE", "CVE" },
+            { "CZK", "CZK" },
+            { "DJF", "DJF" },
+            { "DKK", "DKK" },
+            { "DOP", "DOP" },
+            { "DZD", "DZD" },
+            { "EGP", "EGP" },
+            { "ERN", "ERN" },
+            { "ETB", "ETB" },
+            { "FJD", "FJD" },
+            { "FKP", "FKP" },
+            { "GEL", "GEL" },
+            { "GHS", "GHS" },
+            { "GIP", "GIP" },
+            { "GMD", "GMD" },
+            { "GNF", "GNF" },
+            { "GTQ", "GTQ" },
+            { "GYD", "GYD" },
+            { "HNL", "HNL" },
+            { "HRK", "HRK" },
+            { "HTG", "HTG" },
+            { "HUF", "HUF" },
+            { "IDR", "IDR" },
+            { "IQD", "IQD" },
+            { "IRR", "IRR" },
+            { "ISK", "ISK" },
+            { "JMD", "JMD" },
+            { "JOD", "JOD" },
+            { "KES", "KES" },
+            { "KGS", "KGS" },
+            { "KHR", "KHR" },
+            { "KMF", "KMF" },
+            { "KPW", "KPW" },
+            { "KWD", "KWD" },
+            { "KYD", "KYD" },
+            { "KZT", "KZT" },
+            { "LAK", "LAK" },
+            { "LBP", "LBP" },
+            { "LKR", "LKR" },
+            { "LRD", "LRD" },
+            { "LTL", "LTL" },
+            { "LVL", "LVL" },
+            { "LYD", "LYD" },
+            { "MAD", "MAD" },
+            { "MDL", "MDL" },
+            { "MGA", "MGA" },
+            { "MKD", "MKD" },
+            { "MMK", "MMK" },
+            { "MNT", "MNT" },
+            { "MOP", "MOP" },
+            { "MRO", "MRO" },
+            { "MRU", "MRU" },
+            { "MUR", "MUR" },
+            { "MVR", "MVR" },
+            { "MWK", "MWK" },
+            { "MYR", "MYR" },
+            { "MZN", "MZN" },
+            { "NAD", "NAD" },
+            { "NGN", "NGN" },
+            { "NIO", "NIO" },
+            { "NOK", "NOK" },
+            { "NPR", "NPR" },
+            { "OMR", "OMR" },
+            { "PAB", "PAB" },
+            { "PEN", "PEN" },
+            { "PGK", "PGK" },
+            { "PHP", "PHP" },
             { "PKR", "Rs" },
+            { "PLN", "PLN" },
+            { "PYG", "PYG" },
+            { "QAR", "QAR" },
+            { "RON", "RON" },
+            { "RSD", "RSD" },
+            { "RUB", "RUB" },
+            { "RWF", "RWF" },
+            { "SAR", "SAR" },
+            { "SBD", "SBD" },
+            { "SCR", "SCR" },
+            { "SDG", "SDG" },
+            { "SEK", "SEK" },
+            { "SGD", "SGD" },
+            { "SHP", "SHP" },
+            { "SLL", "SLL" },
+            { "SOS", "SOS" },
+            { "SRD", "SRD" },
+            { "SSP", "SSP" },
+            { "STD", "STD" },
+            { "STN", "STN" },
+            { "SYP", "SYP" },
+            { "SZL", "SZL" },
             { "THB", "\u0e3f" },
+            { "TJS", "TJS" },
+            { "TMT", "TMT" },
+            { "TND", "TND" },
+            { "TOP", "TOP" },
+            { "TRY", "TRY" },
+            { "TTD", "TTD" },
+            { "TZS", "TZS" },
+            { "UAH", "UAH" },
+            { "UGX", "UGX" },
             { "USD", "$" },
+            { "UYU", "UYU" },
+            { "UZS", "UZS" },
+            { "VEF", "VEF" },
+            { "VES", "VES" },
+            { "VUV", "VUV" },
+            { "WST", "WST" },
+            { "YER", "YER" },
+            { "ZAR", "ZAR" },
+            { "ZMW", "ZMW" },
             { "aed", "\u0645\u062a\u062d\u062f\u06c1 \u0639\u0631\u0628 \u0627\u0645\u0627\u0631\u0627\u062a\u06cc \u062f\u0631\u06c1\u0645" },
             { "afn", "\u0627\u0641\u063a\u0627\u0646 \u0627\u0641\u063a\u0627\u0646\u06cc" },
             { "all", "\u0627\u0644\u0628\u0627\u0646\u06cc\u0627 \u06a9\u0627 \u0644\u06cc\u06a9" },
@@ -111,7 +250,7 @@ public class CurrencyNames_ur extends OpenListResourceBundle {
             { "cuc", "\u06a9\u06cc\u0648\u0628\u0627 \u06a9\u0627 \u0642\u0627\u0628\u0644 \u0645\u0646\u062a\u0642\u0644\u06cc \u067e\u06cc\u0633\u0648" },
             { "cup", "\u06a9\u06cc\u0648\u0628\u0627 \u06a9\u0627 \u067e\u06cc\u0633\u0648" },
             { "cve", "\u06a9\u06cc\u067e \u0648\u0631\u0688\u06cc \u06a9\u0627 \u0627\u0633\u06a9\u06cc\u0648\u0688\u0648" },
-            { "czk", "\u062c\u0645\u06c1\u0648\u0631\u06cc\u06c1 \u0686\u06cc\u06a9 \u06a9\u0631\u0648\u0646\u0627" },
+            { "czk", "\u0686\u06cc\u06a9 \u06a9\u0631\u0648\u0646\u0627" },
             { "dem", "\u0688\u0686 \u0645\u0627\u0631\u06a9\u0633" },
             { "djf", "\u062c\u0628\u0648\u062a\u06cc \u0641\u0631\u0627\u0646\u06a9" },
             { "dkk", "\u0688\u0646\u0645\u0627\u0631\u06a9 \u06a9\u0631\u0648\u0646" },
@@ -124,7 +263,7 @@ public class CurrencyNames_ur extends OpenListResourceBundle {
             { "eur", "\u06cc\u0648\u0631\u0648" },
             { "fjd", "\u0641\u062c\u06cc \u06a9\u0627 \u0688\u0627\u0644\u0631" },
             { "fkp", "\u0641\u0627\u06a9\u0644\u06cc\u0646\u0688 \u0622\u0626\u0644\u06cc\u0646\u0688\u0632 \u067e\u0648\u0646\u0688" },
-            { "gbp", "\u0627\u0646\u06af\u0644\u0633\u062a\u0627\u0646\u06cc \u067e\u0627\u0648\u0646\u0688 \u0633\u0679\u0631\u0644\u0646\u06af" },
+            { "gbp", "\u0628\u0631\u0637\u0627\u0646\u0648\u06cc \u067e\u0627\u0624\u0646\u0688" },
             { "gel", "\u062c\u0627\u0631\u062c\u06cc\u0627\u0626\u06cc \u0644\u0627\u0631\u06cc" },
             { "ghs", "\u06af\u06be\u0627\u0646\u0627 \u06a9\u0627 \u0633\u06cc\u0688\u06cc" },
             { "gip", "\u062c\u0628\u0644 \u0627\u0644\u0637\u0627\u0631\u0642 \u067e\u0648\u0646\u0688" },
@@ -186,7 +325,7 @@ public class CurrencyNames_ur extends OpenListResourceBundle {
             { "nzd", "\u0646\u06cc\u0648\u0632\u06cc \u0644\u06cc\u0646\u0688 \u0688\u0627\u0644\u0631" },
             { "omr", "\u0639\u0645\u0627\u0646\u06cc \u0631\u06cc\u0627\u0644" },
             { "pab", "\u067e\u0646\u0627\u0645\u06c1 \u06a9\u0627 \u0628\u0627\u0644\u0628\u0648\u0622" },
-            { "pen", "\u067e\u06cc\u0631\u0648 \u0646\u06cc\u0648\u0648\u0633\u0648\u0644" },
+            { "pen", "\u067e\u06cc\u0631\u0648\u0648\u06cc\u0626\u0646 \u0633\u0648\u0644" },
             { "pgk", "\u067e\u0627\u067e\u0648\u0622 \u0646\u06cc\u0648 \u06af\u0646\u06cc \u06a9\u0627 \u06a9\u06cc\u0646\u0627" },
             { "php", "\u0641\u0644\u067e\u0627\u0626\u06cc\u0646\u06cc \u067e\u06cc\u0633\u06c1" },
             { "pkr", "\u067e\u0627\u06a9\u0633\u062a\u0627\u0646\u06cc \u0631\u0648\u067e\u06cc\u06c1" },
@@ -211,7 +350,7 @@ public class CurrencyNames_ur extends OpenListResourceBundle {
             { "srd", "\u0633\u0648\u0631\u06cc\u0646\u0627\u0645\u06cc \u0688\u0627\u0644\u0631" },
             { "ssp", "\u062c\u0646\u0648\u0628\u06cc \u0633\u0648\u0688\u0627\u0646\u06cc \u067e\u0627\u0624\u0646\u0688" },
             { "std", "\u0633\u0627\u0624 \u0679\u0648\u0645 \u0627\u0648\u0631 \u067e\u0631\u0646\u0633\u067e\u06d2 \u0688\u0648\u0628\u0631\u0627 (1977\u20132017)" },
-            { "stn", "\u0633\u0627\u0624 \u0679\u0648\u0645 \u0627\u0648\u0631 \u067e\u0631\u0646\u0633\u067e\u06d2 \u0688\u0648\u0628\u0631\u0627" },
+            { "stn", "\u0633\u0627\u0624 \u0679\u0648\u0645\u06d2 \u0627\u0648\u0631 \u067e\u0631\u0646\u0633\u067e\u06d2 \u0688\u0648\u0628\u0631\u0627" },
             { "syp", "\u0634\u0627\u0645\u06cc \u067e\u0648\u0646\u0688" },
             { "szl", "\u0633\u0648\u0627\u0632\u06cc \u0644\u06cc\u0644\u0627\u0646\u062c\u06cc\u0646\u06cc" },
             { "thb", "\u062a\u06be\u0627\u0626\u06cc \u0628\u0627\u06c1\u062a" },
@@ -227,7 +366,7 @@ public class CurrencyNames_ur extends OpenListResourceBundle {
             { "ugx", "\u06cc\u0648\u06af\u0627\u0646\u0688\u0627 \u0634\u0644\u0646\u06af" },
             { "usd", "\u0627\u0645\u0631\u06cc\u06a9\u06cc \u0688\u0627\u0644\u0631" },
             { "uyu", "\u06cc\u0648\u0631\u0648\u06af\u0648\u06cc\u0627\u0646 \u067e\u06cc\u0633\u0648" },
-            { "uzs", "\u0627\u0632\u0628\u06a9\u0633\u062a\u0627\u0646 \u0633\u0648\u0645" },
+            { "uzs", "\u0627\u0632\u0628\u06a9\u0633\u062a\u0627\u0646\u06cc \u0633\u0648\u0645" },
             { "veb", "\u0648\u06cc\u0646\u0632\u0648\u06cc\u0644\u0627 \u0628\u0648\u0644\u06cc\u0648\u0631 (1871\u20132008)" },
             { "vef", "\u0648\u06cc\u0646\u0632\u0648\u06cc\u0644\u0627 \u0628\u0648\u0644\u06cc\u0648\u0631 (2008\u20132018)" },
             { "ves", "\u0648\u06cc\u0646\u0632\u0648\u06cc\u0644\u0627 \u0628\u0648\u0644\u06cc\u0648\u0631" },
