@@ -97,6 +97,7 @@ public class LocaleNames_af extends OpenListResourceBundle {
             { "mwl", "Mirandees" },
             { "Zsym", "Simbole" },
             { "Zsye", "Emoji" },
+            { "ccp", "Tsjaakma" },
             { "egy", "Antieke Egipties" },
             { "tem", "Timne" },
             { "teo", "Teso" },
@@ -283,7 +284,6 @@ public class LocaleNames_af extends OpenListResourceBundle {
             { "ain", "Ainu" },
             { "guz", "Gusii" },
             { "type.nu.knda", "Kannada-syfers" },
-            { "de_CH", "Switserse hoog-Duits" },
             { "type.co.phonetic", "Fonetiese sorteerorde" },
             { "type.ca.buddhist", "Boeddhistiese kalender" },
             { "KE", "Kenia" },
@@ -306,7 +306,7 @@ public class LocaleNames_af extends OpenListResourceBundle {
             { "LC", "Sint Lucia" },
             { "phn", "Fenisies" },
             { "gwi", "Gwich\u02bcin" },
-            { "nds", "Lae Duits" },
+            { "nds", "Nederduits" },
             { "LI", "Liechtenstein" },
             { "LK", "Sri Lanka" },
             { "cop", "Kopties" },
@@ -331,7 +331,7 @@ public class LocaleNames_af extends OpenListResourceBundle {
             { "MH", "Marshalleilande" },
             { "ale", "Aleut" },
             { "type.nu.vaii", "Vai-syfers" },
-            { "MK", "Macedoni\u00eb" },
+            { "MK", "Noord-Macedoni\u00eb" },
             { "ML", "Mali" },
             { "MM", "Mianmar (Birma)" },
             { "MN", "Mongoli\u00eb" },
@@ -441,7 +441,7 @@ public class LocaleNames_af extends OpenListResourceBundle {
             { "SV", "El Salvador" },
             { "SX", "Sint Maarten" },
             { "SY", "Siri\u00eb" },
-            { "SZ", "Swaziland" },
+            { "SZ", "Eswatini" },
             { "TA", "Tristan da Cunha" },
             { "asa", "Asu" },
             { "type.ms.ussystem", "VSA-maatstelsel" },
@@ -511,7 +511,9 @@ public class LocaleNames_af extends OpenListResourceBundle {
             { "wae", "Walser" },
             { "WS", "Samoa" },
             { "wal", "Wolaytta" },
+            { "XA", "Pseudoaksente" },
             { "war", "Waray" },
+            { "XB", "Pseudotweerigting" },
             { "awa", "Awadhi" },
             { "061", "Polinesi\u00eb" },
             { "XK", "Kosovo" },
@@ -630,7 +632,7 @@ public class LocaleNames_af extends OpenListResourceBundle {
             { "type.co.big5han", "Tradisionele Chinese sorteervolgorde - Groot5" },
             { "es", "Spaans" },
             { "et", "Estnies" },
-            { "Hanb", "Hanb" },
+            { "Hanb", "Han met Bopomofo" },
             { "eu", "Baskies" },
             { "Hang", "Hangul" },
             { "shi", "Tachelhit" },
@@ -658,7 +660,7 @@ public class LocaleNames_af extends OpenListResourceBundle {
             { "gl", "Galisies" },
             { "gn", "Guarani" },
             { "bho", "Bhojpuri" },
-            { "und", "Onbekende of ongeldige taal" },
+            { "und", "Onbekende taal" },
             { "type.ca.ethiopic-amete-alem", "Etiopiese Amete Alem-kalender" },
             { "gu", "Goedjarati" },
             { "gv", "Manx" },
@@ -853,7 +855,7 @@ public class LocaleNames_af extends OpenListResourceBundle {
             { "155", "Wes-Europa" },
             { "ug", "Uighur" },
             { "Kore", metaValue_ko },
-            { "Zyyy", "Algemeen" },
+            { "Zyyy", "Gemeenskaplik" },
             { "uk", "Oekra\u00efens" },
             { "type.ca.coptic", "Koptiese kalender" },
             { "ur", "Oerdoe" },
@@ -893,7 +895,7 @@ public class LocaleNames_af extends OpenListResourceBundle {
             { "type.nu.traditional", "Tradisionele syfers" },
             { "vai", "Vai" },
             { "kln", "Kalenjin" },
-            { "zh", "Sjinees" },
+            { "zh", "Chinees" },
             { "Bopo", "Bopomofo" },
             { "key.lb", "Re\u00eblafbreek-styl" },
             { "zu", "Zoeloe" },
@@ -904,10 +906,8 @@ public class LocaleNames_af extends OpenListResourceBundle {
             { "gez", "Geez" },
             { "type.co.reformed", "Gereformeerde sorteervolgorde" },
             { "ebu", "Embu" },
-            { "zh_Hans", "Chinees (Vereenvoudig)" },
             { "koi", "Komi-Permyaks" },
             { "kok", "Konkani" },
-            { "zh_Hant", "Chinees (Tradisioneel)" },
             { "kpe", "Kpellees" },
             { "type.nu.khmr", "Khmer-syfers" },
             { "ilo", "Iloko" },
@@ -920,6 +920,7 @@ public class LocaleNames_af extends OpenListResourceBundle {
             { "type.nu.tamldec", "Tamil-syfers" },
             { "krc", "Karachay-Balkar" },
             { "inh", "Ingush" },
+            { "fa_AF", "Dari" },
             { "krl", "Karelies" },
             { "efi", "Efik" },
             { "key.nu", "Syfers" },
