@@ -83,7 +83,8 @@ public class LocaleNames_am extends OpenListResourceBundle {
             { "mwl", "\u121a\u122b\u1295\u12f4\u12dd\u129b" },
             { "Zsym", "\u121d\u120d\u12ad\u1276\u127d" },
             { "cch", "\u12a0\u1275\u1233\u121d" },
-            { "Zsye", "Zsye" },
+            { "Zsye", "\u12a2\u121e\u1302" },
+            { "ccp", "\u127b\u12ad\u121b" },
             { "egy", "\u12e8\u1325\u1295\u1273\u12ca \u130d\u1265\u133d\u129b" },
             { "tem", "\u1272\u121d\u1294" },
             { "teo", "\u1274\u1236" },
@@ -142,7 +143,7 @@ public class LocaleNames_am extends OpenListResourceBundle {
             { "CC", "\u12ae\u12ae\u1235(\u12ac\u120a\u1295\u130d) \u12f0\u1234\u1276\u127d" },
             { "mzn", "\u121b\u12db\u1295\u12f0\u122b\u1292" },
             { "CD", "\u12ae\u1295\u130e-\u12aa\u1295\u123b\u1233" },
-            { "CF", "\u12e8\u1218\u12ab\u12a8\u1208\u129b\u12cd \u12a0\u134d\u122a\u12ab \u122a\u1350\u1265\u120a\u12ad" },
+            { "CF", "\u121b\u12d5\u12a8\u120b\u12ca \u12a0\u134d\u122a\u12ab \u122a\u1351\u1265\u120a\u12ad" },
             { "CG", "\u12ae\u1295\u130e \u1265\u122b\u12db\u126a\u120d" },
             { "CH", "\u1235\u12ca\u12d8\u122d\u120b\u1295\u12f5" },
             { "CI", "\u12ae\u1275 \u12f2\u126f\u122d" },
@@ -263,7 +264,7 @@ public class LocaleNames_am extends OpenListResourceBundle {
             { "IR", "\u12a2\u122b\u1295" },
             { "IS", "\u12a0\u12ed\u1235\u120b\u1295\u12f5" },
             { "IT", "\u1323\u120a\u12eb\u1295" },
-            { "Zmth", "Zmth" },
+            { "Zmth", "\u12e8\u1202\u1233\u1265 \u1218\u130d\u1208\u132b" },
             { "type.nu.thai", "\u12e8\u1273\u12ed \u12a0\u1203\u12de\u127d" },
             { "type.nu.beng", "\u12e8\u1264\u1295\u130b\u120a \u12a0\u1203\u12de\u127d" },
             { "JE", "\u1300\u122d\u1232" },
@@ -515,7 +516,9 @@ public class LocaleNames_am extends OpenListResourceBundle {
             { "wae", "\u12cb\u120d\u1230\u122d" },
             { "WS", "\u1233\u121e\u12a0" },
             { "wal", "\u12c8\u120b\u12ed\u1275\u129b" },
+            { "XA", "\u12e8\u1200\u1230\u1275 \u1275\u12a5\u121d\u122d\u1275" },
             { "war", "\u12cb\u122b\u12ed" },
+            { "XB", "\u12e8\u1200\u1230\u1275 \u1263\u1208\u1201\u1208\u1275 \u12a0\u1245\u1323\u132b" },
             { "awa", "\u12a0\u12cb\u12f5\u1202" },
             { "061", "\u1356\u120a\u1294\u12e5\u12eb" },
             { "XK", "\u12ae\u1236\u126e" },
@@ -970,6 +973,7 @@ public class LocaleNames_am extends OpenListResourceBundle {
             { "type.nu.tamldec", "\u12e8\u1273\u121a\u120d \u12a0\u1203\u12de\u127d" },
             { "krc", "\u12ab\u122b\u127b\u12ed-\u1263\u120d\u12ab\u122d" },
             { "inh", "\u12a2\u1295\u1309\u123d" },
+            { "fa_AF", "\u12f3\u122a\u129b" },
             { "krl", "\u12ab\u1228\u120a\u129b" },
             { "efi", "\u12a4\u134a\u12ad" },
             { "key.nu", "\u1241\u1325\u122e\u127d" },
