@@ -103,6 +103,7 @@ public class LocaleNames_ar extends OpenListResourceBundle {
             { "mwr", "\u0627\u0644\u0645\u0627\u0631\u0648\u0627\u0631\u064a\u0629" },
             { "Tagb", "\u0627\u0644\u062a\u0627\u062c\u0628\u0627\u0646\u0648\u0627" },
             { "Zsye", "\u0625\u064a\u0645\u0648\u062c\u064a" },
+            { "ccp", "\u062a\u0634\u0627\u0643\u0645\u0627" },
             { "egy", "\u0627\u0644\u0645\u0635\u0631\u064a\u0629 \u0627\u0644\u0642\u062f\u064a\u0645\u0629" },
             { "raj", "\u0627\u0644\u0631\u0627\u062c\u0627\u0633\u062b\u0627\u0646\u064a\u0629" },
             { "Phag", "\u0627\u0644\u0641\u0627\u062c\u0633\u0628\u0627" },
@@ -155,7 +156,7 @@ public class LocaleNames_ar extends OpenListResourceBundle {
             { "BO", "\u0628\u0648\u0644\u064a\u0641\u064a\u0627" },
             { "BQ", "\u0647\u0648\u0644\u0646\u062f\u0627 \u0627\u0644\u0643\u0627\u0631\u064a\u0628\u064a\u0629" },
             { "BR", "\u0627\u0644\u0628\u0631\u0627\u0632\u064a\u0644" },
-            { "BS", "\u0627\u0644\u0628\u0647\u0627\u0645\u0627" },
+            { "BS", "\u062c\u0632\u0631 \u0627\u0644\u0628\u0647\u0627\u0645\u0627" },
             { "xog", "\u0627\u0644\u0633\u0648\u063a\u0627" },
             { "BT", "\u0628\u0648\u062a\u0627\u0646" },
             { "BV", "\u062c\u0632\u064a\u0631\u0629 \u0628\u0648\u0641\u064a\u0647" },
@@ -204,6 +205,7 @@ public class LocaleNames_ar extends OpenListResourceBundle {
             { "DO", "\u062c\u0645\u0647\u0648\u0631\u064a\u0629 \u0627\u0644\u062f\u0648\u0645\u064a\u0646\u064a\u0643\u0627\u0646" },
             { "gor", "\u0627\u0644\u062c\u0648\u0631\u0648\u0646\u062a\u0627\u0644\u0648" },
             { "got", metaValue_got },
+            { "Mtei", "\u0645\u064a\u062a\u064a \u0645\u0627\u064a\u064a\u0643" },
             { "zun", "\u0627\u0644\u0632\u0648\u0646\u064a\u0629" },
             { "tig", "\u0627\u0644\u062a\u064a\u063a\u0631\u064a\u0629" },
             { "DZ", "\u0627\u0644\u062c\u0632\u0627\u0626\u0631" },
@@ -385,7 +387,7 @@ public class LocaleNames_ar extends OpenListResourceBundle {
             { "MM", "\u0645\u064a\u0627\u0646\u0645\u0627\u0631 (\u0628\u0648\u0631\u0645\u0627)" },
             { "MN", "\u0645\u0646\u063a\u0648\u0644\u064a\u0627" },
             { "new", "\u0627\u0644\u0646\u0648\u0627\u0631\u064a\u0629" },
-            { "MO", "\u0645\u0643\u0627\u0648 \u0627\u0644\u0635\u064a\u0646\u064a\u0629 (\u0645\u0646\u0637\u0642\u0629 \u0625\u062f\u0627\u0631\u064a\u0629 \u062e\u0627\u0635\u0629)" },
+            { "MO", "\u0645\u0646\u0637\u0642\u0629 \u0645\u0627\u0643\u0627\u0648 \u0627\u0644\u0625\u062f\u0627\u0631\u064a\u0629 \u0627\u0644\u062e\u0627\u0635\u0629" },
             { "MP", "\u062c\u0632\u0631 \u0645\u0627\u0631\u064a\u0627\u0646\u0627 \u0627\u0644\u0634\u0645\u0627\u0644\u064a\u0629" },
             { "MQ", "\u062c\u0632\u0631 \u0627\u0644\u0645\u0627\u0631\u062a\u064a\u0646\u064a\u0643" },
             { "MR", "\u0645\u0648\u0631\u064a\u062a\u0627\u0646\u064a\u0627" },
@@ -519,6 +521,7 @@ public class LocaleNames_ar extends OpenListResourceBundle {
             { "TC", "\u062c\u0632\u0631 \u062a\u0648\u0631\u0643\u0633 \u0648\u0643\u0627\u064a\u0643\u0648\u0633" },
             { "yav", "\u064a\u0627\u0646\u062c\u0628\u0646" },
             { "TD", "\u062a\u0634\u0627\u062f" },
+            { "Qaag", "\u0632\u0648\u062c\u064a\u064a" },
             { "TF", "\u0627\u0644\u0623\u0642\u0627\u0644\u064a\u0645 \u0627\u0644\u062c\u0646\u0648\u0628\u064a\u0629 \u0627\u0644\u0641\u0631\u0646\u0633\u064a\u0629" },
             { "TG", "\u062a\u0648\u063a\u0648" },
             { "TH", "\u062a\u0627\u064a\u0644\u0627\u0646\u062f" },
@@ -590,13 +593,15 @@ public class LocaleNames_ar extends OpenListResourceBundle {
             { "WS", "\u0633\u0627\u0645\u0648\u0627" },
             { "wal", "\u0627\u0644\u0648\u0644\u0627\u064a\u0627\u062a\u0627" },
             { "was", "\u0627\u0644\u0648\u0627\u0634\u0648" },
-            { "XA", "XA" },
+            { "XA", "\u0644\u0643\u0646\u0627\u062a \u062a\u062c\u0631\u064a\u0628\u064a\u0629 \u063a\u064a\u0631 \u0623\u0635\u0644\u064a\u0629" },
             { "war", "\u0627\u0644\u0648\u0627\u0631\u0627\u064a" },
+            { "XB", "\u0644\u0643\u0646\u0627\u062a \u062a\u062c\u0631\u064a\u0628\u064a\u0629 \u062b\u0646\u0627\u0626\u064a\u0629 \u0627\u0644\u0627\u062a\u062c\u0627\u0647" },
             { "awa", "\u0627\u0644\u0623\u0648\u0627\u062f\u064a\u0629" },
             { "061", "\u0628\u0648\u0644\u064a\u0646\u064a\u0632\u064a\u0627" },
             { "XK", "\u0643\u0648\u0633\u0648\u0641\u0648" },
             { "Gujr", "\u0627\u0644\u062a\u0627\u063a\u062c\u0631\u0627\u062a\u064a\u0629" },
             { "Zxxx", "\u063a\u064a\u0631 \u0645\u0643\u062a\u0648\u0628" },
+            { "Olck", "\u0623\u0648\u0644 \u062a\u0634\u064a\u0643\u064a" },
             { "wbp", "\u0648\u0627\u0631\u0644\u0628\u064a\u0631\u064a" },
             { "Batk", "\u0627\u0644\u0628\u0627\u062a\u0627\u0643" },
             { "Blis", "\u0631\u0645\u0648\u0632 \u0628\u0644\u064a\u0633" },
@@ -681,6 +686,7 @@ public class LocaleNames_ar extends OpenListResourceBundle {
             { "scn", "\u0627\u0644\u0635\u0642\u0644\u064a\u0629" },
             { "aa", "\u0627\u0644\u0623\u0641\u0627\u0631\u064a\u0629" },
             { "ab", "\u0627\u0644\u0623\u0628\u062e\u0627\u0632\u064a\u0629" },
+            { "Aran", "\u0646\u0633\u062a\u0639\u0644\u064a\u0642" },
             { "ae", "\u0627\u0644\u0623\u0641\u0633\u062a\u064a\u0629" },
             { "af", "\u0627\u0644\u0623\u0641\u0631\u064a\u0642\u0627\u0646\u064a\u0629" },
             { "ak", "\u0627\u0644\u0623\u0643\u0627\u0646\u064a\u0629" },
@@ -1064,7 +1070,7 @@ public class LocaleNames_ar extends OpenListResourceBundle {
             { "Xsux", "\u0627\u0644\u0643\u062a\u0627\u0628\u0629 \u0627\u0644\u0645\u0633\u0645\u0627\u0631\u064a\u0629 \u0627\u0644\u0623\u0643\u062f\u064a\u0629 \u0627\u0644\u0633\u0648\u0645\u0631\u064a\u0629" },
             { "wo", "\u0627\u0644\u0648\u0644\u0648\u0641\u064a\u0629" },
             { "zgh", "\u0627\u0644\u062a\u0645\u0627\u0632\u064a\u063a\u064a\u0629 \u0627\u0644\u0645\u063a\u0631\u0628\u064a\u0629 \u0627\u0644\u0642\u064a\u0627\u0633\u064a\u0629" },
-            { "ar_001", "\u0627\u0644\u0639\u0631\u0628\u064a\u0629 \u0627\u0644\u0631\u0633\u0645\u064a\u0629 \u0627\u0644\u062d\u062f\u064a\u062b\u0629" },
+            { "ar_001", "\u0627\u0644\u0639\u0631\u0628\u064a\u0629 \u0627\u0644\u0641\u0635\u062d\u0649 \u0627\u0644\u062d\u062f\u064a\u062b\u0629" },
             { "Cans", "\u0645\u0642\u0627\u0637\u0639 \u0643\u0646\u062f\u064a\u0629 \u0623\u0635\u0644\u064a\u0629 \u0645\u0648\u062d\u062f\u0629" },
             { "gay", "\u0627\u0644\u062c\u0627\u064a\u0648" },
             { "Mong", "\u0627\u0644\u0645\u063a\u0648\u0644\u064a\u0629" },
@@ -1149,6 +1155,7 @@ public class LocaleNames_ar extends OpenListResourceBundle {
             { "type.nu.tamldec", "\u0627\u0644\u0623\u0631\u0642\u0627\u0645 \u0627\u0644\u062a\u0627\u0645\u064a\u0644\u064a\u0629" },
             { "krc", "\u0627\u0644\u0643\u0627\u0631\u0627\u062a\u0634\u0627\u064a-\u0628\u0627\u0644\u0643\u0627\u0631" },
             { "inh", "\u0627\u0644\u0625\u0646\u062c\u0648\u0634\u064a\u0629" },
+            { "fa_AF", "\u0627\u0644\u062f\u0627\u0631\u064a\u0629" },
             { "krl", "\u0627\u0644\u0643\u0627\u0631\u064a\u0644\u064a\u0629" },
             { "efi", "\u0627\u0644\u0625\u0641\u064a\u0643" },
             { "key.nu", "\u0627\u0644\u0623\u0631\u0642\u0627\u0645" },
