@@ -322,12 +322,12 @@ public class LocaleNames_as extends OpenListResourceBundle {
             { "Thai", metaValue_th },
             { "MH", "\u09ae\u09be\u09f0\u09cd\u09b6\u09cd\u09ac\u09be\u09b2 \u09a6\u09cd\u09ac\u09c0\u09aa\u09aa\u09c1\u099e\u09cd\u099c" },
             { "ale", "\u0986\u09b2\u09c7\u0989\u099f" },
-            { "MK", "\u09ae\u09c7\u099a\u09bf\u09a1\u09cb\u09a8\u09c0\u09af\u09bc\u09be" },
+            { "MK", "\u0989\u09a4\u09cd\u09a4\u09f0 \u09ae\u09c7\u099a\u09bf\u09a1\u09cb\u09a8\u09c0\u09af\u09bc\u09be" },
             { "ML", "\u09ae\u09be\u09b2\u09bf" },
             { "MM", "\u09ae\u09cd\u09af\u09be\u09a8\u09ae\u09be\u09f0 (\u09ac\u09be\u09f0\u09cd\u09ae\u09be)" },
             { "MN", "\u09ae\u0999\u09cd\u0997\u09cb\u09b2\u09bf\u09af\u09bc\u09be" },
             { "new", "\u09a8\u09c7\u09f1\u09be\u09f0\u09bf" },
-            { "MO", "\u09ae\u09be\u0995\u09be\u0989 \u098f\u099b. \u098f. \u0986\u09f0. \u099a\u09c0\u09a8" },
+            { "MO", "\u09ae\u09be\u0995\u09be\u0993 \u098f\u099b. \u098f. \u0986\u09f0. \u099a\u09c0\u09a8" },
             { "MP", "\u0989\u09a4\u09cd\u09a4\u09f0 \u09ae\u09be\u09f0\u09bf\u09af\u09bc\u09be\u09a8\u09be \u09a6\u09cd\u09ac\u09c0\u09aa\u09aa\u09c1\u099e\u09cd\u099c" },
             { "MQ", "\u09ae\u09be\u09f0\u09cd\u099f\u09bf\u09a8\u09bf\u0995" },
             { "MR", "\u09ae\u09be\u0989\u09f0\u09bf\u099f\u09be\u09a8\u09bf\u09af\u09bc\u09be" },
@@ -388,7 +388,7 @@ public class LocaleNames_as extends OpenListResourceBundle {
             { "tvl", metaValue_TV },
             { "001", "\u09ac\u09bf\u09b6\u09cd\u09ac" },
             { "002", "\u0986\u09ab\u09cd\u09f0\u09bf\u0995\u09be" },
-            { "003", "\u0989\u09a6\u09c0\u099a\u09cd\u09af \u0986\u09ae\u09c7\u09f0\u09bf\u0995\u09be" },
+            { "003", "\u0989\u09a4\u09cd\u09a4\u09f0 \u0986\u09ae\u09c7\u09f0\u09bf\u0995\u09be" },
             { "RE", "\u09f0\u09bf\u0987\u0989\u09a8\u09bf\u09af\u09bc\u09a8" },
             { "005", "\u09a6\u0995\u09cd\u09b7\u09bf\u09a3 \u0986\u09ae\u09c7\u09f0\u09bf\u0995\u09be" },
             { "jbo", "\u09b2\u09cb\u099c\u09cd\u09ac\u09be\u09a8" },
@@ -433,7 +433,7 @@ public class LocaleNames_as extends OpenListResourceBundle {
             { "TA", "\u09a4\u09cd\u09f0\u09bf\u09b8\u09cd\u09a4\u09be\u09a8 \u09a6\u09cd\u09af\u09be \u0995\u09c1\u09a8\u09b9\u09be" },
             { "asa", "\u0986\u099b\u09c1" },
             { "type.ms.ussystem", "\u09ae\u09be\u09f0\u09cd\u0995\u09bf\u09a8 \u09af\u09c1\u0995\u09cd\u09a4\u09f0\u09be\u09b7\u09cd\u099f\u09cd\u09f0\u09f0 \u099c\u09cb\u0996-\u09ae\u09be\u0996\u09f0 \u09aa\u09cd\u09f0\u09a3\u09be\u09b2\u09c0" },
-            { "021", "\u0989\u09a4\u09cd\u09a4\u09f0\u09c0\u09af\u09bc \u0986\u09ae\u09c7\u09f0\u09bf\u0995\u09be" },
+            { "021", "\u0989\u09a6\u09c0\u099a\u09cd\u09af \u0986\u09ae\u09c7\u09f0\u09bf\u0995\u09be" },
             { "TC", "\u099f\u09be\u09f0\u09cd\u0995\u099b \u0985\u09f0\u09c1 \u0995\u09c7\u0987\u0995\u2019\u099b \u09a6\u09cd\u09ac\u09c0\u09aa\u09aa\u09c1\u099e\u09cd\u099c" },
             { "yav", "\u09af\u09bc\u09be\u0982\u09ac\u09c7\u09a8" },
             { "TD", "\u099a\u09be\u09a1" },
@@ -780,7 +780,7 @@ public class LocaleNames_as extends OpenListResourceBundle {
             { "en_AU", "\u0985\u09b7\u09cd\u099f\u09cd\u09f0\u09c7\u09b2\u09bf\u09af\u09bc\u09be\u09a8 \u0987\u0982\u09f0\u09be\u099c\u09c0" },
             { "sa", "\u09b8\u0982\u09b8\u09cd\u0995\u09c3\u09a4" },
             { "sc", "\u099b\u09be\u09f0\u09cd\u09a1\u09bf\u09a8\u09bf\u09af\u09bc\u09be\u09a8" },
-            { "sd", "\u09b8\u09bf\u09a8\u09cd\u09a7\u09bf" },
+            { "sd", "\u09b8\u09bf\u09a8\u09cd\u09a7\u09c0" },
             { "se", "\u0989\u09a6\u09c0\u099a\u09cd\u09af \u099b\u09be\u09ae\u09bf" },
             { "min", "\u09ae\u09bf\u09a8\u09be\u0982\u0995\u09be\u09ac\u09be\u0989" },
             { "sg", "\u099b\u09be\u0999\u09cd\u0997\u09cb" },
@@ -891,6 +891,7 @@ public class LocaleNames_as extends OpenListResourceBundle {
             { "type.nu.tamldec", "\u09a4\u09be\u09ae\u09bf\u09b2 \u0985\u0982\u0995" },
             { "krc", "\u0995\u09be\u09f0\u09be\u099a\u09c7-\u09ac\u09be\u09b2\u09cd\u0995\u09be\u09f0" },
             { "inh", "\u0987\u0982\u0997\u09c1\u099a" },
+            { "fa_AF", "\u09a6\u09be\u09f0\u09bf" },
             { "krl", "\u0995\u09c7\u09f0\u09c7\u09b2\u09bf\u09af\u09bc\u09be\u09a8" },
             { "efi", "\u098f\u09ab\u09bf\u0995" },
             { "key.nu", "\u09b8\u0982\u0996\u09cd\u09af\u09be" },
