@@ -281,11 +281,9 @@ public class LocaleNames_ast extends OpenListResourceBundle {
             { "Taml", metaValue_ta },
             { "FR", "Francia" },
             { "Kpel", metaValue_kpe },
-            { "%%SIMPLE", "SIMPLE" },
             { "pcd", "p\u00edcaru" },
             { "tkl", "tokelau" },
             { "grb", "grebo" },
-            { "root", "root" },
             { "%%DAJNKO", "alfabetu dajnko" },
             { "type.ca.indian", "calendariu nacional indiu" },
             { "rgn", "roma\u00f1ol" },
@@ -379,7 +377,6 @@ public class LocaleNames_ast extends OpenListResourceBundle {
             { "JP", "Xap\u00f3n" },
             { "%%1606NICT", "\u00faltimu franc\u00e9s mediu fasta 1606" },
             { "ain", "ainu" },
-            { "%%KOCIEWIE", "KOCIEWIE" },
             { "Mend", metaValue_men },
             { "guz", "gusii" },
             { "tog", "tonga nyasa" },
@@ -414,7 +411,6 @@ public class LocaleNames_ast extends OpenListResourceBundle {
             { "LC", "Santa Lluc\u00eda" },
             { "Cyrs", "eslav\u00f3nicu cir\u00edlicu eclesi\u00e1sticu antiguu" },
             { "gwi", "gwich\u02bcin" },
-            { "%%LUNA1918", "LUNA1918" },
             { "nds", "baxu alem\u00e1n" },
             { "LI", "Liechtenstein" },
             { "LK", "Sri Lanka" },
@@ -433,7 +429,6 @@ public class LocaleNames_ast extends OpenListResourceBundle {
             { "lad", "ladino" },
             { "vun", "vunjo" },
             { "akz", "alabama" },
-            { "%%LAUKIKA", "LAUKIKA" },
             { "lah", "lahnda" },
             { "Mahj", "mahajani" },
             { "lag", "langi" },
@@ -450,7 +445,6 @@ public class LocaleNames_ast extends OpenListResourceBundle {
             { "MH", "Islles Marshall" },
             { "ale", "aleut" },
             { "type.nu.vaii", "n\u00famberos vai" },
-            { "MK", "Macedonia" },
             { "type.nu.mathdbl", "n\u00famberos matem\u00e1ticos con trazu doble" },
             { "ML", "Mal\u00ed" },
             { "MM", "Myanmar (Birmania)" },
@@ -504,7 +498,6 @@ public class LocaleNames_ast extends OpenListResourceBundle {
             { "crh", "turcu de Crimea" },
             { "ang", "ingl\u00e9s antiguu" },
             { "OM", "Om\u00e1n" },
-            { "%%PETR1708", "PETR1708" },
             { "anp", "angika" },
             { "crs", "franc\u00e9s criollu seselwa" },
             { "Xpeo", metaValue_peo },
@@ -558,7 +551,6 @@ public class LocaleNames_ast extends OpenListResourceBundle {
             { "pnt", "p\u00f3nticu" },
             { "Rjng", "rejang" },
             { "009", "Ocean\u00eda" },
-            { "%%SURSILV", "SURSILV" },
             { "RO", "Ruman\u00eda" },
             { "RS", "Serbia" },
             { "Mroo", "mro" },
@@ -727,12 +719,10 @@ public class LocaleNames_ast extends OpenListResourceBundle {
             { "fan", "fang" },
             { "%%BALANKA", "dialectu balanka del anii" },
             { "%%ROZAJ", "resianu" },
-            { "%%SUTSILV", "SUTSILV" },
             { "fat", "fanti" },
             { "Sgnw", "escritura de signos" },
             { "YT", "Mayotte" },
             { "type.nu.cham", "n\u00famberos cham" },
-            { "%%NEWFOUND", "NEWFOUND" },
             { "ZA", "Sud\u00e1frica" },
             { "type.nu.sund", "n\u00famberos sondaneses" },
             { "type.lb.loose", "saltu de llinia relax\u00e1u" },
@@ -790,7 +780,6 @@ public class LocaleNames_ast extends OpenListResourceBundle {
             { "Guru", "gurmukhi" },
             { "%%ALUKU", "dialectu aluku" },
             { "lua", "luba-lulua" },
-            { "%%BISCAYAN", "BISCAYAN" },
             { "type.nu.tirh", "n\u00famberos tirhuta" },
             { "sbp", "sangu" },
             { "lui", "luiseno" },
@@ -922,7 +911,6 @@ public class LocaleNames_ast extends OpenListResourceBundle {
             { "shi", "tachelhit" },
             { "hsb", "altu sorbiu" },
             { "Hani", "han" },
-            { "%%ULSTER", "ULSTER" },
             { "shn", "shan" },
             { "Hano", "hanun\u00f3\u2019o" },
             { "fa", "persa" },
@@ -975,7 +963,6 @@ public class LocaleNames_ast extends OpenListResourceBundle {
             { "ig", "igbo" },
             { "ii", "yi de Sichu\u00e1n" },
             { "frm", "franc\u00e9s mediu" },
-            { "%%RUMGR", "RUMGR" },
             { "%%AO1990", "alcuerdu ortogr\u00e1ficu de 1990 pa la llingua portuguesa" },
             { "ik", "inupiaq" },
             { "fro", "franc\u00e9s antiguu" },
@@ -988,8 +975,6 @@ public class LocaleNames_ast extends OpenListResourceBundle {
             { "it", "italianu" },
             { "iu", "inuktitut" },
             { "sli", "baxu silesianu" },
-            { "%%CORNU", "CORNU" },
-            { "%%HOGNORSK", "HOGNORSK" },
             { "ja", metaValue_ja },
             { "Mlym", metaValue_ml },
             { "Sarb", "\u00e1rabe del sur antiguu" },
@@ -1001,7 +986,6 @@ public class LocaleNames_ast extends OpenListResourceBundle {
             { "sma", "sami del sur" },
             { "jv", metaValue_jv },
             { "Shaw", "shavianu" },
-            { "%%BAUDDHA", "BAUDDHA" },
             { "mad", "madur\u00e9s" },
             { "smj", "lule sami" },
             { "mag", "magahi" },
@@ -1118,7 +1102,6 @@ public class LocaleNames_ast extends OpenListResourceBundle {
             { "dum", "neerland\u00e9s mediu" },
             { "type.nu.saur", "n\u00famberos saurashtra" },
             { "type.ca.dangi", "calendariu dangi" },
-            { "%%VALLADER", "VALLADER" },
             { "ps", "pashtu" },
             { "pt", "portugu\u00e9s" },
             { "mga", "\u00edrland\u00e9s mediu" },
@@ -1131,9 +1114,7 @@ public class LocaleNames_ast extends OpenListResourceBundle {
             { "type.nu.nkoo", "n\u00famberos N\u2019Ko" },
             { "bra", "braj" },
             { "key.ca", "calendariu" },
-            { "%%JAUER", "JAUER" },
             { "Laoo", metaValue_lo },
-            { "%%SURMIRAN", "SURMIRAN" },
             { "mgo", "meta\u2019" },
             { "type.hc.h23", "sistema de 24 hores (0\u201323)" },
             { "type.hc.h24", "sistema de 24 hores (1\u201324)" },
@@ -1145,10 +1126,8 @@ public class LocaleNames_ast extends OpenListResourceBundle {
             { "brx", "bodo" },
             { "Lana", "lanna" },
             { "kde", "makonde" },
-            { "%%VAIDIKA", "VAIDIKA" },
             { "stq", "fris\u00f3n de Saterland" },
             { "Ethi", "et\u00edope" },
-            { "%%JYUTPING", "JYUTPING" },
             { "type.hc.h12", "sistema de 12 hores (1\u201312)" },
             { "type.hc.h11", "sistema de 12 hores (0\u201311)" },
             { "rm", "romanche" },
@@ -1183,7 +1162,6 @@ public class LocaleNames_ast extends OpenListResourceBundle {
             { "sl", "eslovenu" },
             { "Gran", "grantha" },
             { "sm", "samoanu" },
-            { "%%BASICENG", "BASICENG" },
             { "sn", "shona" },
             { "so", "somal\u00edn" },
             { "type.nu.arab", "n\u00famberos ar\u00e1bico-\u00edndicos" },
@@ -1280,7 +1258,6 @@ public class LocaleNames_ast extends OpenListResourceBundle {
             { "zgh", "tamazight est\u00e1ndar de Marruecos" },
             { "ar_001", "\u00e1rabe est\u00e1ndar modernu" },
             { "Cans", "sil\u00e1bicu unific\u00e1u de los nativos canadienses" },
-            { "%%FONXSAMP", "FONXSAMP" },
             { "gay", "gayo" },
             { "Mong", metaValue_mn },
             { "mnc", "manch\u00fa" },
@@ -1342,7 +1319,6 @@ public class LocaleNames_ast extends OpenListResourceBundle {
             { "Tglg", metaValue_tl },
             { "Egyd", "dem\u00f3ticu exipcianu" },
             { "Egyh", "hier\u00e1ticu exipcianu" },
-            { "%%ITIHASA", "ITIHASA" },
             { "Palm", "palmirenu" },
             { "ebu", "emb\u00fa" },
             { "Egyp", "xerogl\u00edficos exipcianos" },
@@ -1369,7 +1345,6 @@ public class LocaleNames_ast extends OpenListResourceBundle {
             { "mua", "mundang" },
             { "type.nu.guru", "n\u00famberos gurmukhi" },
             { "mul", "m\u00faltiples lling\u00fces" },
-            { "%%PUTER", "PUTER" },
             { "cad", "caddo" },
             { "key.ms", "sistema de midida" },
             { "mus", "creek" },
