@@ -282,7 +282,7 @@ public class LocaleNames_az extends OpenListResourceBundle {
             { "ckb", "M\u0259rk\u0259zi k\u00fcrdc\u0259" },
             { "zxx", "dil m\u0259zmunu yoxdur" },
             { "de_AT", "Avstriya almancas\u0131" },
-            { "HK", "Honq Konq X\u00fcsusi \u0130nzibati \u018frazi \u00c7in" },
+            { "HK", "Honq Konq X\u00fcsusi \u0130nzibati Rayonu \u00c7in" },
             { "Vaii", "vay" },
             { "HM", "Herd v\u0259 Makdonald adalar\u0131" },
             { "HN", "Honduras" },
@@ -381,7 +381,7 @@ public class LocaleNames_az extends OpenListResourceBundle {
             { "MM", "Myanma" },
             { "MN", "Monqolustan" },
             { "new", "nevari" },
-            { "MO", "Makao X\u00fcsusi \u0130nzibati \u018frazi \u00c7in" },
+            { "MO", "Makao X\u0130R \u00c7in" },
             { "MP", "\u015eimali Marian adalar\u0131" },
             { "MQ", "Martinik" },
             { "MR", "Mavritaniya" },
@@ -590,7 +590,6 @@ public class LocaleNames_az extends OpenListResourceBundle {
             { "Batk", "batak" },
             { "Blis", "blissymbols" },
             { "YE", "Y\u0259m\u0259n" },
-            { "nqo", "nqo" },
             { "type.co.standard", "Standart S\u0131ralama" },
             { "fan", "fang" },
             { "fat", "fanti" },
@@ -1096,6 +1095,7 @@ public class LocaleNames_az extends OpenListResourceBundle {
             { "type.nu.tamldec", "Tamil R\u0259q\u0259ml\u0259ri" },
             { "krc", "qara\u00e7ay-balkar" },
             { "inh", "inqu\u015f" },
+            { "fa_AF", "dari" },
             { "krl", "karel" },
             { "efi", "efik" },
             { "key.nu", "R\u0259q\u0259ml\u0259r" },
