@@ -71,6 +71,7 @@ public class LocaleNames_bs extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
         final String metaValue_tl = "tagalog";
+        final String metaValue_chr = "\u010deroki";
         final Object[][] data = new Object[][] {
             { "ksh", "kelnski" },
             { "Ogam", "ogham pismo" },
@@ -81,6 +82,7 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "Tagb", "tagbanva pismo" },
             { "Zsye", "emoji sli\u010dice" },
             { "%%NJIVA", "Gnjiva/Njiva dijalekt" },
+            { "ccp", "\u010dakma" },
             { "egy", "staroegipatski" },
             { "raj", "rajastani" },
             { "Phag", "phags-pa pismo" },
@@ -98,6 +100,7 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "AG", "Antigva i Barbuda" },
             { "type.ca.ethiopic", "etiopski kalendar" },
             { "AI", "Angvila" },
+            { "key.tz", "Vremenska zona" },
             { "AL", "Albanija" },
             { "AM", "Armenija" },
             { "Teng", "tengvar pismo" },
@@ -207,7 +210,7 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "chm", "mari" },
             { "chp", "\u010dipvijanski" },
             { "cho", "\u010doktav" },
-            { "chr", "\u010diroki" },
+            { "chr", metaValue_chr },
             { "ER", "Eritreja" },
             { "ES", "\u0160panija" },
             { "ET", "Etiopija" },
@@ -223,6 +226,7 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "FJ", "Fid\u017ei" },
             { "FK", "Folklandska ostrva" },
             { "FM", "Mikronezija" },
+            { "key.va", "Varijanta zemlje/jezika" },
             { "FO", "Farska ostrva" },
             { "Taml", "tamilsko pismo" },
             { "FR", "Francuska" },
@@ -233,7 +237,7 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "grc", "starogr\u010dki" },
             { "GA", "Gabon" },
             { "vot", "votski" },
-            { "GB", "Velika Britanija" },
+            { "GB", "Ujedinjeno Kraljevstvo" },
             { "pcm", "nigerijski pid\u017ein" },
             { "GD", "Grenada" },
             { "GE", "Gruzija" },
@@ -301,7 +305,7 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "tog", "njasa tonga" },
             { "type.nu.knda", "brojevi pisma kanada" },
             { "Kali", "kajah li pismo" },
-            { "de_CH", "gornjonjema\u010dki (\u0160vicarska)" },
+            { "de_CH", "visoki njema\u010dki (\u0160vicarska)" },
             { "type.ca.buddhist", "budisti\u010dki kalendar" },
             { "KE", "Kenija" },
             { "419", "Latinska Amerika" },
@@ -484,7 +488,7 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "SX", "Sint Marten" },
             { "SY", "Sirija" },
             { "yao", "jao" },
-            { "SZ", "Svazilend" },
+            { "SZ", "Esvatini" },
             { "arw", "aravak" },
             { "yap", "jape\u0161ki" },
             { "TA", "Tristan da Cunha" },
@@ -528,7 +532,7 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "Sinh", "pismo sinhala" },
             { "UM", "Ameri\u010dka Vanjska Ostrva" },
             { "UN", "Ujedinjene Nacije" },
-            { "US", "Sjedinjene Ameri\u010dke Dr\u017eave" },
+            { "US", "Sjedinjene Dr\u017eave" },
             { "haw", "havajski" },
             { "type.co.gb2312han", "Pojednostavljeno kinesko sortiranje" },
             { "UY", "Urugvaj" },
@@ -560,7 +564,9 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "WS", "Samoa" },
             { "wal", "valamo" },
             { "was", "va\u0161o" },
+            { "XA", "Pseudo naglasci" },
             { "war", "varej" },
+            { "XB", "Pseudo bidi" },
             { "awa", "avadhi" },
             { "061", "Polinezija" },
             { "XK", "Kosovo" },
@@ -882,7 +888,7 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "type.nu.armn", "armenski brojevi" },
             { "om", "oromo" },
             { "kaw", "kavi" },
-            { "or", "orijski" },
+            { "or", "odija" },
             { "os", "osetski" },
             { "kbd", "kabardijski" },
             { "mfe", "mauricijski kreolski" },
@@ -1102,13 +1108,14 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "mus", "kri\u0161ki" },
             { "Glag", "glagoljica" },
             { "gil", "gilbertski" },
-            { "Cher", "\u010deroki" },
+            { "Cher", metaValue_chr },
             { "car", "karipski" },
             { "cay", "kajuga" },
             { "type.nu.tamldec", "tamilski brojevi" },
             { "krc", "kara\u010daj-balkar" },
             { "inh", "ingu\u0161etski" },
             { "kri", "krio" },
+            { "fa_AF", "dari" },
             { "krl", "karelijski" },
             { "efi", "efik" },
             { "key.nu", "Brojevi" },
