@@ -279,7 +279,7 @@ public class LocaleNames_ckb extends OpenListResourceBundle {
             { "fj", metaValue_FJ },
             { "FJ", metaValue_FJ },
             { "fon", "\u0641\u06c6\u0646\u06cc" },
-            { "FK", "\u062f\u0648\u0648\u0631\u06af\u06d5\u06a9\u0627\u0646\u06cc \u0645\u0627\u0644\u06a4\u06cc\u0646\u0627\u0633" },
+            { "FK", "\u062f\u0648\u0648\u0631\u06af\u06d5\u06a9\u0627\u0646\u06cc \u0645\u0627\u0644\u06a4\u06cc\u0646\u0627\u0633 (\u062f\u0648\u0648\u0631\u06af\u06d5\u06a9\u0627\u0646\u06cc \u0641\u0627\u06b5\u06a9\u0644\u0627\u0646\u062f)" },
             { "FM", "\u0645\u0627\u06cc\u06a9\u0631\u06c6\u0646\u06cc\u0632\u06cc\u0627" },
             { "yue", "\u06a9\u0627\u0646\u062a\u06c6\u0646\u06cc" },
             { "FO", "\u062f\u0648\u0648\u0631\u06af\u06d5\u06a9\u0627\u0646\u06cc \u0641\u0627\u0631\u06d5\u0648" },
@@ -336,7 +336,7 @@ public class LocaleNames_ckb extends OpenListResourceBundle {
             { "HT", "\u06be\u0627\u06cc\u062a\u06cc" },
             { "ht", "\u06a9\u0631\u06cc\u0648\u0644\u06cc \u0647\u0627\u0626\u06cc\u062a\u06cc" },
             { "HU", "\u0647\u06d5\u0646\u06af\u0627\u0631\u06cc\u0627" },
-            { "hu", "\u0647\u06d5\u0646\u06af\u0627\u0631\u06cc (\u0645\u06d5\u062c\u0627\u0631\u06cc)" },
+            { "hu", "\u0647\u06d5\u0646\u06af\u0627\u0631\u06cc" },
             { "hy", metaValue_hy },
             { "hz", "\u0647\u06ce\u0631\u06ce\u0631\u06c6" },
             { "ia", "\u0626\u06cc\u0646\u062a\u0631\u0644\u06cc\u0646\u06af\u0648\u0648\u0627" },
@@ -385,7 +385,7 @@ public class LocaleNames_ckb extends OpenListResourceBundle {
             { "sms", "\u0633\u0627\u0645\u06cc\u06cc \u0633\u06a9\u06c6\u06b5\u062a" },
             { "KE", "\u06a9\u06cc\u0646\u06cc\u0627" },
             { "419", "\u0626\u06d5\u0645\u06d5\u0631\u06cc\u06a9\u0627\u06cc \u0644\u0627\u062a\u06cc\u0646" },
-            { "KG", "\u0642\u0631\u063a\u06cc\u0632\u0633\u062a\u0627\u0646" },
+            { "KG", "\u06a9\u0631\u06af\u06cc\u0632\u0633\u062a\u0627\u0646" },
             { "KH", "\u06a9\u06d5\u0645\u0628\u06c6\u062f\u06cc\u0627" },
             { "KI", "\u06a9\u06cc\u0631\u06cc\u0628\u0627\u0633" },
             { "ki", "\u06a9\u06cc\u06a9\u0648\u0648\u06cc\u0648\u0648" },
@@ -453,7 +453,7 @@ public class LocaleNames_ckb extends OpenListResourceBundle {
             { "mh", "\u0645\u0627\u0631\u0634\u0627\u06b5\u06cc" },
             { "ale", "\u0626\u0627\u0644\u06cc\u0648\u062a" },
             { "mi", "\u0645\u0627\u0626\u06c6\u0631\u06cc" },
-            { "MK", "\u0645\u0627\u06a9\u06d5\u062f\u06c6\u0646\u06cc\u0627" },
+            { "MK", "\u0645\u06d5\u06a9\u062f\u06c6\u0646\u06cc\u0627\u06cc \u0628\u0627\u06a9\u0648\u0648\u0631" },
             { "mk", "\u0645\u0627\u0643\u06ce\u062f\u06c6\u0646\u06cc" },
             { "ml", metaValue_ml },
             { "ML", "\u0645\u0627\u0644\u06cc" },
