@@ -74,7 +74,6 @@ public class LocaleNames_cy extends OpenListResourceBundle {
         final String metaValue_te = "Telugu";
         final Object[][] data = new Object[][] {
             { "ksh", "Cwleneg" },
-            { "Ogam", "Ogam" },
             { "mwl", "Mirandeg" },
             { "Zsym", "Symbolau" },
             { "cch", "Atsameg" },
@@ -111,7 +110,7 @@ public class LocaleNames_cy extends OpenListResourceBundle {
             { "AX", "Ynysoedd \u00c5land" },
             { "AZ", "Azerbaijan" },
             { "%%AREVELA", "Armeneg Dwyreiniol" },
-            { "BA", "Bosnia & Herzegovina" },
+            { "BA", "Bosnia a Herzegovina" },
             { "BB", "Barbados" },
             { "ceb", "Cebuano" },
             { "BD", "Bangladesh" },
@@ -290,7 +289,6 @@ public class LocaleNames_cy extends OpenListResourceBundle {
             { "JP", "Japan" },
             { "%%1606NICT", "Ffrangeg Canol Diweddar hyd at 1606" },
             { "ain", "Ain\u0175eg" },
-            { "%%KOCIEWIE", "KOCIEWIE" },
             { "guz", "Gusii" },
             { "type.nu.knda", "Digidau Kannaraidd" },
             { "de_CH", "Almaeneg Safonol y Swistir" },
@@ -317,7 +315,6 @@ public class LocaleNames_cy extends OpenListResourceBundle {
             { "LC", "Saint Lucia" },
             { "phn", "Phoeniceg" },
             { "gwi", "Gwich\u02bcin" },
-            { "%%LUNA1918", "LUNA1918" },
             { "nds", "Almaeneg Isel" },
             { "LI", "Liechtenstein" },
             { "LK", "Sri Lanka" },
@@ -333,7 +330,6 @@ public class LocaleNames_cy extends OpenListResourceBundle {
             { "lad", "Iddew-Sbaeneg" },
             { "vun", "Funjo" },
             { "akz", "Alabam\u00e4eg" },
-            { "%%LAUKIKA", "LAUKIKA" },
             { "lah", "Lahnda" },
             { "lag", "Langi" },
             { "Thaa", "Thaana" },
@@ -430,7 +426,6 @@ public class LocaleNames_cy extends OpenListResourceBundle {
             { "jbo", "Lojban" },
             { "pnt", "Ponteg" },
             { "009", "Oceania" },
-            { "%%SURSILV", "SURSILV" },
             { "RO", "Rwmania" },
             { "RS", "Serbia" },
             { "RU", "Rwsia" },
@@ -525,7 +520,7 @@ public class LocaleNames_cy extends OpenListResourceBundle {
             { "UY", "Uruguay" },
             { "prg", "Prwseg" },
             { "UZ", "Uzbekistan" },
-            { "tzm", "Tamaseit Canolbarth Moroco" },
+            { "tzm", "Tamazight Canol yr Atlas" },
             { "nnh", "Ngiemboon" },
             { "VA", "Y Fatican" },
             { "pro", "Hen Brofensaleg" },
@@ -564,7 +559,6 @@ public class LocaleNames_cy extends OpenListResourceBundle {
             { "nqo", "N\u2019Ko" },
             { "type.co.standard", "Trefn Safonol" },
             { "lmo", "Lombardeg" },
-            { "%%SUTSILV", "SUTSILV" },
             { "fat", "Ffanti" },
             { "YT", "Mayotte" },
             { "ZA", "De Affrica" },
@@ -609,7 +603,6 @@ public class LocaleNames_cy extends OpenListResourceBundle {
             { "Guru", "Gwrmwci" },
             { "%%ALUKU", "tafodiaith Aluku" },
             { "lua", "Luba-Lulua" },
-            { "%%BISCAYAN", "BISCAYAN" },
             { "sbp", "Sangw" },
             { "nyn", "Niancole" },
             { "nym", "Niamwezi" },
@@ -768,19 +761,17 @@ public class LocaleNames_cy extends OpenListResourceBundle {
             { "it", "Eidaleg" },
             { "iu", "Inwctitwt" },
             { "sli", "Is-silesieg" },
-            { "%%HOGNORSK", "HOGNORSK" },
             { "ja", "Japaneeg" },
             { "Mlym", "Malayalamaidd" },
             { "doi", "Dogri" },
             { "bkm", "Comeg" },
             { "sma", "Sami Deheuol" },
             { "jv", "Jafanaeg" },
-            { "%%BAUDDHA", "BAUDDHA" },
             { "mad", "Madwreg" },
             { "smj", "Sami Lwle" },
             { "mag", "Magahi" },
             { "mai", "Maithili" },
-            { "smn", "Sami Inari" },
+            { "smn", "Inari Sami" },
             { "ka", "Georgeg" },
             { "bla", "Siksika" },
             { "mak", "Macasareg" },
@@ -867,7 +858,6 @@ public class LocaleNames_cy extends OpenListResourceBundle {
             { "pl", "Pwyleg" },
             { "dum", "Iseldireg Canol" },
             { "type.ca.dangi", "Calendr Dangi" },
-            { "%%VALLADER", "VALLADER" },
             { "ps", "Pashto" },
             { "pt", "Portiwgeeg" },
             { "mga", "Gwyddeleg Canol" },
@@ -878,9 +868,7 @@ public class LocaleNames_cy extends OpenListResourceBundle {
             { "mgh", "Makhuwa-Meetto" },
             { "key.cf", "Fformat Arian" },
             { "key.ca", "Calendr" },
-            { "%%JAUER", "JAUER" },
             { "Laoo", "Laoaidd" },
-            { "%%SURMIRAN", "SURMIRAN" },
             { "mgo", "Meta" },
             { "type.hc.h23", "System 24 Awr (0\u201323)" },
             { "type.hc.h24", "System 24 Awr (1\u201324)" },
@@ -891,15 +879,13 @@ public class LocaleNames_cy extends OpenListResourceBundle {
             { "zap", "Zapoteceg" },
             { "brx", "Bodo" },
             { "kde", "Macondeg" },
-            { "%%VAIDIKA", "VAIDIKA" },
             { "stq", "Ffriseg Saterland" },
             { "Ethi", "Ethiopig" },
-            { "%%JYUTPING", "JYUTPING" },
             { "type.hc.h12", "System 12 Awr (1\u201312)" },
             { "type.hc.h11", "System 12 Awr (0\u201311)" },
             { "rm", "Rom\u00e1nsh" },
             { "rn", "Rwndi" },
-            { "key.cu", "Arian Breiniol" },
+            { "key.cu", "Math o Arian" },
             { "ro", "Rwmaneg" },
             { "type.nu.orya", "Digidau Or\u00efaidd" },
             { "type.nu.hanidec", "Rhifolion Degol Tsieineaidd" },
@@ -951,7 +937,7 @@ public class LocaleNames_cy extends OpenListResourceBundle {
             { "bug", "Bwginaeg" },
             { "kfo", "Koro" },
             { "en_CA", "Saesneg Canada" },
-            { "tk", "Twrcmeneg" },
+            { "tk", "Tyrcmeneg" },
             { "tl", "Tagalog" },
             { "tn", "Tswana" },
             { "to", "Tongeg" },
@@ -997,7 +983,6 @@ public class LocaleNames_cy extends OpenListResourceBundle {
             { "wo", "Woloff" },
             { "zgh", "Tamaseit Safonol" },
             { "ar_001", "Arabeg Modern Safonol" },
-            { "%%FONXSAMP", "FONXSAMP" },
             { "gay", "Gaio" },
             { "Mong", "Mongolaidd" },
             { "mnc", "Manshw" },
@@ -1023,7 +1008,7 @@ public class LocaleNames_cy extends OpenListResourceBundle {
             { "ota", "Tyrceg Otoman" },
             { "vai", "Faieg" },
             { "kln", "Kalenjin" },
-            { "zh", "Tsieineeg" },
+            { "zh", "Tsiein\u00ebeg" },
             { "Bopo", "Bopomofo" },
             { "key.lb", "Arddull Toriad Llinell" },
             { "zu", "Swlw" },
@@ -1034,14 +1019,13 @@ public class LocaleNames_cy extends OpenListResourceBundle {
             { "gez", "Geez" },
             { "mrj", "Mari Gorllewinol" },
             { "type.co.reformed", "Trefn Diwygiedig" },
-            { "%%ITIHASA", "ITIHASA" },
             { "ebu", "Embw" },
-            { "zh_Hans", "Tsieineeg Symledig" },
+            { "zh_Hans", "Tsiein\u00ebeg Symledig" },
             { "koi", "Komi-Permyak" },
             { "kok", "Concani" },
             { "%%1901", "orgraff draddodiadol yr Almaeneg" },
             { "vec", "Feniseg" },
-            { "zh_Hant", "Tsieineeg Traddodiadol" },
+            { "zh_Hant", "Tsiein\u00ebeg Traddodiadol" },
             { "vep", "Feps" },
             { "kpe", "Kpelle" },
             { "type.nu.khmr", "Digidau Chmeraidd" },
@@ -1058,6 +1042,7 @@ public class LocaleNames_cy extends OpenListResourceBundle {
             { "type.nu.tamldec", "Digidau Tamilaidd" },
             { "krc", "Karachay-Balkar" },
             { "inh", "Ingwsieg" },
+            { "fa_AF", "Dari" },
             { "krl", "Careleg" },
             { "efi", "Efik" },
             { "tcy", "Tulu" },
