@@ -117,6 +117,7 @@ public class LocaleNames_da extends OpenListResourceBundle {
             { "Tagb", "tagbanwa" },
             { "Zsye", "emoji" },
             { "%%NJIVA", "Gniva-/Nijva-dialekt" },
+            { "ccp", "chakma" },
             { "egy", "oldegyptisk" },
             { "raj", "rajasthani" },
             { "Phag", "phags-pa" },
@@ -334,7 +335,7 @@ public class LocaleNames_da extends OpenListResourceBundle {
             { "IM", "Isle of Man" },
             { "IN", "Indien" },
             { "type.co.eor", "europ\u00e6isk sorteringsr\u00e6kkef\u00f8lge" },
-            { "IO", "Det britiske territorium i Det Indiske Ocean" },
+            { "IO", "Det Britiske Territorium i Det Indiske Ocean" },
             { "IQ", "Irak" },
             { "IR", "Iran" },
             { "IS", "Island" },
@@ -384,7 +385,6 @@ public class LocaleNames_da extends OpenListResourceBundle {
             { "LC", "Saint Lucia" },
             { "Cyrs", "kyrillisk - oldkirkeslavisk variant" },
             { "gwi", "gwichin" },
-            { "%%LUNA1918", "LUNA1918" },
             { "nds", "nedertysk" },
             { "LI", "Liechtenstein" },
             { "LK", "Sri Lanka" },
@@ -467,7 +467,6 @@ public class LocaleNames_da extends OpenListResourceBundle {
             { "crh", "krim-tyrkisk" },
             { "ang", "oldengelsk" },
             { "OM", "Oman" },
-            { "%%PETR1708", "PETR1708" },
             { "anp", "angika" },
             { "crs", "seselwa (kreol-fransk)" },
             { "Xpeo", metaValue_peo },
@@ -572,7 +571,8 @@ public class LocaleNames_da extends OpenListResourceBundle {
             { "TC", "Turks- og Caicos\u00f8erne" },
             { "yav", "yangben" },
             { "TD", "Tchad" },
-            { "TF", "De Franske Besiddelser i Det Sydlige Indiske Ocean" },
+            { "Qaag", "zawgyi" },
+            { "TF", "De Franske Besiddelser i Det Sydlige Indiske Ocean og Antarktis" },
             { "TG", "Togo" },
             { "TH", "Thailand" },
             { "TJ", "Tadsjikistan" },
@@ -649,7 +649,9 @@ public class LocaleNames_da extends OpenListResourceBundle {
             { "type.nu.mtei", "Meetei Mayek-tal" },
             { "wal", "walamo" },
             { "was", "washo" },
+            { "XA", "pseudo-accenter" },
             { "war", "waray" },
+            { "XB", "pseudo-bidi" },
             { "awa", "awadhi" },
             { "061", "Polynesien" },
             { "%%KSCOR", "standardortografi" },
@@ -753,6 +755,7 @@ public class LocaleNames_da extends OpenListResourceBundle {
             { "scn", "siciliansk" },
             { "aa", "afar" },
             { "ab", "abkhasisk" },
+            { "Aran", "nastaliq" },
             { "ae", "avestan" },
             { "af", "afrikaans" },
             { "ak", "akan" },
@@ -761,7 +764,6 @@ public class LocaleNames_da extends OpenListResourceBundle {
             { "am", "amharisk" },
             { "Arab", metaValue_ar },
             { "an", "aragonesisk" },
-            { "%%SOLBA", "SOLBA" },
             { "Jpan", metaValue_ja },
             { "ar", metaValue_ar },
             { "Hrkt", "japanske skrifttegn" },
@@ -896,7 +898,6 @@ public class LocaleNames_da extends OpenListResourceBundle {
             { "ig", "igbo" },
             { "ii", "sichuan yi" },
             { "frm", "middelfransk" },
-            { "%%RUMGR", "RUMGR" },
             { "ik", "inupiaq" },
             { "fro", "oldfransk" },
             { "io", "ido" },
@@ -1257,7 +1258,6 @@ public class LocaleNames_da extends OpenListResourceBundle {
             { "mua", "mundang" },
             { "type.nu.guru", "gurmukhi tal" },
             { "mul", "flere sprog" },
-            { "%%PUTER", "PUTER" },
             { "cad", "caddo" },
             { "key.ms", "m\u00e5lesystem" },
             { "mus", "creek" },
@@ -1270,6 +1270,7 @@ public class LocaleNames_da extends OpenListResourceBundle {
             { "type.nu.tamldec", "tamilske tal" },
             { "krc", "karatjai-balkar" },
             { "inh", "ingush" },
+            { "fa_AF", "dari" },
             { "krl", "karelsk" },
             { "efi", "efik" },
             { "key.nu", "tal" },
