@@ -112,6 +112,7 @@ public class LocaleNames_es extends OpenListResourceBundle {
             { "mwr", "marwari" },
             { "Tagb", "tagban\u00faa" },
             { "Zsye", "emojis" },
+            { "ccp", "chakma" },
             { "egy", "egipcio antiguo" },
             { "raj", "rajasthani" },
             { "Phag", "phags-pa" },
@@ -129,7 +130,7 @@ public class LocaleNames_es extends OpenListResourceBundle {
             { "AG", "Antigua y Barbuda" },
             { "type.ca.ethiopic", "calendario et\u00edope" },
             { "AI", "Anguila" },
-            { "key.tz", "Zona horaria" },
+            { "key.tz", "zona horaria" },
             { "AL", "Albania" },
             { "AM", "Armenia" },
             { "Teng", "tengwar" },
@@ -254,7 +255,7 @@ public class LocaleNames_es extends OpenListResourceBundle {
             { "FJ", "Fiyi" },
             { "FK", "Islas Malvinas" },
             { "FM", "Micronesia" },
-            { "key.va", "Variante local" },
+            { "key.va", "variante local" },
             { "FO", "Islas Feroe" },
             { "Taml", metaValue_ta },
             { "FR", "Francia" },
@@ -531,6 +532,7 @@ public class LocaleNames_es extends OpenListResourceBundle {
             { "TC", "Islas Turcas y Caicos" },
             { "yav", "yangben" },
             { "TD", "Chad" },
+            { "Qaag", "zawgyi" },
             { "TF", "Territorios Australes Franceses" },
             { "TG", "Togo" },
             { "TH", "Tailandia" },
@@ -600,7 +602,9 @@ public class LocaleNames_es extends OpenListResourceBundle {
             { "WS", "Samoa" },
             { "wal", "wolayta" },
             { "was", "washo" },
+            { "XA", "Pseudoacentos" },
             { "war", "waray" },
+            { "XB", "Pseudobidi" },
             { "awa", "avadhi" },
             { "061", "Polinesia" },
             { "XK", "Kosovo" },
@@ -691,6 +695,7 @@ public class LocaleNames_es extends OpenListResourceBundle {
             { "scn", "siciliano" },
             { "aa", "afar" },
             { "ab", "abjasio" },
+            { "Aran", "nastaliq" },
             { "ae", metaValue_ae },
             { "af", "afrik\u00e1ans" },
             { "ak", "akan" },
@@ -934,7 +939,7 @@ public class LocaleNames_es extends OpenListResourceBundle {
             { "kbd", "kabardiano" },
             { "mfe", "criollo mauriciano" },
             { "srn", "sranan tongo" },
-            { "pa", "panyab\u00ed" },
+            { "pa", "punyab\u00ed" },
             { "dua", "duala" },
             { "srr", "serer" },
             { "kbl", "kanembu" },
@@ -1155,6 +1160,7 @@ public class LocaleNames_es extends OpenListResourceBundle {
             { "type.nu.tamldec", "d\u00edgitos en tamil" },
             { "krc", "karachay-balkar" },
             { "inh", "ingush" },
+            { "fa_AF", "dar\u00ed" },
             { "krl", "carelio" },
             { "efi", "efik" },
             { "key.nu", "n\u00fameros" },
