@@ -99,6 +99,7 @@ public class LocaleNames_et extends OpenListResourceBundle {
         final String metaValue_ban = "bali";
         final String metaValue_bbc = "bataki";
         final String metaValue_bug = "bugi";
+        final String metaValue_ccp = "t\u0161aakma";
         final String metaValue_chr = "t\u0161erokii";
         final String metaValue_cop = "kopti";
         final String metaValue_gez = "etioopia";
@@ -130,7 +131,7 @@ public class LocaleNames_et extends OpenListResourceBundle {
             { "Zsye", "emoji" },
             { "%%NJIVA", "Gniva/Njiva murre" },
             { "xmf", "megreli" },
-            { "ccp", "Chakma" },
+            { "ccp", metaValue_ccp },
             { "egy", "egiptuse" },
             { "raj", "rad\u017eastani" },
             { "Phag", "phakpa" },
@@ -293,7 +294,6 @@ public class LocaleNames_et extends OpenListResourceBundle {
             { "pcd", "pikardi" },
             { "tkl", "tokelau" },
             { "grb", "grebo" },
-            { "root", "root" },
             { "type.ca.indian", "India rahvuslik kalender" },
             { "rgn", "romanja" },
             { "grc", "vanakreeka" },
@@ -663,7 +663,7 @@ public class LocaleNames_et extends OpenListResourceBundle {
             { "Sinh", metaValue_si },
             { "UM", "\u00dchendriikide hajasaared" },
             { "liv", "liivi" },
-            { "UN", "\u00dchendatud Rahvaste Organisatsioon" },
+            { "UN", "\u00dchinenud Rahvaste Organisatsioon" },
             { "US", "Ameerika \u00dchendriigid" },
             { "haw", "havai" },
             { "%%1959ACAD", "akadeemiline" },
@@ -698,7 +698,7 @@ public class LocaleNames_et extends OpenListResourceBundle {
             { "type.nu.finance", "finantsnumbrid" },
             { "%%HEPBURN", "Hepburni latinisatsioon" },
             { "type.co.compat", "varasem sortimisj\u00e4rjestus (\u00fchilduvuse jaoks)" },
-            { "wae", "walseri" },
+            { "wae", "valsi" },
             { "WS", "Samoa" },
             { "Bass", "bassa" },
             { "type.nu.mtei", "meitei numbrid" },
@@ -739,7 +739,7 @@ public class LocaleNames_et extends OpenListResourceBundle {
             { "ZM", "Sambia" },
             { "%%PINYIN", "pinyin" },
             { "ZW", "Zimbabwe" },
-            { "ZZ", "Tundmatu piirkond" },
+            { "ZZ", "tundmatu piirkond" },
             { "Runr", "ruunikiri" },
             { "type.ms.metric", "meeterm\u00f5\u00f5dustik" },
             { "type.ca.iso8601", "ISO-8601 kalender" },
@@ -792,7 +792,7 @@ public class LocaleNames_et extends OpenListResourceBundle {
             { "type.d0.fwidth", "t\u00e4islaius" },
             { "sbp", "sangu" },
             { "lui", "luisenjo" },
-            { "nyn", "nkole" },
+            { "nyn", "njankole" },
             { "nym", "njamvesi" },
             { "lun", "lunda" },
             { "nyo", "njoro" },
@@ -969,7 +969,7 @@ public class LocaleNames_et extends OpenListResourceBundle {
             { "type.nu.tibt", "tiibeti numbrid" },
             { "ie", "interlingue" },
             { "ig", "ibo" },
-            { "ii", "Sichuani jii" },
+            { "ii", "nuosu" },
             { "frm", "keskprantsuse" },
             { "ik", "injupiaki" },
             { "fro", "vanaprantsuse" },
@@ -1040,7 +1040,7 @@ public class LocaleNames_et extends OpenListResourceBundle {
             { "type.ms.uksystem", "inglise m\u00f5\u00f5dustik" },
             { "type.nu.lana", "tai tham hora numbrid" },
             { "lt", "leedu" },
-            { "lu", "luba" },
+            { "lu", "Katanga luba" },
             { "lv", "l\u00e4ti" },
             { "sog", "sogdi" },
             { "mg", "malagassi" },
@@ -1203,9 +1203,9 @@ public class LocaleNames_et extends OpenListResourceBundle {
             { "dyo", "fonji" },
             { "type.nu.jpan", "jaapani numbrid" },
             { "tr", "t\u00fcrgi" },
+            { "Cakm", metaValue_ccp },
             { "ts", "tsonga" },
             { "swb", "komoori" },
-            { "Cakm", "t\u0161aakma" },
             { "tt", "tatari" },
             { "dyu", "djula" },
             { "tw", "tvii" },
@@ -1248,7 +1248,6 @@ public class LocaleNames_et extends OpenListResourceBundle {
             { "quc", "kit\u0161e" },
             { "type.nu.gonm", "masaram gondi numbrid" },
             { "Newa", metaValue_new },
-            { "gaa", "gaa" },
             { "wa", "vallooni" },
             { "gag", "gagauusi" },
             { "syr", metaValue_syr },
@@ -1361,6 +1360,7 @@ public class LocaleNames_et extends OpenListResourceBundle {
             { "inh", "ingu\u0161i" },
             { "krj", "kinaraia" },
             { "kri", "krio" },
+            { "fa_AF", "dari" },
             { "krl", "karjala" },
             { "efi", "efiki" },
             { "tcy", "tulu" },
