@@ -76,6 +76,7 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "mwl", "mirandera" },
             { "Zsym", "ikurrak" },
             { "Zsye", "emotikonoa" },
+            { "ccp", "chakmera" },
             { "tem", "temnea" },
             { "teo", "tesoera" },
             { "rap", "rapa nui" },
@@ -222,7 +223,7 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "GW", "Ginea Bissau" },
             { "tlh", "klingonera" },
             { "GY", "Guyana" },
-            { "ckb", "sorania" },
+            { "ckb", "erdialdeko kurduera" },
             { "zxx", "ez dago eduki linguistikorik" },
             { "de_AT", "Austriako aleman" },
             { "HK", "Hong Kong Txinako AEB" },
@@ -283,6 +284,7 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "LB", "Libano" },
             { "LC", "Santa Luzia" },
             { "gwi", "gwich\u02bcin" },
+            { "nds", "behe-aleman" },
             { "LI", "Liechtenstein" },
             { "LK", "Sri Lanka" },
             { "LR", "Liberia" },
@@ -341,7 +343,7 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "NP", "Nepal" },
             { "NR", "Nauru" },
             { "NU", "Niue" },
-            { "rof", "romboera" },
+            { "rof", "rombo" },
             { "NZ", "Zeelanda Berria" },
             { "OM", "Oman" },
             { "anp", "angikera" },
@@ -418,11 +420,11 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "SY", "Siria" },
             { "SZ", "Swazilandia" },
             { "TA", "Tristan da Cunha" },
-            { "asa", "asua" },
+            { "asa", "asu" },
             { "type.ms.ussystem", "Neurketa-sistema anglosaxoia" },
             { "021", "Amerikako iparraldea" },
             { "TC", "Turk eta Caico uharteak" },
-            { "yav", "jangbenera" },
+            { "yav", "yangbenera" },
             { "TD", "Txad" },
             { "TF", "Hegoaldeko lurralde frantsesak" },
             { "TG", "Togo" },
@@ -474,7 +476,7 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "VN", "Vietnam" },
             { "VU", "Vanuatu" },
             { "nog", "nogaiera" },
-            { "rwk", "rwaera" },
+            { "rwk", "rwera" },
             { "053", "Australasia" },
             { "054", "Melanesia" },
             { "WF", "Wallis eta Futuna" },
@@ -486,7 +488,9 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "wae", "walserera" },
             { "WS", "Samoa" },
             { "wal", "welayta" },
+            { "XA", "Sasiazentuak" },
             { "war", "samerera" },
+            { "XB", "pseudobidia" },
             { "awa", "awadhiera" },
             { "061", "Polinesia" },
             { "XK", "Kosovo" },
@@ -509,7 +513,7 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "nso", "pediera" },
             { "type.nu.telu", "Digitu teluguarrak" },
             { "loz", "loziera" },
-            { "jmc", "machamera" },
+            { "jmc", "machame" },
             { "type.nu.hansfin", "Finantzetarako zenbaki txinatar sinplifikatuak" },
             { "hil", "hiligainon" },
             { "type.nu.arabext", "Digitu arabiar-hindiko hedatuak" },
@@ -574,7 +578,7 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "type.nu.laoo", "Digitu laostarrak" },
             { "seh", "senera" },
             { "ca", "katalan" },
-            { "ses", "koyraboro sennia" },
+            { "ses", "koyraboro senni" },
             { "ce", "txetxenera" },
             { "ch", "chamorrera" },
             { "%%REVISED", "BERRIKUSIA" },
@@ -610,7 +614,7 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "Hanb", "h\u00e4nera" },
             { "eu", "euskara" },
             { "Hang", "hangula" },
-            { "shi", "tachelhita" },
+            { "shi", "tachelhit" },
             { "hsb", "goi-sorabiera" },
             { "Hani", "idazkera txinatarra" },
             { "shn", "shanera" },
@@ -628,7 +632,7 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "umb", "umbundu" },
             { "fr", "frantses" },
             { "fy", "frisiera" },
-            { "ga", "gaeliko" },
+            { "ga", "irlandera" },
             { "gd", "Eskoziako gaeliko" },
             { "gl", "galiziera" },
             { "gn", "guaraniera" },
@@ -698,7 +702,7 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "lo", "laosera" },
             { "type.ms.uksystem", "Neurketa-sistema inperiala" },
             { "lt", "lituaniera" },
-            { "lu", "luba-katangera" },
+            { "lu", "Katangako lubera" },
             { "lv", "letoniera" },
             { "mg", "malgaxe" },
             { "mh", "marshallera" },
@@ -754,14 +758,14 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "key.cf", "Moneta-formatua" },
             { "key.ca", "Egutegia" },
             { "Laoo", "laosarra" },
-            { "mgo", "metera" },
+            { "mgo", "meta\u02bcera" },
             { "type.hc.h23", "24 orduko sistema (0\u201323)" },
             { "type.hc.h24", "24 orduko sistema (1\u201324)" },
             { "ssy", "sahoa" },
             { "type.nu.mymr", "Digitu birmaniarrak" },
             { "qu", "kitxua" },
             { "brx", "bodoera" },
-            { "kde", "makondera" },
+            { "kde", "makondeera" },
             { "Ethi", "etiopiarra" },
             { "type.hc.h12", "12 orduko sistema (1\u201312)" },
             { "type.hc.h11", "12 orduko sistema (0\u201311)" },
@@ -844,14 +848,14 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "ve", "vendera" },
             { "type.ca.roc", "Minguo egutegia" },
             { "vi", "vietnamera" },
-            { "khq", "koyra chiiniera" },
+            { "khq", "koyra chiini" },
             { "key.hc", "Ordu-zikloa (12 vs 24)" },
             { "vo", "volap\u00fck" },
             { "quc", "quicheera" },
             { "gaa", "ga" },
             { "wa", "waloiera" },
             { "gag", "gagauzera" },
-            { "syr", "siriera" },
+            { "syr", "asiriera" },
             { "Grek", "grekoa" },
             { "wo", "wolofera" },
             { "zgh", "amazigera estandarra" },
@@ -865,7 +869,7 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "type.nu.romanlow", "Zenbaki erromatarrak minuskulaz" },
             { "byn", "bilena" },
             { "moh", "mohawkera" },
-            { "kkj", "kakoa" },
+            { "kkj", "kako" },
             { "yi", "yiddish" },
             { "mos", "moreera" },
             { "yo", "jorubera" },
@@ -889,7 +893,7 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "kok", "konkanera" },
             { "zh_Hant", "txinera tradizionala" },
             { "kpe", "kpellea" },
-            { "type.nu.khmr", "Digitu khmerarrak" },
+            { "type.nu.khmr", "Digitu khemerarrak" },
             { "ilo", "ilokanera" },
             { "%%VALENCIA", "VALENTZIERA" },
             { "mua", "mudangera" },
@@ -901,6 +905,7 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "type.nu.tamldec", "Digitu tamilarrak" },
             { "krc", "karachayera-balkarera" },
             { "inh", "ingushera" },
+            { "fa_AF", "daria" },
             { "krl", "kareliera" },
             { "efi", "efikera" },
             { "key.nu", "Zenbakiak" },
