@@ -658,7 +658,7 @@ public class LocaleNames_fil extends OpenListResourceBundle {
             { "type.co.big5han", "Pagkakasunod-sunod ng Pag-uuri ng Tradisyunal na Chinese - Big5" },
             { "es", "Spanish" },
             { "et", "Estonian" },
-            { "Hanb", "Hanb" },
+            { "Hanb", "Han na may Bopomofo" },
             { "eu", "Basque" },
             { "Hang", "Hangul" },
             { "shi", "Tachelhit" },
@@ -961,6 +961,7 @@ public class LocaleNames_fil extends OpenListResourceBundle {
             { "type.nu.tamldec", "Mga Tamil na Digit" },
             { "krc", "Karachay-Balkar" },
             { "inh", "Ingush" },
+            { "fa_AF", "Dari" },
             { "krl", "Karelian" },
             { "efi", "Efik" },
             { "key.nu", "Mga Numero" },
