@@ -135,7 +135,7 @@ public class LocaleNames_fr extends OpenListResourceBundle {
             { "type.ca.ethiopic", "calendrier \u00e9thiopien" },
             { "glk", "gilaki" },
             { "AI", "Anguilla" },
-            { "key.tz", "Fuseau horaire" },
+            { "key.tz", "fuseau horaire" },
             { "AL", "Albanie" },
             { "AM", "Arm\u00e9nie" },
             { "Teng", "tengwar" },
@@ -266,7 +266,7 @@ public class LocaleNames_fr extends OpenListResourceBundle {
             { "FJ", "Fidji" },
             { "FK", "\u00celes Malouines" },
             { "FM", "\u00c9tats f\u00e9d\u00e9r\u00e9s de Micron\u00e9sie" },
-            { "key.va", "Variante locale" },
+            { "key.va", "variante locale" },
             { "FO", "\u00celes F\u00e9ro\u00e9" },
             { "Taml", metaValue_ta },
             { "FR", "France" },
@@ -583,6 +583,7 @@ public class LocaleNames_fr extends OpenListResourceBundle {
             { "TC", "\u00celes Turques-et-Ca\u00efques" },
             { "yav", "yangben" },
             { "TD", "Tchad" },
+            { "Qaag", "zawgyi" },
             { "TF", "Terres australes fran\u00e7aises" },
             { "ase", "langue des signes am\u00e9ricaine" },
             { "TG", "Togo" },
@@ -763,6 +764,7 @@ public class LocaleNames_fr extends OpenListResourceBundle {
             { "scn", "sicilien" },
             { "aa", "afar" },
             { "ab", "abkhaze" },
+            { "Aran", "nastaliq" },
             { "bbc", "batak toba" },
             { "ae", metaValue_ae },
             { "af", "afrikaans" },
@@ -1277,6 +1279,7 @@ public class LocaleNames_fr extends OpenListResourceBundle {
             { "inh", "ingouche" },
             { "krj", "kinaray-a" },
             { "kri", "krio" },
+            { "fa_AF", "dari" },
             { "krl", "car\u00e9lien" },
             { "efi", "\u00e9fik" },
             { "tcy", "toulou" },
