@@ -322,7 +322,7 @@ public class LocaleNames_ga extends OpenListResourceBundle {
             { "SV", "an tSalvad\u00f3ir" },
             { "SX", "Sint Maarten" },
             { "SY", "an tSiria" },
-            { "SZ", "an tSuasalainn" },
+            { "SZ", "eSuait\u00edn\u00ed" },
             { "TA", "Tristan da Cunha" },
             { "TC", "Oile\u00e1in na dTurcach agus Caicos" },
             { "TD", "Sead" },
@@ -343,7 +343,7 @@ public class LocaleNames_ga extends OpenListResourceBundle {
             { "UA", "an \u00dacr\u00e1in" },
             { "UG", "Uganda" },
             { "UM", "Oile\u00e1in Imeallacha S.A.M." },
-            { "UN", "na N\u00e1isi\u00fain Aontaiteh" },
+            { "UN", "na N\u00e1isi\u00fain Aontaithe" },
             { "US", "St\u00e1it Aontaithe Mheirice\u00e1" },
             { "UY", "Uragua" },
             { "UZ", "an \u00daisb\u00e9iceast\u00e1in" },
@@ -356,8 +356,8 @@ public class LocaleNames_ga extends OpenListResourceBundle {
             { "VU", "Vanuat\u00fa" },
             { "WF", "Vail\u00eds agus Fut\u00fana" },
             { "WS", "Sam\u00f3" },
-            { "XA", "XA" },
-            { "XB", "XB" },
+            { "XA", "Br\u00e9agdhiaicritic\u00ed" },
+            { "XB", "Br\u00e9ag-Bidi" },
             { "XK", "an Chosaiv" },
             { "YE", "\u00c9imin" },
             { "YT", "Mayotte" },
@@ -381,7 +381,7 @@ public class LocaleNames_ga extends OpenListResourceBundle {
             { "be", "Bealar\u00faisis" },
             { "bg", "Bulg\u00e1iris" },
             { "bi", "Bioslaimis" },
-            { "bm", "bm" },
+            { "bm", "Bambairis" },
             { "bn", "Beang\u00e1ilis" },
             { "bo", "Tib\u00e9idis" },
             { "br", "Briot\u00e1inis" },
@@ -399,7 +399,7 @@ public class LocaleNames_ga extends OpenListResourceBundle {
             { "de", "Gearm\u00e1inis" },
             { "dv", "Div\u00e9ihis" },
             { "dz", "Seoinicis" },
-            { "ee", "ee" },
+            { "ee", "\u00c9abhais" },
             { "el", "Gr\u00e9igis" },
             { "en", "B\u00e9arla" },
             { "eo", "Esperanto" },
@@ -432,7 +432,6 @@ public class LocaleNames_ga extends OpenListResourceBundle {
             { "id", "Indin\u00e9isis" },
             { "ie", "Interlingue" },
             { "ig", "\u00cdogb\u00f3is" },
-            { "ii", "ii" },
             { "ik", "Ini\u00faipiaicis" },
             { "io", "Ido" },
             { "is", "\u00cdoslainnis" },
@@ -549,80 +548,48 @@ public class LocaleNames_ga extends OpenListResourceBundle {
             { "za", "Siu\u00e1ingis" },
             { "zh", "S\u00ednis" },
             { "zu", "S\u00fal\u00fais" },
-            { "ace", "ace" },
-            { "ada", "ada" },
             { "ady", "Adaig\u00e9is" },
-            { "agq", "agq" },
             { "ain", "Aidhni\u00fais" },
             { "akk", "Ac\u00e1idis" },
-            { "ale", "ale" },
-            { "alt", "alt" },
             { "ang", "Sean-Bh\u00e9arla" },
-            { "anp", "anp" },
             { "arc", "Aramais" },
             { "arn", "Map\u00faitsis" },
-            { "arp", "arp" },
-            { "asa", "asa" },
             { "ast", "Ast\u00fairis" },
-            { "awa", "awa" },
             { "ban", "Bail\u00eds" },
             { "bar", "Bav\u00e1iris" },
-            { "bas", "bas" },
             { "bem", "Beimbis" },
-            { "bez", "bez" },
-            { "bho", "bho" },
-            { "bin", "bin" },
-            { "bla", "bla" },
-            { "brx", "brx" },
             { "bua", "Buiri\u00e1itis" },
             { "bug", "Buiginis" },
-            { "byn", "byn" },
-            { "ccp", "ccp" },
+            { "ccp", "Chakma" },
             { "ceb", "Seab\u00fa\u00e1inis" },
-            { "cgg", "cgg" },
-            { "chk", "chk" },
             { "chm", "Mairis" },
-            { "cho", "cho" },
             { "chr", "Seiricis" },
-            { "chy", "chy" },
             { "ckb", "Coirdis L\u00e1rnach" },
             { "cop", "Coptais" },
             { "crs", "Cri\u00f3l Fraincise Seselwa" },
             { "csb", "Caisi\u00faibis" },
-            { "dak", "dak" },
-            { "dar", "dar" },
             { "dav", "Taita" },
-            { "dgr", "dgr" },
             { "dje", "Zarmais" },
             { "dsb", "Sorbais \u00cdochtarach" },
-            { "dua", "dua" },
+            { "dua", "Duailis" },
             { "dum", "Me\u00e1n-Ollainnis" },
-            { "dyo", "dyo" },
-            { "dzg", "dzg" },
-            { "ebu", "ebu" },
-            { "efi", "efi" },
             { "egy", "Sean-\u00c9igiptis" },
-            { "eka", "eka" },
             { "enm", "Me\u00e1n-Bh\u00e9arla" },
-            { "ewo", "ewo" },
+            { "ewo", "\u00c9abhand\u00f3is" },
             { "fil", "Filip\u00ednis" },
             { "fon", "fon" },
             { "frm", "Me\u00e1n-Fhraincis" },
             { "fro", "Sean-Fhraincis" },
             { "frr", "Freaslainnis an Tuaiscirt" },
             { "fur", "Fri\u00failis" },
-            { "gaa", "gaa" },
             { "gan", "S\u00ednis Gan" },
             { "gez", "Aet\u00f3ipis" },
             { "gil", "Cireabaitis" },
             { "gmh", "Me\u00e1n-Ard-Ghearm\u00e1inis" },
             { "goh", "Sean-Ard-Ghearm\u00e1inis" },
-            { "gor", "gor" },
             { "grc", "Sean-Ghr\u00e9igis" },
             { "gsw", "Gearm\u00e1inis Eilv\u00e9iseach" },
             { "guc", "Ua\u00fais" },
-            { "guz", "guz" },
-            { "gwi", "gwi" },
             { "hak", "Haic\u00e9is" },
             { "haw", "Hav\u00e1is" },
             { "hif", "Hiond\u00fais Fhids\u00ed" },
@@ -632,168 +599,102 @@ public class LocaleNames_ga extends OpenListResourceBundle {
             { "hsb", "Sorbais Uachtarach" },
             { "hsn", "S\u00ednis Xiang" },
             { "hup", "H\u00faipis" },
-            { "iba", "iba" },
             { "ibb", "Ibibis" },
-            { "ilo", "ilo" },
             { "inh", "Iong\u00fais" },
             { "jbo", "Lojban" },
-            { "jgo", "jgo" },
-            { "jmc", "jmc" },
+            { "jgo", "Ngomba" },
+            { "jmc", "Machame" },
             { "jut", "I\u00fatlainnis" },
             { "kaa", "Cara-Chalp\u00e1is" },
-            { "kab", "kab" },
-            { "kac", "kac" },
-            { "kaj", "kaj" },
-            { "kam", "kam" },
-            { "kbd", "kbd" },
-            { "kcg", "kcg" },
-            { "kde", "kde" },
+            { "kab", "Caib\u00edlis" },
+            { "kam", "Cambais" },
+            { "kde", "Makonde" },
             { "kea", "Kabuverdianu" },
-            { "kfo", "kfo" },
-            { "kha", "kha" },
-            { "khq", "khq" },
-            { "kkj", "kkj" },
-            { "kln", "kln" },
-            { "kmb", "kmb" },
+            { "khq", "Koyra Chiini" },
+            { "kkj", "Kako" },
+            { "kln", "Kalenjin" },
             { "kok", "Conc\u00e1inis" },
-            { "kpe", "kpe" },
-            { "krc", "krc" },
             { "krl", "Cair\u00e9ilis" },
             { "kru", "Cur\u00faicis" },
-            { "ksb", "ksb" },
-            { "ksf", "ksf" },
-            { "ksh", "ksh" },
-            { "kum", "kum" },
             { "lad", "Laid\u00ednis" },
-            { "lag", "lag" },
+            { "lag", "Langi" },
             { "lah", "Puinse\u00e1ibis Iartharach" },
-            { "lez", "lez" },
             { "lij", "Liog\u00fairis" },
             { "liv", "Liov\u00f3inis" },
-            { "lkt", "lkt" },
+            { "lkt", "Lakota" },
             { "lmo", "Lombairdis" },
-            { "loz", "loz" },
-            { "lrc", "lrc" },
-            { "lua", "lua" },
-            { "lun", "lun" },
-            { "luo", "luo" },
-            { "lus", "lus" },
-            { "luy", "luy" },
-            { "mad", "mad" },
-            { "mag", "mag" },
-            { "mai", "mai" },
-            { "mak", "mak" },
-            { "mas", "mas" },
-            { "mdf", "mdf" },
+            { "lrc", "Luri Thuaidh" },
+            { "luo", "L\u00fa\u00f3is" },
+            { "luy", "Luyia" },
+            { "mai", "Maitilis" },
+            { "mas", "M\u00e1sais" },
             { "men", "Meindis" },
-            { "mer", "mer" },
-            { "mfe", "mfe" },
+            { "mer", "Meru" },
+            { "mfe", "Morisyen" },
             { "mga", "Me\u00e1n-Ghaeilge" },
-            { "mgh", "mgh" },
-            { "mgo", "mgo" },
-            { "mic", "mic" },
-            { "min", "min" },
+            { "mgh", "Makhuwa-Meetto" },
+            { "mgo", "Meta\u02bc" },
             { "mni", "Manap\u00fairis" },
             { "moh", "M\u00f3h\u00e1icis" },
-            { "mos", "mos" },
             { "mrj", "Mairis Iartharach" },
-            { "mua", "mua" },
+            { "mua", "Mundang" },
             { "mul", "Ilteangacha" },
-            { "mus", "mus" },
             { "mwl", "Mioraind\u00e9is" },
             { "mwr", "Marmhairis" },
-            { "myv", "myv" },
-            { "mzn", "mzn" },
+            { "mzn", "Mazanderani" },
             { "nan", "S\u00ednis Min Nan" },
             { "nap", "Nap\u00f3ilis" },
-            { "naq", "naq" },
+            { "naq", "Nama" },
             { "nds", "Gearm\u00e1inis \u00cdochtarach" },
-            { "new", "new" },
-            { "nia", "nia" },
             { "niu", "N\u00edobhais" },
-            { "nmg", "nmg" },
-            { "nnh", "nnh" },
-            { "nog", "nog" },
+            { "nmg", "Kwasio" },
+            { "nnh", "Ngiemboon" },
             { "non", "Sean-Lochlainnis" },
-            { "nqo", "nqo" },
             { "nso", "S\u00fat\u00fais an Tuaiscirt" },
-            { "nus", "nus" },
-            { "nyn", "nyn" },
-            { "pag", "pag" },
-            { "pam", "pam" },
-            { "pap", "pap" },
-            { "pau", "pau" },
-            { "pcm", "pcm" },
+            { "nus", "Nuer" },
+            { "nyn", "Nianc\u00f3ilis" },
             { "peo", "Sean-Pheirsis" },
             { "prg", "Pr\u00faisis" },
             { "quc", "Cuits\u00e9is" },
-            { "rap", "rap" },
-            { "rar", "rar" },
-            { "rof", "rof" },
             { "rom", "Romainis" },
             { "rup", "Ar\u00f3m\u00e1inis" },
-            { "rwk", "rwk" },
-            { "sad", "sad" },
             { "sah", "Sachais" },
             { "sam", "Aramais Sham\u00e1rach" },
-            { "saq", "saq" },
             { "sat", "Sant\u00e1ilis" },
-            { "sba", "sba" },
-            { "sbp", "sbp" },
             { "scn", "Sicilis" },
             { "sco", "Albainis" },
-            { "seh", "seh" },
-            { "ses", "ses" },
+            { "ses", "Koyraboro Senni" },
             { "sga", "Sean-Ghaeilge" },
             { "shi", "Tachelhit" },
-            { "shn", "shn" },
             { "sma", "S\u00e1imis Theas" },
             { "smj", "S\u00e1imis Lule" },
             { "smn", "S\u00e1imis Inari" },
             { "sms", "S\u00e1imis Skolt" },
-            { "snk", "snk" },
             { "sog", "Sogd\u00e1nais" },
-            { "srn", "srn" },
-            { "ssy", "ssy" },
-            { "suk", "suk" },
             { "sux", "Suim\u00e9iris" },
             { "swb", "Com\u00f3iris" },
             { "syr", "Siricis" },
             { "szl", "Sil\u00e9isis" },
-            { "tem", "tem" },
-            { "teo", "teo" },
-            { "tet", "tet" },
-            { "tig", "tig" },
+            { "teo", "Teso" },
             { "tlh", "Klingon" },
             { "tpi", "Tok Pisin" },
-            { "trv", "trv" },
-            { "tum", "tum" },
-            { "tvl", "tvl" },
-            { "twq", "twq" },
-            { "tyv", "tyv" },
+            { "twq", "Tasawaq" },
             { "tzm", "Tamazight Atlais L\u00e1ir" },
             { "udm", "Udmairtis" },
-            { "umb", "umb" },
             { "und", "Teanga Anaithnid" },
             { "vai", "vai" },
             { "vec", "Vein\u00e9isis" },
             { "vls", "Pl\u00e9imeannais Iartharach" },
-            { "vun", "vun" },
-            { "wae", "wae" },
-            { "wal", "wal" },
-            { "war", "war" },
-            { "wuu", "wuu" },
+            { "vun", "Vunjo" },
+            { "wae", "Walser" },
             { "xal", "Cailm\u00edcis" },
-            { "xog", "xog" },
-            { "yav", "yav" },
-            { "ybb", "ybb" },
+            { "yav", "Yangben" },
             { "yue", "Cantainis" },
             { "zea", "S\u00e9alainnis" },
             { "zgh", "Tamazight Caighde\u00e1nach Mharac\u00f3" },
             { "zun", "Z\u00fainis" },
             { "zxx", "Gan \u00e1bhar teangeola\u00edoch" },
-            { "zza", "zza" },
-            { "Adlm", "Adlm" },
+            { "Adlm", "Adlam" },
             { "Aghb", "Alb\u00e1nach Cugasach" },
             { "Ahom", "Ahom" },
             { "Arab", "Arabach" },
@@ -801,70 +702,50 @@ public class LocaleNames_ga extends OpenListResourceBundle {
             { "Armn", "Airm\u00e9anach" },
             { "Avst", "Aiv\u00e9isteach" },
             { "Bali", "Bail\u00edoch" },
-            { "Bamu", "Bamu" },
-            { "Bass", "Bass" },
             { "Batk", "Batacach" },
             { "Beng", "Beang\u00e1lach" },
-            { "Bhks", "Bhks" },
             { "Bopo", "Bopomofo" },
-            { "Brah", "Brah" },
             { "Brai", "Braille" },
             { "Bugi", "Buigineach" },
             { "Buhd", "Buthaideach" },
-            { "Cakm", "Cakm" },
-            { "Cans", "Cans" },
-            { "Cari", "Cari" },
-            { "Cham", "Cham" },
+            { "Cans", "Siollach Bund\u00fachasach Ceanadach Aontaithe" },
             { "Cher", "Seiric\u00edoch" },
             { "Copt", "Coptach" },
             { "Cprt", "Cipireach" },
             { "Cyrl", "Coireallach" },
             { "Deva", "D\u00e9ivean\u00e1grach" },
-            { "Dsrt", "Dsrt" },
-            { "Dupl", "Dupl" },
+            { "Dupl", "Gearrscr\u00edobh Duployan" },
             { "Egyd", "\u00c9igipteach coiteann" },
             { "Egyh", "\u00c9igipteach cliar\u00fail" },
             { "Egyp", "Iairiglif\u00ed \u00c9igipteacha" },
-            { "Elba", "Elba" },
             { "Ethi", "Aet\u00f3pach" },
             { "Geor", "Seoirseach" },
             { "Glag", "Glagalach" },
-            { "Gonm", "Gonm" },
             { "Goth", "Gotach" },
-            { "Gran", "Gran" },
             { "Grek", "Gr\u00e9agach" },
             { "Gujr", "G\u00faisear\u00e1tach" },
             { "Guru", "Gurm\u00facach" },
             { "Hanb", "Han agus Bopomofo" },
             { "Hang", "Hangalach" },
             { "Hani", "Han" },
-            { "Hano", "Hano" },
             { "Hans", "Simplithe" },
             { "Hant", "Traidisi\u00fanta" },
-            { "Hatr", "Hatr" },
             { "Hebr", "Eabhrach" },
             { "Hira", "Hireag\u00e1nach" },
             { "Hluw", "Iairiglif\u00ed Anat\u00f3lacha" },
-            { "Hmng", "Hmng" },
             { "Hrkt", "Siollabra\u00ed Seap\u00e1nacha" },
             { "Hung", "Sean-Ung\u00e1rach" },
             { "Ital", "Sean-Iod\u00e1ilic" },
             { "Jamo", "Seam\u00f3" },
             { "Java", "I\u00e1vach" },
             { "Jpan", "Seap\u00e1nach" },
-            { "Kali", "Kali" },
             { "Kana", "Catac\u00e1nach" },
-            { "Khar", "Khar" },
             { "Khmr", "Cim\u00e9arach" },
-            { "Khoj", "Khoj" },
             { "Knda", "Cannadach" },
             { "Kore", "C\u00f3ir\u00e9ach" },
-            { "Kthi", "Kthi" },
-            { "Lana", "Lana" },
             { "Laoo", "Laosach" },
             { "Latg", "Cl\u00f3 Gaelach" },
             { "Latn", "Laidineach" },
-            { "Lepc", "Lepc" },
             { "Limb", "Liomb\u00fach" },
             { "Lina", "L\u00edneach A" },
             { "Linb", "L\u00edneach B" },
@@ -872,77 +753,39 @@ public class LocaleNames_ga extends OpenListResourceBundle {
             { "Lyci", "Liciach" },
             { "Lydi", "Lidiach" },
             { "Mahj", "Mahas\u00e1nach" },
-            { "Mand", "Mand" },
             { "Mani", "Mainic\u00e9asach" },
-            { "Marc", "Marc" },
             { "Maya", "Iairiglif\u00ed M\u00e1igheacha" },
             { "Mend", "Meindeach" },
-            { "Merc", "Merc" },
-            { "Mero", "Mero" },
             { "Mlym", "Mail\u00e9alamach" },
-            { "Modi", "Modi" },
             { "Mong", "Mong\u00f3lach" },
-            { "Mroo", "Mroo" },
-            { "Mtei", "Mtei" },
-            { "Mult", "Mult" },
+            { "Mult", "Multani" },
             { "Mymr", "Maenmarach" },
             { "Narb", "Sean-Arabach Thuaidh" },
-            { "Nbat", "Nbat" },
             { "Newa", "Newa" },
-            { "Nkoo", "Nkoo" },
-            { "Nshu", "Nshu" },
             { "Ogam", "Ogham" },
-            { "Olck", "Olck" },
-            { "Orkh", "Orkh" },
             { "Orya", "Oir\u00edseach" },
-            { "Osge", "Osge" },
-            { "Osma", "Osma" },
-            { "Palm", "Palm" },
-            { "Pauc", "Pauc" },
             { "Perm", "Sean-Pheirmeach" },
-            { "Phag", "Phag" },
-            { "Phli", "Phli" },
-            { "Phlp", "Phlp" },
             { "Phnx", "F\u00e9in\u00edceach" },
             { "Plrd", "Pollard Foghrach" },
             { "Prti", "Pairtiach Inscr\u00edbhinni\u00fail" },
-            { "Rjng", "Rjng" },
             { "Runr", "R\u00fanach" },
             { "Samr", "Sam\u00e1rach" },
             { "Sarb", "Sean-Arabach Theas" },
-            { "Saur", "Saur" },
-            { "Sgnw", "Sgnw" },
             { "Shaw", "Shawach" },
-            { "Shrd", "Shrd" },
-            { "Sidd", "Sidd" },
-            { "Sind", "Sind" },
             { "Sinh", "Siol\u00f3nach" },
-            { "Sora", "Sora" },
-            { "Soyo", "Soyo" },
-            { "Sund", "Sund" },
-            { "Sylo", "Sylo" },
+            { "Sund", "Sundain\u00e9is" },
             { "Syrc", "Siriceach" },
-            { "Tagb", "Tagb" },
-            { "Takr", "Takr" },
-            { "Tale", "Tale" },
-            { "Talu", "Talu" },
             { "Taml", "Tamalach" },
-            { "Tang", "Tang" },
-            { "Tavt", "Tavt" },
             { "Telu", "Teileag\u00fach" },
             { "Tfng", "Tifinagh" },
             { "Tglg", "Tag\u00e1lagach" },
             { "Thaa", "T\u00e1nach" },
             { "Thai", "T\u00e9alannach" },
             { "Tibt", "Tib\u00e9adach" },
-            { "Tirh", "Tirh" },
             { "Ugar", "\u00dagair\u00edteach" },
-            { "Vaii", "Vaii" },
-            { "Wara", "Wara" },
             { "Xpeo", "Sean-Pheirseach" },
             { "Xsux", "Dingchruthach Suim\u00e9ar-Ac\u00e1dach" },
             { "Yiii", "\u00cds" },
-            { "Zanb", "Zanb" },
             { "Zinh", "Oidhreacht" },
             { "Zmth", "Nodaireacht Mhatamaitici\u00fail" },
             { "Zsye", "Emoji" },
@@ -950,7 +793,7 @@ public class LocaleNames_ga extends OpenListResourceBundle {
             { "Zxxx", "Gan Scr\u00edobh" },
             { "Zyyy", "Coitianta" },
             { "Zzzz", "Script Anaithnid" },
-            { "root", "root" },
+            { "root", "Root" },
             { "de_AT", "Gearm\u00e1inis Ostarach" },
             { "de_CH", "Ard-Ghearm\u00e1inis Eilv\u00e9iseach" },
             { "en_AU", "B\u00e9arla Astr\u00e1lach" },
@@ -959,6 +802,7 @@ public class LocaleNames_ga extends OpenListResourceBundle {
             { "en_US", "B\u00e9arla Meirice\u00e1nach" },
             { "es_ES", "Sp\u00e1innis Eorpach" },
             { "es_MX", "Sp\u00e1innis Mheicsiceach" },
+            { "fa_AF", "Dairis" },
             { "fr_CA", "Fraincis Cheanadach" },
             { "fr_CH", "Fraincis Eilv\u00e9iseach" },
             { "nl_BE", "Pl\u00e9imeannais" },
@@ -967,8 +811,6 @@ public class LocaleNames_ga extends OpenListResourceBundle {
             { "ro_MD", "Mold\u00e1ivis" },
             { "sw_CD", "Svaha\u00edlis an Chong\u00f3" },
             { "%%1901", "Litri\u00fa Traidisi\u00fanta na Gearm\u00e1inise" },
-            { "%%1994", "1994" },
-            { "%%1996", "1996" },
             { "ar_001", "Araibis Chaighde\u00e1nach" },
             { "es_419", "Sp\u00e1innis Mheirice\u00e1 Laidinigh" },
             { "key.ca", "F\u00e9ilire" },
@@ -980,165 +822,120 @@ public class LocaleNames_ga extends OpenListResourceBundle {
             { "key.ms", "C\u00f3ras Tomhais" },
             { "key.nu", "Uimhreacha" },
             { "nds_NL", "Sacsainis \u00cdochtarach" },
-            { "%%ALUKU", "ALUKU" },
-            { "%%BARLA", "BARLA" },
-            { "%%BISKE", "BISKE" },
-            { "%%BOONT", "BOONT" },
+            { "%%BISKE", "Can\u00faint San Giorgo/Bila" },
+            { "%%BOONT", "Boontling" },
             { "%%CORNU", "B\u00e9arla an Choirn" },
-            { "%%JAUER", "JAUER" },
+            { "%%JAUER", "Jauer" },
             { "%%KKCOR", "Gn\u00e1th-Litri\u00fa" },
             { "%%KSCOR", "Litri\u00fa Caighde\u00e1nach" },
-            { "%%LIPAW", "LIPAW" },
-            { "%%NEDIS", "NEDIS" },
-            { "%%NJIVA", "NJIVA" },
+            { "%%NJIVA", "Can\u00faint Gniva/Njiva" },
             { "%%NULIK", "Volap\u00fck Nua-Aimseartha" },
-            { "%%OSOJS", "OSOJS" },
             { "%%POSIX", "R\u00edomhaire" },
-            { "%%PUTER", "PUTER" },
+            { "%%PUTER", "Puter" },
             { "%%RIGIK", "Volap\u00fck Clasaiceach" },
-            { "%%ROZAJ", "ROZAJ" },
-            { "%%RUMGR", "RUMGR" },
-            { "%%SAAHO", "SAAHO" },
-            { "%%SOLBA", "SOLBA" },
-            { "%%SOTAV", "SOTAV" },
+            { "%%ROZAJ", "Reisiach" },
+            { "%%RUMGR", "Rumgr" },
+            { "%%SAAHO", "Saho" },
             { "%%UCCOR", "Litri\u00fa Comhaontaithe" },
             { "zh_Hans", "S\u00ednis Shimplithe" },
             { "zh_Hant", "S\u00ednis Thraidisi\u00fanta" },
-            { "%%AO1990", "AO1990" },
             { "%%DAJNKO", "Aib\u00edtir Dajnko" },
-            { "%%EKAVSK", "EKAVSK" },
             { "%%FONIPA", "Fogharscr\u00edobh IPA" },
             { "%%FONUPA", "Fogharscr\u00edobh UPA" },
-            { "%%NDYUKA", "NDYUKA" },
-            { "%%PAMAKA", "PAMAKA" },
             { "%%PINYIN", "R\u00f3mh\u00e1n\u00fa Pinyin" },
             { "%%SCOUSE", "B\u00e9arla Learphoill" },
             { "%%SIMPLE", "Simpl\u00ed" },
-            { "%%TARASK", "TARASK" },
             { "%%UCRCOR", "Litri\u00fa Comhaontaithe Athbhreithnithe" },
             { "%%ULSTER", "C\u00faige Uladh" },
             { "%%UNIFON", "Aib\u00edtir foghra\u00edochta Unifon" },
-            { "%%ABL1943", "ABL1943" },
             { "%%ALALC97", "R\u00f3mh\u00e1n\u00fa ALA-LC, eagr\u00e1n 1997" },
             { "%%AREVELA", "Airm\u00e9inis an Oirthir" },
             { "%%AREVMDA", "Airm\u00e9inis an Iarthair" },
-            { "%%BALANKA", "BALANKA" },
-            { "%%BAUDDHA", "BAUDDHA" },
+            { "%%BAUDDHA", "Bauddha" },
             { "%%BOHORIC", "Aib\u00edtir Bohori\u010d" },
             { "%%EMODENG", "Nua-Bh\u00e9arla Moch" },
-            { "%%FONNAPA", "FONNAPA" },
+            { "%%FONNAPA", "Fonnapa" },
             { "%%HEPBURN", "R\u00f3mh\u00e1n\u00fa Hepburn" },
-            { "%%ITIHASA", "ITIHASA" },
-            { "%%LAUKIKA", "LAUKIKA" },
+            { "%%ITIHASA", "Itihasa" },
+            { "%%LAUKIKA", "Laukika" },
             { "%%METELKO", "Aib\u00edtir Metelko" },
             { "%%MONOTON", "Aontonach" },
-            { "%%PAHAWH2", "PAHAWH2" },
-            { "%%PAHAWH3", "PAHAWH3" },
-            { "%%PAHAWH4", "PAHAWH4" },
+            { "%%PAHAWH2", "Pahawh2" },
+            { "%%PAHAWH3", "Pahawh3" },
+            { "%%PAHAWH4", "Pahawh4" },
             { "%%POLYTON", "Iltonach" },
             { "%%REVISED", "Litri\u00fa Athbhreithnithe" },
-            { "%%SURSILV", "SURSILV" },
-            { "%%SUTSILV", "SUTSILV" },
+            { "%%SURSILV", "Sursilvan" },
+            { "%%SUTSILV", "Sutsilv" },
             { "%%VAIDIKA", "V\u00e9ideach" },
-            { "%%1606NICT", "1606NICT" },
             { "%%1694ACAD", "Nua-Fhraincis Mhoch" },
             { "%%1959ACAD", "Acad\u00fail" },
-            { "%%BAKU1926", "BAKU1926" },
             { "%%BASICENG", "Bun-Bh\u00e9arla" },
-            { "%%BISCAYAN", "BISCAYAN" },
-            { "%%COLB1945", "COLB1945" },
-            { "%%FONXSAMP", "FONXSAMP" },
-            { "%%HOGNORSK", "HOGNORSK" },
-            { "%%HSISTEMO", "HSISTEMO" },
-            { "%%IJEKAVSK", "IJEKAVSK" },
-            { "%%JYUTPING", "JYUTPING" },
-            { "%%KOCIEWIE", "KOCIEWIE" },
-            { "%%LUNA1918", "LUNA1918" },
+            { "%%BISCAYAN", "BIOSC\u00c1NACH" },
+            { "%%FONXSAMP", "Fonxsamp" },
+            { "%%HOGNORSK", "Hognorsk" },
+            { "%%HSISTEMO", "Hsistemo" },
+            { "%%JYUTPING", "Jyutping" },
+            { "%%KOCIEWIE", "Kociewie" },
+            { "%%LUNA1918", "Luna1918" },
             { "%%NEWFOUND", "Talamh an \u00c9isc" },
             { "%%OXENDICT", "Litri\u00fa OED" },
-            { "%%PETR1708", "PETR1708" },
+            { "%%PETR1708", "Petr1708" },
             { "%%SCOTLAND", "B\u00e9arla Caighde\u00e1nach na hAlban" },
-            { "%%SPANGLIS", "SPANGLIS" },
-            { "%%SURMIRAN", "SURMIRAN" },
+            { "%%SPANGLIS", "Spainglis" },
+            { "%%SURMIRAN", "Surmiran" },
             { "%%VALENCIA", "Vaileinsis" },
-            { "%%VALLADER", "VALLADER" },
+            { "%%VALLADER", "Vallader" },
             { "%%WADEGILE", "R\u00f3mh\u00e1n\u00fa Wade-Giles" },
-            { "%%XSISTEMO", "XSISTEMO" },
+            { "%%XSISTEMO", "Xsistemo" },
             { "type.ca.roc", "F\u00e9ilire T\u00e9av\u00e1nach" },
-            { "type.co.eor", "eor" },
             { "type.hc.h11", "C\u00f3ras 12 Uair (0\u201311)" },
             { "type.hc.h12", "C\u00f3ras 12 Uair (1\u201312)" },
             { "type.hc.h23", "C\u00f3ras 24 Uair (0\u201323)" },
             { "type.hc.h24", "C\u00f3ras 24 Uair (1\u201324)" },
-            { "type.nu.ahom", "ahom" },
+            { "type.nu.ahom", "Digit\u00ed Ahom" },
             { "type.nu.arab", "Digit\u00ed Ind-Arabacha" },
             { "type.nu.armn", "Uimhreacha Airm\u00e9anacha" },
             { "type.nu.bali", "Digit\u00ed Bail\u00edocha" },
             { "type.nu.beng", "Digit\u00ed Beang\u00e1lacha" },
-            { "type.nu.brah", "brah" },
-            { "type.nu.cakm", "cakm" },
-            { "type.nu.cham", "cham" },
+            { "type.nu.brah", "Digit\u00ed Brahmi" },
+            { "type.nu.cakm", "Digit\u00ed Chakma" },
+            { "type.nu.cham", "Digit\u00ed Cham" },
             { "type.nu.cyrl", "Uimhreacha Coireallacha" },
             { "type.nu.deva", "Digit\u00ed D\u00e9ivean\u00e1gracha" },
             { "type.nu.ethi", "Uimhreacha Aet\u00f3ipice" },
             { "type.nu.geor", "Uimhreacha Seoirseacha" },
-            { "type.nu.gonm", "gonm" },
             { "type.nu.grek", "Uimhreacha Gr\u00e9agacha" },
             { "type.nu.gujr", "Digit\u00ed G\u00faisear\u00e1tacha" },
             { "type.nu.guru", "Digit\u00ed Gurm\u00facacha" },
             { "type.nu.hans", "Uimhreacha sa tS\u00ednis Shimplithe" },
             { "type.nu.hant", "Uimhreacha sa tS\u00ednis Thraidisi\u00fanta" },
             { "type.nu.hebr", "Uimhreacha Eabhracha" },
-            { "type.nu.hmng", "hmng" },
             { "type.nu.java", "Digit\u00ed I\u00e1vacha" },
             { "type.nu.jpan", "Uimhreacha Seap\u00e1nacha" },
-            { "type.nu.kali", "kali" },
             { "type.nu.khmr", "Digit\u00ed Cim\u00e9aracha" },
             { "type.nu.knda", "Digit\u00ed Cannadacha" },
-            { "type.nu.lana", "lana" },
             { "type.nu.laoo", "Digit\u00ed Laosacha" },
             { "type.nu.latn", "Digit\u00ed Iartharacha" },
-            { "type.nu.lepc", "lepc" },
-            { "type.nu.limb", "limb" },
             { "type.nu.mlym", "Digit\u00ed Mail\u00e9alamacha" },
-            { "type.nu.modi", "modi" },
             { "type.nu.mong", "Digit\u00ed Mong\u00f3lacha" },
-            { "type.nu.mroo", "mroo" },
-            { "type.nu.mtei", "mtei" },
             { "type.nu.mymr", "Digit\u00ed Maenmaracha" },
-            { "type.nu.nkoo", "nkoo" },
-            { "type.nu.olck", "olck" },
             { "type.nu.orya", "Digit\u00ed Oir\u00edseacha" },
-            { "type.nu.osma", "osma" },
-            { "type.nu.saur", "saur" },
-            { "type.nu.shrd", "shrd" },
-            { "type.nu.sind", "sind" },
-            { "type.nu.sinh", "sinh" },
-            { "type.nu.sora", "sora" },
-            { "type.nu.sund", "sund" },
-            { "type.nu.takr", "takr" },
-            { "type.nu.talu", "talu" },
             { "type.nu.taml", "Uimhreacha Traidisi\u00fanta Tamalacha" },
             { "type.nu.telu", "Digit\u00ed Teileag\u00facha" },
             { "type.nu.thai", "Digit\u00ed T\u00e9alannacha" },
             { "type.nu.tibt", "Digit\u00ed Tib\u00e9adacha" },
-            { "type.nu.tirh", "tirh" },
-            { "type.nu.vaii", "vaii" },
-            { "type.nu.wara", "wara" },
             { "type.ca.dangi", "F\u00e9ilire Dangi" },
             { "type.co.ducet", "Ord S\u00f3rt\u00e1la R\u00e9amhshocraithe Unicode" },
-            { "type.co.emoji", "emoji" },
+            { "type.co.emoji", "Ord S\u00f3rt\u00e1la Emoji" },
             { "type.lb.loose", "St\u00edl Briseadh L\u00edne Scaoilte" },
             { "type.nu.roman", "Uimhreacha R\u00f3mh\u00e1nacha" },
             { "type.ca.coptic", "F\u00e9ilire Coptach" },
             { "type.ca.hebrew", "F\u00e9ilire na nEabhrach" },
             { "type.ca.indian", "F\u00e9ilire N\u00e1isi\u00fanta na hIndia" },
-            { "type.co.compat", "compat" },
             { "type.co.pinyin", "Ord s\u00f3rt\u00e1la pinyin" },
             { "type.co.search", "Cuardach Ilfh\u00f3inteach" },
             { "type.co.stroke", "Ord s\u00f3rt\u00e1la str\u00edce" },
-            { "type.co.unihan", "unihan" },
-            { "type.co.zhuyin", "zhuyin" },
             { "type.lb.normal", "St\u00edl Gn\u00e1thbhriseadh L\u00edne" },
             { "type.lb.strict", "St\u00edl Briseadh L\u00edne Docht" },
             { "type.ms.metric", "C\u00f3ras M\u00e9adrach" },
@@ -1155,36 +952,22 @@ public class LocaleNames_ga extends OpenListResourceBundle {
             { "type.nu.hansfin", "Uimhreacha Airgead\u00fala sa tS\u00ednis Shimplithe" },
             { "type.nu.hantfin", "Uimhreacha Airgead\u00fala sa tS\u00ednis Thraidisi\u00fanta" },
             { "type.nu.jpanfin", "Uimhreacha Airgead\u00fala Seap\u00e1nacha" },
-            { "type.nu.mathdbl", "mathdbl" },
             { "type.nu.tamldec", "Digit\u00ed Tamalacha" },
             { "type.ca.buddhist", "F\u00e9ilire B\u00fada\u00edoch" },
             { "type.ca.ethiopic", "F\u00e9ilire Aet\u00f3ipice" },
             { "type.ca.japanese", "F\u00e9ilire Seap\u00e1nach" },
             { "type.cf.standard", "Form\u00e1id Airgeadra Caighde\u00e1nach" },
-            { "type.co.reformed", "reformed" },
-            { "type.co.searchjl", "searchjl" },
             { "type.co.standard", "Ord S\u00f3rt\u00e1la Caighde\u00e1nach" },
             { "type.ms.uksystem", "C\u00f3ras Tomhais Reacht\u00fail" },
             { "type.ms.ussystem", "C\u00f3ras Tomhais SAM" },
             { "type.nu.fullwide", "Digit\u00ed L\u00e1nleithid" },
-            { "type.nu.lanatham", "lanatham" },
-            { "type.nu.mathbold", "mathbold" },
-            { "type.nu.mathmono", "mathmono" },
-            { "type.nu.mathsanb", "mathsanb" },
-            { "type.nu.mathsans", "mathsans" },
-            { "type.nu.mymrshan", "mymrshan" },
-            { "type.nu.mymrtlng", "mymrtlng" },
             { "type.nu.romanlow", "Uimhreacha C\u00e1s \u00cdochtair R\u00f3mh\u00e1nacha" },
             { "type.ca.gregorian", "F\u00e9ilire Ghr\u00e9ag\u00f3ra" },
             { "type.co.gb2312han", "Ord s\u00f3rt\u00e1la S\u00edneach simplithe - GB 2312" },
             { "type.co.phonebook", "Ord s\u00f3rt\u00e1la an eolaire teileaf\u00f3in" },
-            { "type.co.dictionary", "dictionary" },
+            { "type.co.dictionary", "Ord S\u00f3rt\u00e1la Focl\u00f3ir\u00ed" },
             { "type.co.traditional", "Ord s\u00f3rt\u00e1la traidisi\u00fanta" },
-            { "type.ca.islamic-rgsa", "islamic-rgsa" },
-            { "type.ca.islamic-tbla", "islamic-tbla" },
-            { "type.ca.islamic-civil", "islamic-civil" },
-            { "type.ca.islamic-umalqura", "islamic-umalqura" },
-            { "type.ca.ethiopic-amete-alem", "ethiopic-amete-alem" },
+            { "type.ca.ethiopic-amete-alem", "F\u00e9ilire Aet\u00f3ipice Amete Alem" },
         };
         return data;
     }
