@@ -95,6 +95,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
         final String metaValue_si = "Sinhala";
         final String metaValue_te = "Telugu";
         final String metaValue_tl = "Tagalog";
+        final String metaValue_ccp = "Chakma";
         final String metaValue_chr = "Cherokee";
         final String metaValue_cop = "Coptais";
         final String metaValue_gez = "Ge\u2019ez";
@@ -121,6 +122,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "Tagb", "Tagbanwa" },
             { "Zsye", "Emoji" },
             { "%%NJIVA", "Dual-chainnt Gniva/Njiva" },
+            { "ccp", metaValue_ccp },
             { "egy", "\u00c8ipheitis \u00c0rsaidh" },
             { "raj", "Rajasthani" },
             { "Phag", "Phags-pa" },
@@ -283,7 +285,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "Taml", "Taimil" },
             { "FR", "An Fhraing" },
             { "Kpel", metaValue_kpe },
-            { "%%SIMPLE", "SIMPLE" },
+            { "%%SIMPLE", "Samhlaidhean s\u00ecmplichte" },
             { "pcd", "Picard" },
             { "tkl", metaValue_TK },
             { "grb", "Grebo" },
@@ -412,12 +414,13 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "phn", "Phenicis" },
             { "Cyrs", "Cirilis Seann-Sl\u00e0bhais na h-Eaglaise" },
             { "gwi", "Gwich\u02bcin" },
-            { "%%LUNA1918", "LUNA1918" },
+            { "%%LUNA1918", "Litreachadh na Ruisise \u00e0s d\u00e8idh 1917" },
             { "nds", "Gearmailtis \u00ccochdarach" },
             { "LI", "Lichtenstein" },
             { "LK", "Sri Lanca" },
             { "akk", "Acadais" },
             { "cop", metaValue_cop },
+            { "Hmnp", "Nyiakeng Puachue Hmong" },
             { "LR", "Lib\u00e8ir" },
             { "esu", "Yupik Mheadhanach" },
             { "LS", "Leasoto" },
@@ -505,6 +508,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "%%PETR1708", "Litreachadh Pheadair 1708" },
             { "anp", "Angika" },
             { "crs", "Seiseallais" },
+            { "type.nu.hmnp", "\u00c0ireamhan Nyiakeng Puachue" },
             { "Xpeo", metaValue_peo },
             { "type.nu.hmng", "\u00c0ireamhan Pahawh Hmong" },
             { "PA", "Panama" },
@@ -556,6 +560,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "jbo", "Lojban" },
             { "Rjng", "Rejang" },
             { "009", "Roinn a\u2019 Chuain S\u00e8imh" },
+            { "Elym", "Elymaidheach" },
             { "%%SURSILV", "Sursilvan" },
             { "RO", "Rom\u00e0inia" },
             { "RS", "An t-S\u00e8irb" },
@@ -609,7 +614,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "SX", "Sint Maarten" },
             { "SY", "Siridhea" },
             { "yao", "Yao" },
-            { "SZ", "D\u00f9thaich nan Suasaidh" },
+            { "SZ", "eSwatini" },
             { "arw", "Arawak" },
             { "arz", "Arabais \u00c8ipheiteach" },
             { "ary", "Arabais Mhorocach" },
@@ -621,6 +626,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "TC", "Na h-Eileanan Turcach is Caiceo" },
             { "yav", "Yangben" },
             { "TD", "An t-Se\u00e0d" },
+            { "Qaag", "Zawgyi" },
             { "TF", "Ranntairean a Deas na Frainge" },
             { "ase", "Cainnt-shanais na h-Aimeireaga" },
             { "TG", "Togo" },
@@ -667,7 +673,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "US", "Na St\u00e0itean Aonaichte" },
             { "haw", "C\u00e0nan Hawai\u2019i" },
             { "%%1959ACAD", "Bealaruisis Acadamaigeach" },
-            { "%%IVANCHOV", "IVANCHOV" },
+            { "%%IVANCHOV", "Bulgarian in 1899 orthography = Bulgairis le litreachadh na bliadhna 1899" },
             { "type.co.gb2312han", "\u00d2rdugh se\u00f2rsachaidh na S\u00ecnise Simplichte - GB2312" },
             { "UY", "Uruguaidh" },
             { "prg", "Pruisis" },
@@ -678,7 +684,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "VA", "Cathair na Bhatacain" },
             { "pro", "Seann-Phroven\u00e7al" },
             { "VC", "Naomh Bhionsant agus Eileanan Greanadach" },
-            { "%%HSISTEMO", "HSISTEMO" },
+            { "%%HSISTEMO", "Roghainn-\u00e8iginn stannardach litreachadh na h-Esperanto le h" },
             { "VE", "A\u2019 Bheiniseala" },
             { "VG", "Eileanan Breatannach na Maighdinn" },
             { "VI", "Eileanan na Maighdinn aig na SA" },
@@ -707,7 +713,9 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "type.nu.mtei", "\u00c0ireamhan Meetei Mayek" },
             { "wal", "Wolaytta" },
             { "was", "Washo" },
+            { "XA", "Sr\u00e0can fuadain" },
             { "war", "Waray" },
+            { "XB", "D\u00e0-chomhaireach fuadain" },
             { "awa", "Awadhi" },
             { "061", "Poilin\u00e8is" },
             { "%%KSCOR", "Litreachadh stannardach" },
@@ -753,7 +761,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "lou", "Cr\u00ectheol Louisiana" },
             { "loz", "Lozi" },
             { "Nkgb", "Naxi Geba" },
-            { "%%ASANTE", "ASANTE" },
+            { "%%ASANTE", "Asante" },
             { "jmc", "Machame" },
             { "hif", "Hindis Fh\u00ecditheach" },
             { "type.nu.hansfin", "\u00c0ireamhan ionmhasail na S\u00ecnise Shimplichte" },
@@ -772,7 +780,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "nwc", "Newari Chlasaigeach" },
             { "udm", "Udmurt" },
             { "Khmr", metaValue_km },
-            { "%%FONNAPA", "FONNAPA" },
+            { "%%FONNAPA", "Aibidil Fhuaim-e\u00f2lach Aimeireaga a Tuath" },
             { "type.ca.islamic-rgsa", "Am M\u00ecosachan Ioslamach (Ar\u00e0ibia nan Sabhd, sealladh)" },
             { "Limb", "Limbu" },
             { "sad", "Sandawe" },
@@ -942,10 +950,11 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "type.m0.bgn", "Tar-litreachadh BGN nan St\u00e0itean Aonaichte" },
             { "umb", "Umbundu" },
             { "fr", "Fraingis" },
-            { "%%AKUAPEM", "AKUAPEM" },
+            { "%%AKUAPEM", "Akuapem" },
             { "sid", "Sidamo" },
             { "fy", "Fr\u00ecoslannais Shiarach" },
             { "ga", "Gaeilge" },
+            { "Wcho", "Wancho" },
             { "gd", "G\u00e0idhlig" },
             { "Gong", "Gunjala Gondi" },
             { "gl", "Gail\u00ecsis" },
@@ -963,7 +972,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "hi", "Hindis" },
             { "hup", "Hupa" },
             { "bik", "Bikol" },
-            { "bin", "Bini" },
+            { "bin", "Edo" },
             { "ho", "Hiri Motu" },
             { "hr", "Cr\u00f2thaisis" },
             { "ht", "Cr\u00ectheol Haidhti" },
@@ -1199,6 +1208,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "%%NEDIS", "Dual-chainnt Natisone" },
             { "sv", "Suainis" },
             { "sw", "Kiswahili" },
+            { "type.nu.wcho", "\u00c0ireamhan Wancho" },
             { "type.nu.hantfin", "\u00c0ireamhan ionmhasail na S\u00ecnise Thradaiseanta" },
             { "ibb", "Ibibio" },
             { "iba", "Iban" },
@@ -1223,11 +1233,11 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "dyo", "Jola-Fonyi" },
             { "type.nu.jpan", "\u00c0ireamhan na Seapanaise" },
             { "tr", "Turcais" },
+            { "Cakm", metaValue_ccp },
             { "ts", "Tsonga" },
             { "swb", "Comorais" },
-            { "Cakm", "Chakma" },
             { "tt", "Tatarais" },
-            { "%%XSISTEMO", "XSISTEMO" },
+            { "%%XSISTEMO", "Roghainn-\u00e8iginn stannardach litreachadh na h-Esperanto le x" },
             { "dyu", "Dyula" },
             { "tw", "Twi" },
             { "ty", "C\u00e0nan Tahiti" },
@@ -1287,7 +1297,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "zgh", "Tamazight Stannardach Moroco" },
             { "ar_001", "Nuadh-Arabais Stannardach" },
             { "Cans", "Sgr\u00ecobhadh Lideach Aonaichte nan T\u00f9sanach Canadach" },
-            { "%%FONXSAMP", "FONXSAMP" },
+            { "%%FONXSAMP", "Tar-sgr\u00ecobhadh X-SAMPA" },
             { "gay", "Gayo" },
             { "Mong", metaValue_mn },
             { "mnc", "Manchu" },
@@ -1297,6 +1307,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "mni", "Manipuri" },
             { "Latn", metaValue_la },
             { "Latg", "Laideann Gh\u00e0idhealach" },
+            { "Nand", "Nandinagari" },
             { "type.nu.hans", "\u00c0ireamhan na S\u00ecnise Shimplichte" },
             { "type.nu.hant", "\u00c0ireamhan na S\u00ecnise Thradaiseanta" },
             { "xh", "Xhosa" },
@@ -1387,6 +1398,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "inh", "Ingush" },
             { "krj", "Kinaray-a" },
             { "kri", "Krio" },
+            { "fa_AF", "Dari" },
             { "krl", "Cairealais" },
             { "%%OXENDICT", "Litreachadh faclair Oxford na Beurla" },
             { "efi", "Efik" },
