@@ -74,16 +74,19 @@ public class LocaleNames_gl extends OpenListResourceBundle {
         final String metaValue_bn = "bengal\u00ed";
         final String metaValue_bo = "tibetano";
         final String metaValue_el = "grego";
+        final String metaValue_gu = "guxarati";
         final String metaValue_he = "hebreo";
         final String metaValue_hy = "armenio";
         final String metaValue_ja = "xapon\u00e9s";
         final String metaValue_ka = "xeorxiano";
         final String metaValue_km = "khmer";
+        final String metaValue_kn = "kannar\u00e1";
         final String metaValue_ko = "coreano";
         final String metaValue_lo = "laosiano";
         final String metaValue_ml = "malabar";
         final String metaValue_mn = "mongol";
         final String metaValue_my = "birmano";
+        final String metaValue_or = "odi\u00e1";
         final String metaValue_si = "cingal\u00e9s";
         final String metaValue_ta = "t\u00e1mil";
         final String metaValue_te = "telugu";
@@ -93,6 +96,7 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "mwl", "mirand\u00e9s" },
             { "Zsym", "s\u00edmbolos" },
             { "Zsye", "emojis" },
+            { "ccp", "chakma" },
             { "egy", "exipcio antigo" },
             { "tem", "temne" },
             { "teo", "teso" },
@@ -107,7 +111,7 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "AG", "Antigua e Barbuda" },
             { "type.ca.ethiopic", "calendario et\u00edope" },
             { "AI", "Anguila" },
-            { "key.tz", "Fuso horario" },
+            { "key.tz", "fuso horario" },
             { "AL", "Albania" },
             { "AM", "Armenia" },
             { "AO", "Angola" },
@@ -154,7 +158,7 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "CF", "Rep\u00fablica Centroafricana" },
             { "CG", "Rep\u00fablica do Congo" },
             { "CH", "Su\u00edza" },
-            { "CI", "Costa do Marfil" },
+            { "CI", "C\u00f4te d\u2019Ivoire" },
             { "CK", "Illas Cook" },
             { "CL", "Chile" },
             { "CM", "Camer\u00fan" },
@@ -207,13 +211,13 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "type.ca.gregorian", "calendario gregoriano" },
             { "EZ", "Eurozona" },
             { "chy", "cheyenne" },
-            { "type.nu.gujr", "d\u00edxitos guxarat\u00eds" },
+            { "type.nu.gujr", "d\u00edxitos guxaratis" },
             { "ady", "adigueo" },
             { "FI", "Finlandia" },
             { "FJ", "Fixi" },
             { "FK", "Illas Malvinas" },
             { "FM", "Micronesia" },
-            { "key.va", "Variante local" },
+            { "key.va", "variante rexional" },
             { "FO", "Illas Feroe" },
             { "Taml", metaValue_ta },
             { "FR", "Francia" },
@@ -241,7 +245,7 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "GW", "A Guinea Bissau" },
             { "tlh", "klingon" },
             { "GY", "G\u00fciana" },
-            { "ckb", "kurdo soran\u00ed" },
+            { "ckb", "kurdo central" },
             { "zxx", "sen contido ling\u00fc\u00edstico" },
             { "de_AT", "alem\u00e1n austr\u00edaco" },
             { "HK", "Hong Kong RAE da China" },
@@ -277,7 +281,7 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "JP", "O Xap\u00f3n" },
             { "ain", "ainu" },
             { "guz", "gusii" },
-            { "type.nu.knda", "d\u00edxitos canareses" },
+            { "type.nu.knda", "d\u00edxitos kannar\u00e1s" },
             { "de_CH", "alto alem\u00e1n su\u00edzo" },
             { "type.co.phonetic", "Orde de clasificaci\u00f3n fon\u00e9tica" },
             { "type.ca.buddhist", "calendario budista" },
@@ -287,8 +291,8 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "KH", "Camboxa" },
             { "KI", "Kiribati" },
             { "KM", "Comores" },
+            { "Knda", metaValue_kn },
             { "KN", "Saint Kitts e Nevis" },
-            { "Knda", "canar\u00e9s" },
             { "fr_CA", "franc\u00e9s canadense" },
             { "KP", "Corea do Norte" },
             { "KR", "Corea do Sur" },
@@ -296,7 +300,7 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "KW", "Kuwait" },
             { "tpi", "tok pisin" },
             { "KY", "Illas Caim\u00e1n" },
-            { "KZ", "Casaquist\u00e1n" },
+            { "KZ", "Kazakist\u00e1n" },
             { "Cyrl", "cir\u00edlico" },
             { "LA", "Laos" },
             { "LB", "O L\u00edbano" },
@@ -394,9 +398,9 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "tvl", "tuval\u00e9s" },
             { "001", "Mundo" },
             { "002", "\u00c1frica" },
-            { "003", "Norteam\u00e9rica" },
+            { "003", "Am\u00e9rica do Norte" },
             { "RE", "Reuni\u00f3n" },
-            { "005", "Suram\u00e9rica" },
+            { "005", "Am\u00e9rica do Sur" },
             { "jbo", "lojban" },
             { "009", "Ocean\u00eda" },
             { "RO", "Roman\u00eda" },
@@ -436,11 +440,11 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "SV", "O Salvador" },
             { "SX", "Sint Maarten" },
             { "SY", "Siria" },
-            { "SZ", "Suazilandia" },
+            { "SZ", "Eswatini" },
             { "TA", "Trist\u00e1n da Cunha" },
             { "asa", "asu" },
             { "type.ms.ussystem", "sistema estadounidense de unidades" },
-            { "021", "Am\u00e9rica do Norte" },
+            { "021", "Am\u00e9rica Setentrional" },
             { "TC", "Illas Turks e Caicos" },
             { "yav", "yangben" },
             { "TD", "Chad" },
@@ -463,7 +467,7 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "ast", "asturiano" },
             { "TZ", "Tanzania" },
             { "nmg", "kwasio" },
-            { "Zzzz", "alfabeto desco\u00f1ecido" },
+            { "Zzzz", "sistema de escritura desco\u00f1ecido" },
             { "UA", "Ucra\u00edna" },
             { "rup", "aroman\u00e9s" },
             { "030", "Asia Oriental" },
@@ -482,7 +486,7 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "type.co.gb2312han", "orde de clasifcaci\u00f3n chinesa simplificada - GB2312" },
             { "UY", "O Uruguai" },
             { "prg", "prusiano" },
-            { "UZ", "Uzbequist\u00e1n" },
+            { "UZ", "Uzbekist\u00e1n" },
             { "tzm", "tamazight de Marrocos central" },
             { "type.co.stroke", "Orde de clasificaci\u00f3n polo n\u00famero de trazos" },
             { "nnh", "ngiemboon" },
@@ -499,18 +503,20 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "054", "Melanesia" },
             { "WF", "Wallis e Futuna" },
             { "type.co.traditional", "Orde de clasificaci\u00f3n tradicional" },
-            { "057", "Rexi\u00f3n da Micronesia" },
+            { "057", "Rexi\u00f3n de Micronesia" },
             { "jgo", "ngomba" },
             { "lkt", "lakota" },
             { "type.nu.finance", "N\u00fameros financeiros" },
             { "wae", "walser" },
             { "WS", "Samoa" },
             { "wal", "wolaytta" },
+            { "XA", "Pseudoacentos" },
             { "war", "waray-waray" },
+            { "XB", "Pseudobidireccional" },
             { "awa", "awadhi" },
             { "061", "Polinesia" },
             { "XK", "Kosovo" },
-            { "Gujr", "guxarat\u00ed" },
+            { "Gujr", metaValue_gu },
             { "Zxxx", "non escrito" },
             { "wbp", "walrpiri" },
             { "YE", "O Iemen" },
@@ -518,7 +524,7 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "type.co.standard", "criterio de ordenaci\u00f3n est\u00e1ndar" },
             { "YT", "Mayotte" },
             { "ZA", "Sur\u00e1frica" },
-            { "type.lb.loose", "estilo de quebra de li\u00f1a separada" },
+            { "type.lb.loose", "estilo de quebra de li\u00f1a flexible" },
             { "Deva", "devan\u00e1gari" },
             { "type.nu.geor", "numeraci\u00f3n xeorxiana" },
             { "Hira", "hiragana" },
@@ -533,7 +539,7 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "jmc", "machame" },
             { "type.nu.hansfin", "numeraci\u00f3n financeira chinesa simplificada" },
             { "hil", "hiligaynon" },
-            { "type.nu.arabext", "d\u00edxitos ar\u00e1bigo-\u00edndicos ampliados" },
+            { "type.nu.arabext", "d\u00edxitos indoar\u00e1bigos ampliados" },
             { "nus", "nuer" },
             { "dak", "dakota" },
             { "type.nu.fullwide", "d\u00edxitos de ancho completo" },
@@ -584,7 +590,7 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "az", "acerbaixano" },
             { "ba", "baxkir" },
             { "type.co.unihan", "Criterio de ordenaci\u00f3n radical-trazo" },
-            { "be", "bielorruso" },
+            { "be", "belaruso" },
             { "bg", "b\u00falgaro" },
             { "bi", "bislama" },
             { "bm", "bambara" },
@@ -601,7 +607,7 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "ce", "checheno" },
             { "ch", "chamorro" },
             { "co", "corso" },
-            { "Orya", "ori\u00e1" },
+            { "Orya", metaValue_or },
             { "cs", "checo" },
             { "cu", "eslavo eclesi\u00e1stico" },
             { "cv", "chuvaxo" },
@@ -629,7 +635,7 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "type.co.big5han", "Orde de clasificaci\u00f3n chinesa tradicional - Big5" },
             { "es", "espa\u00f1ol" },
             { "et", "estoniano" },
-            { "Hanb", "hanb" },
+            { "Hanb", "han con bopomofo" },
             { "eu", "\u00e9uscaro" },
             { "Hang", "hangul" },
             { "shi", "tachelhit" },
@@ -658,7 +664,7 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "bho", "bhojpuri" },
             { "und", "lingua desco\u00f1ecida" },
             { "type.ca.ethiopic-amete-alem", "Calendario Amete Alem et\u00edope" },
-            { "gu", "guxarati" },
+            { "gu", metaValue_gu },
             { "gv", "manx" },
             { "ha", "hausa" },
             { "he", metaValue_he },
@@ -697,10 +703,10 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "ki", "kikuyu" },
             { "mas", "masai" },
             { "kj", "kuanyama" },
-            { "kk", "casaco" },
+            { "kk", "kazako" },
             { "kl", "groenland\u00e9s" },
             { "km", metaValue_km },
-            { "kn", "kannar\u00e1" },
+            { "kn", metaValue_kn },
             { "ko", metaValue_ko },
             { "kr", "kanuri" },
             { "ks", "caxemir\u00e9s" },
@@ -747,7 +753,7 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "no", "noruegu\u00e9s" },
             { "nr", "ndebele meridional" },
             { "nv", "navajo" },
-            { "ny", "nyanja" },
+            { "ny", "chewa" },
             { "kac", "kachin" },
             { "kab", "cabila" },
             { "oc", "occitano" },
@@ -757,7 +763,7 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "mer", "meru" },
             { "type.nu.armn", "numeraci\u00f3n armenia" },
             { "om", "oromo" },
-            { "or", "odi\u00e1" },
+            { "or", metaValue_or },
             { "os", "ossetio" },
             { "kbd", "cabardiano" },
             { "mfe", "crioulo mauriciano" },
@@ -790,7 +796,7 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "rn", "rundi" },
             { "key.cu", "moeda" },
             { "ro", "roman\u00e9s" },
-            { "type.nu.orya", "d\u00edxitos do ori\u00e1" },
+            { "type.nu.orya", "d\u00edxitos do odi\u00e1" },
             { "type.nu.hanidec", "numeraci\u00f3n decimal chinesa" },
             { "ru", "ruso" },
             { "rw", "ki\u00f1aruanda" },
@@ -811,7 +817,7 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "sm", "samoano" },
             { "sn", "shona" },
             { "so", "somal\u00ed" },
-            { "type.nu.arab", "d\u00edxitos ar\u00e1bigo-\u00edndicos" },
+            { "type.nu.arab", "d\u00edxitos indoar\u00e1bigos" },
             { "sq", "alban\u00e9s" },
             { "sr", "serbio" },
             { "ss", "suazi" },
@@ -834,7 +840,7 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "bug", "bugin\u00e9s" },
             { "kfo", "koro" },
             { "en_CA", "ingl\u00e9s canadense" },
-            { "tk", "turcom\u00e1n" },
+            { "tk", "turkmeno" },
             { "tl", "tagalo" },
             { "tn", "tswana" },
             { "to", "tongano" },
@@ -858,7 +864,7 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "type.ca.coptic", "Calendario c\u00f3ptico" },
             { "ur", "urd\u00fa" },
             { "xal", "calmuco" },
-            { "uz", "uzbeco" },
+            { "uz", "uzbeko" },
             { "kha", "khasi" },
             { "nds_NL", "baixo sax\u00f3n" },
             { "ve", "venda" },
@@ -921,6 +927,7 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "type.nu.tamldec", "d\u00edxitos do t\u00e1mil" },
             { "krc", "carachaio-b\u00e1lcara" },
             { "inh", "inguxo" },
+            { "fa_AF", "dari" },
             { "krl", "carelio" },
             { "efi", "efik" },
             { "key.nu", "n\u00fameros" },
