@@ -438,7 +438,7 @@ public class LocaleNames_hr extends OpenListResourceBundle {
             { "PK", "Pakistan" },
             { "PL", "Poljska" },
             { "ewo", "ewondo" },
-            { "PM", "Sveti Petar i Mikelon" },
+            { "PM", "Saint-Pierre-et-Miquelon" },
             { "PN", "Otoci Pitcairn" },
             { "PR", "Portoriko" },
             { "PS", "Palestinsko podru\u010dje" },
@@ -515,7 +515,7 @@ public class LocaleNames_hr extends OpenListResourceBundle {
             { "SX", "Sint Maarten" },
             { "SY", "Sirija" },
             { "yao", "yao" },
-            { "SZ", "Svazi" },
+            { "SZ", "Esvatini" },
             { "arw", "arava\u010dki" },
             { "yap", "japski" },
             { "TA", "Tristan da Cunha" },
@@ -525,6 +525,7 @@ public class LocaleNames_hr extends OpenListResourceBundle {
             { "TC", "Otoci Turks i Caicos" },
             { "yav", "yangben" },
             { "TD", "\u010cad" },
+            { "Qaag", "zawgyi" },
             { "TF", "Francuski ju\u017eni i antarkti\u010dki teritoriji" },
             { "TG", "Togo" },
             { "TH", "Tajland" },
@@ -699,6 +700,7 @@ public class LocaleNames_hr extends OpenListResourceBundle {
             { "scn", "sicilijski" },
             { "aa", "afarski" },
             { "ab", "abhaski" },
+            { "Aran", "nastaliq" },
             { "ae", "avesti\u010dki" },
             { "af", "afrikaans" },
             { "ak", "akanski" },
@@ -1192,6 +1194,7 @@ public class LocaleNames_hr extends OpenListResourceBundle {
             { "type.nu.tamldec", "tamilske znamenke" },
             { "krc", "karachay-balkar" },
             { "inh", "ingu\u0161etski" },
+            { "fa_AF", "dari" },
             { "krl", "karelijski" },
             { "efi", "efik" },
             { "key.nu", "brojevi" },
