@@ -80,6 +80,7 @@ public class LocaleNames_hy extends OpenListResourceBundle {
             { "mwl", "\u0574\u056b\u0580\u0561\u0576\u0564\u0565\u0580\u0565\u0576" },
             { "Zsym", "\u0576\u0577\u0561\u0576\u0576\u0565\u0580" },
             { "Zsye", "\u0567\u0574\u0578\u0571\u056b" },
+            { "ccp", "\u0579\u0561\u056f\u0574\u0561" },
             { "egy", "\u0570\u056b\u0576 \u0565\u0563\u056b\u057a\u057f\u0565\u0580\u0565\u0576" },
             { "raj", "\u057c\u0561\u057b\u0561\u057d\u057f\u0561\u0576\u0565\u0580\u0565\u0576" },
             { "tem", "\u057f\u0565\u0574\u0576\u0565" },
@@ -135,7 +136,7 @@ public class LocaleNames_hy extends OpenListResourceBundle {
             { "BY", "\u0532\u0565\u056c\u0561\u057c\u0578\u0582\u057d" },
             { "BZ", "\u0532\u0565\u056c\u056b\u0566" },
             { "type.ca.persian", "\u057a\u0561\u0580\u057d\u056f\u0561\u056f\u0561\u0576 \u0585\u0580\u0561\u0581\u0578\u0582\u0575\u0581" },
-            { "type.nu.hebr", "\u0565\u0562\u0580\u0561\u0575\u0565\u0580\u0565\u0576 \u0569\u057e\u0565\u0580" },
+            { "type.nu.hebr", "\u0565\u0562\u0580\u0561\u0575\u0561\u056f\u0561\u0576 \u0569\u057e\u0561\u0576\u056b\u0577\u0565\u0580" },
             { "CA", "\u053f\u0561\u0576\u0561\u0564\u0561" },
             { "CC", "\u053f\u0578\u056f\u0578\u057d\u0575\u0561\u0576 (\u0554\u056b\u056c\u056b\u0576\u0563) \u056f\u0572\u0566\u056b\u0576\u0565\u0580" },
             { "mzn", "\u0574\u0561\u0566\u0561\u0576\u0564\u0561\u0580\u0561\u0576\u0565\u0580\u0565\u0576" },
@@ -143,7 +144,7 @@ public class LocaleNames_hy extends OpenListResourceBundle {
             { "CF", "\u053f\u0565\u0576\u057f\u0580\u0578\u0576\u0561\u056f\u0561\u0576 \u0531\u0586\u0580\u056b\u056f\u0575\u0561\u0576 \u0540\u0561\u0576\u0580\u0561\u057a\u0565\u057f\u0578\u0582\u0569\u0575\u0578\u0582\u0576" },
             { "CG", "\u053f\u0578\u0576\u0563\u0578 - \u0532\u0580\u0561\u0566\u0561\u057e\u056b\u056c" },
             { "CH", "\u0547\u057e\u0565\u0575\u0581\u0561\u0580\u056b\u0561" },
-            { "CI", "\u053f\u0578\u057f \u0564\u2019\u053b\u057e\u0578\u0582\u0561\u0580" },
+            { "CI", "\u053f\u0578\u057f \u0564\u055a\u053b\u057e\u0578\u0582\u0561\u0580" },
             { "CK", "\u053f\u0578\u0582\u056f\u056b \u056f\u0572\u0566\u056b\u0576\u0565\u0580" },
             { "CL", "\u0549\u056b\u056c\u056b" },
             { "CM", "\u053f\u0561\u0574\u0565\u0580\u0578\u0582\u0576" },
@@ -170,7 +171,7 @@ public class LocaleNames_hy extends OpenListResourceBundle {
             { "ach", "\u0561\u0579\u0578\u056c\u056b" },
             { "Brai", "\u0562\u0580\u0561\u0575\u056c\u056b" },
             { "DM", "\u0534\u0578\u0574\u056b\u0576\u056b\u056f\u0561" },
-            { "type.nu.armnlow", "\u0570\u0561\u0575\u056f\u0561\u056f\u0561\u0576 \u0569\u057e\u0565\u0580 (\u0583\u0578\u0584\u0580\u0561\u057f\u0561\u057c)" },
+            { "type.nu.armnlow", "\u0570\u0561\u0575\u056f\u0561\u056f\u0561\u0576 \u0583\u0578\u0584\u0580\u0561\u057f\u0561\u057c \u0569\u057e\u0561\u0576\u056b\u0577\u0565\u0580" },
             { "DO", "\u0534\u0578\u0574\u056b\u0576\u056b\u056f\u0575\u0561\u0576 \u0540\u0561\u0576\u0580\u0561\u057a\u0565\u057f\u0578\u0582\u0569\u0575\u0578\u0582\u0576" },
             { "gor", "\u0563\u0578\u0580\u0578\u0576\u057f\u0561\u056c\u0578" },
             { "got", "\u0563\u0578\u0569\u0565\u0580\u0565\u0576" },
@@ -309,6 +310,7 @@ public class LocaleNames_hy extends OpenListResourceBundle {
             { "LC", "\u054d\u0565\u0576\u0569 \u053c\u0575\u0578\u0582\u057d\u056b\u0561" },
             { "phn", "\u0583\u0575\u0578\u0582\u0576\u056b\u056f\u0565\u0580\u0565\u0576" },
             { "gwi", "\u0563\u057e\u056b\u0579\u056b\u0576" },
+            { "nds", "\u057d\u057f\u0578\u0580\u056b\u0576 \u0563\u0565\u0580\u0574\u0561\u0576\u0565\u0580\u0565\u0576" },
             { "LI", "\u053c\u056b\u056d\u057f\u0565\u0576\u0577\u057f\u0565\u0575\u0576" },
             { "LK", "\u0547\u0580\u056b \u053c\u0561\u0576\u056f\u0561" },
             { "akk", "\u0561\u0584\u0584\u0561\u0564\u0565\u0580\u0565\u0576" },
@@ -393,7 +395,7 @@ public class LocaleNames_hy extends OpenListResourceBundle {
             { "PT", "\u054a\u0578\u0580\u057f\u0578\u0582\u0563\u0561\u056c\u056b\u0561" },
             { "PW", "\u054a\u0561\u056c\u0561\u0578\u0582" },
             { "nia", "\u0576\u056b\u0561\u057d\u0565\u0580\u0565\u0576" },
-            { "type.nu.greklow", "\u0570\u0578\u0582\u0576\u0561\u056f\u0561\u0576 \u0569\u057e\u0565\u0580 (\u0583\u0578\u0584\u0580\u0561\u057f\u0561\u057c)" },
+            { "type.nu.greklow", "\u0570\u0578\u0582\u0576\u0561\u056f\u0561\u0576 \u0583\u0578\u0584\u0580\u0561\u057f\u0561\u057c \u0569\u057e\u0561\u0576\u056b\u0577\u0565\u0580" },
             { "PY", "\u054a\u0561\u0580\u0561\u0563\u057e\u0561\u0575" },
             { "tum", "\u057f\u0578\u0582\u0574\u0562\u0578\u0582\u056f\u0561" },
             { "Hebr", "\u0565\u0562\u0580\u0561\u0575\u0561\u056f\u0561\u0576" },
@@ -442,7 +444,7 @@ public class LocaleNames_hy extends OpenListResourceBundle {
             { "SO", "\u054d\u0578\u0574\u0561\u056c\u056b" },
             { "arn", "\u0574\u0561\u057a\u0578\u0582\u0579\u056b" },
             { "arp", "\u0561\u0580\u0561\u057a\u0561\u0570\u0578" },
-            { "type.nu.taml", "\u0569\u0561\u0574\u056b\u056c\u0561\u056f\u0561\u0576 \u0561\u057e\u0561\u0576\u0564\u0561\u056f\u0561\u0576 \u0569\u057e\u0565\u0580" },
+            { "type.nu.taml", "\u0569\u0561\u0574\u056b\u056c\u0561\u056f\u0561\u0576 \u0561\u057e\u0561\u0576\u0564\u0561\u056f\u0561\u0576 \u0569\u057e\u0561\u0576\u056b\u0577\u0565\u0580" },
             { "SR", "\u054d\u0578\u0582\u0580\u056b\u0576\u0561\u0574" },
             { "SS", "\u0540\u0561\u0580\u0561\u057e\u0561\u0575\u056b\u0576 \u054d\u0578\u0582\u0564\u0561\u0576" },
             { "ST", "\u054d\u0561\u0576 \u054f\u0578\u0574\u0565 \u0587 \u0553\u0580\u056b\u0576\u057d\u056b\u057a\u056b" },
@@ -525,7 +527,9 @@ public class LocaleNames_hy extends OpenListResourceBundle {
             { "WS", "\u054d\u0561\u0574\u0578\u0561" },
             { "wal", "\u057e\u0578\u056c\u0561\u0575\u057f\u0561" },
             { "was", "\u057e\u0561\u0577\u0578" },
+            { "XA", "\u056f\u0565\u0572\u056e \u057f\u0561\u0580\u0562\u0565\u0580\u056b\u0579\u0576\u0565\u0580" },
             { "war", "\u057e\u0561\u0580\u0561\u0575\u0565\u0580\u0565\u0576" },
+            { "XB", "\u056f\u0565\u0572\u056e \u0565\u0580\u056f\u0578\u0582\u0572\u0572\u057e\u0561\u056e" },
             { "awa", "\u0561\u057e\u0561\u0564\u0570\u056b" },
             { "061", "\u054a\u0578\u056c\u056b\u0576\u0565\u0566\u056b\u0561" },
             { "XK", "\u053f\u0578\u057d\u0578\u057e\u0578" },
@@ -539,7 +543,7 @@ public class LocaleNames_hy extends OpenListResourceBundle {
             { "ZA", "\u0540\u0561\u0580\u0561\u057e\u0561\u0586\u0580\u056b\u056f\u0575\u0561\u0576 \u0540\u0561\u0576\u0580\u0561\u057a\u0565\u057f\u0578\u0582\u0569\u0575\u0578\u0582\u0576" },
             { "type.lb.loose", "\u0583\u0561\u0583\u0578\u0582\u056f \u057f\u0578\u0572\u0561\u0576\u0581\u0578\u0582\u0574" },
             { "Deva", "\u0564\u0565\u0582\u0561\u0576\u0561\u0563\u0561\u0580\u056b" },
-            { "type.nu.geor", "\u057e\u0580\u0561\u0581\u0561\u056f\u0561\u0576 \u0569\u057e\u0565\u0580" },
+            { "type.nu.geor", "\u057e\u0580\u0561\u0581\u0561\u056f\u0561\u0576 \u0569\u057e\u0561\u0576\u056b\u0577\u0565\u0580" },
             { "Hira", "\u0570\u056b\u0580\u0561\u0563\u0561\u0576\u0561" },
             { "ZM", "\u0536\u0561\u0574\u0562\u056b\u0561" },
             { "ZW", "\u0536\u056b\u0574\u0562\u0561\u0562\u057e\u0565" },
@@ -550,7 +554,7 @@ public class LocaleNames_hy extends OpenListResourceBundle {
             { "type.nu.telu", "\u0569\u0565\u056c\u0578\u0582\u0563\u0578\u0582 \u0569\u057e\u0561\u0576\u0577\u0561\u0576\u0576\u0565\u0580" },
             { "loz", "\u056c\u0578\u0566\u056b" },
             { "jmc", "\u0574\u0561\u0577\u0561\u0574\u0565" },
-            { "type.nu.hansfin", "\u0579\u056b\u0576\u0561\u056f\u0561\u0576 \u057a\u0561\u0580\u0566\u0565\u0581\u057e\u0561\u056e \u0586\u056b\u0576\u0561\u0576\u057d\u0561\u056f\u0561\u0576 \u0569\u057e\u0565\u0580" },
+            { "type.nu.hansfin", "\u0579\u056b\u0576\u0561\u056f\u0561\u0576 \u057a\u0561\u0580\u0566\u0565\u0581\u057e\u0561\u056e \u0586\u056b\u0576\u0561\u0576\u057d\u0561\u056f\u0561\u0576 \u0569\u057e\u0561\u0576\u056b\u0577\u0565\u0580" },
             { "hil", "\u0570\u056b\u056c\u056b\u0563\u0561\u0575\u0576\u0578\u0576" },
             { "type.nu.arabext", "\u0561\u0580\u0561\u0562\u0561-\u0570\u0576\u0564\u056f\u0561\u056f\u0561\u0576 \u0569\u057e\u0565\u0580\u056b \u0568\u0576\u0564\u056c\u0561\u0575\u0576\u057e\u0561\u056e \u0570\u0561\u0574\u0561\u056f\u0561\u0580\u0563" },
             { "nus", "\u0576\u0578\u0582\u0565\u0580" },
@@ -562,7 +566,7 @@ public class LocaleNames_hy extends OpenListResourceBundle {
             { "udm", "\u0578\u0582\u0564\u0574\u0578\u0582\u0580\u057f\u0565\u0580\u0565\u0576" },
             { "Khmr", "\u0584\u0574\u0565\u0580\u0561\u056f\u0561\u0576" },
             { "sad", "\u057d\u0561\u0576\u0564\u0561\u057e\u0565" },
-            { "type.nu.roman", "\u0570\u057c\u0578\u0574\u0565\u0561\u056f\u0561\u0576 \u0569\u057e\u0565\u0580" },
+            { "type.nu.roman", "\u0570\u057c\u0578\u0574\u0565\u0561\u056f\u0561\u0576 \u0569\u057e\u0561\u0576\u056b\u0577\u0565\u0580" },
             { "sah", "\u0575\u0561\u056f\u0578\u0582\u057f\u0565\u0580\u0565\u0576" },
             { "saq", "\u057d\u0561\u0574\u0562\u0578\u0582\u0580\u0578\u0582" },
             { "sat", "\u057d\u0561\u0576\u057f\u0561\u056c\u056b" },
@@ -619,10 +623,10 @@ public class LocaleNames_hy extends OpenListResourceBundle {
             { "co", "\u056f\u0578\u0580\u057d\u056b\u056f\u0565\u0580\u0565\u0576" },
             { "Orya", metaValue_or },
             { "cs", "\u0579\u0565\u056d\u0565\u0580\u0565\u0576" },
-            { "cu", "\u0565\u056f\u0565\u0572\u0565\u0581\u0561\u056f\u0561\u0576 \u057d\u056c\u0561\u057e\u0578\u0576\u0565\u0580\u0565\u0576" },
+            { "cu", "\u057d\u056c\u0561\u057e\u0578\u0576\u0565\u0580\u0565\u0576, \u0565\u056f\u0565\u0572\u0565\u0581\u0561\u056f\u0561\u0576" },
             { "cv", "\u0579\u0578\u0582\u057e\u0561\u0577\u0565\u0580\u0565\u0576" },
             { "cy", "\u0578\u0582\u0565\u056c\u057d\u0565\u0580\u0565\u0576" },
-            { "type.nu.ethi", "\u0565\u0569\u0578\u057e\u057a\u0561\u056f\u0561\u0576 \u0569\u057e\u0561\u0576\u0577\u0561\u0576\u0576\u0565\u0580" },
+            { "type.nu.ethi", "\u0565\u0569\u0578\u057e\u057a\u0561\u056f\u0561\u0576 \u0569\u057e\u0561\u0576\u056b\u0577\u0565\u0580" },
             { "da", "\u0564\u0561\u0576\u056b\u0565\u0580\u0565\u0576" },
             { "pt_PT", "\u0565\u057e\u0580\u0578\u057a\u0561\u056f\u0561\u0576 \u057a\u0578\u0580\u057f\u0578\u0582\u0563\u0561\u056c\u0565\u0580\u0565\u0576" },
             { "de", "\u0563\u0565\u0580\u0574\u0561\u0576\u0565\u0580\u0565\u0576" },
@@ -635,7 +639,7 @@ public class LocaleNames_hy extends OpenListResourceBundle {
             { "bez", "\u0562\u0565\u0576\u0561" },
             { "type.ca.chinese", "\u0579\u056b\u0576\u0561\u056f\u0561\u0576 \u0585\u0580\u0561\u0581\u0578\u0582\u0575\u0581" },
             { "dje", "\u0566\u0561\u0580\u0574\u0561" },
-            { "type.nu.grek", "\u0570\u0578\u0582\u0576\u0561\u056f\u0561\u0576 \u0569\u057e\u0565\u0580" },
+            { "type.nu.grek", "\u0570\u0578\u0582\u0576\u0561\u056f\u0561\u0576 \u0569\u057e\u0561\u0576\u056b\u0577\u0565\u0580" },
             { "ee", "\u0567\u057e\u0565" },
             { "type.lb.normal", "\u057d\u0578\u057e\u0578\u0580\u0561\u056f\u0561\u0576 \u057f\u0578\u0572\u0561\u0576\u0581\u0578\u0582\u0574" },
             { "ro_MD", "\u0574\u0578\u056c\u0564\u0578\u057e\u0565\u0580\u0565\u0576" },
@@ -773,7 +777,7 @@ public class LocaleNames_hy extends OpenListResourceBundle {
             { "men", "\u0574\u0565\u0576\u0564\u0565" },
             { "oj", "\u0585\u057b\u056b\u0562\u057e\u0561" },
             { "mer", "\u0574\u0565\u0580\u0578\u0582" },
-            { "type.nu.armn", "\u0570\u0561\u0575\u056f\u0561\u056f\u0561\u0576 \u0569\u057e\u0561\u0576\u0577\u0561\u0576\u0576\u0565\u0580" },
+            { "type.nu.armn", "\u0570\u0561\u0575\u056f\u0561\u056f\u0561\u0576 \u0569\u057e\u0561\u0576\u056b\u0577\u0565\u0580" },
             { "om", "\u0585\u0580\u0578\u0574\u0578" },
             { "or", metaValue_or },
             { "os", "\u0585\u057d\u0565\u0580\u0565\u0576" },
@@ -842,7 +846,7 @@ public class LocaleNames_hy extends OpenListResourceBundle {
             { "su", "\u057d\u0578\u0582\u0576\u0564\u0561\u0576\u0565\u0580\u0565\u0576" },
             { "sv", "\u0577\u057e\u0565\u0564\u0565\u0580\u0565\u0576" },
             { "sw", "\u057d\u0578\u0582\u0561\u0570\u056b\u056c\u056b" },
-            { "type.nu.hantfin", "\u0579\u056b\u0576\u0561\u056f\u0561\u0576 \u0561\u057e\u0561\u0576\u0564\u0561\u056f\u0561\u0576 \u0586\u056b\u0576\u0561\u0576\u057d\u0561\u056f\u0561\u0576 \u0569\u057e\u0565\u0580" },
+            { "type.nu.hantfin", "\u0579\u056b\u0576\u0561\u056f\u0561\u0576 \u0561\u057e\u0561\u0576\u0564\u0561\u056f\u0561\u0576 \u0586\u056b\u0576\u0561\u0576\u057d\u0561\u056f\u0561\u0576 \u0569\u057e\u0561\u0576\u056b\u0577\u0565\u0580" },
             { "ibb", "\u056b\u0562\u056b\u0562\u056b\u0578" },
             { "iba", "\u056b\u0562\u0561\u0576\u0565\u0580\u0565\u0576" },
             { "ta", "\u0569\u0561\u0574\u056b\u056c\u0565\u0580\u0565\u0576" },
@@ -861,7 +865,7 @@ public class LocaleNames_hy extends OpenListResourceBundle {
             { "tn", "\u0581\u057e\u0561\u0576\u0561" },
             { "to", "\u057f\u0578\u0576\u0563\u0565\u0580\u0565\u0576" },
             { "dyo", "\u057b\u0578\u056c\u0561-\u0586\u0578\u0576\u0575\u056b" },
-            { "type.nu.jpan", "\u0573\u0561\u057a\u0578\u0576\u0561\u056f\u0561\u0576 \u0569\u057e\u0565\u0580" },
+            { "type.nu.jpan", "\u0573\u0561\u057a\u0578\u0576\u0561\u056f\u0561\u0576 \u0569\u057e\u0561\u0576\u056b\u0577\u0565\u0580" },
             { "tr", "\u0569\u0578\u0582\u0580\u0584\u0565\u0580\u0565\u0576" },
             { "ts", "\u0581\u0578\u0576\u0563\u0561" },
             { "swb", "\u056f\u0578\u0574\u0578\u0580\u0565\u0580\u0565\u0576" },
@@ -902,10 +906,10 @@ public class LocaleNames_hy extends OpenListResourceBundle {
             { "Mong", "\u0574\u0578\u0576\u0572\u0578\u056c\u0561\u056f\u0561\u0576" },
             { "mni", "\u0574\u0561\u0576\u056b\u057a\u0578\u0582\u0580\u056b" },
             { "Latn", "\u056c\u0561\u057f\u056b\u0576\u0561\u056f\u0561\u0576" },
-            { "type.nu.hans", "\u0579\u056b\u0576\u0561\u056f\u0561\u0576 \u057a\u0561\u0580\u0566\u0565\u0581\u057e\u0561\u056e \u0569\u057e\u0565\u0580" },
-            { "type.nu.hant", "\u0579\u056b\u0576\u0561\u056f\u0561\u0576 \u0561\u057e\u0561\u0576\u0564\u0561\u056f\u0561\u0576 \u0569\u057e\u0565\u0580" },
+            { "type.nu.hans", "\u0579\u056b\u0576\u0561\u056f\u0561\u0576 \u057a\u0561\u0580\u0566\u0565\u0581\u057e\u0561\u056e \u0569\u057e\u0561\u0576\u056b\u0577\u0565\u0580" },
+            { "type.nu.hant", "\u0579\u056b\u0576\u0561\u056f\u0561\u0576 \u0561\u057e\u0561\u0576\u0564\u0561\u056f\u0561\u0576 \u0569\u057e\u0561\u0576\u056b\u0577\u0565\u0580" },
             { "xh", "\u0584\u0578\u057d\u0561" },
-            { "type.nu.romanlow", "\u0570\u057c\u0578\u0574\u0565\u0561\u056f\u0561\u0576 \u0569\u057e\u0565\u0580 (\u0583\u0578\u0584\u0580\u0561\u057f\u0561\u057c)" },
+            { "type.nu.romanlow", "\u0570\u057c\u0578\u0574\u0565\u0561\u056f\u0561\u0576 \u0583\u0578\u0584\u0580\u0561\u057f\u0561\u057c \u0569\u057e\u0561\u0576\u056b\u0577\u0565\u0580" },
             { "byn", "\u0562\u056b\u056c\u056b\u0576" },
             { "osa", "\u0585\u057d\u0565\u0575\u057b" },
             { "gbz", "\u0566\u0580\u0561\u0564\u0561\u0577\u057f\u0561\u056f\u0561\u0576 \u0564\u0561\u0580\u056b" },
@@ -925,7 +929,7 @@ public class LocaleNames_hy extends OpenListResourceBundle {
             { "zu", "\u0566\u0578\u0582\u056c\u0578\u0582\u0565\u0580\u0565\u0576" },
             { "Geor", "\u057e\u0580\u0561\u0581\u0561\u056f\u0561\u0576" },
             { "kmb", "\u056f\u056b\u0574\u0562\u0578\u0582\u0576\u0564\u0578\u0582" },
-            { "type.nu.jpanfin", "\u0573\u0561\u057a\u0578\u0576\u0561\u056f\u0561\u0576 \u0586\u056b\u0576\u0561\u0576\u057d\u0561\u056f\u0561\u0576 \u0569\u057e\u0565\u0580" },
+            { "type.nu.jpanfin", "\u0573\u0561\u057a\u0578\u0576\u0561\u056f\u0561\u0576 \u0586\u056b\u0576\u0561\u0576\u057d\u0561\u056f\u0561\u0576 \u0569\u057e\u0561\u0576\u056b\u0577\u0565\u0580" },
             { "gez", "\u0563\u0565\u0565\u0566" },
             { "mrj", "\u0561\u0580\u0587\u0574\u057f\u0561\u0574\u0561\u0580\u056b\u0565\u0580\u0565\u0576" },
             { "ebu", "\u0567\u0574\u0562\u0578\u0582" },
@@ -933,7 +937,7 @@ public class LocaleNames_hy extends OpenListResourceBundle {
             { "koi", "\u057a\u0565\u0580\u0574\u0575\u0561\u056f \u056f\u0578\u0574\u056b\u0565\u0580\u0565\u0576" },
             { "kok", "\u056f\u0578\u0576\u056f\u0561\u0576\u056b" },
             { "vec", "\u057e\u0565\u0576\u0565\u057f\u0565\u0580\u0565\u0576" },
-            { "zh_Hant", "\u0561\u057e\u0561\u0576\u0564\u0561\u056f\u0561\u0576 \u0579\u056b\u0576\u0561\u0580\u0565\u0576" },
+            { "zh_Hant", "\u0579\u056b\u0576\u0561\u0580\u0565\u0576, \u0561\u057e\u0561\u0576\u0564\u0561\u056f\u0561\u0576" },
             { "vep", "\u057e\u0565\u057a\u057d\u0565\u0580\u0565\u0576" },
             { "kpe", "\u056f\u057a\u0565\u056c\u056c\u0565\u0565\u0580\u0565\u0576" },
             { "type.nu.khmr", "\u0584\u0574\u0565\u0580\u0561\u056f\u0561\u0576 \u0569\u057e\u0561\u0576\u0577\u0561\u0576\u0576\u0565\u0580" },
@@ -947,6 +951,7 @@ public class LocaleNames_hy extends OpenListResourceBundle {
             { "type.nu.tamldec", "\u0569\u0561\u0574\u056b\u056c\u0561\u056f\u0561\u0576 \u0569\u057e\u0561\u0576\u0577\u0561\u0576\u0576\u0565\u0580" },
             { "krc", "\u056f\u0561\u0580\u0561\u0579\u0561\u0575-\u0562\u0561\u056c\u056f\u0561\u0580\u0565\u0580\u0565\u0576" },
             { "inh", "\u056b\u0576\u0563\u0578\u0582\u0577\u0565\u0580\u0565\u0576" },
+            { "fa_AF", "\u0564\u0561\u0580\u056b" },
             { "krl", "\u056f\u0561\u0580\u0565\u056c\u0565\u0580\u0565\u0576" },
             { "efi", "\u0567\u0586\u056b\u056f" },
             { "tcy", "\u057f\u0578\u0582\u056c\u0578\u0582" },
