@@ -82,6 +82,7 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "cch", "atsam" },
             { "mwr", "marvar\u00ed" },
             { "Zsye", "emoji-t\u00e1kn" },
+            { "ccp", "tsjakma" },
             { "egy", "fornegypska" },
             { "raj", "rajastan\u00ed" },
             { "tem", "t\u00edmne" },
@@ -265,7 +266,6 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "HU", "Ungverjaland" },
             { "tmh", "tamasjek" },
             { "IC", "Kanar\u00edeyjar" },
-            { "nan", "nan" },
             { "ID", "Ind\u00f3nes\u00eda" },
             { "peo", "fornpersneska" },
             { "IE", "\u00cdrland" },
@@ -340,7 +340,7 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "MC", "M\u00f3nak\u00f3" },
             { "MD", "Mold\u00f3va" },
             { "ME", "Svartfjallaland" },
-            { "MF", "St. Martin" },
+            { "MF", "Saint-Martin" },
             { "lam", "lamba" },
             { "MG", "Madagaskar" },
             { "MH", "Marshalleyjar" },
@@ -506,7 +506,6 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "hai", "ha\u00edda" },
             { "035", "Su\u00f0austur-As\u00eda" },
             { "UG", "\u00daganda" },
-            { "hak", "hak" },
             { "type.co.pinyin", "Pinyin-r\u00f6\u00f0un" },
             { "039", "Su\u00f0ur-Evr\u00f3pa" },
             { "Sinh", "sinhala" },
@@ -545,7 +544,9 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "WS", "Sam\u00f3a" },
             { "wal", "volayatta" },
             { "was", "vasj\u00f3" },
+            { "XA", "gervihreimur" },
             { "war", "vara\u00ed" },
+            { "XB", "gervista\u00f0ur" },
             { "awa", "avad\u00ed" },
             { "061", "P\u00f3l\u00fdnes\u00eda" },
             { "XK", "K\u00f3s\u00f3v\u00f3" },
@@ -707,7 +708,6 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "type.nu.latn", "Vestr\u00e6nar t\u00f6lur" },
             { "Hant", "hef\u00f0bundi\u00f0" },
             { "ff", "f\u00fala" },
-            { "hsn", "hsn" },
             { "fi", "finnska" },
             { "fj", "f\u00eddjeyska" },
             { "fon", "f\u00f3n" },
@@ -770,7 +770,6 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "ka", "georg\u00edska" },
             { "bla", "siksika" },
             { "mak", "makasar" },
-            { "wuu", "wuu" },
             { "sms", "skoltesam\u00edska" },
             { "man", "manding\u00f3" },
             { "kg", "kong\u00f3ska" },
@@ -830,7 +829,7 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "nr", "su\u00f0urndebele" },
             { "nv", "navah\u00f3" },
             { "kaa", "karakalpak" },
-            { "ny", "njanja; s\u00edsjeva; sjeva" },
+            { "ny", "n\u00fdanja" },
             { "kac", "kas\u00edn" },
             { "kab", "kab\u00edle" },
             { "oc", "oks\u00edtan\u00edska" },
@@ -1033,6 +1032,7 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "type.nu.tamldec", "Tam\u00edlskar t\u00f6lur" },
             { "krc", "karasa\u00edbalkar" },
             { "inh", "ing\u00fas" },
+            { "fa_AF", "dar\u00ed" },
             { "krl", "kar\u00e9lska" },
             { "efi", "ef\u00edk" },
             { "key.nu", "T\u00f6lur" },
