@@ -279,7 +279,6 @@ public class LocaleNames_it extends OpenListResourceBundle {
             { "pcd", "piccardo" },
             { "tkl", "tokelau" },
             { "grb", "grebo" },
-            { "root", "root" },
             { "%%DAJNKO", "alfabeto Dajnko" },
             { "type.ca.indian", "calendario nazionale indiano" },
             { "rgn", "romagnolo" },
@@ -602,6 +601,7 @@ public class LocaleNames_it extends OpenListResourceBundle {
             { "TC", "Isole Turks e Caicos" },
             { "yav", "yangben" },
             { "TD", "Ciad" },
+            { "Qaag", "zawgyi" },
             { "TF", "Terre australi francesi" },
             { "ase", "lingua dei segni americana" },
             { "TG", "Togo" },
@@ -686,9 +686,9 @@ public class LocaleNames_it extends OpenListResourceBundle {
             { "type.nu.mtei", "Cifre Meetei Mayek" },
             { "wal", "walamo" },
             { "was", "washo" },
-            { "XA", "pseudo-accenti" },
+            { "XA", "Pseudo-accenti" },
             { "war", "waray" },
-            { "XB", "pseudo-bidi" },
+            { "XB", "Pseudo-bidi" },
             { "awa", "awadhi" },
             { "061", "Polinesia" },
             { "%%KSCOR", "ortografia standard" },
@@ -796,6 +796,7 @@ public class LocaleNames_it extends OpenListResourceBundle {
             { "scn", "siciliano" },
             { "aa", "afar" },
             { "ab", "abcaso" },
+            { "Aran", "nastaliq" },
             { "bbc", "batak toba" },
             { "ae", "avestan" },
             { "af", "afrikaans" },
@@ -1331,6 +1332,7 @@ public class LocaleNames_it extends OpenListResourceBundle {
             { "type.nu.tamldec", "Cifre tamil" },
             { "krc", "karachay-Balkar" },
             { "inh", "ingush" },
+            { "fa_AF", "dari" },
             { "krl", "careliano" },
             { "efi", "efik" },
             { "tcy", "tulu" },
