@@ -73,9 +73,9 @@ public class LocaleNames_iw extends OpenListResourceBundle {
         final String metaValue_TK = "\u05d8\u05d5\u05e7\u05dc\u05d0\u05d5";
         final String metaValue_TV = "\u05d8\u05d5\u05d1\u05d0\u05dc\u05d5";
         final String metaValue_ml = "\u05de\u05dc\u05d9\u05d0\u05dc\u05d0\u05dd";
-        final String metaValue_or = "\u05d0\u05d5\u05e8\u05d9\u05d9\u05d4";
         final String metaValue_si = "\u05e1\u05d9\u05e0\u05d4\u05dc\u05d4";
         final String metaValue_te = "\u05d8\u05dc\u05d5\u05d2\u05d5";
+        final String metaValue_nqo = "\u05e0\u05f3\u05e7\u05d5";
         final Object[][] data = new Object[][] {
             { "ksh", "\u05e7\u05d5\u05dc\u05d5\u05e0\u05d9\u05d0\u05df" },
             { "mwl", "\u05de\u05d9\u05e8\u05e0\u05d3\u05d6\u05d9\u05ea" },
@@ -181,6 +181,7 @@ public class LocaleNames_iw extends OpenListResourceBundle {
             { "DO", "\u05d4\u05e8\u05e4\u05d5\u05d1\u05dc\u05d9\u05e7\u05d4 \u05d4\u05d3\u05d5\u05de\u05d9\u05e0\u05d9\u05e7\u05e0\u05d9\u05ea" },
             { "gor", "\u05d2\u05d5\u05e8\u05d5\u05e0\u05d8\u05d0\u05dc\u05d5" },
             { "got", "\u05d2\u05d5\u05ea\u05d9\u05ea" },
+            { "Mtei", "\u05de\u05d0\u05d9\u05d8\u05d9 \u05de\u05d0\u05d9\u05d9\u05e7" },
             { "zun", "\u05d6\u05d5\u05e0\u05d9" },
             { "tig", "\u05d8\u05d9\u05d2\u05e8\u05d9\u05ea" },
             { "DZ", "\u05d0\u05dc\u05d2\u05f3\u05d9\u05e8\u05d9\u05d4" },
@@ -252,7 +253,7 @@ public class LocaleNames_iw extends OpenListResourceBundle {
             { "GU", "\u05d2\u05d5\u05d0\u05dd" },
             { "GW", "\u05d2\u05d9\u05e0\u05d0\u05d4-\u05d1\u05d9\u05e1\u05d0\u05d5" },
             { "tli", "\u05d8\u05dc\u05d9\u05e0\u05d2\u05d9\u05d8" },
-            { "tlh", "\u05e7\u05dc\u05d9\u05e0\u05d2\u05d5\u05df" },
+            { "tlh", "\u05e7\u05dc\u05d9\u05e0\u05d2\u05d5\u05e0\u05d9\u05ea" },
             { "GY", "\u05d2\u05d9\u05d0\u05e0\u05d4" },
             { "ckb", "\u05db\u05d5\u05e8\u05d3\u05d9\u05ea \u05e1\u05d5\u05e8\u05d0\u05e0\u05d9\u05ea" },
             { "zxx", "\u05dc\u05dc\u05d0 \u05ea\u05d5\u05db\u05df \u05dc\u05e9\u05d5\u05e0\u05d9" },
@@ -261,7 +262,7 @@ public class LocaleNames_iw extends OpenListResourceBundle {
             { "HN", "\u05d4\u05d5\u05e0\u05d3\u05d5\u05e8\u05e1" },
             { "HR", "\u05e7\u05e8\u05d5\u05d0\u05d8\u05d9\u05d4" },
             { "agq", "\u05d0\u05e2\u05f3\u05dd" },
-            { "gsw", "\u05d2\u05e8\u05de\u05e0\u05d9\u05ea \u05e9\u05d5\u05d5\u05d9\u05e6\u05e8\u05d9\u05ea" },
+            { "gsw", "\u05d2\u05e8\u05de\u05e0\u05d9\u05ea (\u05d1\u05e9\u05d5\u05d5\u05d9\u05e5)" },
             { "type.ca.islamic-umalqura", "\u05dc\u05d5\u05d7 \u05d4\u05e9\u05e0\u05d4 \u05d4\u05de\u05d5\u05e1\u05dc\u05de\u05d9 \u05d0\u05d5\u05dd \u05d0\u05dc-\u05e7\u05d5\u05e8\u05d0" },
             { "HT", "\u05d4\u05d0\u05d9\u05d8\u05d9" },
             { "HU", "\u05d4\u05d5\u05e0\u05d2\u05e8\u05d9\u05d4" },
@@ -484,6 +485,7 @@ public class LocaleNames_iw extends OpenListResourceBundle {
             { "TC", "\u05d0\u05d9\u05d9 \u05d8\u05e8\u05e7\u05e1 \u05d5\u05e7\u05d9\u05d9\u05e7\u05d5\u05e1" },
             { "yav", "\u05d9\u05d0\u05e0\u05d2\u05d1\u05df" },
             { "TD", "\u05e6\u05f3\u05d0\u05d3" },
+            { "Qaag", "\u05d6\u05d0\u05d5\u05d2\u05d9\u05d9" },
             { "TF", "\u05d4\u05d8\u05e8\u05d9\u05d8\u05d5\u05e8\u05d9\u05d5\u05ea \u05d4\u05d3\u05e8\u05d5\u05de\u05d9\u05d5\u05ea \u05e9\u05dc \u05e6\u05e8\u05e4\u05ea" },
             { "TG", "\u05d8\u05d5\u05d2\u05d5" },
             { "TH", "\u05ea\u05d0\u05d9\u05dc\u05e0\u05d3" },
@@ -553,15 +555,18 @@ public class LocaleNames_iw extends OpenListResourceBundle {
             { "WS", "\u05e1\u05de\u05d5\u05d0\u05d4" },
             { "wal", "\u05d5\u05d5\u05dc\u05d9\u05d0\u05d8\u05d4" },
             { "was", "\u05d5\u05d5\u05d0\u05e9\u05d5" },
+            { "XA", "\u05de\u05d1\u05d8\u05d0\u05d9\u05dd \u05d7\u05dc\u05e7\u05d9\u05d9\u05dd" },
             { "war", "\u05d5\u05d5\u05e8\u05d0\u05d9" },
+            { "XB", "\u05d3\u05d5-\u05db\u05d9\u05d5\u05d5\u05e0\u05d9 \u05d7\u05dc\u05e7\u05d9" },
             { "awa", "\u05d0\u05d5\u05d5\u05d0\u05d3\u05d9\u05ea" },
             { "061", "\u05e4\u05d5\u05dc\u05d9\u05e0\u05d6\u05d9\u05d4" },
             { "XK", "\u05e7\u05d5\u05e1\u05d5\u05d1\u05d5" },
             { "Gujr", "\u05d2\u05d5\u05d2\u05f3\u05e8\u05d8\u05d9" },
             { "Zxxx", "\u05dc\u05d0 \u05db\u05ea\u05d5\u05d1" },
+            { "Olck", "\u05d0\u05d5\u05dc \u05e6\u05f3\u05d9\u05e7\u05d9" },
             { "wbp", "\u05d5\u05d5\u05e8\u05dc\u05e4\u05d9\u05e8\u05d9" },
             { "YE", "\u05ea\u05d9\u05de\u05df" },
-            { "nqo", "\u05e0\u05f3\u05e7\u05d5" },
+            { "nqo", metaValue_nqo },
             { "type.co.standard", "\u05e1\u05d3\u05e8 \u05de\u05d9\u05d5\u05df \u05e8\u05d2\u05d9\u05dc" },
             { "fan", "\u05e4\u05e0\u05d2" },
             { "fat", "\u05e4\u05d0\u05e0\u05d8\u05d9" },
@@ -639,6 +644,7 @@ public class LocaleNames_iw extends OpenListResourceBundle {
             { "scn", "\u05e1\u05d9\u05e6\u05d9\u05dc\u05d9\u05d0\u05e0\u05d9\u05ea" },
             { "aa", "\u05d0\u05e4\u05d0\u05e8\u05d9\u05ea" },
             { "ab", "\u05d0\u05d1\u05d7\u05d6\u05d9\u05ea" },
+            { "Aran", "\u05e0\u05e1\u05ea\u05e2\u05dc\u05d9\u05e7" },
             { "ae", "\u05d0\u05d1\u05e1\u05d8\u05df" },
             { "af", "\u05d0\u05e4\u05e8\u05d9\u05e7\u05d0\u05e0\u05e1" },
             { "ak", "\u05d0\u05e7\u05d0\u05df" },
@@ -669,13 +675,14 @@ public class LocaleNames_iw extends OpenListResourceBundle {
             { "Mymr", "\u05de\u05d9\u05d0\u05e0\u05de\u05e8" },
             { "type.nu.laoo", "\u05e1\u05e4\u05e8\u05d5\u05ea \u05e9\u05dc \u05dc\u05d0\u05d5\u05e1" },
             { "seh", "\u05e1\u05e0\u05d4" },
+            { "Nkoo", metaValue_nqo },
             { "sel", "\u05e1\u05dc\u05e7\u05d5\u05e4" },
             { "ca", "\u05e7\u05d8\u05dc\u05d0\u05e0\u05d9\u05ea" },
             { "ses", "\u05e7\u05d5\u05d9\u05e8\u05d0\u05d1\u05d5\u05e8\u05d5 \u05e1\u05e0\u05d9" },
             { "ce", "\u05e6\u05f3\u05e6\u05f3\u05e0\u05d9\u05ea" },
             { "ch", "\u05e6\u05f3\u05de\u05d5\u05e8\u05d5" },
             { "co", "\u05e7\u05d5\u05e8\u05e1\u05d9\u05e7\u05e0\u05d9\u05ea" },
-            { "Orya", metaValue_or },
+            { "Orya", "\u05d0\u05d5\u05d3\u05d9\u05d9\u05d4" },
             { "cr", "\u05e7\u05e8\u05d9" },
             { "cs", "\u05e6\u05f3\u05db\u05d9\u05ea" },
             { "cu", "\u05e1\u05dc\u05d0\u05d1\u05d9\u05ea \u05db\u05e0\u05e1\u05d9\u05d9\u05ea\u05d9\u05ea \u05e2\u05ea\u05d9\u05e7\u05d4" },
@@ -706,11 +713,11 @@ public class LocaleNames_iw extends OpenListResourceBundle {
             { "type.co.big5han", "\u05de\u05d9\u05d5\u05df \u05e1\u05d9\u05e0\u05d9\u05ea \u05de\u05e1\u05d5\u05e8\u05ea\u05d9\u05ea" },
             { "es", "\u05e1\u05e4\u05e8\u05d3\u05d9\u05ea" },
             { "et", "\u05d0\u05e1\u05d8\u05d5\u05e0\u05d9\u05ea" },
-            { "Hanb", "\u05d4\u05d0\u05e0\u05d1" },
+            { "Hanb", "\u05d4\u05d0\u05df \u05e2\u05dd \u05d1\u05d5\u05e4\u05d5\u05de\u05d5\u05e4\u05d5" },
             { "eu", "\u05d1\u05e1\u05e7\u05d9\u05ea" },
             { "Hang", "\u05d4\u05d0\u05e0\u05d2\u05d5\u05dc" },
             { "shi", "\u05e9\u05d9\u05dc\u05d4" },
-            { "hsb", "\u05e1\u05d5\u05e8\u05d1\u05d9\u05ea \u05d2\u05d1\u05d5\u05d4\u05d4" },
+            { "hsb", "\u05e1\u05d5\u05e8\u05d1\u05d9\u05ea \u05e2\u05d9\u05dc\u05d9\u05ea" },
             { "Hani", "\u05d4\u05d0\u05df" },
             { "shn", "\u05e9\u05d0\u05df" },
             { "fa", "\u05e4\u05e8\u05e1\u05d9\u05ea" },
@@ -834,6 +841,7 @@ public class LocaleNames_iw extends OpenListResourceBundle {
             { "mdf", "\u05de\u05d5\u05e7\u05e9\u05d4" },
             { "mde", "\u05de\u05d0\u05d1\u05d0" },
             { "dsb", "\u05e1\u05d5\u05e8\u05d1\u05d9\u05ea \u05ea\u05d7\u05ea\u05d9\u05ea" },
+            { "Armi", "\u05d0\u05e8\u05de\u05d9\u05ea \u05e8\u05e9\u05de\u05d9\u05ea" },
             { "na", "\u05e0\u05d0\u05d5\u05e8\u05d9\u05ea" },
             { "type.co.search", "\u05d7\u05d9\u05e4\u05d5\u05e9 \u05dc\u05de\u05d8\u05e8\u05d4 \u05db\u05dc\u05dc\u05d9\u05ea" },
             { "nb", "\u05e0\u05d5\u05e8\u05d5\u05d5\u05d2\u05d9\u05ea \u05e1\u05e4\u05e8\u05d5\u05ea\u05d9\u05ea" },
@@ -859,7 +867,7 @@ public class LocaleNames_iw extends OpenListResourceBundle {
             { "type.nu.armn", "\u05e1\u05e4\u05e8\u05d5\u05ea \u05d0\u05e8\u05de\u05e0\u05d9\u05d5\u05ea" },
             { "om", "\u05d0\u05d5\u05e8\u05d5\u05de\u05d5" },
             { "kaw", "\u05e7\u05d0\u05d5\u05d5\u05d9" },
-            { "or", metaValue_or },
+            { "or", "\u05d0\u05d5\u05e8\u05d9\u05d9\u05d4" },
             { "os", "\u05d0\u05d5\u05e1\u05d8\u05d9\u05ea" },
             { "kbd", "\u05e7\u05d1\u05e8\u05d3\u05d9\u05ea" },
             { "mfe", "\u05e7\u05e8\u05d9\u05d0\u05d5\u05dc\u05d9\u05ea \u05de\u05d0\u05d5\u05e8\u05d9\u05e6\u05d9\u05d0\u05e0\u05d9\u05ea" },
@@ -881,7 +889,7 @@ public class LocaleNames_iw extends OpenListResourceBundle {
             { "key.cf", "\u05ea\u05d1\u05e0\u05d9\u05ea \u05de\u05d8\u05d1\u05e2" },
             { "bra", "\u05d1\u05e8\u05d0\u05d2\u05f3" },
             { "key.ca", "\u05dc\u05d5\u05d7 \u05e9\u05e0\u05d4" },
-            { "Laoo", "\u05dc\u05d0\u05d9\u05ea" },
+            { "Laoo", "\u05dc\u05d0\u05d9" },
             { "mgo", "\u05de\u05d8\u05d0" },
             { "type.hc.h23", "\u05de\u05e2\u05e8\u05db\u05ea \u05e9\u05dc 24 \u05e9\u05e2\u05d5\u05ea (0\u200e\u201323)" },
             { "type.hc.h24", "\u05de\u05e2\u05e8\u05db\u05ea \u05e9\u05dc 24 \u05e9\u05e2\u05d5\u05ea (1\u200e\u201324)" },
@@ -979,8 +987,8 @@ public class LocaleNames_iw extends OpenListResourceBundle {
             { "kha", "\u05e7\u05d4\u05d0\u05e1\u05d9" },
             { "nds_NL", "\u05e1\u05e7\u05e1\u05d5\u05e0\u05d9\u05ea \u05ea\u05d7\u05ea\u05d9\u05ea" },
             { "ve", "\u05d5\u05d5\u05e0\u05d3\u05d4" },
-            { "type.ca.roc", "\u05dc\u05d5\u05d7 \u05d4\u05e9\u05e0\u05d4 \u05d4\u05d8\u05d0\u05d9\u05d5\u05d5\u05e0\u05d9" },
-            { "vi", "\u05d5\u05d9\u05d0\u05d8\u05e0\u05de\u05d9\u05ea" },
+            { "type.ca.roc", "\u05dc\u05d5\u05d7 \u05d4\u05e9\u05e0\u05d4 \u05d4\u05d8\u05d9\u05d9\u05d5\u05d5\u05d0\u05e0\u05d9" },
+            { "vi", "\u05d5\u05d9\u05d9\u05d8\u05e0\u05d0\u05de\u05d9\u05ea" },
             { "kho", "\u05e7\u05d5\u05d8\u05d0\u05e0\u05d6\u05d9\u05ea" },
             { "khq", "\u05e7\u05d5\u05d9\u05e8\u05d4 \u05e6\u05f3\u05d9\u05e0\u05d9" },
             { "key.hc", "\u05de\u05d7\u05d6\u05d5\u05e8 \u05d4\u05e9\u05e2\u05d5\u05ea (12 \u05d0\u05d5 24)" },
@@ -1062,6 +1070,7 @@ public class LocaleNames_iw extends OpenListResourceBundle {
             { "type.nu.tamldec", "\u05e1\u05e4\u05e8\u05d5\u05ea \u05d8\u05de\u05d9\u05dc\u05d9\u05d5\u05ea" },
             { "krc", "\u05e7\u05e8\u05d0\u05e6\u05f3\u05d9-\u05d1\u05dc\u05e7\u05e8" },
             { "inh", "\u05d0\u05d9\u05e0\u05d2\u05d5\u05e9\u05d9\u05ea" },
+            { "fa_AF", "\u05d3\u05d0\u05e8\u05d9" },
             { "krl", "\u05e7\u05d0\u05e8\u05dc\u05d9\u05ea" },
             { "efi", "\u05d0\u05e4\u05d9\u05e7" },
             { "key.nu", "\u05de\u05e1\u05e4\u05e8\u05d9\u05dd" },
