@@ -185,7 +185,7 @@ public class LocaleNames_ja extends OpenListResourceBundle {
             { "cgg", "\u30c1\u30ac\u8a9e" },
             { "DG", "\u30c7\u30a3\u30a8\u30b4\u30ac\u30eb\u30b7\u30a2\u5cf6" },
             { "gom", "\u30b4\u30a2\u30fb\u30b3\u30f3\u30ab\u30cb\u8a9e" },
-            { "type.nu.deva", "\u30c7\u30fc\u30f4\u30a1\u30ca\u30fc\u30ac\u30ea\u30fc\u6570\u5b57" },
+            { "type.nu.deva", "\u30c7\u30fc\u30d0\u30ca\u30fc\u30ac\u30ea\u30fc\u6570\u5b57" },
             { "DJ", "\u30b8\u30d6\u30c1" },
             { "DK", "\u30c7\u30f3\u30de\u30fc\u30af" },
             { "ach", "\u30a2\u30c1\u30e7\u30ea\u8a9e" },
@@ -242,7 +242,7 @@ public class LocaleNames_ja extends OpenListResourceBundle {
             { "FM", "\u30df\u30af\u30ed\u30cd\u30b7\u30a2\u9023\u90a6" },
             { "key.va", "\u30ed\u30b1\u30fc\u30eb\u306e\u30d0\u30ea\u30a2\u30f3\u30c8" },
             { "FO", "\u30d5\u30a7\u30ed\u30fc\u8af8\u5cf6" },
-            { "Taml", "\u30bf\u30df\u30fc\u30eb\u6587\u5b57" },
+            { "Taml", "\u30bf\u30df\u30eb\u6587\u5b57" },
             { "FR", "\u30d5\u30e9\u30f3\u30b9" },
             { "Kpel", "\u30af\u30da\u30ec\u6587\u5b57" },
             { "pcd", "\u30d4\u30ab\u30eb\u30c7\u30a3\u8a9e" },
@@ -551,7 +551,7 @@ public class LocaleNames_ja extends OpenListResourceBundle {
             { "SO", "\u30bd\u30de\u30ea\u30a2" },
             { "arn", "\u30de\u30d7\u30c1\u30a7\u8a9e" },
             { "arp", "\u30a2\u30e9\u30d1\u30db\u30fc\u8a9e" },
-            { "type.nu.taml", "\u30bf\u30df\u30fc\u30eb\u6570\u5b57" },
+            { "type.nu.taml", "\u4f1d\u7d71\u7684\u30bf\u30df\u30eb\u6570\u5b57" },
             { "SR", "\u30b9\u30ea\u30ca\u30e0" },
             { "aro", "\u30a2\u30e9\u30aa\u30ca\u8a9e" },
             { "SS", "\u5357\u30b9\u30fc\u30c0\u30f3" },
@@ -600,7 +600,7 @@ public class LocaleNames_ja extends OpenListResourceBundle {
             { "Orkh", "\u30aa\u30eb\u30db\u30f3\u6587\u5b57" },
             { "TZ", "\u30bf\u30f3\u30b6\u30cb\u30a2" },
             { "nmg", "\u30af\u30ef\u30b7\u30aa\u8a9e" },
-            { "Zzzz", "\u672a\u5b9a\u7fa9\u6587\u5b57" },
+            { "Zzzz", "\u4e0d\u660e\u306a\u6587\u5b57" },
             { "Sind", "\u30af\u30c0\u30ef\u30c7\u30a3\u6587\u5b57" },
             { "UA", "\u30a6\u30af\u30e9\u30a4\u30ca" },
             { "lij", "\u30ea\u30b0\u30ea\u30a2\u8a9e" },
@@ -659,7 +659,9 @@ public class LocaleNames_ja extends OpenListResourceBundle {
             { "type.nu.mtei", "\u30de\u30cb\u30d7\u30ea\u6570\u5b57" },
             { "wal", "\u30a6\u30a9\u30e9\u30a4\u30bf\u8a9e" },
             { "was", "\u30ef\u30b7\u30e7\u8a9e" },
+            { "XA", "\u7591\u4f3c\u30a2\u30af\u30bb\u30f3\u30c8" },
             { "war", "\u30ef\u30e9\u30a4\u8a9e" },
+            { "XB", "\u7591\u4f3c BIDI" },
             { "awa", "\u30a2\u30ef\u30c7\u30a3\u30fc\u8a9e" },
             { "061", "\u30dd\u30ea\u30cd\u30b7\u30a2" },
             { "%%KSCOR", "\u6a19\u6e96\u30b3\u30fc\u30f3\u30a6\u30a9\u30fc\u30eb\u8a9e\u6b63\u66f8\u6cd5" },
@@ -673,7 +675,7 @@ public class LocaleNames_ja extends OpenListResourceBundle {
             { "Blis", metaValue_zbl },
             { "YE", "\u30a4\u30a8\u30e1\u30f3" },
             { "nqo", "\u30f3\u30b3\u8a9e" },
-            { "type.co.standard", "\u6a19\u6e96\u30bd\u30fc\u30c8\u9806\u5e8f" },
+            { "type.co.standard", "\u6a19\u6e96\u4e26\u3079\u66ff\u3048\u9806\u5e8f" },
             { "lmo", "\u30ed\u30f3\u30d0\u30eb\u30c9\u8a9e" },
             { "fan", "\u30d5\u30a1\u30f3\u30b0\u8a9e" },
             { "%%ROZAJ", "\u30ec\u30b7\u30a2\u65b9\u8a00" },
@@ -770,6 +772,7 @@ public class LocaleNames_ja extends OpenListResourceBundle {
             { "scn", "\u30b7\u30c1\u30ea\u30a2\u8a9e" },
             { "aa", "\u30a2\u30d5\u30a1\u30eb\u8a9e" },
             { "ab", "\u30a2\u30d6\u30cf\u30ba\u8a9e" },
+            { "Aran", "\u30ca\u30b9\u30bf\u30a2\u30ea\u30fc\u30af\u4f53" },
             { "bbc", "\u30c8\u30d0\u30fb\u30d0\u30bf\u30af\u8a9e" },
             { "ae", "\u30a2\u30f4\u30a7\u30b9\u30bf\u8a9e" },
             { "af", "\u30a2\u30d5\u30ea\u30ab\u30fc\u30f3\u30b9\u8a9e" },
@@ -818,7 +821,7 @@ public class LocaleNames_ja extends OpenListResourceBundle {
             { "ch", "\u30c1\u30e3\u30e2\u30ed\u8a9e" },
             { "%%REVISED", "\u6539\u8a02\u7248" },
             { "co", "\u30b3\u30eb\u30b7\u30ab\u8a9e" },
-            { "Orya", "\u30aa\u30ea\u30e4\u30fc\u6587\u5b57" },
+            { "Orya", "\u30aa\u30c7\u30a3\u30a2\u6587\u5b57" },
             { "cr", "\u30af\u30ea\u30fc\u8a9e" },
             { "cs", "\u30c1\u30a7\u30b3\u8a9e" },
             { "cu", "\u6559\u4f1a\u30b9\u30e9\u30d6\u8a9e" },
@@ -1096,7 +1099,7 @@ public class LocaleNames_ja extends OpenListResourceBundle {
             { "key.cu", "\u901a\u8ca8" },
             { "ro", "\u30eb\u30fc\u30de\u30cb\u30a2\u8a9e" },
             { "%%SAAHO", metaValue_ssy },
-            { "type.nu.orya", "\u30aa\u30ea\u30e4\u30fc\u6570\u5b57" },
+            { "type.nu.orya", "\u30aa\u30c7\u30a3\u30a2\u6570\u5b57" },
             { "type.nu.hanidec", "\u6f22\u6570\u5b57(\u4f4d\u53d6\u308a\u8a18\u6570\u6cd5)" },
             { "ru", "\u30ed\u30b7\u30a2\u8a9e" },
             { "bss", "\u30a2\u30b3\u30fc\u30b9\u8a9e" },
@@ -1318,6 +1321,7 @@ public class LocaleNames_ja extends OpenListResourceBundle {
             { "inh", "\u30a4\u30f3\u30b0\u30fc\u30b7\u8a9e" },
             { "krj", "\u30ad\u30ca\u30e9\u30a4\u30a2\u8a9e" },
             { "kri", "\u30af\u30ea\u30aa\u8a9e" },
+            { "fa_AF", "\u30c0\u30ea\u30fc\u8a9e" },
             { "krl", "\u30ab\u30ec\u30ea\u30a2\u8a9e" },
             { "efi", "\u30a8\u30d5\u30a3\u30af\u8a9e" },
             { "tcy", "\u30c8\u30a5\u30eb\u8a9e" },
