@@ -70,6 +70,7 @@ import sun.util.resources.OpenListResourceBundle;
 public class LocaleNames_jv extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
+        final String metaValue_002 = "Afrika";
         final String metaValue_AZ = "Azerbaijan";
         final String metaValue_DE = "J\u00e9rman";
         final String metaValue_FR = "Prancis";
@@ -86,7 +87,6 @@ public class LocaleNames_jv extends OpenListResourceBundle {
         final String metaValue_TO = "Tonga";
         final String metaValue_TR = "Turki";
         final String metaValue_WS = "Samoa";
-        final String metaValue_ar = "Arab";
         final String metaValue_el = "Yunani";
         final String metaValue_he = "Ibrani";
         final String metaValue_hy = "Armenia";
@@ -100,6 +100,8 @@ public class LocaleNames_jv extends OpenListResourceBundle {
         final String metaValue_or = "Odia";
         final String metaValue_si = "Sinhala";
         final String metaValue_ta = "Tamil";
+        final String metaValue_te = "Telugu";
+        final String metaValue_th = "Thailand";
         final Object[][] data = new Object[][] {
             { "sbp", "Sangu" },
             { "ksh", "Colonia" },
@@ -108,8 +110,8 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "Zsym", "Simbol" },
             { "fil", "Tagalog" },
             { "hmn", "Hmong" },
-            { "ban", "ban" },
             { "Zsye", "Emoji" },
+            { "ccp", "Chakma" },
             { "luy", "Luyia" },
             { "bas", "Basaa" },
             { "es_ES", "Spanyol (Eropah)" },
@@ -118,8 +120,8 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "AD", "Andora" },
             { "AE", "Uni \u00c9mirat Arab" },
             { "nl_BE", "Flemis" },
+            { "af", metaValue_002 },
             { "AF", "Afganistan" },
-            { "af", "af" },
             { "AG", "Antigua lan Barbuda" },
             { "type.ca.ethiopic", "Tanggalan Etiopia" },
             { "AI", "Anguilla" },
@@ -127,12 +129,12 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "AL", "Albani" },
             { "AM", "Arm\u00e9nia" },
             { "am", "Amharik" },
-            { "Arab", metaValue_ar },
+            { "Arab", "hija\u2019iyah" },
             { "AO", "Angola" },
             { "Jpan", metaValue_JP },
             { "AQ", "Antartika" },
-            { "ar", metaValue_ar },
             { "AR", "Arg\u00e8ntina" },
+            { "ar", "Arab" },
             { "Hrkt", "Silabaris Jepang" },
             { "AS", "Samoa Amerika" },
             { "as", "Assam" },
@@ -147,13 +149,14 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "ceb", "Cebuano" },
             { "BD", "Banggalad\u00e9sa" },
             { "BE", "B\u00e8lgi" },
-            { "be", "be" },
+            { "be", "Belarus" },
             { "BF", "Burkina Faso" },
             { "BG", "Bulgari" },
             { "bg", "Bulgaria" },
             { "BH", "Bahrain" },
             { "BI", "Burundi" },
             { "BJ", "B\u00e9nin" },
+            { "BL", "Saint Barth\u00e9l\u00e9mi" },
             { "BM", "Bermuda" },
             { "bm", "Bambara" },
             { "BN", "Brun\u00e9i" },
@@ -164,7 +167,7 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "BR", "Brasil" },
             { "br", "Breton" },
             { "BS", "Bahamas" },
-            { "bs", "bs" },
+            { "bs", "Bosnia lan Hercegovina" },
             { "xog", "Soga" },
             { "BT", "Bhutan" },
             { "BV", "Pulo Bov\u00e8t" },
@@ -262,6 +265,7 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "fi", "Suomi" },
             { "FJ", "Fiji" },
             { "FK", "Kapuloan Falkland" },
+            { "FM", "F\u00e9derasi Mikron\u00e9sia" },
             { "yue", "Kanton" },
             { "FO", "Kapuloan Faro" },
             { "fo", "Faroe" },
@@ -284,7 +288,9 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "GM", "Gambia" },
             { "GN", "Guinea" },
             { "GP", "Guad\u00e9lup" },
+            { "GQ", "Guin\u00e9a Katulistiwa" },
             { "und", "Basa Ora Dikenali" },
+            { "GR", "Grikenlan" },
             { "GS", "Georgia Kidul lan Kapuloan Sandwich Kidul" },
             { "GT", "Guat\u00e9mala" },
             { "GU", "Guam" },
@@ -357,6 +363,7 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "KM", "Komoro" },
             { "Knda", metaValue_kn },
             { "kn", metaValue_kn },
+            { "KN", "Saint Kits lan N\u00e8vis" },
             { "ko", metaValue_ko },
             { "KR", "Kor\u00e9a Kidul" },
             { "ks", "Kashmiri" },
@@ -402,6 +409,7 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "MF", "Santa Martin" },
             { "MG", "Madagaskar" },
             { "mg", "Malagasi" },
+            { "Thai", metaValue_th },
             { "MH", "Kapuloan Marshall" },
             { "type.co.ducet", "Urutan Pamilahan Unicode Default" },
             { "mi", "Maori" },
@@ -471,6 +479,7 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "PL", "Polen" },
             { "pl", "Polandia" },
             { "ewo", "Ewondo" },
+            { "PM", "Saint Pi\u00e8r lan Miku\u00e9lon" },
             { "PN", "Kapuloan Pitcairn" },
             { "type.ca.dangi", "Tanggalan Dangi" },
             { "PR", "Pu\u00e8rto Riko" },
@@ -498,7 +507,7 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "kde", "Makonde" },
             { "001", "Donya" },
             { "Ethi", "Ethiopik" },
-            { "002", "Afrika" },
+            { "002", metaValue_002 },
             { "RE", "R\u00e9union" },
             { "type.hc.h12", "Sistem 12 Jam (1\u201312)" },
             { "005", "Am\u00e9rika Kidul" },
@@ -509,6 +518,7 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "key.cu", "Mata Uang" },
             { "RO", "Rum\u00e9ni" },
             { "ro", "Rumania" },
+            { "RS", "S\u00e8rbi" },
             { "type.nu.orya", "Digit Odia" },
             { "type.nu.hanidec", "Angka Desimal Mandarin" },
             { "ru", metaValue_RU },
@@ -530,6 +540,7 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "014", "Afrika W\u00e9tan" },
             { "SG", "Singapura" },
             { "sg", "Sango" },
+            { "SH", "Saint H\u00e9l\u00e9na" },
             { "type.lb.strict", "Gaya Ganti Baris Strik" },
             { "si", metaValue_si },
             { "017", "Afrika Sisih Tengah" },
@@ -574,13 +585,13 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "yav", "Yangben" },
             { "143", "Asia Tengah" },
             { "TD", "Chad" },
-            { "te", "Telugu" },
+            { "te", metaValue_te },
             { "145", "Asia Kulon" },
             { "TF", "Wilayah Prancis nang Kutub Kidul" },
             { "TG", "Togo" },
             { "tg", "Tajik" },
+            { "th", metaValue_th },
             { "TH", "Tanah Thai" },
-            { "th", "Thailand" },
             { "ti", "Tigrinya" },
             { "TJ", "Tajikistan" },
             { "029", "Karibia" },
@@ -629,6 +640,7 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "tzm", "Tamazight Atlas Tengah" },
             { "nnh", "Ngiemboon" },
             { "VA", "Kutha Vatikan" },
+            { "VC", "Saint Vinsen lan Gr\u00e9nadin" },
             { "VE", "V\u00e9n\u00e9su\u00e9la" },
             { "type.ca.roc", "Tanggalan Minguo" },
             { "VG", "Kapuloan Virgin Britania" },
@@ -653,9 +665,11 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "ar_001", "Arab Standar Anyar" },
             { "WS", metaValue_WS },
             { "Mong", metaValue_MN },
+            { "XA", "Logat Semu" },
+            { "XB", "Rong Arah Semu" },
             { "Latn", metaValue_la },
             { "061", "Polinesia" },
-            { "type.nu.hans", "Angka Mandarin Prasaja" },
+            { "type.nu.hans", "Angka Mandarin Ringkes" },
             { "type.nu.hant", "Angka Mandarin Tradisional" },
             { "xh", "Xhosa" },
             { "XK", "Kosovo" },
@@ -690,7 +704,7 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "type.nu.jpanfin", "Angka Finansial Jepang" },
             { "ebu", "Embu" },
             { "jmc", "Machame" },
-            { "type.nu.hansfin", "Angka Finansial Mandarin Prasaja" },
+            { "type.nu.hansfin", "Angka Finansial Mandarin Ringkes" },
             { "kok", "Konkani" },
             { "type.nu.arabext", "Digit Hindu-Arab Diambakake" },
             { "nus", "Nuer" },
@@ -711,6 +725,7 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "key.nu", "Angka" },
             { "Guru", "Gurmukhi" },
             { "ksb", "Shambala" },
+            { "Telu", metaValue_te },
             { "ksf", "Bafia" },
         };
         return data;
