@@ -693,7 +693,7 @@ public class LocaleNames_kk extends OpenListResourceBundle {
             { "rup", "\u0430\u0440\u0443\u043c\u044b\u043d \u0442\u0456\u043b\u0456" },
             { "rwk", "\u0440\u0443\u0430 \u0442\u0456\u043b\u0456" },
             { "sad", "\u0441\u0430\u043d\u0434\u0430\u0432\u0435 \u0442\u0456\u043b\u0456" },
-            { "sah", "\u044f\u043a\u0443\u0442 \u0442\u0456\u043b\u0456" },
+            { "sah", "\u0441\u0430\u0445\u0430 \u0442\u0456\u043b\u0456" },
             { "saq", "\u0441\u0430\u043c\u0431\u0443\u0440\u0443 \u0442\u0456\u043b\u0456" },
             { "sat", "\u0441\u0430\u043d\u0442\u0430\u043b\u0438 \u0442\u0456\u043b\u0456" },
             { "sba", "\u043d\u0433\u0430\u043c\u0431\u0430\u0439 \u0442\u0456\u043b\u0456" },
@@ -798,6 +798,7 @@ public class LocaleNames_kk extends OpenListResourceBundle {
             { "en_US", "\u0430\u043c\u0435\u0440\u0438\u043a\u0430\u043b\u044b\u049b \u0430\u0493\u044b\u043b\u0448\u044b\u043d \u0442\u0456\u043b\u0456" },
             { "es_ES", "\u0435\u0443\u0440\u043e\u043f\u0430\u043b\u044b\u049b \u0438\u0441\u043f\u0430\u043d \u0442\u0456\u043b\u0456" },
             { "es_MX", "\u043c\u0435\u043a\u0441\u0438\u043a\u0430\u043b\u044b\u049b \u0438\u0441\u043f\u0430\u043d \u0442\u0456\u043b\u0456" },
+            { "fa_AF", "\u0434\u0430\u0440\u0438 \u0442\u0456\u043b\u0456" },
             { "fr_CA", "\u043a\u0430\u043d\u0430\u0434\u0430\u043b\u044b\u049b \u0444\u0440\u0430\u043d\u0446\u0443\u0437 \u0442\u0456\u043b\u0456" },
             { "fr_CH", "\u0448\u0432\u0435\u0439\u0446\u0430\u0440\u0438\u044f\u043b\u044b\u049b \u0444\u0440\u0430\u043d\u0446\u0443\u0437 \u0442\u0456\u043b\u0456" },
             { "nl_BE", "\u0444\u043b\u0430\u043c\u0430\u043d\u0434 \u0442\u0456\u043b\u0456" },
