@@ -135,6 +135,7 @@ public class LocaleNames_km extends OpenListResourceBundle {
             { "mwl", "\u1798\u17b8\u179a\u17c9\u17b6\u1793\u178a\u17c1\u179f" },
             { "Zsym", "\u1793\u17b7\u1798\u17b7\u178f\u17d2\u178f\u179f\u1789\u17d2\u1789\u17b6" },
             { "Zsye", "\u179f\u1789\u17d2\u1789\u17b6\u17a2\u17b6\u179a\u1798\u17d2\u1798\u178e\u17cd" },
+            { "ccp", "\u1785\u17b6\u1780\u17cb\u1798\u17c9\u17b6" },
             { "tem", "\u1792\u17b8\u1798\u1793\u17b8" },
             { "teo", "\u178f\u17c1\u179f\u17bc" },
             { "rap", "\u179a\u17c9\u17b6\u1794\u17c9\u17b6\u1793\u17bc" },
@@ -311,6 +312,7 @@ public class LocaleNames_km extends OpenListResourceBundle {
             { "ain", "\u17a2\u17b6\u1799\u1793\u17bc" },
             { "guz", "\u17a0\u17d2\u1782\u17bc\u179f\u17ca\u17b8" },
             { "type.nu.knda", "\u179b\u17c1\u1781\u1781\u17b6\u178e\u17b6\u178a\u17b6" },
+            { "de_CH", "\u17a2\u17b6\u179b\u17d2\u179b\u17ba\u1798\u17c9\u1784\u17cb (\u179f\u17d2\u179c\u17ca\u17b8\u179f)" },
             { "type.ca.buddhist", "\u1794\u17d2\u179a\u178f\u17b7\u1791\u17b7\u1793\u1796\u17bb\u1791\u17d2\u1792\u179f\u17b6\u179f\u1793\u17b6" },
             { "KE", "\u1780\u17c1\u1793\u1799\u17c9\u17b6" },
             { "419", "\u17a2\u17b6\u1798\u17c1\u179a\u17b7\u1780\u200b\u17a1\u17b6\u1791\u17b8\u1793" },
@@ -322,6 +324,7 @@ public class LocaleNames_km extends OpenListResourceBundle {
             { "KN", "\u179f\u17b6\u17c6\u1784\u200b\u1782\u17b8\u178f \u1793\u17b7\u1784 \u178e\u17c1\u179c\u17b8\u179f" },
             { "KP", "\u1780\u17bc\u179a\u17c9\u17c1\u200b\u1781\u17b6\u1784\u200b\u1787\u17be\u1784" },
             { "KR", "\u1780\u17bc\u179a\u17c9\u17c1\u200b\u1781\u17b6\u1784\u200b\u178f\u17d2\u1794\u17bc\u1784" },
+            { "fr_CH", "\u1794\u17b6\u179a\u17b6\u17c6\u1784 (\u179f\u17d2\u179c\u17ca\u17b8\u179f)" },
             { "KW", "\u1780\u17bc\u179c\u17c9\u17c2\u178f" },
             { "tpi", "\u1790\u17bb\u1780\u1796\u17b8\u179f\u17ca\u17b8\u1793" },
             { "KY", "\u1780\u17c4\u17c7\u200b\u1780\u17c3\u1798\u17c9\u1784\u17cb" },
@@ -473,7 +476,7 @@ public class LocaleNames_km extends OpenListResourceBundle {
             { "TJ", "\u178f\u17b6\u17a0\u17d2\u179f\u17ca\u17b8\u1782\u17b8\u179f\u17d2\u1790\u17b6\u1793" },
             { "029", "\u1780\u17b6\u179a\u17c9\u17b6\u1794\u17ca\u17b8\u1793" },
             { "TK", "\u178f\u17bc\u1781\u17c1\u17a1\u17c5" },
-            { "TL", "\u1791\u17b8\u1798\u17d0\u179a\u179b\u17b8\u179f" },
+            { "TL", "\u1791\u17b8\u1798\u17d0\u179a\u179b\u17c1\u179f\u17d2\u178f\u17c1" },
             { "ybb", "\u1799\u17c1\u1798\u1794\u17b6" },
             { "TM", "\u178f\u17bd\u1780\u1798\u17c9\u17c1\u1793\u17b8\u179f\u17d2\u1790\u17b6\u1793" },
             { "TN", "\u1791\u17bb\u1799\u1793\u17b8\u179f\u17ca\u17b8" },
@@ -523,7 +526,9 @@ public class LocaleNames_km extends OpenListResourceBundle {
             { "wae", "\u179c\u17c1\u179b\u179f\u17ba" },
             { "WS", metaValue_WS },
             { "wal", "\u179c\u17c9\u17bc\u17a1\u17b6\u1799\u178f\u17b6" },
+            { "XA", "Pseudo-Accents" },
             { "war", "\u179c\u17c9\u17b6\u179a\u17c1\u1799" },
+            { "XB", "Pseudo-Bidi" },
             { "awa", "\u17a2\u17b6\u179c\u17c9\u17b6\u178c\u17b8" },
             { "061", "\u1794\u17c9\u17bc\u179b\u17b8\u178e\u17c1\u179f\u17ca\u17b8" },
             { "XK", "\u1780\u17bc\u179f\u17bc\u179c\u17c9\u17bc" },
@@ -920,6 +925,7 @@ public class LocaleNames_km extends OpenListResourceBundle {
             { "type.nu.tamldec", metaValue_type_nu_taml },
             { "krc", "\u1780\u17b6\u179a\u17c9\u17b6\u1786\u17b6\u1799\u1794\u17b6\u179b\u17cb\u1780\u17b6" },
             { "inh", "\u17a2\u17ca\u17b7\u1793\u17a0\u17d2\u1782\u17bc\u179f" },
+            { "fa_AF", "\u178a\u17b6\u179a\u17b8" },
             { "krl", "\u1780\u17b6\u179a\u17b8\u179b\u17b6" },
             { "efi", "\u17a2\u17ca\u17b8\u17a0\u17d2\u179c\u17b7\u1780" },
             { "key.nu", "\u179b\u17c1\u1781" },
