@@ -105,6 +105,7 @@ public class LocaleNames_kn extends OpenListResourceBundle {
             { "mwr", "\u0cae\u0cbe\u0cb0\u0ccd\u0cb5\u0cbe\u0ca1\u0cbf" },
             { "Tagb", "\u0c9f\u0cbe\u0c97\u0ccd\u0cac\u0cbe\u0ca8\u0cb5\u0cbe" },
             { "Zsye", "\u0c8e\u0cae\u0ccb\u0c9c\u0cbf" },
+            { "ccp", "\u0c9a\u0c95\u0ccd\u0cae\u0cbe" },
             { "egy", "\u0caa\u0ccd\u0cb0\u0cbe\u0c9a\u0cc0\u0ca8 \u0c88\u0c9c\u0cbf\u0caa\u0ccd\u0c9f\u0cbf\u0caf\u0ca8\u0ccd" },
             { "raj", "\u0cb0\u0cbe\u0c9c\u0cb8\u0ccd\u0ca5\u0cbe\u0ca8\u0cbf" },
             { "Phag", "\u0cab\u0cbe\u0c97\u0ccd\u0cb8\u0ccd-\u0caa\u0cbe" },
@@ -258,7 +259,7 @@ public class LocaleNames_kn extends OpenListResourceBundle {
             { "grc", "\u0caa\u0ccd\u0cb0\u0cbe\u0c9a\u0cc0\u0ca8 \u0c97\u0ccd\u0cb0\u0cc0\u0c95\u0ccd" },
             { "GA", "\u0c97\u0cc6\u0cac\u0cca\u0ca8\u0ccd" },
             { "vot", "\u0cb5\u0ccb\u0c9f\u0cbf\u0c95\u0ccd" },
-            { "GB", "\u0cac\u0ccd\u0cb0\u0cbf\u0c9f\u0ca8\u0ccd/\u0c87\u0c82\u0c97\u0ccd\u0cb2\u0cc6\u0c82\u0ca1\u0ccd" },
+            { "GB", "\u0caf\u0cc1\u0ca8\u0cc8\u0c9f\u0cc6\u0ca1\u0ccd \u0c95\u0cbf\u0c82\u0c97\u0ccd\u200c\u0ca1\u0cae\u0ccd" },
             { "pcm", "\u0ca8\u0cc8\u0c9c\u0cc0\u0cb0\u0cbf\u0caf\u0ca8\u0ccd \u0caa\u0cbf\u0ca1\u0ccd\u0c97\u0cbf\u0ca8\u0ccd" },
             { "GD", "\u0c97\u0ccd\u0cb0\u0cc6\u0ca8\u0cc6\u0ca1\u0cbe" },
             { "GE", "\u0c9c\u0cbe\u0cb0\u0ccd\u0c9c\u0cbf\u0caf\u0cbe" },
@@ -385,7 +386,7 @@ public class LocaleNames_kn extends OpenListResourceBundle {
             { "MH", "\u0cae\u0cbe\u0cb0\u0ccd\u0cb7\u0cb2\u0ccd \u0ca6\u0ccd\u0cb5\u0cc0\u0caa\u0c97\u0cb3\u0cc1" },
             { "ale", "\u0c85\u0cb2\u0cc6\u0caf\u0cc1\u0c9f\u0ccd" },
             { "type.nu.vaii", "\u0cb5\u0cbe\u0caf\u0ccd \u0c85\u0c82\u0c95\u0cc6\u0c97\u0cb3\u0cc1" },
-            { "MK", "\u0cae\u0ccd\u0caf\u0cbe\u0cb8\u0cbf\u0ca1\u0ccb\u0ca8\u0cbf\u0caf\u0cbe" },
+            { "MK", "\u0c89\u0ca4\u0ccd\u0ca4\u0cb0 \u0cae\u0ccd\u0caf\u0cbe\u0cb8\u0cbf\u0ca1\u0ccb\u0ca8\u0cbf\u0caf\u0cbe" },
             { "ML", "\u0cae\u0cbe\u0cb2\u0cbf" },
             { "MM", "\u0cae\u0caf\u0ca8\u0ccd\u0cae\u0cbe\u0cb0\u0ccd (\u0cac\u0cb0\u0ccd\u0cae\u0cbe)" },
             { "MN", "\u0cae\u0c82\u0c97\u0ccb\u0cb2\u0cbf\u0caf\u0cbe" },
@@ -515,7 +516,7 @@ public class LocaleNames_kn extends OpenListResourceBundle {
             { "SX", "\u0cb8\u0cbf\u0c82\u0c9f\u0ccd \u0cae\u0cbe\u0cb0\u0ccd\u0c9f\u0cc6\u0ca8\u0ccd" },
             { "SY", "\u0cb8\u0cbf\u0cb0\u0cbf\u0caf\u0cbe" },
             { "yao", "\u0caf\u0cbe\u0cb5\u0cca" },
-            { "SZ", "\u0cb8\u0ccd\u0cb5\u0cbe\u0c9c\u0cbf\u0cb2\u0ccd\u0caf\u0cbe\u0c82\u0ca1\u0ccd" },
+            { "SZ", "\u0cb8\u0ccd\u0cb5\u0cbe\u0ca4\u0cbf\u0ca8\u0cbf" },
             { "arw", "\u0c85\u0cb0\u0cbe\u0cb5\u0cbe\u0c95\u0ccd" },
             { "yap", "\u0caf\u0caa\u0cc0\u0cb8\u0cc6" },
             { "TA", "\u0c9f\u0ccd\u0cb0\u0cbf\u0cb8\u0ccd\u0ca4\u0ca8\u0ccd \u0ca1\u0cbe \u0c95\u0cc1\u0ca8\u0ccd\u0cb9\u0cbe" },
@@ -594,7 +595,9 @@ public class LocaleNames_kn extends OpenListResourceBundle {
             { "WS", "\u0cb8\u0cae\u0ccb\u0cb5\u0cbe" },
             { "wal", "\u0cb5\u0cb2\u0cbe\u0caf\u0ccd\u0ca4\u0cbe" },
             { "was", "\u0cb5\u0cbe\u0cb7\u0ccb" },
+            { "XA", "\u0cb8\u0ccd\u0caf\u0cc1\u0ca1\u0cca \u0c89\u0c9a\u0ccd\u0c9b\u0cbe\u0cb0\u0ca3\u0cc6\u0c97\u0cb3\u0cc1" },
             { "war", "\u0cb5\u0cb0\u0cbe\u0caf\u0ccd" },
+            { "XB", "\u0cb8\u0ccd\u0caf\u0cc1\u0ca1\u0cca-\u0cac\u0cbf\u0ca1\u0cbf" },
             { "awa", "\u0c85\u0cb5\u0ca7\u0cbf" },
             { "061", "\u0caa\u0cbe\u0cb2\u0cbf\u0ca8\u0cc7\u0cb7\u0ccd\u0caf\u0cbe" },
             { "XK", "\u0c95\u0cca\u0cb8\u0cca\u0cb5\u0cca" },
@@ -643,6 +646,7 @@ public class LocaleNames_kn extends OpenListResourceBundle {
             { "nwc", "\u0cb6\u0cbe\u0cb8\u0ccd\u0ca4\u0ccd\u0cb0\u0cc0\u0caf \u0ca8\u0cc7\u0cb5\u0cbe\u0cb0\u0cbf" },
             { "udm", "\u0c89\u0ca1\u0ccd\u200c\u0cae\u0cc1\u0cb0\u0ccd\u0c9f\u0ccd" },
             { "Khmr", metaValue_km },
+            { "type.ca.islamic-rgsa", "\u0c87\u0cb8\u0ccd\u0cb2\u0cbe\u0cae\u0cbf\u0c95\u0ccd\u200c \u0c95\u0ccd\u0caf\u0cbe\u0cb2\u0cc6\u0c82\u0ca1\u0cb0\u0ccd\u200c (\u0cb8\u0ccc\u0ca6\u0cbf \u0c85\u0cb0\u0cc7\u0cac\u0cbf\u0caf\u0cbe, \u0cb8\u0cc8\u0c9f\u0cbf\u0c82\u0c97\u0ccd\u200c)bia, sighting)" },
             { "Limb", "\u0cb2\u0cbf\u0c82\u0cac\u0cc1" },
             { "sad", "\u0cb8\u0c82\u0ca1\u0cbe\u0cb5\u0cc7" },
             { "type.nu.roman", "\u0cb0\u0ccb\u0cae\u0ca8\u0ccd \u0cb8\u0c82\u0c96\u0ccd\u0caf\u0cc6\u0c97\u0cb3\u0cc1" },
@@ -720,7 +724,7 @@ public class LocaleNames_kn extends OpenListResourceBundle {
             { "ce", "\u0c9a\u0cc6\u0c9a\u0ca8\u0ccd" },
             { "ch", "\u0c95\u0cae\u0cca\u0cb0\u0cca" },
             { "co", "\u0c95\u0ccb\u0cb0\u0ccd\u0cb8\u0cbf\u0c95\u0ca8\u0ccd" },
-            { "Orya", "\u0c92\u0cb0\u0cbf\u0caf\u0cbe" },
+            { "Orya", "\u0c92\u0ca1\u0cbf\u0caf\u0cbe" },
             { "cr", "\u0c95\u0ccd\u0cb0\u0cc0" },
             { "cs", "\u0c9c\u0cc6\u0c95\u0ccd" },
             { "cu", "\u0c9a\u0cb0\u0ccd\u0c9a\u0ccd \u0cb8\u0ccd\u0cb2\u0cbe\u0cb5\u0cbf\u0c95\u0ccd" },
@@ -754,7 +758,7 @@ public class LocaleNames_kn extends OpenListResourceBundle {
             { "type.co.big5han", "\u0cb8\u0cbe\u0c82\u0caa\u0ccd\u0cb0\u0ca6\u0cbe\u0caf\u0cbf\u0c95 \u0c9a\u0cc0\u0ca8\u0cbe\u0ca6 \u0c85\u0ca8\u0cc1\u0c95\u0ccd\u0cb0\u0cae \u0cb5\u0cbf\u0ca8\u0ccd\u0caf\u0cbe\u0cb8 - \u0ca6\u0cca\u0ca1\u0ccd\u0ca1 \u0c90\u0ca6\u0cc1" },
             { "es", "\u0cb8\u0ccd\u0caa\u0ccd\u0caf\u0cbe\u0ca8\u0cbf\u0cb7\u0ccd" },
             { "et", "\u0c8e\u0cb8\u0ccd\u0c9f\u0cca\u0ca8\u0cbf\u0caf\u0ca8\u0ccd" },
-            { "Hanb", "\u0cb9\u0c82\u0cac\u0ccd" },
+            { "Hanb", "\u0cac\u0ccb\u0caa\u0ccb\u0cae\u0cca\u0cab\u0ccb \u0c9c\u0cca\u0ca4\u0cc6\u0c97\u0cc6 \u0cb9\u0cbe\u0ca8\u0ccd" },
             { "eu", "\u0cac\u0cbe\u0cb8\u0ccd\u0c95\u0ccd" },
             { "Buhd", "\u0cac\u0cc1\u0cb9\u0cbf\u0ca6\u0ccd" },
             { "Hang", "\u0cb9\u0ccd\u0caf\u0cbe\u0c82\u0c97\u0cc1\u0cb2\u0ccd" },
@@ -886,7 +890,7 @@ public class LocaleNames_kn extends OpenListResourceBundle {
             { "Saur", "\u0cb8\u0ccc\u0cb0\u0cbe\u0cb7\u0ccd\u0c9f\u0ccd\u0cb0" },
             { "Armn", metaValue_hy },
             { "mdf", "\u0cae\u0ccb\u0c95\u0ccd\u0cb7" },
-            { "dsb", "\u0cb2\u0ccb\u0cb5\u0cb0\u0ccd \u0cb8\u0ccb\u0cb0\u0ccd\u0cac\u0cbf\u0caf\u0ca8\u0ccd" },
+            { "dsb", "\u0cb2\u0ccb\u0cb5\u0cb0\u0ccd \u0cb8\u0cb0\u0ccd\u0cac\u0cbf\u0caf\u0ca8\u0ccd" },
             { "Armi", "\u0c87\u0c82\u0caa\u0cc0\u0cb0\u0cbf\u0caf\u0cb2\u0ccd \u0c85\u0cb0\u0cc6\u0cae\u0cbe\u0caf\u0cbf\u0c95\u0ccd" },
             { "na", metaValue_NR },
             { "type.co.search", "\u0cb8\u0cbe\u0cae\u0cbe\u0ca8\u0ccd\u0caf- \u0c89\u0ca6\u0ccd\u0ca6\u0cc7\u0cb6 \u0cb9\u0cc1\u0ca1\u0cc1\u0c95\u0cbe\u0c9f" },
@@ -981,7 +985,7 @@ public class LocaleNames_kn extends OpenListResourceBundle {
             { "sq", "\u0c85\u0cb2\u0ccd\u0cac\u0cc7\u0ca8\u0cbf\u0caf\u0ca8\u0ccd" },
             { "sr", "\u0cb8\u0cc6\u0cb0\u0ccd\u0cac\u0cbf\u0caf\u0ca8\u0ccd" },
             { "ss", "\u0cb8\u0ccd\u0cb5\u0cbe\u0ca4\u0cbf" },
-            { "type.cf.account", "\u0cb2\u0cc6\u0c95\u0ccd\u0c95\u0caa\u0cb0\u0cbf\u0cb6\u0ccb\u0ca7\u0c95 \u0c95\u0cb0\u0cc6\u0ca8\u0ccd\u0c9a\u0cbf \u0cb8\u0ccd\u0cb5\u0cb0\u0cc2\u0caa" },
+            { "type.cf.account", "\u0c85\u0c95\u0ccc\u0c82\u0c9f\u0cbf\u0c82\u0c97\u0ccd \u0c95\u0cb0\u0cc6\u0ca8\u0ccd\u0cb8\u0cbf \u0cb8\u0ccd\u0cb5\u0cb0\u0cc2\u0caa" },
             { "st", "\u0ca6\u0c95\u0ccd\u0cb7\u0cbf\u0ca3 \u0cb8\u0ccb\u0ca5\u0ccb" },
             { "Java", "\u0c9c\u0cbe\u0cb5\u0ca8\u0cc0\u0cb8\u0ccd" },
             { "su", metaValue_su },
@@ -1039,7 +1043,7 @@ public class LocaleNames_kn extends OpenListResourceBundle {
             { "vi", "\u0cb5\u0cbf\u0caf\u0cc6\u0c9f\u0ccd\u0ca8\u0cbe\u0cae\u0cc0\u0cb8\u0ccd" },
             { "kho", "\u0c96\u0ccb\u0c9f\u0cbe\u0ca8\u0cc0\u0cb8\u0ccd" },
             { "khq", "\u0c95\u0cca\u0caf\u0ccd\u0cb0 \u0c9a\u0cc0\u0ca8\u0cbf" },
-            { "key.hc", "\u0c97\u0c82\u0c9f\u0cc6 \u0c9a\u0c95\u0ccd\u0cb0 (12 \u0cb5\u0cbf\u0cb0\u0cc1\u0ca6\u0ccd\u0ca7 24)" },
+            { "key.hc", "\u0c95\u0cbe\u0cb2 \u0c9a\u0c95\u0ccd\u0cb0 (12 \u0cb5\u0cbf\u0cb0\u0cc1\u0ca6\u0ccd\u0ca7 24)" },
             { "vo", "\u0cb5\u0ccb\u0cb2\u0cbe\u0caa\u0cc1\u0c95\u0ccd" },
             { "syc", "\u0cb6\u0cbe\u0cb8\u0ccd\u0ca4\u0ccd\u0cb0\u0cc0\u0caf \u0cb8\u0cbf\u0cb0\u0cbf\u0caf\u0c95\u0ccd" },
             { "Osma", "\u0c93\u0cb8\u0ccd\u0cae\u0cbe\u0ca8\u0ccd\u0caf\u0cbe" },
@@ -1131,6 +1135,7 @@ public class LocaleNames_kn extends OpenListResourceBundle {
             { "type.nu.tamldec", "\u0ca4\u0cae\u0cbf\u0cb3\u0cc1 \u0c85\u0c82\u0c95\u0cc6\u0c97\u0cb3\u0cc1" },
             { "krc", "\u0c95\u0cb0\u0c9a\u0caf\u0ccd-\u0cac\u0cb2\u0ccd\u0c95\u0cbe\u0cb0\u0ccd" },
             { "inh", "\u0c87\u0c82\u0c97\u0cc1\u0cb7\u0ccd" },
+            { "fa_AF", "\u0ca6\u0cb0\u0cbf" },
             { "krl", "\u0c95\u0cb0\u0cc7\u0cb2\u0cbf\u0caf\u0ca8\u0ccd" },
             { "efi", "\u0c8e\u0cab\u0cbf\u0c95\u0ccd" },
             { "key.nu", "\u0cb8\u0c82\u0c96\u0ccd\u0caf\u0cc6\u0c97\u0cb3\u0cc1" },
