@@ -535,6 +535,7 @@ public class LocaleNames_ko extends OpenListResourceBundle {
             { "TC", "\ud130\ud06c\uc2a4 \ucf00\uc774\ucee4\uc2a4 \uc81c\ub3c4" },
             { "yav", "\uc591\ubcf8\uc5b4" },
             { "TD", "\ucc28\ub4dc" },
+            { "Qaag", "\uc800\uc9c0 \ubb38\uc790" },
             { "TF", "\ud504\ub791\uc2a4 \ub0a8\ubd80 \uc9c0\ubc29" },
             { "TG", "\ud1a0\uace0" },
             { "TH", "\ud0dc\uad6d" },
@@ -711,6 +712,7 @@ public class LocaleNames_ko extends OpenListResourceBundle {
             { "scn", "\uc2dc\uce60\ub9ac\uc544\uc5b4" },
             { "aa", "\uc544\ud30c\ub974\uc5b4" },
             { "ab", "\uc555\uce74\uc988\uc5b4" },
+            { "Aran", "\ub098\uc2a4\ud0c8\ub9ac\ud06c\uccb4" },
             { "ae", "\uc544\ubca0\uc2a4\ud0c0\uc5b4" },
             { "af", "\uc544\ud504\ub9ac\uce78\uc2a4\uc5b4" },
             { "ak", "\uc544\uce78\uc5b4" },
@@ -1204,6 +1206,7 @@ public class LocaleNames_ko extends OpenListResourceBundle {
             { "type.nu.tamldec", "\ud0c0\ubc00 \uc22b\uc790" },
             { "krc", "\uce74\ub77c\ucc60\uc774-\ubc1c\uce74\ub974\uc5b4" },
             { "inh", "\uc778\uadc0\uc2dc\uc5b4" },
+            { "fa_AF", "\ub2e4\ub9ac\uc5b4" },
             { "krl", "\uce74\ub810\ub9ac\uc57c\uc5b4" },
             { "efi", "\uc774\ud53d\uc5b4" },
             { "key.nu", metaValue_key_nu },
