@@ -71,22 +71,19 @@ public class LocaleNames_kok extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
         final String metaValue_FJ = "\u092b\u093f\u091c\u0940";
-        final String metaValue_ar = "\u0905\u0930\u0947\u092c\u093f\u0915";
         final String metaValue_bn = "\u092c\u093e\u0902\u0917\u094d\u0932\u093e";
-        final String metaValue_bo = "\u0924\u093f\u092c\u0947\u0924\u093f\u092f\u0928";
         final String metaValue_gu = "\u0917\u0941\u091c\u0930\u093e\u0924\u0940";
         final String metaValue_he = "\u0939\u093f\u092c\u094d\u0930\u0942";
         final String metaValue_hy = "\u0906\u0930\u094d\u092e\u0947\u0928\u093f\u092f\u0928";
         final String metaValue_ja = "\u091c\u092a\u093e\u0928\u0940";
         final String metaValue_lo = "\u0932\u093e\u0913";
-        final String metaValue_or = "\u0913\u0930\u093f\u092f\u093e";
-        final String metaValue_te = "\u0924\u0947\u0932\u0941\u0917\u0942";
         final String metaValue_th = "\u0925\u093e\u0908";
         final Object[][] data = new Object[][] {
             { "ksh", "\u0915\u094b\u0932\u094b\u0928\u093f\u092f\u0928" },
             { "mwl", "\u092e\u093f\u0930\u093e\u0902\u0921\u0940\u0938" },
             { "Zsym", "\u091a\u093f\u0928\u094d\u0928\u093e\u0902" },
             { "Zsye", "Emoji" },
+            { "ccp", "\u091a\u0915\u094d\u092e\u093e" },
             { "tem", "\u0924\u093f\u092e\u094d\u0928\u0947" },
             { "teo", "\u0924\u0947\u0938\u094b" },
             { "rap", "\u0930\u093e\u092a\u093e\u0928\u094d\u092f\u0941" },
@@ -144,7 +141,7 @@ public class LocaleNames_kok extends OpenListResourceBundle {
             { "mzn", "\u092e\u091d\u093e\u0902\u0921\u0947\u0930\u093e\u0923\u0940" },
             { "CD", "\u0915\u094b\u0902\u0917\u094b - \u0915\u093f\u0902\u0936\u093e\u0938\u093e" },
             { "CF", "\u092e\u0927\u094d\u092f \u0905\u092b\u094d\u0930\u0940\u0915\u0940 \u0932\u094b\u0915\u0938\u0924\u094d\u0924\u0915\u0930\u093e\u091c\u094d\u092f" },
-            { "CG", "\u0915\u094b\u0902\u0917\u094b - \u092c\u094d\u0930\u093e\u091d\u093e\u0935\u093f\u0932\u093e" },
+            { "CG", "\u0915\u093e\u0901\u0917\u094b - \u092c\u094d\u0930\u093e\u091d\u093e\u0935\u093f\u0932\u093e" },
             { "CH", "\u0938\u094d\u0935\u093f\u091f\u094d\u091c\u093c\u0930\u0932\u0948\u0902\u0921" },
             { "CI", "\u0915\u094b\u0924 \u0926\u2019\u0908\u0935\u094b\u0906\u0930" },
             { "CK", "\u0915\u0941\u0915 \u0906\u092f\u0932\u0901\u0921\u094d\u0938" },
@@ -189,12 +186,12 @@ public class LocaleNames_kok extends OpenListResourceBundle {
             { "chk", "\u091b\u0941\u0928\u093f\u0938" },
             { "chm", "\u092e\u093e\u0930\u0940" },
             { "cho", "\u091a\u094b\u0924\u093e\u0935" },
-            { "chr", "\u091a\u093f\u0930\u094b\u0915\u0940" },
+            { "chr", "\u091a\u0945\u0930\u094b\u0915\u0940" },
             { "ER", "\u0907\u0930\u093f\u091f\u094d\u0930\u093f\u092f\u093e" },
             { "ES", "\u0938\u094d\u092a\u0947\u0928" },
             { "ET", "\u0907\u0925\u093f\u092f\u094b\u092a\u093f\u092f\u093e" },
             { "EU", "\u092f\u0941\u0930\u094b\u092a\u093f\u092f\u0928 \u092f\u0941\u0928\u093f\u092f\u0928" },
-            { "type.ca.gregorian", "\u0917\u094d\u0930\u0947\u0917\u094b\u0930\u093f\u092f\u0928 \u0926\u093f\u0928\u0926\u0930\u094d\u0936\u093f\u0915\u093e" },
+            { "type.ca.gregorian", "\u0917\u094d\u0930\u0947\u0917\u094b\u0930\u093f\u092f\u0928 \u0915\u0945\u0932\u0947\u0928\u094d\u0921\u0930" },
             { "EZ", "\u092f\u0941\u0930\u094b\u091d\u094b\u0928" },
             { "chy", "\u091a\u0947\u092f\u0928\u0940" },
             { "type.nu.gujr", "\u0917\u0941\u091c\u0930\u093e\u0924\u0940 \u0905\u0902\u0915" },
@@ -226,7 +223,7 @@ public class LocaleNames_kok extends OpenListResourceBundle {
             { "GT", "\u0917\u094d\u0935\u093e\u091f\u0947\u092e\u093e\u0932\u093e" },
             { "GU", "\u0917\u0941\u0906\u092e" },
             { "GW", "\u0917\u0941\u0905\u0928\u093f\u092f\u093e-\u092c\u093f\u0938\u093e\u0909" },
-            { "tlh", "\u0932\u093f\u0902\u0917\u0949\u0928" },
+            { "tlh", "\u0915\u094d\u0932\u093f\u0902\u0917\u0928" },
             { "GY", "\u0917\u092f\u093e\u0928\u093e" },
             { "ckb", "\u092e\u0927\u094d\u092f \u0916\u0941\u0930\u094d\u0926\u0940\u0936" },
             { "zxx", "\u0905\u0923\u0915\u093e\u0930 \u0938\u093e\u092e\u0941\u0917\u094d\u0930\u0940 \u0928\u093e" },
@@ -265,7 +262,7 @@ public class LocaleNames_kok extends OpenListResourceBundle {
             { "ain", "\u0906\u092f\u0928\u0942" },
             { "guz", "\u0917\u0941\u0938\u0940" },
             { "type.nu.knda", "\u0915\u0928\u094d\u0928\u0921 \u0905\u0902\u0915" },
-            { "de_CH", "\u0938\u094d\u0935\u0940\u091d \u092e\u094d\u0939\u093e\u0928 \u091c\u0930\u094d\u092e\u0928" },
+            { "de_CH", "\u0938\u094d\u0935\u093f\u091d \u0939\u093e\u092f \u091c\u0930\u094d\u092e\u0928" },
             { "type.ca.buddhist", "\u092c\u0941\u0927\u094d\u0926\u0940\u0936\u094d\u091f \u0926\u093f\u0928\u0926\u0930\u094d\u0936\u093f\u0915\u093e" },
             { "KE", "\u0915\u0947\u0928\u092f\u093e" },
             { "419", "\u0932\u0945\u091f\u0940\u0928 \u0905\u092e\u0947\u0930\u093f\u0915\u093e" },
@@ -275,10 +272,10 @@ public class LocaleNames_kok extends OpenListResourceBundle {
             { "KM", "\u0915\u094b\u092e\u094b\u0930\u094b\u0938" },
             { "KN", "\u0938\u0947\u0902\u091f \u0915\u093f\u091f\u094d\u0938 \u0906\u0928\u0940 \u0928\u0947\u0935\u093f\u0938" },
             { "Knda", "\u0915\u0928\u094d\u0928\u0921" },
-            { "fr_CA", "\u0915\u0945\u0928\u093e\u0921\u0940\u092f\u0928 \u092b\u094d\u0930\u0947\u0928\u094d\u091a" },
+            { "fr_CA", "\u0915\u0945\u0928\u0921\u093f\u092f\u0928 \u092b\u094d\u0930\u0947\u0902\u091a" },
             { "KP", "\u0909\u0924\u094d\u0924\u0930 \u0915\u094b\u0930\u093f\u092f\u093e" },
             { "KR", "\u0926\u0915\u094d\u0937\u093f\u0923 \u0915\u094b\u0930\u093f\u092f\u093e" },
-            { "fr_CH", "\u0938\u094d\u0935\u0940\u091d \u092b\u094d\u0930\u0947\u0928\u094d\u091a" },
+            { "fr_CH", "\u0938\u094d\u0935\u093f\u091d \u092b\u094d\u0930\u0947\u0902\u091a" },
             { "KW", "\u0915\u0941\u0935\u0947\u0924" },
             { "tpi", "\u0924\u094b\u0915 \u092a\u093f\u0938\u0940\u0928" },
             { "KY", "\u0915\u0948\u092e\u0947\u0928 \u0906\u0907\u0932\u0948\u0902\u0921\u094d\u0938" },
@@ -288,6 +285,7 @@ public class LocaleNames_kok extends OpenListResourceBundle {
             { "LB", "\u0932\u0947\u092c\u0928\u093e\u0928" },
             { "LC", "\u0938\u0901\u091f \u0932\u0941\u0938\u093f\u092f\u093e" },
             { "gwi", "\u0917\u094d\u0935\u093f\u091a" },
+            { "nds", "\u0928\u093f\u092e\u094d\u0928 \u091c\u0930\u094d\u092e\u0928" },
             { "LI", "\u0932\u093f\u091a\u0947\u0902\u0938\u094d\u091f\u0940\u0928" },
             { "LK", "\u0936\u094d\u0930\u0940 \u0932\u0902\u0915\u093e" },
             { "LR", "\u0932\u093e\u092f\u092c\u0947\u0930\u0940\u092f\u093e" },
@@ -295,7 +293,7 @@ public class LocaleNames_kok extends OpenListResourceBundle {
             { "LT", "\u0932\u093f\u0925\u0941\u0906\u0928\u093f\u092f\u093e" },
             { "LU", "\u0932\u0915\u094d\u0938\u0947\u092e\u092c\u0930\u094d\u0917" },
             { "LV", "\u0932\u0945\u091f\u0935\u093f\u092f\u093e" },
-            { "Kana", "\u0915\u093e\u091f\u0915\u093e\u0928\u093e" },
+            { "Kana", "\u0915\u091f\u093e\u0915\u093e\u0928\u093e" },
             { "LY", "\u0932\u0940\u092c\u093f\u092f\u093e" },
             { "lad", "\u0932\u093e\u0921\u093f\u0928\u094b" },
             { "vun", "\u0935\u0941\u0902\u091c\u094b" },
@@ -325,8 +323,8 @@ public class LocaleNames_kok extends OpenListResourceBundle {
             { "alt", "\u0926\u0915\u094d\u0937\u093f\u0923\u0940 \u0905\u0932\u094d\u091f\u093e\u092f" },
             { "MV", "\u092e\u093e\u0932\u0926\u0940\u0935" },
             { "MW", "\u092e\u0932\u093e\u0935\u0940" },
-            { "type.ca.japanese", metaValue_ja },
             { "MX", "\u092e\u0947\u0915\u094d\u0938\u093f\u0915\u094b" },
+            { "type.ca.japanese", "\u091c\u092a\u093e\u0928\u0940 \u0926\u093f\u0928\u0926\u0930\u094d\u0936\u093f\u0915\u093e" },
             { "MY", "\u092e\u0932\u0947\u0936\u093f\u092f\u093e" },
             { "MZ", "\u092e\u0949\u091d\u093e\u0902\u092c\u0940\u0915" },
             { "NA", "\u0928\u093e\u092e\u0940\u092c\u093f\u092f\u093e" },
@@ -412,11 +410,11 @@ public class LocaleNames_kok extends OpenListResourceBundle {
             { "type.nu.taml", "\u092a\u093e\u0930\u0902\u092a\u093e\u0930\u0940\u0915 \u0924\u092e\u093f\u0933 \u0938\u0902\u0916\u094d\u092f\u093e" },
             { "SR", "\u0938\u0941\u0930\u0940\u0928\u093e\u092e" },
             { "SS", "\u0926\u0915\u094d\u0937\u093f\u0923 \u0938\u0941\u0921\u093e\u0928" },
-            { "ST", "\u0938\u093e\u0935\u094b \u091f\u094b\u092e\u0947 \u0906\u0928\u0940 \u092a\u094d\u0930\u093f\u0902\u0938\u093f\u092a\u0932" },
+            { "ST", "\u0938\u093e\u0913 \u091f\u094b\u092e \u0906\u0928\u0940 \u092a\u094d\u0930\u093f\u0928\u094d\u0938\u093f\u092a" },
             { "SV", "\u090f\u0932 \u0938\u093e\u0932\u094d\u0935\u093e\u0921\u094b\u0930" },
             { "SX", "\u0938\u093f\u0902\u091f \u092e\u093e\u0930\u094d\u091f\u0947\u0928" },
             { "SY", "\u0938\u093f\u0930\u093f\u092f\u093e" },
-            { "SZ", "\u0938\u094d\u0935\u093e\u091c\u0940\u0932\u0901\u0921" },
+            { "SZ", "\u0907\u0938\u094d\u0935\u093e\u0924\u093f\u0928\u0940" },
             { "TA", "\u0924\u094d\u0930\u093f\u0938\u094d\u0924\u093e\u0928 \u0926\u093e \u0915\u0941\u0928\u094d\u0939\u093e" },
             { "asa", "\u0905\u0938\u0941" },
             { "type.ms.ussystem", "\u092f\u0941\u090f\u0938 \u092e\u093e\u092a\u0928 \u092a\u094d\u0930\u0923\u093e\u0932\u0940" },
@@ -480,7 +478,9 @@ public class LocaleNames_kok extends OpenListResourceBundle {
             { "wae", "\u0935\u093e\u0932\u094d\u0938\u0930" },
             { "WS", "\u0938\u093e\u092e\u094b\u0906" },
             { "wal", "\u0935\u094b\u0932\u093e\u092f\u091f\u093e" },
+            { "XA", "\u0938\u094d\u092f\u0941\u0921\u094b-\u090d\u0915\u094d\u0938\u0947\u0902\u091f" },
             { "war", "\u0935\u0930\u092f" },
+            { "XB", "\u0938\u094d\u092f\u0941\u0921\u094b-\u092c\u093f\u0921\u0940" },
             { "awa", "\u0905\u0935\u0927\u0940" },
             { "061", "\u092a\u094b\u0932\u093f\u0928\u0947\u0936\u093f\u092f\u093e" },
             { "XK", "\u0915\u094b\u0938\u094b\u0935\u094b" },
@@ -491,7 +491,7 @@ public class LocaleNames_kok extends OpenListResourceBundle {
             { "type.co.standard", "\u092a\u094d\u0930\u092e\u093e\u0923\u093f\u0924 \u0935\u0930\u094d\u0917\u0935\u093e\u0930\u0940 \u0915\u094d\u0930\u092e" },
             { "YT", "\u092e\u0947\u092f\u094b\u091f" },
             { "ZA", "\u0926\u0915\u094d\u0937\u093f\u0923 \u0906\u092b\u094d\u0930\u0940\u0915\u093e" },
-            { "type.lb.loose", "\u0932\u0942\u091c \u0930\u0947\u0917 \u0916\u0902\u0921 \u0936\u0948\u0932\u0940" },
+            { "type.lb.loose", "\u0938\u0941\u091f\u0940 \u0930\u0947\u0917 \u0916\u0902\u0921 \u0936\u0948\u0932\u0940" },
             { "Deva", "\u0926\u0947\u0935\u0928\u093e\u0917\u0930\u0940" },
             { "type.nu.geor", "\u091c\u0949\u0930\u094d\u091c\u093f\u092f\u0928 \u0938\u0902\u0916\u094d\u092f\u093e" },
             { "Hira", "\u0939\u093f\u0930\u093e\u0917\u0928\u093e" },
@@ -518,7 +518,7 @@ public class LocaleNames_kok extends OpenListResourceBundle {
             { "sad", "\u0938\u0902\u0921\u093e\u0935\u0947" },
             { "type.nu.roman", "\u0930\u094b\u092e\u0928 \u0938\u0902\u0916\u094d\u092f\u093e" },
             { "sah", "\u0938\u0916\u093e" },
-            { "saq", "\u0938\u093e\u0902\u092c\u093e\u0930\u0941" },
+            { "saq", "\u0938\u093e\u092e\u094d\u092c\u0930\u0942" },
             { "sat", "\u0938\u0902\u0925\u093e\u0932\u0940" },
             { "sba", "\u0917\u093e\u0902\u092c\u0947" },
             { "Guru", "\u0917\u0941\u0930\u092e\u0941\u0916\u0940" },
@@ -533,7 +533,7 @@ public class LocaleNames_kok extends OpenListResourceBundle {
             { "ban", "\u092c\u093e\u0932\u093f\u0928\u093f\u0938" },
             { "luy", "\u0932\u0941\u092f" },
             { "bas", "\u092c\u0938\u094d\u0938\u093e" },
-            { "es_ES", "\u092f\u0941\u0930\u094b\u092a\u093f\u092f\u0928 \u0938\u094d\u092a\u0945\u0928\u093f\u0936" },
+            { "es_ES", "\u092f\u0941\u0930\u094b\u092a\u093f\u092f\u0928 \u0938\u094d\u092a\u0945\u0928\u0940\u0936" },
             { "sco", "\u0938\u094d\u0915\u0949\u091f\u094d\u0938" },
             { "scn", "\u0938\u093f\u0938\u093f\u0932\u093f\u092f\u093e\u0928" },
             { "aa", "\u0905\u092b\u093e\u0930" },
@@ -541,10 +541,10 @@ public class LocaleNames_kok extends OpenListResourceBundle {
             { "af", "\u0905\u092b\u094d\u0930\u093f\u0915\u093e\u0928\u094d\u0938" },
             { "ak", "\u0905\u0915\u093e\u0928" },
             { "am", "\u0905\u092e\u0939\u093e\u0930\u093f\u0915\u094d" },
-            { "Arab", metaValue_ar },
             { "an", "\u0906\u0930\u093e\u0917\u094b\u0928\u093f\u0938" },
+            { "Arab", "\u0906\u0930\u092c\u0940" },
             { "Jpan", metaValue_ja },
-            { "ar", metaValue_ar },
+            { "ar", "\u0905\u0930\u0947\u092c\u093f\u0915" },
             { "Hrkt", "\u091c\u092a\u093e\u0928\u0940 \u0905\u0915\u094d\u0937\u0930\u092e\u093e\u0933" },
             { "as", "\u0906\u0938\u093e\u092e\u0940" },
             { "av", "\u0905\u0935\u093e\u0930\u093f\u0915" },
@@ -556,7 +556,7 @@ public class LocaleNames_kok extends OpenListResourceBundle {
             { "bi", "\u092c\u093f\u0938\u0932\u092e\u093e" },
             { "bm", "\u092c\u0902\u092c\u093e\u0930\u093e" },
             { "bn", metaValue_bn },
-            { "bo", metaValue_bo },
+            { "bo", "\u0924\u093f\u092c\u0947\u091f\u0940" },
             { "dgr", "\u0921\u094b\u0917\u0930\u0940\u092c" },
             { "br", "\u092c\u094d\u0930\u0947\u091f\u0928" },
             { "bs", "\u092c\u094b\u0938\u094d\u0928\u093f\u092f\u0928" },
@@ -568,19 +568,19 @@ public class LocaleNames_kok extends OpenListResourceBundle {
             { "ce", "\u091a\u093f\u091a\u0947\u0928" },
             { "ch", "\u091a\u093e\u092e\u094b\u0930\u094d\u0930\u094b" },
             { "co", "\u0915\u094b\u0930\u094d\u0936\u093f\u092f\u0928" },
-            { "Orya", metaValue_or },
+            { "Orya", "\u0913\u0930\u093f\u092f\u093e" },
             { "cs", "\u091a\u0947\u0915" },
             { "cu", "\u091a\u0930\u094d\u091a \u0938\u094d\u0932\u0947\u0935\u094d\u0939\u0940\u0915" },
             { "cv", "\u091b\u0941\u0935\u093e\u0938" },
             { "cy", "\u0935\u0947\u0933\u094d\u0937\u094d" },
             { "type.nu.ethi", "\u0907\u0925\u093f\u092f\u094b\u092a\u093f\u0915 \u0938\u0902\u0916\u094d\u092f\u093e" },
             { "da", "\u0921\u0945\u0928\u093f\u0936" },
-            { "pt_PT", "\u092f\u0941\u0930\u094b\u092a\u093f\u092f\u0928 \u092a\u094b\u0930\u094d\u0924\u0941\u0917\u093f\u091c" },
+            { "pt_PT", "\u092f\u0941\u0930\u094b\u092a\u093f\u092f\u0928 \u092a\u094b\u0930\u094d\u0924\u0941\u0917\u0940\u091c" },
             { "de", "\u091c\u0930\u094d\u092e\u0928" },
-            { "type.cf.standard", "\u092a\u094d\u0930\u092e\u093e\u0923\u093f\u0924" },
+            { "type.cf.standard", "\u092a\u094d\u0930\u092e\u093e\u0923\u093f\u0924 \u091a\u0932\u0928 \u0938\u094d\u0935\u0930\u0941\u092a" },
             { "bem", "\u092c\u0947\u092e\u094d\u092c\u093e" },
             { "dv", "\u0926\u093f\u0935\u0947\u0939\u0940" },
-            { "es_419", "\u0932\u0945\u091f\u093f\u0928 \u0905\u092e\u0947\u0930\u093f\u0915\u0928 \u0938\u094d\u092a\u0945\u0928\u093f\u0936" },
+            { "es_419", "\u0932\u093e\u0924\u0940\u0902 \u0905\u092e\u0947\u0930\u093f\u0915\u0928 \u0938\u094d\u092a\u0945\u0928\u0940\u0936" },
             { "dz", "\u091d\u094b\u0902\u0917\u094d\u0916\u093e" },
             { "bez", "\u092c\u0947\u0928\u093e" },
             { "type.ca.chinese", "\u091a\u0940\u0928\u0940 \u0926\u093f\u0928\u0926\u0930\u094d\u0936\u093f\u0915\u093e" },
@@ -592,18 +592,18 @@ public class LocaleNames_kok extends OpenListResourceBundle {
             { "el", "\u0917\u094d\u0930\u0940\u0915\u094d" },
             { "en", "\u0907\u0902\u0917\u094d\u0932\u0940\u0936" },
             { "eo", "\u0907\u0938\u094d\u092a\u0930\u093e\u0928\u094d\u091f\u094b" },
-            { "es", "\u0938\u094d\u092a\u0945\u0928\u093f\u0936" },
+            { "es", "\u0938\u094d\u092a\u0945\u0928\u0940\u0936" },
             { "et", "\u0907\u0938\u094d\u091f\u094b\u0928\u093f\u092f\u0928\u094d" },
-            { "Hanb", "\u092c\u094b\u092a\u094b\u092e\u094b\u092b\u094b \u0935\u093e\u0902\u0917\u0921\u093e \u0939\u0945\u0928" },
+            { "Hanb", "\u092c\u094b\u092a\u094b\u092b\u094b\u092e\u094b \u0935\u0930\u0935\u0940\u0902 \u0939\u093e\u0928" },
             { "eu", "\u092c\u093e\u0938\u094d\u0915" },
             { "Hang", "\u0939\u0902\u0917\u0942\u0932" },
             { "shi", "\u0924\u093e\u091b\u0947\u0939\u0940\u091f" },
             { "hsb", "\u0905\u092a\u0930 \u0938\u094b\u0930\u094d\u092c\u093f\u092f\u0928" },
-            { "Hani", "\u0939\u0945\u0928" },
+            { "Hani", "\u0939\u093e\u0928" },
             { "shn", "\u0936\u093e\u0928" },
-            { "fa", "\u092a\u0930\u094d\u0937\u093f\u092f\u0928\u094d" },
+            { "fa", "\u092a\u0930\u094d\u0936\u093f\u092f\u0928" },
             { "Hans", "\u0938\u094b\u0902\u092a\u0940" },
-            { "type.nu.latn", "\u0905\u0938\u094d\u0924\u0902\u0924 \u0905\u0902\u0915" },
+            { "type.nu.latn", "\u0905\u0938\u094d\u0924\u0902\u0924\u0940\u092f \u0905\u0902\u0915" },
             { "Hant", "\u092a\u093e\u0930\u0902\u092a\u093e\u0930\u0940\u0915" },
             { "ff", "\u092b\u0941\u0932\u093e" },
             { "fi", "\u092b\u093f\u0928\u094d\u0928\u093f\u0937\u094d" },
@@ -612,14 +612,14 @@ public class LocaleNames_kok extends OpenListResourceBundle {
             { "yue", "\u0915\u093e\u0902\u091f\u094b\u0938\u0940" },
             { "fo", "\u092b\u0947\u0930\u094b\u0938\u094d" },
             { "umb", "\u092f\u092e\u092c\u0941\u0902\u0921\u0941" },
-            { "fr", "\u092b\u094d\u0930\u0947\u0928\u094d\u091a" },
+            { "fr", "\u092b\u094d\u0930\u0947\u0902\u091a" },
             { "fy", "\u092a\u0936\u094d\u091a\u093f\u092e\u0940 \u092b\u094d\u0930\u093f\u0936\u093f\u092f\u0928" },
             { "ga", "\u0910\u0930\u093f\u0937" },
-            { "gd", "\u0938\u094d\u0915\u093e\u091f\u0938\u094d \u0917\u0947\u0932\u093f\u0915\u094d" },
+            { "gd", "\u0938\u094d\u0915\u0949\u091f\u0940\u0936 \u0917\u0945\u0932\u0940\u0915" },
             { "gl", "\u0917\u0947\u0932\u0940\u0936\u093f\u092f\u0928" },
             { "gn", "\u0917\u094c\u0930\u093e\u0928\u0940" },
             { "bho", "\u092d\u094b\u091c\u092a\u0941\u0930\u0940" },
-            { "und", "\u0905\u091c\u094d\u091e\u093e\u0924 \u092d\u093e\u0936\u093e" },
+            { "und", "\u0905\u091c\u094d\u091e\u093e\u0924 \u092d\u093e\u0938" },
             { "gu", metaValue_gu },
             { "gv", "\u092e\u0945\u0928\u094d\u0938" },
             { "ha", "\u0939\u094c\u0938\u093e" },
@@ -634,8 +634,8 @@ public class LocaleNames_kok extends OpenListResourceBundle {
             { "hz", "\u0939\u093f\u0930\u093f\u0930\u094b" },
             { "ia", "\u0907\u0928\u094d\u091f\u0930\u0932\u093f\u0902\u0917\u094d\u0935\u093e" },
             { "Jamo", "\u091c\u093e\u092e\u094b" },
-            { "type.nu.tibt", metaValue_bo },
             { "id", "\u0907\u0902\u0921\u094b\u0928\u0947\u0936\u093f\u092f\u0928" },
+            { "type.nu.tibt", "\u0924\u093f\u092c\u0947\u0924\u093f\u092f\u0928 \u0905\u0902\u0915" },
             { "ie", "\u0907\u0928\u094d\u091f\u0930\u0932\u093f\u0902\u0917\u094d" },
             { "ig", "\u0907\u0917\u094d\u092c\u094b" },
             { "ii", "\u0938\u093f\u091a\u094d\u092f\u0941\u0906\u0928 \u092f\u0940" },
@@ -681,7 +681,7 @@ public class LocaleNames_kok extends OpenListResourceBundle {
             { "ln", "\u0932\u093f\u0902\u0917\u093e\u0932\u093e" },
             { "fur", "\u092b\u094d\u0930\u093f\u0932\u093f\u092f\u0928" },
             { "lo", metaValue_lo },
-            { "type.ms.uksystem", "\u0935\u094d\u0939\u0921\u0932\u0940 \u092e\u093e\u092a\u0928 \u092a\u094d\u0930\u0923\u093e\u0932\u0940" },
+            { "type.ms.uksystem", "\u092d\u0935\u094d\u092f \u092e\u093e\u092a\u0928 \u092a\u094d\u0930\u0923\u093e\u0932\u0940" },
             { "lt", "\u0932\u093f\u0925\u0941\u0906\u0928\u093f\u092f\u0928\u094d" },
             { "lu", "\u0932\u0941\u092c\u093e-\u0915\u093e\u091f\u093e\u0902\u0917\u093e" },
             { "lv", "\u0932\u093e\u091f\u094d\u0935\u093f\u092f\u0928\u094d (\u0932\u0947\u091f\u094d\u091f\u093f\u0937\u094d)" },
@@ -691,7 +691,7 @@ public class LocaleNames_kok extends OpenListResourceBundle {
             { "mi", "\u092e\u0941\u0930\u0940" },
             { "mk", "\u092e\u0938\u0940\u0921\u094b\u0928\u093f\u092f\u0928\u094d" },
             { "ml", "\u092e\u0933\u093f\u092f\u093e\u0933\u092e" },
-            { "mn", "\u092e\u0902\u0917\u094b\u0932\u093f\u092f\u0928\u094d" },
+            { "mn", "\u092e\u0902\u0917\u094b\u0932\u093f\u092f\u0928" },
             { "mr", "\u092e\u0930\u093e\u0920\u0940" },
             { "ms", "\u092e\u0932\u092f" },
             { "mt", "\u092e\u093e\u0932\u0924\u0940\u0938\u094d" },
@@ -700,7 +700,7 @@ public class LocaleNames_kok extends OpenListResourceBundle {
             { "mdf", "\u092e\u094b\u0915\u094d\u0937" },
             { "dsb", "\u0932\u094b\u0935\u0930 \u0938\u094b\u0930\u094d\u092c\u093f\u092f\u0928" },
             { "na", "\u0928\u094c\u0930\u094b" },
-            { "type.co.search", "\u0938\u094b\u0926 \u0918\u0947\u0935\u091a\u094b" },
+            { "type.co.search", "\u0938\u093e\u092e\u093e\u0928\u094d\u092f-\u0909\u0926\u094d\u0926\u0947\u0936\u093e\u0928 \u0915\u0947\u0932\u094d\u0932\u094b \u0938\u094b\u0926" },
             { "nb", "\u0928\u094b\u0930\u094d\u0935\u0947\u091c\u093f\u092f\u0928 \u092c\u094b\u0915\u092e\u093e\u0932" },
             { "nd", "\u0909\u0924\u094d\u0924\u0930 \u0928\u094d\u0921\u0947\u092c\u0947\u0932\u0947" },
             { "ne", "\u0928\u0947\u092a\u093e\u0933\u0940" },
@@ -720,19 +720,19 @@ public class LocaleNames_kok extends OpenListResourceBundle {
             { "mer", "\u092e\u0947\u0930\u0942" },
             { "type.nu.armn", "\u0906\u0930\u094d\u092e\u0947\u0928\u093f\u092f\u0928 \u0938\u0902\u0916\u094d\u092f\u093e" },
             { "om", "\u0913\u0930\u094b\u092e\u094b" },
-            { "or", metaValue_or },
+            { "or", "\u0913\u0921\u093f\u092f\u093e" },
             { "os", "\u0913\u0938\u0947\u091f\u093f\u0915" },
             { "kbd", "\u0915\u093e\u092c\u093e\u0930\u094d\u0921\u093f\u092f\u0928" },
             { "mfe", "\u092e\u094b\u0930\u093f\u0938\u0947\u0928" },
             { "srn", "\u0936\u094d\u0930\u093e\u0928\u0928 \u091f\u094b\u0902\u0917\u094b" },
             { "pa", "\u092a\u0902\u091c\u093e\u092c\u0940" },
             { "dua", "\u0921\u094c\u0932" },
-            { "pl", "\u092a\u094b\u0932\u093f\u0937" },
+            { "pl", "\u092a\u0949\u0932\u0940\u0936" },
             { "type.ca.dangi", "\u0921\u093e\u0902\u0917\u0940 \u0926\u093f\u0928\u0926\u0930\u094d\u0936\u093f\u0915\u093e" },
             { "ps", "\u092a\u093e\u0937\u094d\u091f\u094b" },
-            { "pt", "\u092a\u094b\u0930\u094d\u0924\u0941\u0917\u093f\u091c" },
+            { "pt", "\u092a\u094b\u0930\u094d\u0924\u0941\u0917\u0940\u091c" },
             { "key.co", "\u0935\u0930\u094d\u0917\u0935\u093e\u0930\u0940 \u0915\u094d\u0930\u092e" },
-            { "pt_BR", "\u092c\u094d\u0930\u093e\u091d\u093f\u0932\u093f\u092f\u0928 \u092a\u094b\u0930\u094d\u0924\u0941\u0917\u093f\u091c" },
+            { "pt_BR", "\u092c\u094d\u0930\u093e\u091d\u093f\u0932\u093f\u092f\u0928 \u092a\u094b\u0930\u094d\u0924\u0941\u0917\u0940\u091c" },
             { "kcg", "\u0924\u094d\u092f\u093e\u092a" },
             { "mgh", "\u092e\u093e\u0916\u0941\u0935\u093e-\u092e\u093f\u091f\u094d\u091f\u094b" },
             { "key.cf", "\u091a\u0932\u0928\u093e\u091a\u0947\u0902 \u0938\u094d\u0935\u0930\u0942\u092a" },
@@ -749,11 +749,11 @@ public class LocaleNames_kok extends OpenListResourceBundle {
             { "Ethi", "\u0907\u0925\u093f\u092f\u094b\u092a\u0940\u0915" },
             { "type.hc.h12", "12 \u0935\u0930\u093e\u0902\u091a\u0940 \u092f\u0902\u0924\u094d\u0930\u0923\u093e (1\u201312)" },
             { "type.hc.h11", "12 \u0935\u0930\u093e\u0902\u091a\u0940 \u092f\u0902\u0924\u094d\u0930\u0923\u093e (0\u201311)" },
-            { "rm", "\u0930\u094b\u092e\u093e\u0902\u0928\u094d\u0936" },
+            { "rm", "\u0930\u094b\u092e\u093e\u0928\u094d\u0936" },
             { "rn", "\u0930\u0941\u0902\u0926\u0940" },
             { "key.cu", "\u091a\u0932\u0928" },
-            { "ro", "\u0930\u094b\u092e\u093e\u0928\u093f\u092f\u0928\u094d" },
-            { "type.nu.orya", "\u0913\u0921\u093f\u092f\u093e" },
+            { "ro", "\u0930\u094b\u092e\u093e\u0928\u093f\u092f\u0928" },
+            { "type.nu.orya", "\u0913\u0921\u093f\u092f\u093e \u0905\u0902\u0915" },
             { "type.nu.hanidec", "\u091a\u093f\u0928\u0940 \u0926\u0936\u093e\u0902\u0936 \u0938\u0902\u0916\u094d\u092f\u093e" },
             { "ru", "\u0930\u0936\u093f\u092f\u0928" },
             { "rw", "\u0915\u093f\u0928\u094d\u092f\u093e\u0930\u094d\u0935\u093e\u0928\u094d\u0921\u093e" },
@@ -766,12 +766,12 @@ public class LocaleNames_kok extends OpenListResourceBundle {
             { "sd", "\u0938\u093f\u0902\u0927\u0940" },
             { "se", "\u0909\u0924\u094d\u0924\u0930\u0940\u092f \u0938\u093e\u092e\u0940" },
             { "min", "\u092e\u093f\u0928\u093e\u0917\u094d\u0915\u093e\u092c\u094c" },
-            { "sg", "\u0938\u093e\u0902\u0917\u094d\u0930\u094b" },
+            { "sg", "\u0938\u093e\u0902\u0917\u094b" },
             { "sh", "\u0938\u0947\u0930\u094d\u092c\u094b-\u0915\u094d\u0930\u094b\u092f\u0947\u0937\u093f\u092f\u0928\u094d" },
-            { "si", "\u0938\u093f\u0928\u094d\u0939\u0932\u0940\u0938\u094d" },
+            { "si", "\u0938\u093f\u0928\u0939\u093e\u0932\u0940\u0938" },
             { "sk", "\u0938\u094d\u0932\u094b\u0935\u093e\u0915" },
-            { "sl", "\u0938\u094d\u0932\u094b\u0935\u0947\u0928\u093f\u092f\u0928\u094d" },
-            { "sm", "\u0938\u092e\u094b\u0928" },
+            { "sl", "\u0938\u094d\u0932\u094b\u0935\u093e\u0928\u093f\u092f\u0928" },
+            { "sm", "\u0938\u093e\u092e\u094b\u0905\u0928" },
             { "sn", "\u0936\u094b\u0928\u093e" },
             { "so", "\u0938\u094b\u092e\u093e\u0932\u0940" },
             { "type.nu.arab", "\u0905\u0930\u0947\u092c\u093f\u0915-\u092d\u093e\u0930\u0924\u0940\u092f \u0905\u0902\u0915" },
@@ -779,9 +779,9 @@ public class LocaleNames_kok extends OpenListResourceBundle {
             { "sr", "\u0938\u0930\u094d\u092c\u093f\u092f\u0928" },
             { "ss", "\u0938\u094d\u0935\u093e\u0924\u0940" },
             { "type.cf.account", "\u0932\u0947\u0916\u093e \u091a\u0932\u0928 \u0938\u094d\u0935\u0930\u0942\u092a" },
-            { "st", "\u0938\u0947\u0938\u094b\u0925\u094b" },
+            { "st", "\u0938\u093e\u0935\u0925\u0930\u094d\u0928 \u0938\u094b\u0925\u094b" },
             { "su", "\u0938\u0941\u0902\u0926\u0928\u0940\u0938" },
-            { "sv", "\u0938\u094d\u0935\u0940\u0926\u0940\u0937" },
+            { "sv", "\u0938\u094d\u0935\u093f\u0921\u0940\u0936" },
             { "sw", "\u0938\u094d\u0935\u093e\u0939\u093f\u0932\u0940" },
             { "type.nu.hantfin", "\u092a\u093e\u0930\u0902\u092a\u093e\u0930\u0940\u0915 \u091a\u093f\u0928\u0940 \u092e\u0939\u0938\u0942\u0932 \u0938\u0902\u0916\u094d\u092f\u093e" },
             { "ibb", "\u0908\u092c\u093f\u092c\u093f\u092f\u094b" },
@@ -789,15 +789,15 @@ public class LocaleNames_kok extends OpenListResourceBundle {
             { "ta", "\u0924\u092e\u093f\u0933" },
             { "142", "\u0906\u0936\u093f\u092f\u093e" },
             { "143", "\u092e\u0927\u094d\u092f \u0906\u0936\u093f\u092f\u093e" },
-            { "te", metaValue_te },
+            { "te", "\u0924\u0947\u0932\u0941\u0917\u0942" },
             { "145", "\u0905\u0938\u094d\u0924\u0902\u0924 \u0906\u0936\u093f\u092f\u093e" },
-            { "tg", "\u0924\u091c\u093f\u0915" },
+            { "tg", "\u0924\u093e\u091c\u093f\u0915" },
             { "th", metaValue_th },
             { "ti", "\u0924\u093f\u0917\u094d\u0930\u093f\u0928\u094d\u092f\u093e" },
             { "bug", "\u092c\u0917\u093f\u0928\u093f\u0938" },
             { "kfo", "\u0915\u094b\u0930\u094b" },
-            { "en_CA", "\u0915\u0945\u0928\u093e\u0921\u0940\u092f\u0928 \u0907\u0902\u0917\u094d\u0932\u0940\u0936" },
-            { "tk", "\u0924\u0941\u0930\u094d\u0915\u092e\u0928" },
+            { "en_CA", "\u0915\u0945\u0928\u0921\u093f\u092f\u0928 \u0907\u0902\u0917\u094d\u0932\u0940\u0936" },
+            { "tk", "\u0924\u0941\u0930\u094d\u0915\u092e\u0947\u0928" },
             { "tl", "\u0924\u0917\u093e\u0932\u094b\u0917" },
             { "tn", "\u0938\u0947\u0924\u094d\u0938\u094d\u0935\u093e\u0928\u093e" },
             { "to", "\u0924\u094b\u0902\u0917\u093e" },
@@ -820,7 +820,7 @@ public class LocaleNames_kok extends OpenListResourceBundle {
             { "uk", "\u092f\u0941\u0915\u094d\u0930\u0947\u0928\u093f\u092f\u0928\u094d" },
             { "ur", "\u0909\u0930\u094d\u0926\u0942" },
             { "xal", "\u0915\u093e\u0932\u092e\u093e\u092f\u0915" },
-            { "uz", "\u0909\u091c\u093c\u092c\u0947\u0915" },
+            { "uz", "\u0909\u091d\u092c\u0947\u0915" },
             { "kha", "\u0916\u093e\u0938\u0940" },
             { "ve", "\u0935\u0947\u0902\u0926\u093e" },
             { "type.ca.roc", "\u092e\u093f\u0902\u0917\u0941\u0906 \u0926\u093f\u0928\u0926\u0930\u094d\u0936\u093f\u0915\u093e (\u0905\u0923\u0915\u093e\u0930\u093e\u091a\u0940 \u0915\u0941\u0930\u0942: \u091c\u093e\u0915\u093e \u091a\u093f\u0928\u0940 \u0926\u093f\u0928\u0926\u0930\u094d\u0936\u093f\u0915\u0947\u091a\u0947\u0902 \u092a\u094d\u0930\u091c\u093e\u0938\u0924\u094d\u0924\u093e\u0915\", \"\u0930\u093f\u092a\u092c\u094d\u0932\u093f\u0915\u0928 \u0926\u093f\u0928\u0926\u0930\u094d\u0936\u093f\u0915\u093e\")" },
@@ -834,7 +834,7 @@ public class LocaleNames_kok extends OpenListResourceBundle {
             { "syr", "\u0938\u093f\u0930\u093f\u092f\u093e\u0915" },
             { "Grek", "\u0917\u094d\u0930\u0940\u0915" },
             { "wo", "\u0909\u0932\u094b\u092b\u093c" },
-            { "zgh", "\u092a\u094d\u0930\u092e\u093e\u0923\u093f\u0924 \u092e\u094b\u0930\u094b\u0915\u094d\u0915\u0928 \u0924\u093e\u092e\u093e\u091d\u093e\u092f\u091f" },
+            { "zgh", "\u092a\u094d\u0930\u092e\u093e\u0923\u0940\u0924 \u092e\u0949\u0930\u094b\u0915\u094d\u0915\u0928 \u0924\u092e\u093e\u091d\u0940\u091f" },
             { "ar_001", "\u0906\u0927\u0941\u0928\u093f\u0915 \u092a\u094d\u0930\u092e\u093e\u0923\u093f\u0924 \u0905\u0930\u0947\u092c\u093f\u0915" },
             { "Mong", "\u092e\u094b\u0902\u0917\u094b\u0932\u093f\u092f\u0928" },
             { "mni", "\u092e\u0923\u093f\u092a\u0941\u0930\u0940" },
@@ -849,7 +849,7 @@ public class LocaleNames_kok extends OpenListResourceBundle {
             { "yi", "\u0907\u0926\u094d\u0926\u093f\u0937\u094d" },
             { "mos", "\u092e\u094b\u0938\u094d\u0938\u0940" },
             { "yo", "\u092f\u0942\u0930\u0941\u092c\u093e" },
-            { "es_MX", "\u092e\u0947\u0915\u094d\u0938\u093f\u0915\u0928 \u0938\u094d\u092a\u0945\u0928\u093f\u0936" },
+            { "es_MX", "\u092e\u0945\u0915\u094d\u0938\u093f\u0915\u0928 \u0938\u094d\u092a\u0945\u0928\u0940\u0936" },
             { "vai", "\u0935\u093e\u0908" },
             { "za", "\u091d\u094d\u0939\u0941\u0928\u094d\u0917" },
             { "kln", "\u0915\u093e\u0932\u0947\u0902\u091c\u0940\u0928" },
@@ -877,12 +877,13 @@ public class LocaleNames_kok extends OpenListResourceBundle {
             { "type.nu.tamldec", "\u0924\u092e\u093f\u0933 \u0905\u0902\u0915" },
             { "krc", "\u0915\u0930\u093e\u091a\u0940-\u092c\u093e\u0932\u094d\u0915\u0930" },
             { "inh", "\u0907\u0902\u0917\u0942\u0936" },
+            { "fa_AF", "\u0926\u093e\u0930\u0940" },
             { "krl", "\u0915\u093e\u0930\u0947\u0932\u093f\u092f\u0928" },
             { "efi", "\u090f\u092b\u0940\u0915" },
-            { "key.nu", "\u0915\u094d\u0930\u092e\u093e\u0902\u0915" },
+            { "key.nu", "\u0938\u0902\u0916\u094d\u092f\u093e" },
             { "kru", "\u0915\u0941\u0930\u0941\u0916" },
-            { "ksb", "\u0936\u0902\u092c\u093e\u0932\u093e" },
-            { "Telu", metaValue_te },
+            { "ksb", "\u0936\u093e\u0902\u092c\u093e\u0932\u093e" },
+            { "Telu", "\u0924\u0947\u0932\u0917\u0942" },
             { "ksf", "\u092c\u093e\u092b\u093f\u092f\u093e" },
         };
         return data;
