@@ -334,7 +334,6 @@ public class LocaleNames_ks extends OpenListResourceBundle {
             { "Thai", metaValue_th },
             { "MH", "\u0645\u0627\u0631\u0634\u064e\u0644 \u062c\u0654\u0632\u06cc\u0656\u0631\u0655" },
             { "ale", "\u0627\u064e\u0644\u0648\u06cc\u062a\u06cc" },
-            { "MK", "\u0645\u0620\u0633\u0648\u0691\u0648\u0646\u0650\u06cc\u0627" },
             { "ML", "\u0645\u0627\u0644\u06cc" },
             { "MM", "\u0645\u064e\u06cc\u064e\u0646\u0645\u0627 \u0628\u0654\u0631\u0645\u0627" },
             { "MN", "\u0645\u064e\u0646\u06af\u0648\u0644\u0650\u06cc\u0627" },
@@ -577,6 +576,7 @@ public class LocaleNames_ks extends OpenListResourceBundle {
             { "scn", "\u0633\u0650\u0686\u0650\u0644\u0650\u06cc\u064e\u0646" },
             { "aa", "\u0627\u064e\u0641\u0627\u0631" },
             { "ab", "\u0627\u064e\u0628\u062e\u0627\u0632\u0650\u06cc\u0627\u0646" },
+            { "Aran", "\u0646\u0633\u062a\u0639\u0644\u06cc\u0642" },
             { "ae", metaValue_ae },
             { "af", "\u0627\u064e\u0641\u0631\u06cc\u0656\u06a9\u0627\u0646\u0632" },
             { "ak", "\u0627\u064e\u06a9\u0627\u0646" },
