@@ -342,7 +342,6 @@ public class LocaleNames_ku extends OpenListResourceBundle {
             { "MC", "Monako" },
             { "MD", "Moldova" },
             { "ME", "Montenegro" },
-            { "MF", "MF" },
             { "MG", "Madagaskar" },
             { "mg", "malagas\u00ee" },
             { "MH", "Girav\u00ean Mar\u015fal" },
@@ -561,7 +560,6 @@ public class LocaleNames_ku extends OpenListResourceBundle {
             { "xh", "xosay\u00ee" },
             { "XK", "Kosovo" },
             { "Zxxx", "ne niv\u00eesand\u00ee" },
-            { "byn", "byn" },
             { "moh", "mohawk\u00ee" },
             { "YE", "Yemen" },
             { "yi", "yid\u00ee\u015f\u00ee" },
@@ -574,7 +572,6 @@ public class LocaleNames_ku extends OpenListResourceBundle {
             { "Geor", metaValue_ka },
             { "type.ca.iso8601", "salnameya ISO-8601" },
             { "nso", "sotoyiya bakur" },
-            { "gez", "gez" },
             { "kok", "konkan\u00ee" },
             { "hil", "h\u00eel\u00eegaynon\u00ee" },
             { "lrc", "luriya bakur" },
