@@ -76,6 +76,7 @@ public class LocaleNames_ky extends OpenListResourceBundle {
             { "mwl", "\u043c\u0438\u0440\u0430\u043d\u0434\u0438\u0437\u0447\u0435" },
             { "Zsym", "\u0411\u0435\u043b\u0433\u0438\u043b\u0435\u0440" },
             { "Zsye", "\u0411\u044b\u0439\u0442\u044b\u043a\u0447\u0430" },
+            { "ccp", "\u0427\u0430\u043a\u043c\u0430" },
             { "tem", "\u0442\u0438\u043c\u043d\u0435\u0447\u0435" },
             { "teo", "\u0442\u0435\u0441\u043e\u0447\u043e" },
             { "rap", "\u0440\u0430\u043f\u0430\u043d\u044c\u044e\u0447\u0430" },
@@ -228,7 +229,6 @@ public class LocaleNames_ky extends OpenListResourceBundle {
             { "HT", "\u0413\u0430\u0438\u0442\u0438" },
             { "HU", "\u0412\u0435\u043d\u0433\u0440\u0438\u044f" },
             { "IC", "\u041a\u0430\u043d\u0430\u0440 \u0430\u0440\u0430\u043b\u0434\u0430\u0440\u044b" },
-            { "nan", "nan" },
             { "ID", "\u0418\u043d\u0434\u043e\u043d\u0435\u0437\u0438\u044f" },
             { "IE", "\u0418\u0440\u043b\u0430\u043d\u0434\u0438\u044f" },
             { "nap", "\u043d\u0435\u043e\u043f\u043e\u043b\u0438\u0442\u0430\u043d\u0447\u0430" },
@@ -468,7 +468,9 @@ public class LocaleNames_ky extends OpenListResourceBundle {
             { "wae", "\u0432\u0430\u043b\u0446\u0435\u0440\u0447\u0435" },
             { "WS", "\u0421\u0430\u043c\u043e\u0430" },
             { "wal", "\u0432\u043e\u043b\u044c\u044f\u0442\u0442\u0430\u0447\u0430" },
+            { "XA", "\u0416\u0430\u0441\u0430\u043b\u043c\u0430- \u0410\u043a\u0446\u0435\u043d\u0442" },
             { "war", "\u0432\u0430\u0440\u0430\u0439\u0447\u0430" },
+            { "XB", "\u0416\u0430\u0441\u0430\u043b\u043c\u0430 - \u044d\u043a\u0438 \u0442\u0430\u0440\u0430\u043f\u0442\u0443\u0443" },
             { "awa", "\u0430\u0432\u0430\u0434\u0445\u0438\u0447\u0435" },
             { "061", "\u041f\u043e\u043b\u0438\u043d\u0435\u0437\u0438\u044f" },
             { "XK", "\u041a\u043e\u0441\u043e\u0432\u043e" },
@@ -645,7 +647,6 @@ public class LocaleNames_ky extends OpenListResourceBundle {
             { "ka", "\u0433\u0440\u0443\u0437\u0438\u043d\u0447\u0435" },
             { "bla", "\u0441\u0438\u043a\u0441\u0438\u043a\u0430\u0447\u0430" },
             { "mak", "\u043c\u0430\u043a\u0430\u0441\u0430\u0440\u0447\u0430" },
-            { "wuu", "wuu" },
             { "sms", "\u0441\u043a\u043e\u043b\u0442 \u0441\u0430\u0430\u043c\u0438\u0447\u0435" },
             { "ki", "\u043a\u0438\u043a\u0443\u0439\u0438\u0447\u0435" },
             { "mas", "\u043c\u0430\u0441\u0430\u0439\u0447\u0430" },
@@ -722,6 +723,7 @@ public class LocaleNames_ky extends OpenListResourceBundle {
             { "ps", "\u043f\u0443\u0448\u0442\u0443\u0447\u0430" },
             { "pt", "\u043f\u043e\u0440\u0442\u0443\u0433\u0430\u043b\u0447\u0430" },
             { "key.co", "\u0418\u0440\u0433\u04e9\u04e9 \u0442\u0430\u0440\u0442\u0438\u0431\u0438" },
+            { "pt_BR", "\u0411\u0440\u0430\u0437\u0438\u043b\u0438\u044f\u043b\u044b\u043a \u041f\u043e\u0440\u0442\u0443\u0433\u0430\u043b \u0442\u0438\u043b\u0438" },
             { "kcg", "\u0442\u044f\u043f\u0447\u0430" },
             { "mgh", "\u043c\u0430\u043a\u0443\u0430\u0447\u0430" },
             { "key.cf", "\u0412\u0430\u043b\u044e\u0442\u0430 \u0444\u043e\u0440\u043c\u0430\u0442\u044b" },
@@ -865,6 +867,7 @@ public class LocaleNames_ky extends OpenListResourceBundle {
             { "type.nu.tamldec", "\u0422\u0430\u043c\u0438\u043b \u0441\u0430\u043d\u0434\u0430\u0440\u044b" },
             { "krc", "\u043a\u0430\u0440\u0430\u0447\u0430\u0439-\u0431\u0430\u043b\u043a\u0430\u0440\u0447\u0430" },
             { "inh", "\u0438\u043d\u0433\u0443\u0448\u0447\u0430" },
+            { "fa_AF", "\u0434\u0430\u0440\u0438" },
             { "krl", "\u043a\u0430\u0440\u0435\u043b\u0447\u0435" },
             { "efi", "\u044d\u0444\u0438\u043a\u0447\u0435" },
             { "key.nu", "\u0421\u0430\u043d\u0434\u0430\u0440" },
