@@ -963,7 +963,6 @@ public class LocaleNames_lb extends OpenListResourceBundle {
             { "mdf", "Moksha" },
             { "mde", "Maba" },
             { "dsb", "Niddersorbesch" },
-            { "Armi", "Armi" },
             { "na", "Nauruesch" },
             { "type.co.search", "Allgemeng Sich" },
             { "nb", "Norwegesch Bokm\u00e5l" },
@@ -1194,7 +1193,6 @@ public class LocaleNames_lb extends OpenListResourceBundle {
             { "Geor", metaValue_ka },
             { "kmb", "Kimbundu-Sprooch" },
             { "type.nu.jpanfin", "Japanesch Finanzzifferen" },
-            { "Cham", "Cham" },
             { "gez", "Geez" },
             { "mrj", "West-Mari" },
             { "Syrn", "Ostsyresch" },
