@@ -108,6 +108,7 @@ public class LocaleNames_lo extends OpenListResourceBundle {
             { "Tagb", "\u0e95\u0eb1\u0e81\u0e9a\u0eb1\u0e99\u0ea7\u0eb2" },
             { "Zsye", "\u0ead\u0eb5\u0ec2\u0ea1\u0e88\u0eb4" },
             { "%%NJIVA", "\u0e9e\u0eb2\u0eaa\u0eb2\u0e9e\u0eb7\u0ec9\u0e99\u0ec0\u0ea1\u0eb7\u0ead\u0e87\u0e88\u0eb5\u0ea7\u0eb2/\u0e99\u0eb5\u0ea7\u0eb2" },
+            { "ccp", "Chakma" },
             { "egy", "\u0ead\u0eb5\u0ea2\u0eb4\u0e9a\u0e9a\u0eb9\u0eae\u0eb2\u0e99" },
             { "raj", "\u0ea3\u0eb2\u0e88\u0eb1\u0eaa\u0e97\u0eb2\u0e99\u0eb4" },
             { "Phag", "\u0e9f\u0eb2\u0e81\u0eaa-\u0e9b\u0eb2" },
@@ -219,7 +220,7 @@ public class LocaleNames_lo extends OpenListResourceBundle {
             { "DZ", "\u0ead\u0eb1\u0ea5\u0e88\u0eb4\u0ec0\u0ea3\u0e8d" },
             { "pag", "\u0e9b\u0eb2\u0e99\u0e81\u0eb2\u0e8a\u0eb5\u0ea1\u0eb2\u0e99" },
             { "pal", "\u0e9e\u0eb2\u0ea5\u0eb2\u0ea7\u0eb5" },
-            { "EA", "\u0ec0\u0e8a\u0ea7\u0e95\u0eb2 \u0ec1\u0ea5\u0eb0\u0ec0\u0ea1\u0ea5\u0eb4\u0e99\u0ea5\u0eb2" },
+            { "EA", "\u0ec0\u0e8a\u0ea7\u0e95\u0eb2 & \u0ec0\u0ea1\u0ea5\u0eb4\u0e99\u0ea5\u0eb2" },
             { "chb", "\u0e8a\u0eb4\u0e9a\u0e8a\u0eb2" },
             { "pam", "\u0e9b\u0eb2\u0ea1\u0e9b\u0eb2\u0e99\u0e81\u0eb2" },
             { "EC", "\u0ec0\u0ead\u0e81\u0ea7\u0eb2\u0e94\u0ecd" },
@@ -398,7 +399,7 @@ public class LocaleNames_lo extends OpenListResourceBundle {
             { "MH", "\u0eab\u0ea1\u0eb9\u0ec8\u0ec0\u0e81\u0eb2\u0eb0\u0ea1\u0eb2\u0ec1\u0e8a\u0ea7" },
             { "ale", "\u0ead\u0eb2\u0ec0\u0ea5\u0eb5\u0e94" },
             { "type.nu.vaii", "\u0e95\u0ebb\u0ea7\u0ec0\u0ea5\u0e81\u0ec3\u0e99\u0ea5\u0eb0\u0e9a\u0ebb\u0e9a\u0ec4\u0ea7" },
-            { "MK", "\u0ec1\u0ea1\u0e8a\u0eb4\u0ec2\u0e94\u0ec0\u0e99\u0e8d" },
+            { "MK", "\u0ec1\u0ea1\u0e8a\u0eb4\u0ec2\u0e94\u0ec0\u0e99\u0e8d\u0ec0\u0edc\u0eb7\u0ead" },
             { "ML", "\u0ea1\u0eb2\u0ea5\u0eb5" },
             { "MM", "\u0ea1\u0ebd\u0e99\u0ea1\u0eb2 (\u0ec0\u0e9a\u0eb5\u0ea1\u0eb2)" },
             { "MN", metaValue_MN },
@@ -622,7 +623,9 @@ public class LocaleNames_lo extends OpenListResourceBundle {
             { "type.nu.mtei", "\u0e95\u0ebb\u0ea7\u0ec0\u0ea5\u0e81\u0ec0\u0ea1\u0ec4\u0e95\u0ea1\u0eb2\u0ec0\u0ea2\u0e81" },
             { "wal", "\u0ea7\u0eb2\u0ea5\u0eb2\u0ec2\u0ea1" },
             { "was", "\u0ea7\u0eb2\u0ec2\u0e8a" },
+            { "XA", "Pseudo-Accents" },
             { "war", "\u0ea7\u0eb2\u0ec0\u0ea5" },
+            { "XB", "Pseudo-Bidi" },
             { "awa", "\u0ead\u0eb2\u0ea7\u0eb2\u0eae\u0eb4" },
             { "061", "\u0ec2\u0e9e\u0ea5\u0eb5\u0e99\u0eb5\u0ec0\u0e8a\u0e8d" },
             { "XK", "\u0ec2\u0e84\u0ec2\u0e8a\u0ec2\u0ea7" },
@@ -1223,6 +1226,7 @@ public class LocaleNames_lo extends OpenListResourceBundle {
             { "type.nu.tamldec", "\u0e95\u0ebb\u0ea7\u0ec0\u0ea5\u0e81\u0e97\u0eb2\u0ea1\u0eb4\u0ea7" },
             { "krc", "\u0e81\u0eb2\u0ea3\u0eb2\u0ec4\u0e8a-\u0e9a\u0eb2\u0e99\u0e81\u0eb2" },
             { "inh", "\u0ead\u0eb4\u0e99\u0e81\u0eb1\u0e8a" },
+            { "fa_AF", "\u0e94\u0eb2\u0ea3\u0eb5" },
             { "krl", "\u0e81\u0eb2\u0ec0\u0ea3\u0ea5\u0ebd\u0e99" },
             { "efi", "\u0ead\u0eb5\u0e9f\u0eb4\u0e81" },
             { "key.nu", "\u0e95\u0ebb\u0ea7\u0ec0\u0ea5\u0e81" },
