@@ -683,9 +683,9 @@ public class LocaleNames_lt extends OpenListResourceBundle {
             { "type.nu.mtei", "Meetei Mayek skaitmenys" },
             { "wal", "valamo" },
             { "was", "Va\u0161o" },
-            { "XA", "XA" },
+            { "XA", "pseudo A" },
             { "war", "varai" },
-            { "XB", "XB" },
+            { "XB", "pseudo B" },
             { "awa", "avadhi" },
             { "061", "Polinezija" },
             { "XK", "Kosovas" },
@@ -1059,6 +1059,7 @@ public class LocaleNames_lt extends OpenListResourceBundle {
             { "kaw", "kavi\u0173" },
             { "dtp", "centrinio Dusuno" },
             { "or", "odij\u0173" },
+            { "Modi", "Modi" },
             { "os", "osetin\u0173" },
             { "bpy", "bi\u0161nuprijos" },
             { "kbd", "kabardin\u0173" },
