@@ -107,6 +107,7 @@ public class LocaleNames_mr extends OpenListResourceBundle {
             { "mwr", "\u092e\u093e\u0930\u0935\u093e\u0921\u0940" },
             { "Tagb", "\u0924\u0917\u094b\u0906\u0928\u094d\u0935\u093e" },
             { "Zsye", "\u0907\u092e\u094b\u091c\u0940" },
+            { "ccp", "\u091a\u093e\u0915\u092e\u093e" },
             { "egy", "\u092a\u094d\u0930\u093e\u091a\u0940\u0928 \u0907\u091c\u093f\u092a\u094d\u0936\u093f\u092f\u0928" },
             { "raj", "\u0930\u093e\u091c\u0938\u094d\u0925\u093e\u0928\u0940" },
             { "Phag", "\u092b\u093e\u0917\u094d\u0938-\u092a\u093e" },
@@ -518,7 +519,7 @@ public class LocaleNames_mr extends OpenListResourceBundle {
             { "SX", "\u0938\u093f\u0902\u091f \u092e\u093e\u0930\u094d\u091f\u0947\u0928" },
             { "SY", "\u0938\u0940\u0930\u093f\u092f\u093e" },
             { "yao", "\u092f\u093e\u0913" },
-            { "SZ", "\u0938\u094d\u0935\u093e\u091d\u093f\u0932\u0901\u0921" },
+            { "SZ", "\u0907\u0938\u094d\u0935\u093e\u0924\u093f\u0928\u0940" },
             { "arw", "\u0906\u0930\u093e\u0935\u093e\u0915" },
             { "yap", "\u092f\u093e\u092a\u0940\u0938" },
             { "TA", "\u091f\u094d\u0930\u093f\u0938\u094d\u091f\u0928 \u0926\u093e \u0915\u0941\u0928\u094d\u0939\u093e" },
@@ -597,7 +598,9 @@ public class LocaleNames_mr extends OpenListResourceBundle {
             { "WS", "\u0938\u093e\u092e\u094b\u0906" },
             { "wal", "\u0935\u094b\u0932\u093e\u092f\u0924\u093e" },
             { "was", "\u0935\u093e\u0936\u094b" },
+            { "XA", "\u0928\u0915\u0932\u0940-\u0909\u091a\u094d\u091a\u093e\u0930\u0923\u0947" },
             { "war", "\u0935\u093e\u0930\u0947" },
+            { "XB", "\u0928\u0915\u0932\u0940-\u092c\u0940\u0921\u0940" },
             { "awa", "\u0905\u0935\u0927\u0940" },
             { "061", "\u092a\u0949\u0932\u093f\u0928\u0947\u0936\u093f\u092f\u093e" },
             { "XK", "\u0915\u094b\u0938\u094b\u0935\u094d\u0939\u094b" },
@@ -995,7 +998,7 @@ public class LocaleNames_mr extends OpenListResourceBundle {
             { "ibb", "\u0907\u092c\u093f\u092c\u093f\u0913" },
             { "iba", "\u0907\u092c\u093e\u0928" },
             { "ta", metaValue_ta },
-            { "142", "\u0905\u0936\u093f\u092f\u093e" },
+            { "142", "\u0906\u0936\u093f\u092f\u093e" },
             { "bua", "\u092c\u0941\u0930\u093f\u092f\u093e\u0924" },
             { "143", "\u092e\u0927\u094d\u092f \u0906\u0936\u093f\u092f\u093e" },
             { "te", "\u0924\u0947\u0932\u0917\u0942" },
