@@ -111,6 +111,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
         final String metaValue_RU = "Rusia";
         final String metaValue_SE = "Sweden";
         final String metaValue_SI = "Slovenia";
+        final String metaValue_SY = "Syria";
         final String metaValue_TO = "Tonga";
         final String metaValue_TR = "Turki";
         final String metaValue_TV = "Tuvalu";
@@ -118,34 +119,53 @@ public class LocaleNames_ms extends OpenListResourceBundle {
         final String metaValue_UZ = "Uzbekistan";
         final String metaValue_VN = "Vietnam";
         final String metaValue_WS = "Samoa";
+        final String metaValue_ae = "Avestan";
         final String metaValue_ar = "Arab";
         final String metaValue_bn = "Benggala";
         final String metaValue_bo = "Tibet";
         final String metaValue_el = "Greek";
         final String metaValue_he = "Ibrani";
+        final String metaValue_jv = "Jawa";
         final String metaValue_km = "Khmer";
         final String metaValue_kn = "Kannada";
         final String metaValue_ko = "Korea";
         final String metaValue_la = "Latin";
         final String metaValue_ml = "Malayalam";
         final String metaValue_si = "Sinhala";
+        final String metaValue_su = "Sunda";
         final String metaValue_ta = "Tamil";
         final String metaValue_te = "Telugu";
         final String metaValue_th = "Thai";
+        final String metaValue_ban = "Bali";
+        final String metaValue_bug = "Bugis";
+        final String metaValue_ccp = "Chakma";
+        final String metaValue_chr = "Cherokee";
+        final String metaValue_cop = "Coptic";
+        final String metaValue_mak = "Makasar";
+        final String metaValue_men = "Mende";
+        final String metaValue_nqo = "N\u2019ko";
+        final String metaValue_ssy = "Saho";
+        final String metaValue_vai = "Vai";
         final Object[][] data = new Object[][] {
             { "ksh", "Colognian" },
+            { "Ogam", "Ogham" },
             { "mwl", "Mirandese" },
             { "Zsym", "Simbol" },
             { "type.nu.lanatham", "Digit Tai Tham Tham" },
+            { "Tagb", "Tagbanwa" },
             { "Zsye", "Emoji" },
-            { "ccp", "Chakma" },
+            { "%%NJIVA", "Dialek Gniva/Njiva" },
+            { "ccp", metaValue_ccp },
+            { "Phag", "Phags-pa" },
             { "tem", "Timne" },
+            { "Medf", "Medefaidrin" },
             { "type.nu.sind", "Digit Khudawadi" },
             { "teo", "Teso" },
             { "rap", "Rapanui" },
             { "AC", "Pulau Ascension" },
             { "rar", "Rarotonga" },
             { "tet", "Tetum" },
+            { "%%BARLA", "Kumpulan dialek Barlavento Kabuverdianu" },
             { "type.nu.sinh", "Digit Sinhala Lith" },
             { "AD", "Andorra" },
             { "AE", "Emiriah Arab Bersatu" },
@@ -162,6 +182,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "AO", "Angola" },
             { "AQ", "Antartika" },
             { "AR", "Argentina" },
+            { "Prti", "Inskripsi Parthian" },
             { "AS", "Samoa Amerika" },
             { "AT", "Austria" },
             { "AU", "Australia" },
@@ -176,6 +197,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "BD", "Bangladesh" },
             { "kum", "Kumyk" },
             { "BE", "Belgium" },
+            { "Sogo", "Sogdia Lama" },
             { "BF", "Burkina Faso" },
             { "BG", metaValue_BG },
             { "BH", "Bahrain" },
@@ -207,6 +229,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "CI", "Cote d\u2019Ivoire" },
             { "CK", "Kepulauan Cook" },
             { "CL", "Chile" },
+            { "Kthi", "Kaithi" },
             { "CM", "Cameroon" },
             { "CN", "China" },
             { "CO", "Colombia" },
@@ -220,6 +243,9 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "type.nu.bali", "Digit Bali" },
             { "CZ", "Czechia" },
             { "eka", "Ekajuk" },
+            { "Pauc", "Pau Cin Hau" },
+            { "%%RIGIK", "Vopaluk Klasik" },
+            { "Sogd", "Sogdia" },
             { "DE", metaValue_DE },
             { "ace", "Aceh" },
             { "cgg", "Chiga" },
@@ -229,12 +255,15 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "DK", metaValue_DK },
             { "ach", "Akoli" },
             { "Brai", "Braille" },
+            { "Brah", "Brahmi" },
             { "DM", "Dominica" },
             { "type.nu.armnlow", "Angka Kecil Armenia" },
             { "DO", "Republik Dominica" },
             { "gor", "Gorontalo" },
+            { "Mtei", "Meitei Mayek" },
             { "zun", "Zuni" },
             { "tig", "Tigre" },
+            { "Takr", "Takri" },
             { "DZ", "Algeria" },
             { "pag", "Pangasinan" },
             { "type.d0.hwidth", "Ke Kelebaran Separa" },
@@ -251,7 +280,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "chm", "Mari" },
             { "cho", "Choctaw" },
             { "type.nu.mathbold", "Digit Matematik Tebal" },
-            { "chr", "Cherokee" },
+            { "chr", metaValue_chr },
             { "ER", "Eritrea" },
             { "ES", metaValue_ES },
             { "ET", metaValue_ET },
@@ -271,6 +300,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "Taml", metaValue_ta },
             { "FR", metaValue_FR },
             { "root", "Root" },
+            { "%%DAJNKO", "Abjad Dajnko" },
             { "type.ca.indian", "Kalendar Kebangsaan India" },
             { "grc", "Greek Purba" },
             { "GA", "Gabon" },
@@ -281,6 +311,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "GF", "Guiana Perancis" },
             { "GG", "Guernsey" },
             { "GH", "Ghana" },
+            { "Tale", "Tai Le" },
             { "GI", "Gibraltar" },
             { "GL", "Greenland" },
             { "GM", "Gambia" },
@@ -294,11 +325,13 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "type.nu.mathmono", "Digit Matematik Monospace" },
             { "GW", "Guinea Bissau" },
             { "tlh", "Klingon" },
+            { "Talu", "Tai Lue Baharu" },
             { "GY", "Guyana" },
             { "ckb", "Kurdi Sorani" },
             { "zxx", "Tiada kandungan linguistik" },
             { "tly", "Talysh" },
             { "de_AT", "Jerman Austria" },
+            { "Vaii", metaValue_vai },
             { "HK", "Hong Kong SAR China" },
             { "HM", "Kepulauan Heard & McDonald" },
             { "HN", "Honduras" },
@@ -311,13 +344,17 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "IC", "Kepulauan Canary" },
             { "nan", "Cina Min Nan" },
             { "ID", metaValue_ID },
+            { "Adlm", "Adlam" },
             { "type.nu.kali", "Digit Kayah Li" },
             { "IE", metaValue_IE },
             { "nap", "Neapolitan" },
+            { "%%NDYUKA", "Dialek Ndyuka" },
             { "naq", "Nama" },
             { "type.nu.sora", "Digit Sora Sompeng" },
             { "zza", "Zaza" },
+            { "Tang", "Tangut" },
             { "IL", "Israel" },
+            { "Nbat", "Nabataean" },
             { "IM", "Isle of Man" },
             { "IN", "India" },
             { "type.co.eor", "Peraturan Isihan Eropah" },
@@ -335,11 +372,16 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "type.ca.islamic", "Kalendar Islam" },
             { "Beng", metaValue_bn },
             { "JM", "Jamaica" },
+            { "%%EKAVSK", "Serbia dengan sebutan Ekavia" },
             { "JO", "Jordan" },
             { "JP", metaValue_JP },
+            { "%%1606NICT", "Lewat Pertengahan Era Perancis hingga 1606" },
             { "ain", "Ainu" },
+            { "Mend", metaValue_men },
             { "guz", "Gusii" },
             { "type.nu.knda", "Digit Kannada" },
+            { "Kali", "Kayah Li" },
+            { "Sidd", "Siddham" },
             { "de_CH", "Jerman Halus Switzerland" },
             { "type.co.phonetic", "Urutan Isih Fonetik" },
             { "type.ca.buddhist", "Kalendar Buddha" },
@@ -351,9 +393,11 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "KM", "Comoros" },
             { "Knda", metaValue_kn },
             { "KN", "Saint Kitts dan Nevis" },
+            { "Zinh", "Diwarisi" },
             { "fr_CA", "Perancis Kanada" },
             { "KP", "Korea Utara" },
             { "KR", "Korea Selatan" },
+            { "Plrd", "Fonetik Pollard" },
             { "fr_CH", "Perancis Switzerland" },
             { "KW", "Kuwait" },
             { "tpi", "Tok Pisin" },
@@ -367,22 +411,26 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "nds", "Jerman Rendah" },
             { "LI", "Liechtenstein" },
             { "LK", "Sri Lanka" },
-            { "cop", "Coptic" },
+            { "cop", metaValue_cop },
+            { "Hmnp", "Nyiakeng Puachue Hmong" },
             { "LR", "Liberia" },
             { "LS", "Lesotho" },
             { "LT", metaValue_LT },
             { "LU", metaValue_LU },
             { "LV", metaValue_LV },
             { "Kana", "Katakana" },
+            { "Sora", "Sora Sompeng" },
             { "LY", "Libya" },
             { "lad", "Ladino" },
             { "vun", "Vunjo" },
             { "lah", "Lahnda" },
+            { "Mahj", "Mahajani" },
             { "lag", "Langi" },
             { "Thaa", "Thaana" },
             { "MA", "Maghribi" },
             { "MC", "Monaco" },
             { "MD", "Moldova" },
+            { "Nshu", "Nushu" },
             { "ME", "Montenegro" },
             { "MF", "Saint Martin" },
             { "MG", "Madagaskar" },
@@ -411,27 +459,38 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "type.ca.japanese", "Kalendar Jepun" },
             { "MY", "Malaysia" },
             { "MZ", "Mozambique" },
+            { "Phli", "Inskripsi Pahlavi" },
             { "NA", "Namibia" },
             { "202", "Afrika Sub-Sahara" },
             { "type.ca.hebrew", "Kalendar Ibrani" },
             { "type.co.dictionary", "Aturan Isih Kamus" },
             { "NC", "New Caledonia" },
+            { "%%WADEGILE", "Perumian Wade-Giles" },
+            { "%%UCRCOR", "Sistem Ejaan Semakan Bersatu" },
             { "NE", "Niger" },
             { "NF", "Pulau Norfolk" },
             { "NG", "Nigeria" },
             { "trv", "Taroko" },
+            { "Phlp", "Pslater Pahlavi" },
             { "NI", "Nicaragua" },
+            { "Hmng", "Pahawh Hmong" },
             { "NL", metaValue_NL },
             { "NO", metaValue_NO },
             { "NP", metaValue_NP },
             { "NR", metaValue_NR },
             { "NU", "Niue" },
+            { "Phnx", "Phoenicia" },
             { "rof", "Rombo" },
             { "NZ", "New Zealand" },
+            { "Merc", "Kursif Meroitic" },
+            { "%%COLB1945", "Konvensyen Sistem Ejaan Portugis-Brazil 1945" },
+            { "Mero", "Meroitic" },
             { "crh", "Turki Krimea" },
             { "OM", "Oman" },
             { "anp", "Angika" },
             { "crs", "Perancis Seselwa Creole" },
+            { "type.nu.hmnp", "Digit Nyiakeng Puachue Hmong" },
+            { "Xpeo", "Parsi Lama" },
             { "type.nu.hmng", "Digit Pahawh Hmong" },
             { "PA", "Panama" },
             { "type.ca.islamic-civil", "Kalendar Sivil Islam" },
@@ -446,6 +505,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "PM", "Saint Pierre dan Miquelon" },
             { "PN", "Kepulauan Pitcairn" },
             { "PR", "Puerto Rico" },
+            { "Bali", metaValue_ban },
             { "PS", "Wilayah Palestin" },
             { "PT", "Portugal" },
             { "PW", "Palau" },
@@ -460,21 +520,33 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "QO", "Oceania Terpencil" },
             { "lez", "Lezghian" },
             { "type.nu.ahom", "Digit Ahom" },
+            { "%%FONUPA", "Fonetik UPA" },
             { "type.nu.takr", "Digit Takri" },
             { "tvl", metaValue_TV },
+            { "Tavt", "Tai Viet" },
+            { "%%SOTAV", "Kumpulan dialek Sotavento Kabuverdianu" },
+            { "Maka", metaValue_mak },
             { "001", "Dunia" },
             { "002", "Afrika" },
             { "003", "Amerika Utara" },
             { "RE", "Reunion" },
             { "005", "Amerika Selatan" },
             { "jbo", "Lojban" },
+            { "Rjng", "Rejang" },
             { "009", "Oceania" },
+            { "Elym", "Elymaic" },
             { "RO", metaValue_RO },
             { "RS", metaValue_RS },
+            { "Mroo", "Mro" },
             { "RU", metaValue_RU },
             { "RW", "Rwanda" },
             { "type.nu.talu", "Digit Tai Lue Baru" },
+            { "%%METELKO", "Abjad Metelko" },
+            { "Mani", "Manichaean" },
+            { "Ugar", "Ugaritic" },
+            { "Khar", "Kharoshthi" },
             { "SA", "Arab Saudi" },
+            { "Mand", "Mandaean" },
             { "SB", "Kepulauan Solomon" },
             { "twq", "Tasawaq" },
             { "011", "Afrika Barat" },
@@ -508,7 +580,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "SV", "El Salvador" },
             { "ars", "Arab Najdi" },
             { "SX", "Sint Maarten" },
-            { "SY", "Syria" },
+            { "SY", metaValue_SY },
             { "SZ", "Swaziland" },
             { "arz", "Arab Mesir" },
             { "ary", "Arab Maghribi" },
@@ -519,6 +591,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "TC", "Kepulauan Turks dan Caicos" },
             { "yav", "Yangben" },
             { "TD", "Chad" },
+            { "Qaag", "Zawgyi" },
             { "TF", "Wilayah Selatan Perancis" },
             { "TG", "Togo" },
             { "TH", "Thailand" },
@@ -529,16 +602,20 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "ybb", "Yemba" },
             { "type.co.searchjl", "Cari Mengikut Konsonan Awal Hangul" },
             { "TM", "Turkmenistan" },
+            { "%%BOONT", "Boontling" },
             { "TN", "Tunisia" },
             { "TO", metaValue_TO },
+            { "%%NULIK", "Volapuk Moden" },
             { "TR", metaValue_TR },
             { "TT", "Trinidad dan Tobago" },
             { "TV", metaValue_TV },
             { "TW", "Taiwan" },
             { "ast", "Asturia" },
+            { "Orkh", "Orkhon" },
             { "TZ", "Tanzania" },
             { "nmg", "Kwasio" },
             { "Zzzz", "Tulisan Tidak Diketahui" },
+            { "Sind", "Khudawadi" },
             { "UA", metaValue_UA },
             { "rup", "Aromanian" },
             { "030", "Asia Timur" },
@@ -555,6 +632,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "UN", "Bangsa-bangsa Bersatu" },
             { "US", "Amerika Syarikat" },
             { "haw", "Hawaii" },
+            { "%%1959ACAD", "Akademik" },
             { "type.co.gb2312han", "Aturan Isih Bahasa Cina Ringkas - GB2312" },
             { "UY", "Uruguay" },
             { "prg", "Prusia" },
@@ -567,8 +645,10 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "VE", "Venezuela" },
             { "VG", "Kepulauan Virgin British" },
             { "VI", "Kepulauan Virgin A.S." },
+            { "Soyo", "Soyombo" },
             { "VN", metaValue_VN },
             { "VU", "Vanuatu" },
+            { "Marc", "Marchen" },
             { "nog", "Nogai" },
             { "rwk", "Rwa" },
             { "053", "Australasia" },
@@ -579,24 +659,33 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "jgo", "Ngomba" },
             { "lkt", "Lakota" },
             { "type.nu.finance", "Angka Kewangan" },
+            { "%%HEPBURN", "Perumian Hepburn" },
             { "type.co.compat", "Tertib Isihan Sebelumnya" },
             { "wae", "Walser" },
             { "WS", metaValue_WS },
+            { "Bass", "Bassa Vah" },
             { "type.nu.mtei", "Digit Meetei Mayek" },
             { "wal", "Wolaytta" },
-            { "XA", "XA" },
+            { "XA", "Aksen Pseudo" },
             { "war", "Waray" },
-            { "XB", "XB" },
+            { "XB", "Bidi Pseudo" },
             { "awa", "Awadhi" },
             { "061", "Polinesia" },
+            { "%%KSCOR", "Sistem Ejaan Standard" },
             { "XK", "Kosovo" },
             { "type.nu.brah", "Digit Brahmi" },
             { "Gujr", "Gujarat" },
             { "Zxxx", "Tidak ditulis" },
+            { "Olck", "Ol Chiki" },
             { "wbp", "Warlpiri" },
+            { "Batk", "Batak" },
             { "YE", "Yaman" },
-            { "nqo", "N\u2019ko" },
+            { "nqo", metaValue_nqo },
             { "type.co.standard", "Tertib Isih Standard" },
+            { "Zanb", "Segi Empat Zanabazar" },
+            { "%%BALANKA", "Dialek Balanka Anii" },
+            { "%%ROZAJ", "Resia" },
+            { "Sgnw", "Tulisan Isyarat" },
             { "YT", "Mayotte" },
             { "type.nu.cham", "Digit Cham" },
             { "ZA", "Afrika Selatan" },
@@ -607,8 +696,10 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "type.co.zhuyin", "Aturan Isih Zhuyin" },
             { "Hira", "Hiragana" },
             { "ZM", "Zambia" },
+            { "%%PINYIN", "Perumian Pinyin" },
             { "ZW", "Zimbabwe" },
             { "ZZ", "Wilayah Tidak Diketahui" },
+            { "Runr", "Runic" },
             { "type.ms.metric", "Sistem Metrik" },
             { "type.ca.iso8601", "Kalendar ISO-8601" },
             { "nso", "Sotho Utara" },
@@ -626,19 +717,24 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "dav", "Taita" },
             { "lrc", "Luri Utara" },
             { "type.co.emoji", "Aturan Isih Emoji" },
+            { "Copt", metaValue_cop },
             { "udm", "Udmurt" },
             { "Khmr", metaValue_km },
             { "type.ca.islamic-rgsa", "Kalendar Islam (Arab Saudi, cerapan)" },
+            { "Limb", "Limbu" },
             { "sad", "Sandawe" },
             { "type.nu.roman", "Angka Roman" },
             { "sah", "Sakha" },
             { "type.nu.shrd", "Digit Sharada" },
+            { "Aghb", "Kaukasia Albania" },
             { "saq", "Samburu" },
             { "sat", "Santali" },
+            { "Tfng", "Tifinagh" },
             { "type.d0.npinyin", "Bernombor" },
             { "type.nu.native", "Digit Asal" },
             { "sba", "Ngambay" },
             { "Guru", "Gurmukhi" },
+            { "%%ALUKU", "Dialek Aluku" },
             { "lua", "Luba-Lulua" },
             { "type.nu.tirh", "Digit Tirhuta" },
             { "type.d0.fwidth", "Ke Kelebaran Penuh" },
@@ -650,17 +746,19 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "hmn", "Hmong" },
             { "lus", "Mizo" },
             { "bal", "Baluchi" },
-            { "ban", "Bali" },
+            { "ban", metaValue_ban },
             { "type.nu.wara", "Digit Warang Citi" },
             { "luy", "Luyia" },
             { "bas", "Basaa" },
             { "bax", "Bamun" },
+            { "%%ABL1943", "Perumusan sistem ejaan 1943" },
             { "es_ES", "Sepanyol Eropah" },
             { "sco", "Scots" },
             { "scn", "Sicili" },
             { "aa", "Afar" },
             { "ab", "Abkhazia" },
-            { "ae", "Avestan" },
+            { "Aran", "Nastaliq" },
+            { "ae", metaValue_ae },
             { "af", "Afrikaans" },
             { "ak", "Akan" },
             { "type.nu.cakm", "Digit Chakma" },
@@ -668,14 +766,21 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "am", "Amharic" },
             { "Arab", metaValue_ar },
             { "an", "Aragon" },
+            { "%%SOLBA", "Dialek Stolvizza/Solbica" },
             { "Jpan", metaValue_JP },
             { "ar", metaValue_ar },
             { "Hrkt", "Ejaan sukuan Jepun" },
             { "as", "Assam" },
+            { "Lina", "Linear A" },
             { "av", "Avaric" },
+            { "Linb", "Linear B" },
             { "sdh", "Kurdish Selatan" },
             { "ay", "Aymara" },
             { "az", metaValue_AZ },
+            { "Rohg", "Hanifi Rohingya" },
+            { "Khoj", "Khojki" },
+            { "%%OSOJS", "Dialek Oseacco/Osojane" },
+            { "%%UNIFON", "Abjad fonetik Unifon" },
             { "ba", "Bashkir" },
             { "type.co.unihan", "Aturan Isih Coretan Radikal" },
             { "be", metaValue_BY },
@@ -688,14 +793,17 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "dgr", "Dogrib" },
             { "br", "Breton" },
             { "bs", "Bosnia" },
+            { "Bhks", "Bhaisuki" },
             { "see", "Seneca" },
             { "Mymr", "Myammar" },
             { "type.nu.laoo", "Digit Lao" },
             { "seh", "Sena" },
+            { "Nkoo", metaValue_nqo },
             { "ca", "Catalonia" },
             { "ses", "Koyraboro Senni" },
             { "ce", "Chechen" },
             { "ch", "Chamorro" },
+            { "%%REVISED", "Sistem Ejaan Semakan" },
             { "co", "Corsica" },
             { "Orya", "Oriya" },
             { "cs", "Czech" },
@@ -703,11 +811,13 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "cv", "Chuvash" },
             { "cy", "Wales" },
             { "type.nu.ethi", "Angka Ethiopia" },
+            { "Yiii", "Yi" },
             { "da", metaValue_DK },
             { "pt_PT", "Portugis Eropah" },
             { "de", metaValue_DE },
             { "type.cf.standard", "Format Mata Wang Standard" },
             { "bej", "Beja" },
+            { "Bugi", metaValue_bug },
             { "bem", "Bemba" },
             { "type.nu.mong", "Digit Mongolia" },
             { "dv", "Divehi" },
@@ -715,6 +825,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "dz", "Dzongkha" },
             { "bez", "Bena" },
             { "type.ca.chinese", "Kalendar Cina" },
+            { "Lisu", "Fraser" },
             { "dje", "Zarma" },
             { "type.nu.grek", "Angka Greek" },
             { "ee", "Ewe" },
@@ -729,11 +840,14 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "et", metaValue_EE },
             { "Hanb", "Han dengan Bopomofo" },
             { "eu", "Basque" },
+            { "Buhd", "Buhid" },
             { "Hang", "Hangul" },
+            { "Samr", "Samaritan" },
             { "shi", "Tachelhit" },
             { "hsb", "Sorbian Atas" },
             { "Hani", "Han" },
             { "shn", "Shan" },
+            { "Hano", "Hanunoo" },
             { "fa", "Parsi" },
             { "Hans", "Ringkas" },
             { "type.nu.latn", "Digit Barat" },
@@ -752,8 +866,11 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "fr", metaValue_FR },
             { "fy", "Frisian Barat" },
             { "ga", metaValue_IE },
+            { "Wcho", "Wancho" },
             { "gd", "Scots Gaelic" },
+            { "Gong", "Gunjala Gondi" },
             { "gl", "Galicia" },
+            { "Gonm", "Masaram Gonti" },
             { "gn", "Guarani" },
             { "bho", "Bhojpuri" },
             { "und", "Bahasa Tidak Diketahui" },
@@ -773,6 +890,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "hy", metaValue_AM },
             { "hz", "Herero" },
             { "frc", "Perancis Cajun" },
+            { "%%FONIPA", "Fonetik IPA" },
             { "ia", "Interlingua" },
             { "Jamo", "Jamo" },
             { "id", metaValue_ID },
@@ -780,17 +898,20 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "ie", "Interlingue" },
             { "ig", "Igbo" },
             { "ii", "Sichuan Yi" },
+            { "%%AO1990", "Perjanjian Sistem Ejaan Bahasa Portugis 1990" },
             { "io", "Ido" },
             { "is", metaValue_IS },
             { "it", metaValue_IT },
             { "iu", "Inuktitut" },
             { "ja", metaValue_JP },
             { "Mlym", metaValue_ml },
+            { "Sarb", "Arab Selatan Lama" },
             { "doi", "Dogri" },
             { "type.nu.lepc", "Digit Lepcha" },
             { "bkm", "Kom" },
             { "sma", "Sami Selatan" },
-            { "jv", "Jawa" },
+            { "jv", metaValue_jv },
+            { "Shaw", "Shavia" },
             { "mad", "Madura" },
             { "smj", "Lule Sami" },
             { "mag", "Magahi" },
@@ -798,11 +919,12 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "mai", "Maithili" },
             { "smn", "Inari Sami" },
             { "ka", metaValue_GE },
+            { "mak", metaValue_mak },
             { "bla", "Siksika" },
-            { "mak", "Makasar" },
             { "wuu", "Cina Wu" },
             { "sms", "Skolt Sami" },
             { "kg", "Kongo" },
+            { "Goth", "Gothic" },
             { "ki", "Kikuya" },
             { "mas", "Masai" },
             { "kj", "Kuanyama" },
@@ -813,12 +935,16 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "ko", metaValue_ko },
             { "kr", "Kanuri" },
             { "ks", "Kashmir" },
+            { "Lepc", "Lepcha" },
+            { "Avst", metaValue_ae },
             { "ku", "Kurdish" },
             { "kv", "Komi" },
             { "kw", "Cornish" },
             { "ky", "Kirghiz" },
             { "snk", "Soninke" },
+            { "Mult", "Multani" },
             { "la", metaValue_la },
+            { "Hatr", "Hatran" },
             { "lb", metaValue_LU },
             { "type.nu.mlym", "Digit Malayalam" },
             { "lg", "Ganda" },
@@ -843,10 +969,12 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "ms", "Melayu" },
             { "mt", metaValue_MT },
             { "my", "Burma" },
+            { "Saur", "Saurashtra" },
             { "Armn", metaValue_AM },
             { "mdf", "Moksha" },
             { "mde", "Maba" },
             { "dsb", "Sorbian Rendah" },
+            { "Armi", "Aramia Imperial" },
             { "na", metaValue_NR },
             { "type.co.search", "Carian Tujuan Umum" },
             { "nb", "Bokm\u00e5l Norway" },
@@ -858,25 +986,31 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "no", metaValue_NO },
             { "nr", "Ndebele Selatan" },
             { "type.nu.modi", "Digit Modi" },
+            { "Osge", "Osage" },
             { "nv", "Navajo" },
             { "ny", "Nyanja" },
             { "kac", "Kachin" },
             { "kab", "Kabyle" },
+            { "%%POLYTON", "Banyak Nada" },
             { "oc", "Occitania" },
             { "kaj", "Jju" },
             { "kam", "Kamba" },
-            { "men", "Mende" },
+            { "men", metaValue_men },
+            { "%%EMODENG", "Inggeris Moden Awal" },
             { "mer", "Meru" },
             { "type.nu.armn", "Angka Armenia" },
             { "om", "Oromo" },
             { "or", "Odia" },
+            { "Modi", "Modi" },
             { "os", "Ossete" },
+            { "%%ALALC97", "Perumian ALA-LC, edisi 1997" },
             { "bpy", "Bishnupriya" },
             { "kbd", "Kabardia" },
             { "mfe", "Morisyen" },
             { "srn", "Sranan Tongo" },
             { "pa", "Punjabi" },
             { "dua", "Duala" },
+            { "%%LIPAW", "Dialek Lipovaz Resia" },
             { "kbl", "Kanembu" },
             { "pl", metaValue_PL },
             { "type.nu.saur", "Digit Saurashtra" },
@@ -885,6 +1019,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "pt", "Portugis" },
             { "key.co", "Tertib Isihan" },
             { "pt_BR", "Portugis Brazil" },
+            { "%%BOHORIC", "Abjad Bohoric" },
             { "kcg", "Tyap" },
             { "mgh", "Makhuwa-Meetto" },
             { "key.cf", "Format Mata wang" },
@@ -894,11 +1029,12 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "mgo", "Meta\u2019" },
             { "type.hc.h23", "Sistem 24 Jam (0\u201323)" },
             { "type.hc.h24", "Sistem 24 Jam (1\u201324)" },
-            { "ssy", "Saho" },
+            { "ssy", metaValue_ssy },
             { "brh", "Brahui" },
             { "type.nu.mymr", "Digit Myammar" },
             { "qu", "Quechua" },
             { "brx", "Bodo" },
+            { "Lana", "Lanna" },
             { "kde", "Makonde" },
             { "Ethi", metaValue_ET },
             { "type.hc.h12", "Sistem 12 Jam (1\u201312)" },
@@ -907,6 +1043,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "rn", "Rundi" },
             { "key.cu", "Mata wang" },
             { "ro", metaValue_RO },
+            { "%%SAAHO", metaValue_ssy },
             { "type.nu.orya", "Digit Oriya" },
             { "type.nu.hanidec", "Angka Perpuluhan Cina" },
             { "ru", metaValue_RU },
@@ -916,7 +1053,9 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "mic", "Micmac" },
             { "suk", "Sukuma" },
             { "en_AU", "Inggeris Australia" },
+            { "Dupl", "Trengkas Duployan" },
             { "sa", "Sanskrit" },
+            { "%%UCCOR", "Sistem Ejaan Bersatu" },
             { "sc", "Sardinia" },
             { "sd", "Sindhi" },
             { "se", "Sami Utara" },
@@ -926,6 +1065,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "si", metaValue_si },
             { "sk", "Slovak" },
             { "sl", metaValue_SI },
+            { "Gran", "Grantha" },
             { "sm", metaValue_WS },
             { "sn", "Shona" },
             { "so", "Somali" },
@@ -934,10 +1074,13 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "sr", metaValue_RS },
             { "ss", "Swati" },
             { "type.cf.account", "Format Mata Wang Perakaunan" },
+            { "Java", metaValue_jv },
             { "st", "Sotho Selatan" },
-            { "su", "Sunda" },
+            { "su", metaValue_su },
+            { "%%NEDIS", "Dialek Natisone" },
             { "sv", metaValue_SE },
             { "sw", "Swahili" },
+            { "type.nu.wcho", "Digit Wancho" },
             { "type.nu.hantfin", "Angka Kewangan Cina Tradisional" },
             { "ibb", "Ibibio" },
             { "iba", "Iban" },
@@ -949,8 +1092,8 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "145", "Asia Barat" },
             { "tg", "Tajik" },
             { "th", metaValue_th },
+            { "bug", metaValue_bug },
             { "ti", "Tigrinya" },
-            { "bug", "Bugis" },
             { "kfo", "Koro" },
             { "en_CA", "Inggeris Kanada" },
             { "tk", "Turkmen" },
@@ -960,98 +1103,144 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "dyo", "Jola-Fonyi" },
             { "type.nu.jpan", "Angka Jepun" },
             { "tr", metaValue_TR },
+            { "Cakm", metaValue_ccp },
             { "ts", "Tsonga" },
             { "swb", "Comoria" },
             { "tt", "Tatar" },
             { "tw", "Twi" },
             { "ty", "Tahiti" },
+            { "%%BISKE", "Dialek San Giorgio/Bila" },
             { "150", "Eropah" },
             { "151", "Eropah Timur" },
+            { "type.nu.rohg", "Digit Hanifi Rohingya" },
             { "type.nu.mathsanb", "Digit Matematik San Serif Tebal" },
             { "154", "Eropah Utara" },
             { "dzg", "Dazaga" },
             { "155", "Eropah Barat" },
             { "ug", "Uyghur" },
             { "Kore", metaValue_ko },
+            { "Ital", "Italik Lama" },
             { "Zyyy", "Lazim" },
             { "uk", metaValue_UA },
             { "type.ca.coptic", "Kalendar Qibti" },
             { "ur", "Urdu" },
+            { "%%1994", "Sistem ejaan Resia standard" },
             { "xal", "Kalmyk" },
             { "uz", metaValue_UZ },
             { "kha", "Khasi" },
+            { "%%1996", "Sistem ejaan Jerman 1996" },
             { "nds_NL", "Saxon Rendah" },
+            { "Sylo", "Syloti Nagri" },
             { "ve", "Venda" },
+            { "Wara", "Varang Kshiti" },
             { "type.ca.roc", "Kalendar Minguo" },
             { "vi", metaValue_VN },
             { "khq", "Koyra Chiini" },
             { "key.hc", "Kitaran Jam (12 berbanding 24)" },
+            { "%%TARASK", "Sistem ejaan Taraskievica" },
             { "vo", "Volap\u00fck" },
             { "khw", "Khowar" },
             { "type.nu.mathsans", "Digit Matematik San Serif" },
+            { "Osma", "Osmanya" },
             { "quc", "K\u02bciche\u02bc" },
             { "type.nu.gonm", "Digit Masaram Gondi" },
+            { "Newa", "Newa" },
             { "gaa", "Ga" },
             { "wa", "Walloon" },
             { "gag", "Gagauz" },
             { "syr", "Syriac" },
+            { "type.nu.gong", "Digit Gunjala Gondi" },
             { "Grek", metaValue_el },
             { "gan", "Cina Gan" },
+            { "Lydi", "Lydia" },
+            { "Xsux", "Aksara Paku Sumero-Akkadia" },
             { "wo", "Wolof" },
             { "zgh", "Tamazight Maghribi Standard" },
             { "ar_001", "Arab Standard Moden" },
+            { "Cans", "Suku Kata Orang Asli Kanada Bersatu" },
             { "Mong", metaValue_MN },
+            { "Hluw", "Hiroglif Anatoli" },
             { "gba", "Gbaya" },
             { "mni", "Manipuri" },
             { "Latn", metaValue_la },
+            { "Nand", "Nandinagari" },
             { "type.nu.hans", "Angka Cina Ringkas" },
             { "type.nu.hant", "Angka Cina Tradisional" },
             { "xh", "Xhosa" },
             { "type.nu.romanlow", "Angka Huruf Kecil Roman" },
             { "byn", "Blin" },
+            { "Dogr", "Dogra" },
+            { "%%PAMAKA", "Dialek Pamaka" },
+            { "Lyci", "Lycia" },
             { "byv", "Medumba" },
             { "gbz", "Zoroastrian Dari" },
             { "moh", "Mohawk" },
             { "kkj", "Kako" },
+            { "%%1694ACAD", "Awal Pertengahan Era Perancis" },
+            { "Syrc", metaValue_SY },
             { "yi", "Yiddish" },
             { "mos", "Mossi" },
+            { "Dsrt", "Deseret" },
             { "yo", "Yoruba" },
             { "type.nu.traditional", "Angka Tradisional" },
             { "es_MX", "Sepanyol Mexico" },
-            { "vai", "Vai" },
+            { "vai", metaValue_vai },
+            { "Cari", "Carian" },
             { "kln", "Kalenjin" },
             { "zh", "Cina" },
             { "Bopo", "Bopomofo" },
+            { "Perm", "Permic Lama" },
             { "key.lb", "Gaya Pemisah Baris" },
             { "zu", "Zulu" },
             { "type.co.phonebook", "Aturan Isih Buku Telefon" },
+            { "%%MONOTON", "Ekanada" },
             { "Geor", metaValue_GE },
+            { "Shrd", "Sharada" },
             { "kmb", "Kimbundu" },
             { "type.nu.jpanfin", "Angka Kewangan Jepun" },
+            { "Cham", "Cham" },
             { "gez", "Geez" },
             { "type.nu.mymrshan", "Digit Myanmar Shan" },
+            { "Elba", "Elbasan" },
+            { "Narb", "Arab Utara Lama" },
             { "type.nu.olck", "Digit Ol Chiki" },
             { "type.co.reformed", "Aturan Isih Pembaharuan" },
+            { "Tglg", "Tagalog" },
+            { "Palm", "Palmyrene" },
             { "ebu", "Embu" },
+            { "Egyp", "Hiroglif Mesir" },
             { "zh_Hans", "Cina Ringkas" },
             { "koi", "Komi-Permyak" },
+            { "Hung", "Hungary Lama" },
             { "kok", "Konkani" },
+            { "%%1901", "Sistem ejaan Jerman Tradisional" },
             { "type.nu.limb", "Digit Limbu" },
             { "zh_Hant", "Cina Tradisional" },
+            { "Sund", metaValue_su },
             { "kpe", "Kpelle" },
             { "type.nu.khmr", "Digit Khmer" },
+            { "Tirh", "Tirhuta" },
             { "ilo", "Iloko" },
+            { "%%VALENCIA", "Valencia" },
+            { "Cprt", "Cypriot" },
+            { "%%BAKU1926", "Abjad Latin Turki Disatukan" },
+            { "%%IJEKAVSK", "Fon Serbia dengan sebutan Ijekavia" },
             { "mua", "Mundang" },
             { "type.nu.guru", "Digit Gurmukhi" },
             { "mul", "Pelbagai Bahasa" },
             { "key.ms", "Sistem Ukuran" },
             { "mus", "Creek" },
+            { "Glag", "Glagolitik" },
             { "gil", metaValue_KI },
+            { "%%KKCOR", "Sistem Ejaan Lazim" },
+            { "Cher", metaValue_chr },
             { "cay", "Cayuga" },
             { "type.nu.tamldec", "Digit Tamil" },
             { "krc", "Karachay-Balkar" },
             { "inh", "Ingush" },
+            { "fa_AF", "Dari" },
             { "krl", "Karelian" },
+            { "%%OXENDICT", "Ejaan Kamus Inggeris Oxford" },
             { "efi", "Efik" },
             { "key.nu", "Nombor" },
             { "kru", "Kurukh" },
