@@ -130,6 +130,7 @@ public class LocaleNames_my extends OpenListResourceBundle {
             { "mwl", "\u1019\u102e\u101b\u1014\u103a\u1012\u102e\u1038\u1007\u103a" },
             { "Zsym", "\u101e\u1004\u103a\u1039\u1000\u1031\u1010" },
             { "Zsye", "\u1021\u102e\u1019\u102d\u102f\u1002\u103b\u102e" },
+            { "ccp", "\u1001\u103b\u1010\u103a\u1001\u103a\u1019\u102c" },
             { "egy", "\u101b\u103e\u1031\u1038\u101f\u1031\u102c\u1004\u103a\u1038 \u1021\u102e\u1002\u103b\u1005\u103a" },
             { "tem", "\u1010\u1004\u103a\u1019\u103a\u1014\u1032" },
             { "teo", "\u1010\u102e\u1006\u102d\u102f" },
@@ -541,7 +542,9 @@ public class LocaleNames_my extends OpenListResourceBundle {
             { "wae", "\u101d\u1031\u102b\u101c\u103a\u1006\u102c" },
             { "WS", "\u1006\u1019\u102d\u102f\u1038\u1021\u102c\u1038" },
             { "wal", "\u101d\u102d\u102f\u101c\u1000\u103a\u1010\u102c" },
+            { "XA", "\u1014\u102d\u102f\u1004\u103a\u1004\u1036\u1001\u103c\u102c\u1038\u101e\u1036" },
             { "war", "\u101d\u102b\u101b\u1031\u1038" },
+            { "XB", "\u1005\u102c\u1015\u103c\u1031\u102c\u1004\u103a\u1038\u1015\u103c\u1014\u103a" },
             { "awa", "\u1021\u102c\u101d\u102b\u1012\u102e" },
             { "061", "\u1015\u102d\u102f\u101c\u102e\u1014\u102e\u101b\u103e\u102c\u1038" },
             { "XK", "\u1000\u102d\u102f\u1006\u102d\u102f\u1017\u102d\u102f" },
@@ -914,6 +917,7 @@ public class LocaleNames_my extends OpenListResourceBundle {
             { "Grek", metaValue_GR },
             { "wo", "\u101d\u1030\u101c\u102d\u102f\u1016\u103a" },
             { "zgh", "\u1019\u102d\u102f\u101b\u102d\u102f\u1000\u102d\u102f \u1010\u1019\u1007\u102d\u102f\u1000\u103a" },
+            { "ar_001", "\u1001\u1031\u1010\u103a\u101e\u1005\u103a \u101b\u103e\u1031\u1037\u1006\u1031\u102c\u1004\u103a \u1021\u102c\u101b\u1017\u102e" },
             { "Mong", metaValue_mn },
             { "mnc", "\u1019\u1014\u103a\u1001\u103b\u1030\u1038" },
             { "mni", "\u1019\u1014\u102d\u1015\u1030\u101b" },
@@ -929,6 +933,7 @@ public class LocaleNames_my extends OpenListResourceBundle {
             { "yi", "\u1002\u103b\u1030\u1038" },
             { "mos", "\u1019\u102d\u102f\u1005\u102e" },
             { "yo", "\u101a\u102d\u102f\u101b\u1030\u1018\u102c" },
+            { "es_MX", "\u1005\u1015\u102d\u1014\u103a (\u1019\u1000\u1039\u1000\u1006\u102e\u1000\u102d\u102f)" },
             { "vai", "\u1017\u102d\u102f\u1004\u103a" },
             { "kln", "\u1000\u101c\u1014\u103a\u1002\u103b\u1004\u103a" },
             { "zh", metaValue_CN },
@@ -959,6 +964,7 @@ public class LocaleNames_my extends OpenListResourceBundle {
             { "type.nu.tamldec", "\u1010\u1019\u102e\u1038\u101c\u103a \u1002\u100f\u1014\u103a\u1038\u1001\u103c\u1031" },
             { "krc", "\u1000\u101b\u102c\u1001\u103b\u1031\u1038-\u1018\u102c\u1000\u102c" },
             { "inh", "\u1021\u1004\u103a\u1002\u102f\u101b\u103e\u103a" },
+            { "fa_AF", "\u1012\u102b\u101b\u102e" },
             { "krl", "\u1000\u102c\u101b\u102e\u101c\u102e\u101a\u1014\u103a" },
             { "efi", "\u1021\u102c\u1016\u102d\u1001\u103a" },
             { "key.nu", "\u1000\u102d\u1014\u103a\u1038\u1002\u100f\u1014\u103a\u1038" },
