@@ -96,6 +96,7 @@ public class LocaleNames_nb extends OpenListResourceBundle {
         final String metaValue_arc = "arameisk";
         final String metaValue_ban = "balinesisk";
         final String metaValue_bug = "buginesisk";
+        final String metaValue_ccp = "chakma";
         final String metaValue_cop = "koptisk";
         final String metaValue_got = "gotisk";
         final String metaValue_kpe = "kpelle";
@@ -121,6 +122,7 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "Zsye", "emoji" },
             { "%%NJIVA", "gniva- og njivadialekt" },
             { "xmf", "mingrelsk" },
+            { "ccp", metaValue_ccp },
             { "egy", "gammelegyptisk" },
             { "raj", "rajasthani" },
             { "Phag", "phags-pa" },
@@ -262,7 +264,7 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "ER", "Eritrea" },
             { "ES", "Spania" },
             { "ET", "Etiopia" },
-            { "EU", "EU" },
+            { "EU", "Den europeiske union" },
             { "elx", "elamittisk" },
             { "type.ca.gregorian", "gregoriansk kalender" },
             { "EZ", "eurosonen" },
@@ -275,7 +277,7 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "FJ", "Fiji" },
             { "FK", "Falklands\u00f8yene" },
             { "FM", "Mikronesiaf\u00f8derasjonen" },
-            { "key.va", "Spr\u00e5kvariant" },
+            { "key.va", "spr\u00e5kvariant" },
             { "FO", "F\u00e6r\u00f8yene" },
             { "Taml", "tamilsk" },
             { "FR", "Frankrike" },
@@ -611,6 +613,7 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "TC", "Turks- og Caicos\u00f8yene" },
             { "yav", "yangben" },
             { "TD", "Tsjad" },
+            { "Qaag", "zawgyi" },
             { "TF", "De franske s\u00f8rterritorier" },
             { "ase", "amerikansk tegnspr\u00e5k" },
             { "TG", "Togo" },
@@ -695,7 +698,9 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "type.nu.mtei", "meetei mayek-tall" },
             { "wal", "wolaytta" },
             { "was", "washo" },
+            { "XA", "pseudospr\u00e5k \u2013 aksenter" },
             { "war", "waray-waray" },
+            { "XB", "pseudospr\u00e5k \u2013 RTL" },
             { "awa", "avadhi" },
             { "061", "Polynesia" },
             { "%%KSCOR", "standard ortografi" },
@@ -807,6 +812,7 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "scn", "siciliansk" },
             { "aa", "afar" },
             { "ab", "abkhasisk" },
+            { "Aran", "nastaliq" },
             { "bbc", "batak toba" },
             { "ae", metaValue_ae },
             { "af", "afrikaans" },
@@ -1195,9 +1201,9 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "dyo", "jola-fonyi" },
             { "type.nu.jpan", "japanske tall" },
             { "tr", "tyrkisk" },
+            { "Cakm", metaValue_ccp },
             { "ts", "tsonga" },
             { "swb", "komorisk" },
-            { "Cakm", "chakma" },
             { "tt", "tatarisk" },
             { "dyu", "dyula" },
             { "tw", "twi" },
@@ -1355,6 +1361,7 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "inh", "ingusjisk" },
             { "krj", "kinaray-a" },
             { "kri", "krio" },
+            { "fa_AF", "dari" },
             { "krl", "karelsk" },
             { "efi", "efik" },
             { "tcy", "tulu" },
