@@ -105,8 +105,9 @@ public class LocaleNames_ne extends OpenListResourceBundle {
             { "egl", "\u090f\u092e\u093f\u0932\u093f\u092f\u093e\u0932\u0940" },
             { "mwv", "\u092e\u0947\u0928\u094d\u091f\u093e\u0935\u093e\u0908" },
             { "Tagb", "\u091f\u093e\u0917\u094d\u0935\u093e\u0928\u094d\u0935\u093e" },
-            { "Zsye", "Zsye" },
+            { "Zsye", "\u0907\u092e\u094b\u091c\u0940" },
             { "xmf", "\u092e\u093f\u0928\u0917\u094d\u0930\u0947\u0932\u093f\u092f\u093e\u0932\u0940" },
+            { "ccp", "\u091a\u093e\u0915\u094d\u092e\u093e" },
             { "egy", "\u092a\u0941\u0930\u093e\u0924\u0928 \u0907\u091c\u093f\u092a\u094d\u091f\u0940" },
             { "raj", "\u0930\u093e\u091c\u0938\u094d\u0925\u093e\u0928\u0940" },
             { "Phag", "\u092b\u093e\u0917\u094d\u0938-\u092a\u093e" },
@@ -235,7 +236,7 @@ public class LocaleNames_ne extends OpenListResourceBundle {
             { "chp", "\u091a\u093f\u092a\u0947\u0935\u094d\u092f\u093e\u0928" },
             { "cho", "\u091a\u094b\u0915\u094d\u091f\u093e\u0935" },
             { "chr", metaValue_chr },
-            { "ER", "\u090f\u0930\u093f\u0924\u094d\u0930\u093f\u092f\u093e" },
+            { "ER", "\u090f\u0930\u093f\u091f\u094d\u0930\u0940\u092f\u093e" },
             { "ES", "\u0938\u094d\u092a\u0947\u0928" },
             { "ET", "\u0907\u0925\u093f\u092f\u094b\u092a\u093f\u092f\u093e" },
             { "EU", "\u092f\u0941\u0930\u094b\u092a\u093f\u092f\u0928 \u092f\u0941\u0928\u093f\u092f\u0928" },
@@ -264,7 +265,7 @@ public class LocaleNames_ne extends OpenListResourceBundle {
             { "GD", "\u0917\u094d\u0930\u0947\u0928\u093e\u0921\u093e" },
             { "GE", "\u091c\u0930\u094d\u091c\u093f\u092f\u093e" },
             { "GF", "\u092b\u094d\u0930\u093e\u0928\u094d\u0938\u0947\u0932\u0940 \u0917\u093e\u092f\u0928\u093e" },
-            { "GG", "\u0917\u0941\u090f\u0930\u094d\u0928\u0938\u0947" },
+            { "GG", "\u0917\u094d\u092f\u0942\u0930\u094d\u0928\u094d\u0938\u0940" },
             { "GH", "\u0918\u093e\u0928\u093e" },
             { "Tale", "\u091f\u093e\u0907\u0932\u0947" },
             { "GI", "\u091c\u093f\u092c\u094d\u0930\u093e\u0932\u094d\u091f\u093e\u0930" },
@@ -311,8 +312,8 @@ public class LocaleNames_ne extends OpenListResourceBundle {
             { "IQ", "\u0907\u0930\u093e\u0915" },
             { "IR", "\u0907\u0930\u093e\u0928" },
             { "IS", "\u0906\u0907\u0938\u094d\u0932\u094d\u092f\u093e\u0923\u094d\u0921" },
-            { "IT", "\u0907\u091f\u093e\u0932\u0940" },
-            { "Zmth", "Zmth" },
+            { "IT", "\u0907\u091f\u0932\u0940" },
+            { "Zmth", "\u0917\u0923\u093f\u0924\u0940\u092f \u091a\u093f\u0928\u094d\u0939" },
             { "type.nu.thai", "\u0925\u093e\u0908 \u0905\u0919\u094d\u0915\u0939\u0930\u0942" },
             { "%%POSIX", "\u0915\u092e\u094d\u092a\u094d\u092f\u0941\u091f\u0930" },
             { "type.nu.beng", "\u092c\u0919\u094d\u0917\u093e\u0932\u0940 \u0905\u0919\u094d\u0915\u0939\u0930\u0942" },
@@ -487,7 +488,7 @@ public class LocaleNames_ne extends OpenListResourceBundle {
             { "Khar", "\u0916\u093e\u0930\u094b\u0938\u094d\u0925\u093f\u0924\u093f" },
             { "SA", "\u0938\u093e\u0909\u0926\u0940 \u0905\u0930\u092c" },
             { "Mand", "\u092e\u093e\u0928\u094d\u0921\u093e\u090f\u0928" },
-            { "SB", "\u0938\u094b\u0932\u094b\u092e\u094b\u0928 \u091f\u093e\u092a\u0941\u0939\u0930\u0941" },
+            { "SB", "\u0938\u094b\u0932\u094b\u092e\u0928 \u091f\u093e\u092a\u0941\u0939\u0930\u0942" },
             { "twq", "\u0924\u093e\u0938\u093e\u0935\u093e\u0915" },
             { "011", "\u092a\u0936\u094d\u091a\u093f\u092e\u0940 \u0905\u092b\u094d\u0930\u093f\u0915\u093e" },
             { "SC", "\u0938\u0947\u091a\u0947\u0932\u0947\u0938" },
@@ -499,7 +500,7 @@ public class LocaleNames_ne extends OpenListResourceBundle {
             { "015", "\u0909\u0924\u094d\u0924\u0930\u0940 \u0905\u092b\u094d\u0930\u093f\u0915\u093e" },
             { "SG", "\u0938\u093f\u0919\u094d\u0917\u093e\u092a\u0941\u0930" },
             { "SH", "\u0938\u0947\u0928\u094d\u091f \u0939\u0947\u0932\u0947\u0928\u093e" },
-            { "type.lb.strict", "strict" },
+            { "type.lb.strict", "\u092a\u0919\u094d\u0915\u094d\u0924\u093f \u0935\u093f\u091a\u094d\u091b\u0947\u0926\u0915\u094b \u0915\u0921\u093e \u0936\u0948\u0932\u0940" },
             { "017", "\u092e\u0927\u094d\u092f \u0905\u092b\u094d\u0930\u093f\u0915\u093e" },
             { "SI", "\u0938\u094d\u0932\u094b\u092d\u0947\u0928\u093f\u092f\u093e" },
             { "018", "\u0926\u0915\u094d\u0937\u093f\u0923\u0940 \u0905\u092b\u094d\u0930\u093f\u0915\u093e" },
@@ -532,7 +533,7 @@ public class LocaleNames_ne extends OpenListResourceBundle {
             { "TC", "\u0924\u0941\u0930\u094d\u0915 \u0930 \u0915\u093e\u0907\u0915\u094b\u0938 \u091f\u093e\u092a\u0941" },
             { "yav", "\u092f\u093e\u0919\u094d\u092c\u0947\u0928" },
             { "TD", "\u091a\u093e\u0921" },
-            { "TF", "\u092b\u094d\u0930\u093e\u0928\u094d\u0938\u0947\u0932\u0940 \u0926\u0915\u094d\u0937\u093f\u0923\u0940 \u0915\u094d\u0937\u0947\u0924\u094d\u0930\u0939\u0930\u0941" },
+            { "TF", "\u092b\u094d\u0930\u0947\u0928\u094d\u091a \u0926\u0915\u094d\u0937\u093f\u0923\u0940 \u0930\u093e\u091c\u094d\u092f\u0939\u0930\u0942" },
             { "ase", "\u0905\u092e\u0947\u0930\u093f\u0915\u0940 \u0938\u093e\u0919\u094d\u0915\u0947\u0924\u093f\u0915 \u092d\u093e\u0937\u093e" },
             { "TG", "\u091f\u094b\u0917\u094b" },
             { "TH", "\u0925\u093e\u0907\u0932\u094d\u092f\u093e\u0923\u094d\u0921" },
@@ -602,7 +603,9 @@ public class LocaleNames_ne extends OpenListResourceBundle {
             { "wae", "\u0935\u093e\u0932\u094d\u0938\u0930" },
             { "WS", metaValue_WS },
             { "wal", "\u0935\u094b\u0932\u0947\u091f\u094d\u091f\u093e" },
+            { "XA", "\u0938\u093f\u0909\u0921\u094b-\u090f\u0915\u094d\u0938\u0947\u0928\u094d\u091f\u094d\u0938" },
             { "war", "\u0935\u093e\u0930\u0947" },
+            { "XB", "\u0938\u093f\u0909\u0921\u094b-\u092c\u093f\u0921\u0940" },
             { "awa", "\u0905\u0935\u0927\u0940" },
             { "061", "\u092a\u094b\u0932\u093f\u0928\u0947\u0936\u093f\u092f\u093e" },
             { "XK", "\u0915\u094b\u0938\u094b\u092d\u094b" },
@@ -621,7 +624,7 @@ public class LocaleNames_ne extends OpenListResourceBundle {
             { "Sgnw", "\u0938\u093e\u0907\u0928\u0930\u093e\u0907\u091f\u093f\u0919" },
             { "YT", "\u092e\u093e\u092f\u094b\u091f\u094d\u091f" },
             { "ZA", "\u0926\u0915\u094d\u0937\u093f\u0923 \u0905\u092b\u094d\u0930\u093f\u0915\u093e" },
-            { "type.lb.loose", "loose" },
+            { "type.lb.loose", "\u092a\u0919\u094d\u0915\u094d\u0924\u093f \u0935\u093f\u091a\u094d\u091b\u0947\u0926\u0915\u094b \u0916\u0941\u0932\u093e \u0936\u0948\u0932\u0940" },
             { "Deva", metaValue_Deva },
             { "type.nu.geor", "\u091c\u0930\u094d\u091c\u093f\u092f\u093e\u0932\u0940 \u0905\u0919\u094d\u0915\u0939\u0930\u0942" },
             { "Hira", "\u0939\u093f\u0930\u093e\u0917\u0928\u093e" },
@@ -753,7 +756,7 @@ public class LocaleNames_ne extends OpenListResourceBundle {
             { "type.nu.grek", "\u0917\u094d\u0930\u0940\u0915 \u0905\u0919\u094d\u0915\u0939\u0930\u0942" },
             { "ee", "\u0907\u0935\u0940" },
             { "bfd", "\u092c\u093e\u092b\u0941\u091f" },
-            { "type.lb.normal", "normal" },
+            { "type.lb.normal", "\u092a\u0919\u094d\u0915\u094d\u0924\u093f \u0935\u093f\u091a\u094d\u091b\u0947\u0926\u0915\u094b \u0938\u093e\u092e\u093e\u0928\u094d\u092f \u0936\u0948\u0932\u0940" },
             { "ro_MD", "\u092e\u094b\u0932\u094d\u0921\u093e\u092d\u093f\u092f\u093e\u0932\u0940" },
             { "el", metaValue_el },
             { "en", "\u0905\u0919\u094d\u0917\u094d\u0930\u0947\u091c\u0940" },
@@ -946,7 +949,7 @@ public class LocaleNames_ne extends OpenListResourceBundle {
             { "pt_BR", "\u092c\u094d\u0930\u093e\u091c\u093f\u0932\u0940 \u092a\u094b\u0930\u094d\u0924\u0941\u0917\u0940" },
             { "kcg", "\u091f\u0941\u0906\u092a" },
             { "mgh", "\u092e\u093e\u0916\u0941\u0935\u093e-\u092e\u093f\u091f\u094d\u091f\u094b" },
-            { "key.cf", "cf" },
+            { "key.cf", "\u092e\u0941\u0926\u094d\u0930\u093e\u0915\u094b \u0922\u093e\u0901\u091a\u093e" },
             { "bra", "\u092c\u094d\u0930\u091c" },
             { "key.ca", "\u092a\u093e\u0924\u094d\u0930\u094b" },
             { "Laoo", metaValue_lo },
@@ -1052,7 +1055,7 @@ public class LocaleNames_ne extends OpenListResourceBundle {
             { "vi", "\u092d\u093f\u092f\u0924\u0928\u093e\u092e\u0940" },
             { "kho", "\u0916\u094b\u091f\u093e\u0928\u0940" },
             { "khq", "\u0915\u094b\u092f\u0930\u093e \u091a\u093f\u0928\u0940" },
-            { "key.hc", "hc" },
+            { "key.hc", "\u0938\u092e\u092f \u091a\u0915\u094d\u0930 (12 \u0924\u0925\u093e 24)" },
             { "vo", "\u092d\u094b\u0932\u093e\u092a\u093f\u0915" },
             { "khw", "\u0916\u094b\u0935\u093e\u0930" },
             { "syc", "\u092a\u0930\u092e\u094d\u092a\u0930\u093e\u0917\u0924 \u0938\u093f\u0930\u093f\u092f\u093e\u0915" },
@@ -1104,7 +1107,7 @@ public class LocaleNames_ne extends OpenListResourceBundle {
             { "zh", "\u091a\u093f\u0928\u093f\u092f\u093e\u0901" },
             { "Bopo", "\u092c\u094b\u092a\u094b\u092e\u094b\u092b\u094b" },
             { "Perm", "\u092a\u0941\u0930\u093e\u0928\u094b \u092a\u0930\u094d\u092e\u093f\u0915" },
-            { "key.lb", "lb" },
+            { "key.lb", "\u092a\u0919\u094d\u0915\u094d\u0924\u093f \u0935\u093f\u091a\u094d\u091b\u0947\u0926\u0915\u094b \u0936\u0948\u0932\u0940" },
             { "zu", "\u091c\u0941\u0932\u0941" },
             { "type.co.phonebook", "\u091f\u0947\u0932\u093f\u092b\u094b\u0928 \u092a\u0941\u0938\u094d\u0924\u093f\u0915\u093e \u0915\u094d\u0930\u092e\u092c\u0926\u094d\u0927\u0924\u093e\u092a\u0926\u094d\u0926\u0924\u093f" },
             { "Geor", metaValue_ka },
@@ -1145,6 +1148,7 @@ public class LocaleNames_ne extends OpenListResourceBundle {
             { "inh", "\u0907\u0928\u094d\u0917\u0938" },
             { "krj", "\u0915\u093f\u0928\u093e\u0930\u093e\u092f-\u090f" },
             { "kri", "\u0915\u094d\u0930\u093f\u0913" },
+            { "fa_AF", "\u0926\u093e\u0930\u0940" },
             { "krl", "\u0915\u0930\u0947\u0932\u093f\u092f\u0928" },
             { "efi", "\u090f\u092b\u093f\u0915" },
             { "key.nu", "\u0905\u0919\u094d\u0915\u0939\u0930\u0942" },
