@@ -169,7 +169,7 @@ public class LocaleNames_or extends OpenListResourceBundle {
             { "CA", "\u0b15\u0b3e\u0b28\u0b3e\u0b21\u0b3e" },
             { "CC", "\u0b15\u0b4b\u0b15\u0b4b\u0b38\u0b4d (\u0b15\u0b40\u0b32\u0b3f\u0b02) \u0b26\u0b4d\u0b35\u0b40\u0b2a\u0b2a\u0b41\u0b1e\u0b4d\u0b1c" },
             { "mzn", "\u0b2e\u0b3e\u0b1c\u0b3e\u0b28\u0b21\u0b47\u0b30\u0b3e\u0b28\u0b3f" },
-            { "CD", "\u0b15\u0b19\u0b4d\u0b17\u0b4b-\u0b15\u0b3f\u0b28\u0b38\u0b3e\u0b38\u0b3e" },
+            { "CD", "\u0b15\u0b19\u0b4d\u0b17\u0b4b (\u0b21\u0b3f\u0b06\u0b30\u0b38\u0b3f)" },
             { "CF", "\u0b2e\u0b27\u0b4d\u0b5f \u0b06\u0b2b\u0b4d\u0b30\u0b3f\u0b15\u0b40\u0b5f \u0b38\u0b3e\u0b27\u0b3e\u0b30\u0b23\u0b24\u0b28\u0b4d\u0b24\u0b4d\u0b30" },
             { "CG", "\u0b15\u0b19\u0b4d\u0b17\u0b4b-\u0b2c\u0b4d\u0b30\u0b3e\u0b1c\u0b3f\u0b2d\u0b3f\u0b32\u0b4d\u0b32\u0b47" },
             { "CH", "\u0b38\u0b4d\u0b71\u0b3f\u0b1c\u0b30\u0b32\u0b4d\u0b5f\u0b3e\u0b23\u0b4d\u0b21" },
@@ -548,6 +548,7 @@ public class LocaleNames_or extends OpenListResourceBundle {
             { "UN", "\u0b1c\u0b3e\u0b24\u0b3f\u0b38\u0b02\u0b18" },
             { "US", "\u0b2f\u0b41\u0b15\u0b4d\u0b24 \u0b30\u0b3e\u0b37\u0b4d\u0b1f\u0b4d\u0b30" },
             { "haw", "\u0b39\u0b3e\u0b71\u0b3e\u0b07\u0b28\u0b4d" },
+            { "%%1959ACAD", "\u0b0f\u0b15\u0b3e\u0b21\u0b47\u0b2e\u0b3f\u0b15" },
             { "UY", "\u0b09\u0b30\u0b41\u0b17\u0b41\u0b0f" },
             { "prg", "\u0b2a\u0b4d\u0b30\u0b41\u0b38\u0b3f\u0b5f" },
             { "UZ", "\u0b09\u0b1c\u0b2c\u0b47\u0b15\u0b3f\u0b38\u0b4d\u0b24\u0b3e\u0b28" },
@@ -635,6 +636,7 @@ public class LocaleNames_or extends OpenListResourceBundle {
             { "jpr", "\u0b1c\u0b41\u0b21\u0b47\u0b13-\u0b2a\u0b30\u0b4d\u0b38\u0b3f\u0b06\u0b28\u0b4d" },
             { "sba", "\u0b28\u0b17\u0b3e\u0b2e\u0b2c\u0b47" },
             { "Guru", "\u0b17\u0b41\u0b30\u0b2e\u0b41\u0b16\u0b40" },
+            { "%%ALUKU", "\u0b06\u0b32\u0b41\u0b15\u0b41 \u0b09\u0b2a\u0b2d\u0b3e\u0b37\u0b3e" },
             { "lua", "\u0b32\u0b41\u0b2c\u0b3e-\u0b32\u0b41\u0b32\u0b41\u0b06" },
             { "sbp", "\u0b38\u0b3e\u0b28\u0b17\u0b41" },
             { "lui", "\u0b32\u0b41\u0b07\u0b38\u0b47\u0b28\u0b4b" },
@@ -675,6 +677,7 @@ public class LocaleNames_or extends OpenListResourceBundle {
             { "Linb", "\u0b32\u0b3f\u0b28\u0b3f\u0b5f\u0b30\u0b4d \u0b2c\u0b3f" },
             { "ay", "\u0b06\u0b5f\u0b2e\u0b3e\u0b30\u0b3e" },
             { "az", "\u0b06\u0b1c\u0b47\u0b30\u0b2c\u0b3e\u0b07\u0b1c\u0b3e\u0b28\u0b3f" },
+            { "%%UNIFON", "\u0b5f\u0b41\u0b28\u0b3f\u0b2b\u0b28\u0b4d \u0b2b\u0b28\u0b47\u0b1f\u0b3f\u0b15\u0b4d \u0b06\u0b32\u0b2b\u0b3e\u0b2c\u0b47\u0b1f\u0b4d" },
             { "ba", "\u0b2c\u0b3e\u0b36\u0b15\u0b3f\u0b30\u0b4d" },
             { "be", "\u0b2c\u0b47\u0b32\u0b3e\u0b30\u0b41\u0b37\u0b3f\u0b06\u0b28\u0b4d" },
             { "bg", "\u0b2c\u0b41\u0b32\u0b17\u0b47\u0b30\u0b3f\u0b06\u0b28\u0b4d" },
@@ -712,6 +715,7 @@ public class LocaleNames_or extends OpenListResourceBundle {
             { "Bugi", "\u0b2c\u0b41\u0b17\u0b3e\u0b28\u0b40\u0b1c\u0b4d" },
             { "bem", "\u0b2c\u0b47\u0b2e\u0b4d\u0b2c\u0b3e" },
             { "sga", "\u0b2a\u0b41\u0b30\u0b41\u0b23\u0b3e \u0b07\u0b30\u0b3f\u0b36\u0b4d" },
+            { "type.nu.mong", "\u0b2e\u0b19\u0b4d\u0b17\u0b4b\u0b32\u0b40\u0b5f \u0b21\u0b3f\u0b1c\u0b3f\u0b1f\u0b4d" },
             { "dv", "\u0b21\u0b3f\u0b2d\u0b47\u0b39\u0b40" },
             { "es_419", "\u0b32\u0b3e\u0b1f\u0b3f\u0b28\u0b4d\u200c \u0b06\u0b2e\u0b47\u0b30\u0b3f\u0b15\u0b40\u0b5f \u0b38\u0b4d\u0b2a\u0b3e\u0b28\u0b3f\u0b38\u0b4d\u200c" },
             { "dz", "\u0b26\u0b21\u0b1c\u0b4b\u0b19\u0b4d\u0b17\u0b16\u0b3e" },
@@ -913,6 +917,7 @@ public class LocaleNames_or extends OpenListResourceBundle {
             { "brx", "\u0b2c\u0b4b\u0b21\u0b4b" },
             { "Lana", "\u0b32\u0b3e\u0b28\u0b3e" },
             { "kde", "\u0b2e\u0b3e\u0b15\u0b4b\u0b23\u0b4d\u0b21\u0b47" },
+            { "%%VAIDIKA", "\u0b2c\u0b48\u0b26\u0b3f\u0b15" },
             { "Ethi", "\u0b07\u0b25\u0b3f\u0b13\u0b2a\u0b3f\u0b15\u0b4d\u200c" },
             { "type.hc.h12", "12 \u0b18\u0b23\u0b4d\u0b1f\u0b3f\u0b06 \u0b2a\u0b26\u0b4d\u0b27\u0b24\u0b3f (1\u201312)" },
             { "type.hc.h11", "12 \u0b18\u0b23\u0b4d\u0b1f\u0b3f\u0b06 \u0b2a\u0b26\u0b4d\u0b27\u0b24\u0b3f (0\u201311)" },
@@ -998,6 +1003,7 @@ public class LocaleNames_or extends OpenListResourceBundle {
             { "zen", "\u0b1c\u0b47\u0b28\u0b3e\u0b17\u0b3e" },
             { "uz", "\u0b09\u0b1c\u0b2c\u0b47\u0b15\u0b4d" },
             { "kha", "\u0b16\u0b3e\u0b38\u0b40" },
+            { "%%1996", "1996\u0b30 \u0b1c\u0b30\u0b4d\u0b2e\u0b3e\u0b28 \u0b2c\u0b30\u0b4d\u0b23\u0b4d\u0b23\u0b2a\u0b4d\u0b30\u0b15\u0b30\u0b23" },
             { "Sylo", "\u0b38\u0b40\u0b32\u0b3f\u0b24\u0b4b \u0b28\u0b17\u0b30\u0b40" },
             { "ve", "\u0b2d\u0b47\u0b23\u0b4d\u0b21\u0b3e" },
             { "type.ca.roc", "\u0b2e\u0b3f\u0b19\u0b4d\u0b17\u0b4b\u0b13 \u0b15\u0b4d\u0b5f\u0b3e\u0b32\u0b47\u0b23\u0b4d\u0b21\u0b30\u0b4d\u200c" },
@@ -1037,6 +1043,7 @@ public class LocaleNames_or extends OpenListResourceBundle {
             { "Moon", "\u0b1a\u0b28\u0b4d\u0b26\u0b4d\u0b30" },
             { "moh", "\u0b2e\u0b4b\u0b39\u0b4c\u0b15" },
             { "kkj", "\u0b15\u0b3e\u0b15\u0b4b" },
+            { "%%1694ACAD", "\u0b06\u0b26\u0b4d\u0b5f \u0b06\u0b27\u0b41\u0b28\u0b3f\u0b15 \u0b2b\u0b30\u0b3e\u0b38\u0b40" },
             { "yi", "\u0b5f\u0b3f\u0b21\u0b3f\u0b38\u0b4d" },
             { "mos", "\u0b2e\u0b4b\u0b38\u0b3f" },
             { "Syrc", "\u0b38\u0b3f\u0b30\u0b3f\u0b5f\u0b3e\u0b15\u0b4d" },
@@ -1070,12 +1077,14 @@ public class LocaleNames_or extends OpenListResourceBundle {
             { "zh_Hans", "\u0b38\u0b30\u0b33\u0b40\u0b15\u0b43\u0b24 \u0b1a\u0b3e\u0b07\u0b28\u0b3f\u0b1c\u0b4d\u200c" },
             { "Hung", "\u0b2a\u0b41\u0b30\u0b41\u0b23\u0b3e \u0b39\u0b19\u0b4d\u0b17\u0b47\u0b30\u0b3f\u0b06\u0b28\u0b4d" },
             { "kok", "\u0b15\u0b4b\u0b19\u0b4d\u0b15\u0b23\u0b3f" },
+            { "%%1901", "\u0b2a\u0b3e\u0b30\u0b2e\u0b4d\u0b2a\u0b30\u0b3f\u0b15 \u0b1c\u0b30\u0b4d\u0b2e\u0b3e\u0b28 \u0b2c\u0b30\u0b4d\u0b23\u0b4d\u0b23\u0b2a\u0b4d\u0b30\u0b15\u0b30\u0b23" },
             { "kos", "\u0b15\u0b4b\u0b38\u0b30\u0b48\u0b28\u0b4d" },
             { "zh_Hant", "\u0b2a\u0b3e\u0b30\u0b2e\u0b4d\u0b2a\u0b30\u0b3f\u0b15 \u0b1a\u0b3e\u0b07\u0b28\u0b3f\u0b1c\u0b4d\u200c" },
             { "Sund", metaValue_su },
             { "kpe", "\u0b15\u0b48\u0b2a\u0b47\u0b32\u0b47" },
             { "type.nu.khmr", "\u0b16\u0b3f\u0b2e\u0b30\u0b4d\u200c \u0b05\u0b19\u0b4d\u0b15\u0b17\u0b41\u0b21\u0b3c\u0b3f\u0b15" },
             { "ilo", "\u0b07\u0b32\u0b4b\u0b15\u0b4b" },
+            { "%%VALENCIA", "\u0b2d\u0b47\u0b32\u0b47\u0b28\u0b38\u0b3f\u0b06\u0b28\u0b4d" },
             { "Cprt", "\u0b38\u0b3f\u0b2a\u0b4d\u0b30\u0b05\u0b1f\u0b4d" },
             { "mua", "\u0b2e\u0b41\u0b28\u0b21\u0b3e\u0b02" },
             { "type.nu.guru", "\u0b17\u0b41\u0b30\u0b2e\u0b41\u0b16\u0b40 \u0b05\u0b19\u0b4d\u0b15\u0b17\u0b41\u0b21\u0b3c\u0b3f\u0b15" },
@@ -1090,6 +1099,7 @@ public class LocaleNames_or extends OpenListResourceBundle {
             { "type.nu.tamldec", "\u0b24\u0b3e\u0b2e\u0b3f\u0b32\u0b4d \u0b05\u0b19\u0b4d\u0b15\u0b17\u0b41\u0b21\u0b3c\u0b3f\u0b15" },
             { "krc", "\u0b15\u0b30\u0b3e\u0b1a\u0b5f-\u0b2c\u0b32\u0b4d\u0b15\u0b3e\u0b30" },
             { "inh", "\u0b07\u0b01\u0b19\u0b4d\u0b17\u0b41\u0b36\u0b4d" },
+            { "fa_AF", "\u0b26\u0b3e\u0b30\u0b3f" },
             { "krl", "\u0b15\u0b3e\u0b30\u0b47\u0b32\u0b3f\u0b5f\u0b3e\u0b28\u0b4d" },
             { "efi", "\u0b0f\u0b2b\u0b3f\u0b15\u0b4d" },
             { "key.nu", "\u0b38\u0b02\u0b16\u0b4d\u0b5f\u0b3e\u0b17\u0b41\u0b21\u0b3c\u0b3f\u0b15" },
