@@ -97,6 +97,7 @@ public class LocaleNames_pa extends OpenListResourceBundle {
             { "mwl", "\u0a2e\u0a3f\u0a30\u0a3e\u0a02\u0a21\u0a40" },
             { "Zsym", "\u0a1a\u0a3f\u0a70\u0a28\u0a4d\u0a39" },
             { "Zsye", "\u0a07\u0a2e\u0a4b\u0a1c\u0a40" },
+            { "ccp", "\u0a1a\u0a15\u0a2e\u0a3e" },
             { "egy", "\u0a2a\u0a41\u0a30\u0a3e\u0a24\u0a28 \u0a2e\u0a3f\u0a38\u0a30\u0a40" },
             { "raj", "\u0a30\u0a3e\u0a1c\u0a38\u0a25\u0a3e\u0a28\u0a40" },
             { "tem", "\u0a1f\u0a3f\u0a2e\u0a28\u0a47" },
@@ -327,7 +328,7 @@ public class LocaleNames_pa extends OpenListResourceBundle {
             { "Thai", metaValue_th },
             { "MH", "\u0a2e\u0a3e\u0a30\u0a38\u0a3c\u0a32 \u0a1f\u0a3e\u0a2a\u0a42" },
             { "ale", "\u0a05\u0a32\u0a47\u0a09\u0a1f" },
-            { "MK", "\u0a2e\u0a48\u0a15\u0a21\u0a4b\u0a28\u0a40\u0a06" },
+            { "MK", "\u0a09\u0a71\u0a24\u0a30\u0a40 \u0a2e\u0a48\u0a15\u0a21\u0a4b\u0a28\u0a40\u0a06" },
             { "ML", "\u0a2e\u0a3e\u0a32\u0a40" },
             { "MM", "\u0a2e\u0a3f\u0a06\u0a02\u0a2e\u0a3e\u0a30 (\u0a2c\u0a30\u0a2e\u0a3e)" },
             { "MN", "\u0a2e\u0a70\u0a17\u0a4b\u0a32\u0a40\u0a06" },
@@ -503,7 +504,9 @@ public class LocaleNames_pa extends OpenListResourceBundle {
             { "wae", "\u0a35\u0a3e\u0a32\u0a38\u0a30" },
             { "WS", "\u0a38\u0a3e\u0a2e\u0a4b\u0a06" },
             { "wal", "\u0a35\u0a4b\u0a32\u0a3e\u0a0f\u0a1f\u0a3e" },
+            { "XA", "\u0a17\u0a32\u0a24-\u0a09\u0a1a\u0a3e\u0a30\u0a28" },
             { "war", "\u0a35\u0a48\u0a30\u0a47" },
+            { "XB", "\u0a32\u0a3f\u0a16\u0a24 \u0a26\u0a40 \u0a17\u0a32\u0a24 \u0a26\u0a3f\u0a38\u0a3c\u0a3e" },
             { "awa", "\u0a05\u0a35\u0a27\u0a40" },
             { "061", "\u0a2a\u0a4b\u0a32\u0a40\u0a28\u0a47\u0a38\u0a3c\u0a40\u0a06" },
             { "XK", "\u0a15\u0a4b\u0a38\u0a4b\u0a35\u0a4b" },
@@ -566,6 +569,7 @@ public class LocaleNames_pa extends OpenListResourceBundle {
             { "scn", "\u0a38\u0a3f\u0a38\u0a40\u0a32\u0a40\u0a05\u0a28" },
             { "aa", "\u0a05\u0a2b\u0a3c\u0a3e\u0a30" },
             { "ab", "\u0a05\u0a2c\u0a16\u0a3e\u0a1c\u0a3c\u0a40\u0a05\u0a28" },
+            { "Aran", "\u0a28\u0a38\u0a24\u0a3e\u0a32\u0a40\u0a15" },
             { "af", "\u0a05\u0a2b\u0a3c\u0a30\u0a40\u0a15\u0a40" },
             { "ak", "\u0a05\u0a15\u0a3e\u0a28" },
             { "am", "\u0a05\u0a2e\u0a39\u0a3e\u0a30\u0a3f\u0a15" },
@@ -719,7 +723,7 @@ public class LocaleNames_pa extends OpenListResourceBundle {
             { "lt", "\u0a32\u0a3f\u0a25\u0a41\u0a06\u0a28\u0a40\u0a05\u0a28" },
             { "lu", "\u0a32\u0a42\u0a2c\u0a3e-\u0a15\u0a3e\u0a1f\u0a3e\u0a02\u0a17\u0a3e" },
             { "lv", "\u0a32\u0a3e\u0a24\u0a40\u0a35\u0a40" },
-            { "mg", "\u0a2e\u0a47\u0a32\u0a47\u0a17\u0a38\u0a40" },
+            { "mg", "\u0a2e\u0a3e\u0a32\u0a3e\u0a17\u0a48\u0a38\u0a40" },
             { "mh", "\u0a2e\u0a3e\u0a30\u0a38\u0a3c\u0a32\u0a40\u0a1c\u0a3c" },
             { "type.co.ducet", "\u0a2e\u0a42\u0a32 \u0a2f\u0a42\u0a28\u0a40\u0a15\u0a4b\u0a21 \u0a32\u0a5c\u0a40\u0a2c\u0a71\u0a27 \u0a15\u0a4d\u0a30\u0a2e" },
             { "mi", "\u0a2e\u0a3e\u0a09\u0a30\u0a40" },
@@ -912,6 +916,7 @@ public class LocaleNames_pa extends OpenListResourceBundle {
             { "type.nu.tamldec", "\u0a24\u0a2e\u0a3f\u0a32 \u0a05\u0a70\u0a15" },
             { "krc", "\u0a15\u0a30\u0a3e\u0a1a\u0a47 \u0a2c\u0a32\u0a15\u0a3e\u0a30" },
             { "inh", "\u0a07\u0a70\u0a17\u0a41\u0a38\u0a3c" },
+            { "fa_AF", "\u0a26\u0a3e\u0a30\u0a40" },
             { "krl", "\u0a15\u0a30\u0a40\u0a32\u0a40\u0a05\u0a28" },
             { "efi", "\u0a10\u0a2b\u0a3f\u0a15" },
             { "key.nu", "\u0a38\u0a70\u0a16\u0a3f\u0a06\u0a35\u0a3e\u0a02" },
