@@ -70,6 +70,7 @@ import sun.util.resources.OpenListResourceBundle;
 public class LocaleNames_pl extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
+        final String metaValue_gu = "gud\u017carati";
         final String metaValue_kn = "kannada";
         final String metaValue_ml = "malajalam";
         final String metaValue_or = "orija";
@@ -88,7 +89,7 @@ public class LocaleNames_pl extends OpenListResourceBundle {
             { "egl", "emilijski" },
             { "mwv", "mentawai" },
             { "Tagb", "tagbanwa" },
-            { "Zsye", "Emoji" },
+            { "Zsye", "emoji" },
             { "%%NJIVA", "dialekt Gniva/Njiva" },
             { "xmf", "megrelski" },
             { "ccp", "czakma" },
@@ -323,7 +324,7 @@ public class LocaleNames_pl extends OpenListResourceBundle {
             { "type.nu.beng", "cyfry bengalskie" },
             { "pfl", "palatynacki" },
             { "JE", "Jersey" },
-            { "type.ca.islamic", "kalendarz islamski (metoda wzrokowa)" },
+            { "type.ca.islamic", "kalendarz muzu\u0142ma\u0144ski" },
             { "JM", "Jamajka" },
             { "Beng", "bengalskie" },
             { "JO", "Jordania" },
@@ -383,7 +384,7 @@ public class LocaleNames_pl extends OpenListResourceBundle {
             { "akz", "alabama" },
             { "lah", "lahnda" },
             { "lag", "langi" },
-            { "Thaa", "thaana" },
+            { "Thaa", "taana" },
             { "MA", "Maroko" },
             { "MC", "Monako" },
             { "MD", "Mo\u0142dawia" },
@@ -408,7 +409,7 @@ public class LocaleNames_pl extends OpenListResourceBundle {
             { "MS", "Montserrat" },
             { "MT", "Malta" },
             { "cps", "capiznon" },
-            { "type.m0.ungegn", "UNGEGN" },
+            { "type.m0.ungegn", "transliteracja UNGEGN" },
             { "MU", "Mauritius" },
             { "alt", "po\u0142udniowoa\u0142tajski" },
             { "MV", "Malediwy" },
@@ -557,6 +558,7 @@ public class LocaleNames_pl extends OpenListResourceBundle {
             { "TC", "Turks i Caicos" },
             { "yav", "yangben" },
             { "TD", "Czad" },
+            { "Qaag", "zawgyi" },
             { "TF", "Francuskie Terytoria Po\u0142udniowe i Antarktyczne" },
             { "ase", "ameryka\u0144ski j\u0119zyk migowy" },
             { "TG", "Togo" },
@@ -581,7 +583,7 @@ public class LocaleNames_pl extends OpenListResourceBundle {
             { "Orkh", "orcho\u0144skie" },
             { "TZ", "Tanzania" },
             { "nmg", "ngumba" },
-            { "Zzzz", "nieznany skrypt" },
+            { "Zzzz", "nieznane pismo" },
             { "UA", "Ukraina" },
             { "lij", "liguryjski" },
             { "rup", "arumu\u0144ski" },
@@ -641,7 +643,7 @@ public class LocaleNames_pl extends OpenListResourceBundle {
             { "awa", "awadhi" },
             { "061", "Polinezja" },
             { "XK", "Kosowo" },
-            { "Gujr", "gud\u017aarackie" },
+            { "Gujr", metaValue_gu },
             { "Zxxx", "j\u0119zyk bez systemu pisma" },
             { "Olck", "ol chiki" },
             { "wbp", "warlpiri" },
@@ -649,7 +651,7 @@ public class LocaleNames_pl extends OpenListResourceBundle {
             { "Blis", "symbole Blissa" },
             { "YE", "Jemen" },
             { "nqo", metaValue_nqo },
-            { "type.co.standard", "sortowanie standardowe" },
+            { "type.co.standard", "standardowa kolejno\u015b\u0107 sortowania" },
             { "lmo", "lombardzki" },
             { "fan", "fang" },
             { "%%ROZAJ", "dialekt regionu Resia" },
@@ -736,6 +738,7 @@ public class LocaleNames_pl extends OpenListResourceBundle {
             { "scn", "sycylijski" },
             { "aa", "afar" },
             { "ab", "abchaski" },
+            { "Aran", "nastaliq" },
             { "bbc", "batak toba" },
             { "ae", "awestyjski" },
             { "af", "afrikaans" },
@@ -823,14 +826,14 @@ public class LocaleNames_pl extends OpenListResourceBundle {
             { "type.co.big5han", "chi\u0144ski tradycyjny porz\u0105dek sortowania - Big5" },
             { "es", "hiszpa\u0144ski" },
             { "et", "esto\u0144ski" },
-            { "Hanb", "hanb" },
+            { "Hanb", "chi\u0144skie z bopomofo" },
             { "eu", "baskijski" },
             { "Buhd", "buhid" },
-            { "Hang", "hangyl" },
+            { "Hang", "hangul" },
             { "Samr", "samaryta\u0144ski" },
             { "shi", "tashelhiyt" },
             { "hsb", "g\u00f3rno\u0142u\u017cycki" },
-            { "Hani", "han" },
+            { "Hani", "chi\u0144skie" },
             { "shn", "szan" },
             { "Hano", "hanunoo" },
             { "fa", "perski" },
@@ -846,7 +849,7 @@ public class LocaleNames_pl extends OpenListResourceBundle {
             { "bgn", "belud\u017ci p\u00f3\u0142nocny" },
             { "yue", "kanto\u0144ski" },
             { "fo", "farerski" },
-            { "type.m0.bgn", "BGN" },
+            { "type.m0.bgn", "transliteracja BGN" },
             { "umb", "umbundu" },
             { "fr", "francuski" },
             { "sid", "sidamo" },
@@ -858,7 +861,7 @@ public class LocaleNames_pl extends OpenListResourceBundle {
             { "bho", "bhod\u017cpuri" },
             { "und", "nieznany j\u0119zyk" },
             { "type.ca.ethiopic-amete-alem", "Kalendarz etiopski Amete Alem" },
-            { "gu", "gud\u017carati" },
+            { "gu", metaValue_gu },
             { "type.ca.islamic-tbla", "kalendarz islamski (metoda obliczeniowa, epoka astronomiczna)" },
             { "gv", "manx" },
             { "ha", "hausa" },
@@ -952,7 +955,7 @@ public class LocaleNames_pl extends OpenListResourceBundle {
             { "sog", "sogdyjski" },
             { "mg", "malgaski" },
             { "mh", "marszalski" },
-            { "type.co.ducet", "domy\u015blne sortowanie Unicode" },
+            { "type.co.ducet", "domy\u015blna kolejno\u015b\u0107 sortowania Unicode" },
             { "mi", "maoryjski" },
             { "mk", "macedo\u0144ski" },
             { "ml", metaValue_ml },
@@ -968,7 +971,7 @@ public class LocaleNames_pl extends OpenListResourceBundle {
             { "dsb", "dolno\u0142u\u017cycki" },
             { "Armi", "armi" },
             { "na", "naurua\u0144ski" },
-            { "type.co.search", "wyszukiwanie og\u00f3lnego u\u017cytku" },
+            { "type.co.search", "wyszukiwanie og\u00f3lnego zastosowania" },
             { "nb", "norweski (bokm\u00e5l)" },
             { "nd", "ndebele p\u00f3\u0142nocny" },
             { "ne", "nepalski" },
@@ -1009,11 +1012,11 @@ public class LocaleNames_pl extends OpenListResourceBundle {
             { "bqi", "bachtiarski" },
             { "pl", "polski" },
             { "dum", "\u015bredniowieczny niderlandzki" },
-            { "type.ca.dangi", "kalendarz dangi" },
+            { "type.ca.dangi", "kalendarz korea\u0144ski" },
             { "ps", "paszto" },
             { "pt", "portugalski" },
             { "mga", "\u015brednioirlandzki" },
-            { "key.co", "porz\u0105dek sortowania" },
+            { "key.co", "kolejno\u015b\u0107 sortowania" },
             { "pt_BR", "brazylijski portugalski" },
             { "kcg", "tyap" },
             { "mgh", "makua" },
@@ -1235,7 +1238,7 @@ public class LocaleNames_pl extends OpenListResourceBundle {
             { "type.nu.guru", "cyfry gurmukhi" },
             { "mul", "wiele j\u0119zyk\u00f3w" },
             { "cad", "kaddo" },
-            { "key.ms", "uk\u0142ad miar" },
+            { "key.ms", "system miar" },
             { "mus", "krik" },
             { "Glag", "g\u0142agolica" },
             { "gil", "gilberta\u0144ski" },
@@ -1248,6 +1251,7 @@ public class LocaleNames_pl extends OpenListResourceBundle {
             { "inh", "inguski" },
             { "krj", "kinaraya" },
             { "kri", "krio" },
+            { "fa_AF", "dari" },
             { "krl", "karelski" },
             { "efi", "efik" },
             { "tcy", "tulu" },
