@@ -87,6 +87,7 @@ public class LocaleNames_pt extends OpenListResourceBundle {
         final String metaValue_ml = "malaiala";
         final String metaValue_mn = "mongol";
         final String metaValue_my = "birman\u00eas";
+        final String metaValue_or = "ori\u00e1";
         final String metaValue_si = "cingal\u00eas";
         final String metaValue_su = "sundan\u00eas";
         final String metaValue_ta = "t\u00e2mil";
@@ -103,7 +104,6 @@ public class LocaleNames_pt extends OpenListResourceBundle {
         final String metaValue_syr = "sir\u00edaco";
         final String metaValue_uga = "ugar\u00edtico";
         final String metaValue_vai = "vai";
-        final String metaValue_type_d0_fwidth = "Extens\u00e3o total";
         final Object[][] data = new Object[][] {
             { "ksh", "k\u00f6lsch" },
             { "Ogam", "og\u00e2mico" },
@@ -114,7 +114,7 @@ public class LocaleNames_pt extends OpenListResourceBundle {
             { "Tagb", "tagbanwa" },
             { "Zsye", "Emoji" },
             { "%%NJIVA", "dialeto gniva/njiva" },
-            { "ccp", "Chakma" },
+            { "ccp", "chakma" },
             { "egy", "eg\u00edpcio arcaico" },
             { "raj", "rajastani" },
             { "Phag", "phags-pa" },
@@ -222,8 +222,8 @@ public class LocaleNames_pt extends OpenListResourceBundle {
             { "zun", "zunhi" },
             { "tig", "tigr\u00e9" },
             { "DZ", "Arg\u00e9lia" },
-            { "type.d0.hwidth", metaValue_type_d0_fwidth },
             { "pag", "pangasin\u00e3" },
+            { "type.d0.hwidth", "Meia largura" },
             { "pal", "p\u00e1lavi" },
             { "EA", "Ceuta e Melilla" },
             { "chb", "chibcha" },
@@ -533,7 +533,7 @@ public class LocaleNames_pt extends OpenListResourceBundle {
             { "SX", "Sint Maarten" },
             { "SY", "S\u00edria" },
             { "yao", "yao" },
-            { "SZ", "Suazil\u00e2ndia" },
+            { "SZ", "Essuat\u00edni" },
             { "arw", "arauaqui" },
             { "yap", "yapese" },
             { "TA", "Trist\u00e3o da Cunha" },
@@ -543,6 +543,7 @@ public class LocaleNames_pt extends OpenListResourceBundle {
             { "TC", "Ilhas Turcas e Caicos" },
             { "yav", "yangben" },
             { "TD", "Chade" },
+            { "Qaag", "zawgyi" },
             { "TF", "Territ\u00f3rios Franceses do Sul" },
             { "TG", "Togo" },
             { "TH", "Tail\u00e2ndia" },
@@ -618,7 +619,7 @@ public class LocaleNames_pt extends OpenListResourceBundle {
             { "was", "washo" },
             { "XA", "Pseudossotaques" },
             { "war", "waray" },
-            { "XB", "Pseudobidi" },
+            { "XB", "Pseudobidirecional" },
             { "awa", "awadhi" },
             { "061", "Polin\u00e9sia" },
             { "XK", "Kosovo" },
@@ -656,7 +657,7 @@ public class LocaleNames_pt extends OpenListResourceBundle {
             { "jmc", "machame" },
             { "type.nu.hansfin", "Algarismos financeiros chineses simplificados" },
             { "hil", "hiligaynon" },
-            { "type.nu.arabext", "Algarismos indo-ar\u00e1bicos por extenso" },
+            { "type.nu.arabext", "Algarismos indo-ar\u00e1bicos estendidos" },
             { "nus", "nuer" },
             { "dak", "dacota" },
             { "type.nu.fullwide", "Algarismos em extens\u00e3o total" },
@@ -686,7 +687,7 @@ public class LocaleNames_pt extends OpenListResourceBundle {
             { "Guru", "gurmuqui" },
             { "lua", "luba-lulua" },
             { "%%BISCAYAN", "biscainho" },
-            { "type.d0.fwidth", metaValue_type_d0_fwidth },
+            { "type.d0.fwidth", "Largura inteira" },
             { "sbp", "sangu" },
             { "lui", "luiseno" },
             { "nyn", "nyankole" },
@@ -712,6 +713,7 @@ public class LocaleNames_pt extends OpenListResourceBundle {
             { "scn", "siciliano" },
             { "aa", "afar" },
             { "ab", "abc\u00e1zio" },
+            { "Aran", "nastaliq" },
             { "ae", metaValue_ae },
             { "af", "afric\u00e2ner" },
             { "ak", "akan" },
@@ -754,7 +756,7 @@ public class LocaleNames_pt extends OpenListResourceBundle {
             { "ch", "chamorro" },
             { "%%REVISED", "ortografia revisada" },
             { "co", "corso" },
-            { "Orya", "oriya" },
+            { "Orya", metaValue_or },
             { "cr", "cree" },
             { "cs", "tcheco" },
             { "cu", "eslavo eclesi\u00e1stico" },
@@ -956,7 +958,7 @@ public class LocaleNames_pt extends OpenListResourceBundle {
             { "type.nu.armn", "Algarismos arm\u00eanios" },
             { "om", "oromo" },
             { "kaw", "kawi" },
-            { "or", "ori\u00e1" },
+            { "or", metaValue_or },
             { "os", "osseto" },
             { "kbd", "kabardiano" },
             { "mfe", "morisyen" },
@@ -1190,6 +1192,7 @@ public class LocaleNames_pt extends OpenListResourceBundle {
             { "type.nu.tamldec", "Algarismos t\u00e2mil" },
             { "krc", "karachay-balkar" },
             { "inh", "inguche" },
+            { "fa_AF", "dari" },
             { "krl", "car\u00e9lio" },
             { "efi", "efique" },
             { "key.nu", "N\u00fameros" },
