@@ -121,7 +121,7 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "AG", "Antigua \u0219i Barbuda" },
             { "type.ca.ethiopic", "calendar etiopian" },
             { "AI", "Anguilla" },
-            { "key.tz", "Fusul orar" },
+            { "key.tz", "fus orar" },
             { "AL", "Albania" },
             { "AM", "Armenia" },
             { "AO", "Angola" },
@@ -201,6 +201,7 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "DO", "Republica Dominican\u0103" },
             { "gor", "gorontalo" },
             { "got", metaValue_got },
+            { "Mtei", "meitei mayek" },
             { "zun", "zuni" },
             { "tig", "tigre" },
             { "DZ", "Algeria" },
@@ -240,13 +241,12 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "FJ", "Fiji" },
             { "FK", "Insulele Falkland" },
             { "FM", "Micronezia" },
-            { "key.va", "Varianta local\u0103" },
+            { "key.va", "variant\u0103 local\u0103" },
             { "FO", "Insulele Feroe" },
             { "Taml", metaValue_ta },
             { "FR", "Fran\u021ba" },
             { "tkl", "tokelau" },
             { "grb", "grebo" },
-            { "root", "root" },
             { "type.ca.indian", "calendar na\u021bional indian" },
             { "grc", "greac\u0103 veche" },
             { "GA", "Gabon" },
@@ -485,7 +485,7 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "type.nu.taml", "numerale tradi\u021bionale tamile" },
             { "SR", "Suriname" },
             { "SS", "Sudanul de Sud" },
-            { "ST", "Sao Tome \u0219i Principe" },
+            { "ST", "S\u00e3o Tom\u00e9 \u0219i Pr\u00edncipe" },
             { "SV", "El Salvador" },
             { "ars", "arab\u0103 najdi" },
             { "SX", "Sint-Maarten" },
@@ -501,6 +501,7 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "TC", "Insulele Turks \u0219i Caicos" },
             { "yav", "yangben" },
             { "TD", "Ciad" },
+            { "Qaag", "zawgyi" },
             { "TF", "Teritoriile Australe \u0219i Antarctice Franceze" },
             { "TG", "Togo" },
             { "TH", "Thailanda" },
@@ -577,6 +578,7 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "XK", "Kosovo" },
             { "Gujr", metaValue_gu },
             { "Zxxx", "nescris\u0103" },
+            { "Olck", "ol chiki" },
             { "wbp", "warlpiri" },
             { "YE", "Yemen" },
             { "nqo", "n\u2019ko" },
@@ -657,6 +659,7 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "scn", "sicilian\u0103" },
             { "aa", "afar" },
             { "ab", "abhaz\u0103" },
+            { "Aran", "nastaaliq" },
             { "ae", "avestan\u0103" },
             { "af", "afrikaans" },
             { "ak", "akan" },
@@ -1083,6 +1086,7 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "type.nu.tamldec", "cifre tamile" },
             { "krc", "karaceai-balkar" },
             { "inh", "ingu\u0219\u0103" },
+            { "fa_AF", "dari" },
             { "krl", "karelian\u0103" },
             { "efi", "efik" },
             { "key.nu", "numere" },
