@@ -321,7 +321,7 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "Thai", metaValue_th },
             { "MH", "\u0645\u0627\u0631\u0634\u0644 \u0680\u064a\u067d" },
             { "ale", "\u0627\u0644\u064a\u0648\u067d" },
-            { "MK", "\u0645\u064a\u0633\u064a \u068a\u0648\u0646\u064a\u0627" },
+            { "MK", "\u0634\u0645\u0627\u0644\u064a \u0645\u0642\u062f\u0648\u0646\u064a\u0627" },
             { "ML", "\u0645\u0627\u0644\u064a" },
             { "MM", "\u0645\u064a\u0627\u0646\u0645\u0627\u0631 (\u0628\u0631\u0645\u0627)" },
             { "MN", "\u0645\u0646\u06af\u0648\u0644\u064a\u0627" },
@@ -359,6 +359,7 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "OM", "\u0639\u0645\u0627\u0646" },
             { "anp", "\u0627\u0646\u062c\u064a\u06aa\u0627" },
             { "crs", "\u0633\u064a\u0633\u0644\u0648\u0627 \u06aa\u0631\u064a\u0626\u0648\u0644 \u0641\u0631\u0627\u0646\u0633\u064a" },
+            { "Xpeo", "\u0642\u062f\u064a\u0645 \u0641\u0627\u0631\u0633\u064a" },
             { "PA", "\u067e\u0646\u0627\u0645\u0627" },
             { "en_GB", "\u0628\u0631\u0637\u0627\u0646\u0648\u064a \u0627\u0646\u06af\u0631\u064a\u0632\u064a" },
             { "PE", "\u067e\u064a\u0631\u0648" },
@@ -395,7 +396,7 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "RS", "\u0633\u0631\u0628\u064a\u0627" },
             { "RU", "\u0631\u0648\u0633" },
             { "RW", "\u0631\u0648\u0627\u0646\u068a\u0627" },
-            { "SA", "\u0633\u0639\u0648\u062f\u06cc \u0639\u0631\u0628" },
+            { "SA", "\u0633\u0639\u0648\u062f\u064a \u0639\u0631\u0628" },
             { "SB", "\u0633\u0648\u0644\u0648\u0645\u0648\u0646 \u067b\u064a\u067d\u064e" },
             { "twq", "\u062a\u0633\u0627\u0648\u06aa\u064a" },
             { "011", "\u0627\u0648\u0644\u0647\u0647 \u0622\u0641\u0631\u064a\u0642\u0627" },
@@ -657,6 +658,7 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "iu", "\u0627\u0646\u0648 \u06aa\u062a\u0648\u062a" },
             { "ja", metaValue_ja },
             { "Mlym", metaValue_ml },
+            { "Sarb", "\u0642\u062f\u064a\u0645 \u068f\u0627\u06a9\u06bb\u064a \u0639\u0631\u0628\u064a" },
             { "sma", "\u068f\u06a9\u06bb \u0633\u0627\u0645\u064a" },
             { "jv", "\u062c\u0627\u0648\u0646\u064a\u0632" },
             { "mad", "\u0645\u062f\u0648\u0631\u0627\u0626\u064a" },
@@ -683,6 +685,7 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "kw", "\u06aa\u0648\u0631\u0646\u0634" },
             { "ky", "\u06aa\u0631\u063a\u064a\u0632" },
             { "snk", "\u0633\u0648\u0646\u064a\u0646\u06aa\u064a" },
+            { "Mult", "\u0645\u0644\u062a\u0627\u0646\u064a" },
             { "la", metaValue_la },
             { "lb", "\u0644\u06af\u0632\u0645\u0628\u0631\u06af" },
             { "type.nu.mlym", "\u0645\u0644\u064a\u0627\u0644\u0645 \u0639\u062f\u062f" },
@@ -740,7 +743,7 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "pl", "\u067e\u0648\u0644\u0634" },
             { "type.ca.dangi", "\u062f\u0627\u0646\u06af\u064a \u06aa\u0626\u0644\u064a\u0646\u068a\u0631" },
             { "ps", "\u067e\u0634\u062a\u0648" },
-            { "pt", "\u067e\u0631\u062a\u06af\u0627\u0644\u064a" },
+            { "pt", "\u067e\u0648\u0631\u067d\u06af\u0644\u064a\u0632" },
             { "key.co", "\u062a\u0631\u062a\u064a\u0628 \u0687\u0627\u0646\u067d\u064a" },
             { "pt_BR", "\u0628\u0631\u0627\u0632\u064a\u0644\u064a \u067e\u0631\u062a\u06af\u0627\u0644\u064a" },
             { "kcg", "\u062a\u064a\u0627\u067e" },
@@ -789,6 +792,7 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "ss", "\u0633\u0648\u0627\u062a\u064a" },
             { "type.cf.account", "\u0627\u06aa\u0627\u0626\u0648\u0646\u067d\u0646\u06af \u0633\u06aa\u0648 \u0641\u0627\u0631\u0645\u064a\u067d" },
             { "st", "\u068f\u06a9\u06bb \u0633\u0648\u067f\u064a" },
+            { "Java", "\u062c\u0627\u0648\u0627\u0646\u064a\u0632" },
             { "su", "\u0633\u0648\u068a\u0627\u0646\u064a" },
             { "sv", "\u0633\u0648\u064a\u068a\u0646\u064a" },
             { "sw", "\u0633\u0648\u0627\u062d\u064a\u0644\u064a" },
@@ -823,6 +827,7 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "155", "\u0627\u0648\u0644\u0647\u0647 \u064a\u0648\u0631\u067e" },
             { "ug", "\u064a\u0648\u063a\u0648\u0631" },
             { "Kore", metaValue_ko },
+            { "Ital", "\u0642\u062f\u064a\u0645 \u0627\u0637\u0627\u0644\u0648\u064a" },
             { "Zyyy", "\u06aa\u0627\u0645\u0646" },
             { "uk", "\u064a\u0648\u06aa\u0631\u0627\u0646\u064a" },
             { "ur", "\u0627\u0631\u062f\u0648" },
@@ -883,6 +888,7 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "type.nu.tamldec", "\u062a\u0627\u0645\u0644 \u0639\u062f\u062f" },
             { "krc", "\u06aa\u0631\u0627\u0686\u064a \u0628\u0627\u0644\u06aa\u0631" },
             { "inh", "\u0627\u0646\u06af\u0634" },
+            { "fa_AF", "\u062f\u0631\u064a" },
             { "krl", "\u06aa\u0631\u064a\u0644\u0626\u064a\u0646" },
             { "efi", "\u0627\u064a\u0641\u06aa" },
             { "key.nu", "\u0627\u0646\u06af" },
