@@ -97,6 +97,7 @@ public class LocaleNames_si extends OpenListResourceBundle {
             { "mwl", "\u0db8\u0dd2\u0dbb\u0db1\u0dca\u0da9\u0dd3\u0dc3\u0dca" },
             { "Zsym", "\u0dc3\u0d82\u0d9a\u0dda\u0dad" },
             { "Zsye", "\u0d89\u0db8\u0ddc\u0da2\u0dd2" },
+            { "ccp", "\u0da0\u0d9a\u0dca\u0db8\u0dcf" },
             { "tem", "\u0da7\u0dd2\u0db8\u0dca\u0db1\u0dd9" },
             { "teo", "\u0da7\u0dd9\u0dc3\u0ddd" },
             { "rap", "\u0dbb\u0db4\u0db1\u0dd4\u0dba\u0dd2" },
@@ -152,7 +153,7 @@ public class LocaleNames_si extends OpenListResourceBundle {
             { "CA", "\u0d9a\u0dd0\u0db1\u0da9\u0dcf\u0dc0" },
             { "CC", "\u0d9a\u0ddc\u0d9a\u0ddd\u0dc3\u0dca \u0daf\u0dd6\u0db4\u0dad\u0dca" },
             { "mzn", "\u0db8\u0dd0\u0dc3\u0db1\u0dca\u0da9\u0dbb\u0db1\u0dd2" },
-            { "CD", "\u0d9a\u0ddc\u0d82\u0d9c\u0ddc - \u0d9a\u0dd2\u0db1\u0dca\u0dc1\u0dcf\u0dc3\u0dcf" },
+            { "CD", "\u0d9a\u0ddc\u0d82\u0d9c\u0ddd\u0dc0 (\u0da9\u0dd3\u0d86\u0dbb\u0dca\u0dc3\u0dd3)" },
             { "CF", "\u0db8\u0db0\u0dca\u200d\u0dba\u0db8 \u0d85\u0db4\u0dca\u200d\u0dbb\u0dd2\u0d9a\u0dcf\u0db1\u0dd4 \u0da2\u0db1\u0dbb\u0da2\u0dba" },
             { "CG", "\u0d9a\u0ddc\u0d82\u0d9c\u0ddc - \u0db6\u0dca\u200d\u0dbb\u0dc3\u0dcf\u0dc0\u0dd2\u0dbd\u0dca" },
             { "CH", "\u0dc3\u0dca\u0dc0\u0dd2\u0dc3\u0dca\u0da7\u0dbb\u0dca\u0dbd\u0db1\u0dca\u0dad\u0dba" },
@@ -323,12 +324,12 @@ public class LocaleNames_si extends OpenListResourceBundle {
             { "Thai", metaValue_th },
             { "MH", "\u0db8\u0dcf\u0dc2\u0dbd\u0dca \u0daf\u0dd6\u0db4\u0dad\u0dca" },
             { "ale", "\u0d87\u0dbd\u0dd4\u0d91\u0da7\u0dca" },
-            { "MK", "\u0db8\u0dd0\u0dc3\u0dd2\u0da9\u0ddd\u0db1\u0dd2\u0dba\u0dcf\u0dc0" },
+            { "MK", "\u0d8b\u0dad\u0dd4\u0dbb\u0dd4 \u0db8\u0dd0\u0dc3\u0dd2\u0da9\u0ddd\u0db1\u0dd2\u0dba\u0dcf\u0dc0" },
             { "ML", "\u0db8\u0dcf\u0dbd\u0dd2" },
             { "MM", "\u0db8\u0dd2\u0dba\u0db1\u0dca\u0db8\u0dcf\u0dbb\u0dba (\u0db6\u0dd4\u0dbb\u0dd4\u0db8\u0dba)" },
             { "MN", "\u0db8\u0ddc\u0db1\u0dca\u0d9c\u0ddd\u0dbd\u0dd2\u0dba\u0dcf\u0dc0" },
             { "new", "\u0db1\u0dd9\u0dc0\u0dcf\u0dbb\u0dd2" },
-            { "MO", "\u0db8\u0d9a\u0dcf\u0dc0\u0dd4 \u0da0\u0dd3\u0db1 \u0dc0\u0dd2\u0dc1\u0dda\u0dc2 \u0db4\u0dbb\u0dd2\u0db4\u0dcf\u0dbd\u0db1 \u0d9a\u0dbd\u0dcf\u0db4\u0dba" },
+            { "MO", "\u0db8\u0d9a\u0dcf\u0dc0\u0dd4 \u0d91\u0dc3\u0dca\u0d92\u0d86\u0dbb\u0dca" },
             { "MP", "\u0d8b\u0dad\u0dd4\u0dbb\u0dd4 \u0db8\u0dbb\u0dd2\u0dba\u0dcf\u0db1\u0dcf \u0daf\u0dd6\u0db4\u0dad\u0dca" },
             { "MQ", "\u0db8\u0dbb\u0dca\u0da7\u0dd2\u0db1\u0dd2\u0d9a\u0dca" },
             { "MR", "\u0db8\u0ddc\u0dbb\u0dd2\u0da7\u0dda\u0db1\u0dd2\u0dba\u0dcf\u0dc0" },
@@ -430,7 +431,7 @@ public class LocaleNames_si extends OpenListResourceBundle {
             { "SV", "\u0d91\u0dbd\u0dca \u0dc3\u0dd0\u0dbd\u0dca\u0dc0\u0daf\u0ddd\u0dbb\u0dba" },
             { "SX", "\u0dc1\u0dcf\u0db1\u0dca\u0dad \u0db8\u0dcf\u0dbb\u0dca\u0da7\u0dd9\u0db1\u0dca" },
             { "SY", "\u0dc3\u0dd2\u0dbb\u0dd2\u0dba\u0dcf\u0dc0" },
-            { "SZ", "\u0dc3\u0dca\u0dc0\u0dcf\u0dc3\u0dd2\u0dbd\u0db1\u0dca\u0dad\u0dba" },
+            { "SZ", "\u0d91\u0dc3\u0dca\u0dc0\u0dcf\u0da7\u0dd2\u0db1\u0dd2" },
             { "TA", "\u0da7\u0dca\u200d\u0dbb\u0dd2\u0dc3\u0dca\u0da7\u0db1\u0dca \u0daf \u0d9a\u0dd4\u0db1\u0dca\u0dc4\u0dcf" },
             { "asa", "\u0d85\u0dc3\u0dd4" },
             { "type.ms.ussystem", "\u0d91\u0da2 \u0db8\u0dd2\u0db1\u0dd4\u0db8\u0dca \u0d9a\u0dca\u200d\u0dbb\u0db8\u0dba" },
@@ -495,7 +496,9 @@ public class LocaleNames_si extends OpenListResourceBundle {
             { "wae", "\u0dc0\u0ddc\u0dbd\u0dca\u0dc3\u0dbb\u0dca" },
             { "WS", "\u0dc3\u0dd0\u0db8\u0ddd\u0dc0\u0dcf" },
             { "wal", "\u0dc0\u0ddc\u0dbd\u0dd9\u0da7\u0dca\u0da7" },
+            { "XA", "\u0dc0\u0dca\u200d\u0dba\u0dcf\u0da2-\u0d8b\u0da0\u0dca\u0da0\u0dcf\u0dbb\u0dab" },
             { "war", "\u0dc0\u0ddc\u0dbb\u0dd9\u0dba\u0dca" },
+            { "XB", "\u0dc0\u0dca\u200d\u0dba\u0dcf\u0da2-\u0db6\u0dd2\u0da9\u0dd2" },
             { "awa", "\u0d85\u0dc0\u0daf\u0dd2" },
             { "061", "\u0db4\u0ddc\u0dbd\u0dd2\u0db1\u0dd3\u0dc3\u0dd2\u0dba\u0dcf\u0dc0" },
             { "XK", "\u0d9a\u0ddc\u0dc3\u0ddd\u0dc0\u0ddd" },
@@ -894,6 +897,7 @@ public class LocaleNames_si extends OpenListResourceBundle {
             { "type.nu.tamldec", "\u0daf\u0dd9\u0db8\u0dc5 \u0d89\u0dbd\u0d9a\u0dca\u0d9a\u0db8\u0dca" },
             { "krc", "\u0d9a\u0dbb\u0db1\u0dca\u0da0\u0dd2-\u0db6\u0dcf\u0d9a\u0dbb\u0dca" },
             { "inh", "\u0d89\u0db1\u0dca\u0d9c\u0dd4\u0dc2\u0dca" },
+            { "fa_AF", "\u0da9\u0dcf\u0dbb\u0dd2" },
             { "krl", "\u0d9a\u0dd0\u0dbb\u0dd9\u0dbd\u0dd2\u0dba\u0db1\u0dca" },
             { "efi", "\u0d91\u0dc6\u0dd2\u0d9a\u0dca" },
             { "key.nu", "\u0d89\u0dbd\u0d9a\u0dca\u0d9a\u0db8\u0dca" },
