@@ -322,7 +322,7 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "SV", "Salv\u00e1dor" },
             { "SX", "Sv\u00e4t\u00fd Martin (hol.)" },
             { "SY", "S\u00fdria" },
-            { "SZ", "Svazijsko" },
+            { "SZ", "Eswatini" },
             { "TA", "Tristan da Cunha" },
             { "TC", "Turks a Caicos" },
             { "TD", "\u010cad" },
@@ -356,6 +356,8 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "VU", "Vanuatu" },
             { "WF", "Wallis a Futuna" },
             { "WS", "Samoa" },
+            { "XA", "falo\u0161n\u00e1 diakritika" },
+            { "XB", "obr\u00e1tenie sprava do\u013eava" },
             { "XK", "Kosovo" },
             { "YE", "Jemen" },
             { "YT", "Mayotte" },
@@ -594,6 +596,7 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "car", "karib\u010dina" },
             { "cay", "kajug\u010dina" },
             { "cch", "atsam" },
+            { "ccp", "\u010dakma" },
             { "ceb", "cebu\u00e1n\u010dina" },
             { "cgg", "kiga" },
             { "chb", "\u010dib\u010da" },
@@ -865,11 +868,12 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "zap", "zapot\u00e9\u010dtina" },
             { "zbl", "syst\u00e9m Bliss" },
             { "zen", "zenaga" },
-            { "zgh", "tuareg\u010dina (\u0161tandardn\u00e1 marock\u00e1)" },
+            { "zgh", "tuareg\u010dina (marock\u00e1 \u0161tandardn\u00e1)" },
             { "zun", "zuni\u0161tina" },
             { "zxx", "bez jazykov\u00e9ho obsahu" },
             { "zza", "zaza" },
             { "Arab", "arabsk\u00e9" },
+            { "Aran", "nastaliq" },
             { "Armn", "arm\u00e9nske" },
             { "Bali", "balijsk\u00fd" },
             { "Beng", "beng\u00e1lske" },
@@ -906,9 +910,12 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "Maya", "maysk\u00e9 hieroglyfy" },
             { "Mlym", "malaj\u00e1lamske" },
             { "Mong", "mongolsk\u00e9" },
+            { "Mtei", "mejtej majek (manipursk\u00e9)" },
             { "Mymr", "barmsk\u00e9" },
+            { "Olck", "sant\u00e1lske (ol chiki)" },
             { "Orya", "ur\u00edjske" },
             { "Osma", "osmansk\u00fd" },
+            { "Qaag", "zawgyi" },
             { "Runr", "Runov\u00e9 p\u00edsmo" },
             { "Sinh", "sinh\u00e1lske" },
             { "Taml", "tamilsk\u00e9" },
@@ -931,6 +938,7 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "en_US", "angli\u010dtina (americk\u00e1)" },
             { "es_ES", "\u0161paniel\u010dina (eur\u00f3pska)" },
             { "es_MX", "\u0161paniel\u010dina (mexick\u00e1)" },
+            { "fa_AF", "dar\u00edj\u010dina" },
             { "fr_CA", "franc\u00faz\u0161tina (kanadsk\u00e1)" },
             { "fr_CH", "franc\u00faz\u0161tina (\u0161vaj\u010diarska)" },
             { "nl_BE", "fl\u00e1m\u010dina" },
@@ -948,8 +956,8 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "key.lb", "\u0161t\u00fdl koncov riadka" },
             { "key.ms", "mern\u00e1 s\u00fastava" },
             { "key.nu", "\u010d\u00edsla" },
-            { "key.tz", "\u010casov\u00e9 p\u00e1smo" },
-            { "key.va", "Variant miestneho nastavenia" },
+            { "key.tz", "\u010dasov\u00e9 p\u00e1smo" },
+            { "key.va", "variant miestneho nastavenia" },
             { "nds_NL", "doln\u00e1 sa\u0161tina" },
             { "zh_Hans", "\u010d\u00edn\u0161tina (zjednodu\u0161en\u00e1)" },
             { "zh_Hant", "\u010d\u00edn\u0161tina (tradi\u010dn\u00e1)" },
