@@ -100,7 +100,7 @@ public class LocaleNames_sr_Latn extends OpenListResourceBundle {
             { "151", "Isto\u010dna Evropa" },
             { "154", "Severna Evropa" },
             { "155", "Zapadna Evropa" },
-            { "202", "Afrika ju\u017eno od Sahare" },
+            { "202", "Podsaharska Afrika" },
             { "419", "Latinska Amerika" },
             { "AC", "Ostrvo Asension" },
             { "AD", "Andora" },
@@ -175,7 +175,7 @@ public class LocaleNames_sr_Latn extends OpenListResourceBundle {
             { "ER", "Eritreja" },
             { "ES", "\u0160panija" },
             { "ET", "Etiopija" },
-            { "EU", "Evropska Unija" },
+            { "EU", "Evropska unija" },
             { "EZ", "Evrozona" },
             { "FI", "Finska" },
             { "FJ", "Fid\u017ei" },
@@ -356,8 +356,8 @@ public class LocaleNames_sr_Latn extends OpenListResourceBundle {
             { "VU", "Vanuatu" },
             { "WF", "Valis i Futuna" },
             { "WS", "Samoa" },
-            { "XA", "XA" },
-            { "XB", "XB" },
+            { "XA", "Pseudoakcenti" },
+            { "XB", "Pseudobidi" },
             { "XK", "Kosovo" },
             { "YE", "Jemen" },
             { "YT", "Majot" },
@@ -587,7 +587,7 @@ public class LocaleNames_sr_Latn extends OpenListResourceBundle {
             { "cad", "kado" },
             { "car", "karipski" },
             { "cch", "atsam" },
-            { "ccp", "ccp" },
+            { "ccp", "\u010dakma" },
             { "ceb", "sebuanski" },
             { "cgg", "\u010diga" },
             { "chb", "\u010dip\u010da" },
@@ -613,7 +613,7 @@ public class LocaleNames_sr_Latn extends OpenListResourceBundle {
             { "din", "dinka" },
             { "dje", "zarma" },
             { "doi", "dogri" },
-            { "dsb", "donji lu\u017ei\u010dkosrpski" },
+            { "dsb", "donjolu\u017ei\u010dkosrpski" },
             { "dua", "duala" },
             { "dum", "srednjeholandski" },
             { "dyo", "d\u017eola fonji" },
@@ -657,7 +657,7 @@ public class LocaleNames_sr_Latn extends OpenListResourceBundle {
             { "hil", "hiligajnonski" },
             { "hit", "hetitski" },
             { "hmn", "hmon\u0161ki" },
-            { "hsb", "gornji lu\u017ei\u010dkosrpski" },
+            { "hsb", "gornjolu\u017ei\u010dkosrpski" },
             { "hup", "hupa" },
             { "iba", "ibanski" },
             { "ibb", "ibibio" },
@@ -996,6 +996,7 @@ public class LocaleNames_sr_Latn extends OpenListResourceBundle {
             { "en_GB", "engleski (Velika Britanija)" },
             { "en_US", "engleski (Sjedinjene Ameri\u010dke Dr\u017eave)" },
             { "es_ES", "\u0161panski (Evropa)" },
+            { "fa_AF", "dari" },
             { "nl_BE", "flamanski" },
             { "pt_PT", "portugalski (Portugal)" },
             { "ro_MD", "moldavski" },
