@@ -95,6 +95,7 @@ public class LocaleNames_sw extends OpenListResourceBundle {
             { "mwl", "Kimirandi" },
             { "Zsym", "Alama" },
             { "Zsye", "Emoji" },
+            { "ccp", "Kichakma" },
             { "egy", "Kimisri" },
             { "tem", "Kitemne" },
             { "teo", "Kiteso" },
@@ -109,7 +110,7 @@ public class LocaleNames_sw extends OpenListResourceBundle {
             { "AG", "Antigua na Barbuda" },
             { "type.ca.ethiopic", "Kalenda ya Kiethiopia" },
             { "AI", "Anguilla" },
-            { "key.tz", "Ukanda Saa" },
+            { "key.tz", "Saa za Eneo" },
             { "AL", "Albania" },
             { "AM", "Armenia" },
             { "AO", "Angola" },
@@ -206,7 +207,7 @@ public class LocaleNames_sw extends OpenListResourceBundle {
             { "ET", "Ethiopia" },
             { "EU", "Umoja wa Ulaya" },
             { "type.ca.gregorian", "Kalenda ya Kigregori" },
-            { "EZ", "EZ" },
+            { "EZ", "Jumuiya ya Ulaya" },
             { "chy", "Kicheyeni" },
             { "type.nu.gujr", "Nambari za Kigujarati" },
             { "ady", "Kiadyghe" },
@@ -214,7 +215,7 @@ public class LocaleNames_sw extends OpenListResourceBundle {
             { "FJ", "Fiji" },
             { "FK", "Visiwa vya Falkland" },
             { "FM", "Micronesia" },
-            { "key.va", "Tofauti ya Mandhari" },
+            { "key.va", "Lahaja za Lugha" },
             { "FO", "Visiwa vya Faroe" },
             { "Taml", "Kitamil" },
             { "FR", "Ufaransa" },
@@ -327,12 +328,12 @@ public class LocaleNames_sw extends OpenListResourceBundle {
             { "MH", "Visiwa vya Marshall" },
             { "ale", "Kialeut" },
             { "type.nu.vaii", "Dijiti za Vai" },
-            { "MK", "Macedonia" },
+            { "MK", "Masedonia ya Kaskazini" },
             { "ML", "Mali" },
             { "MM", "Myanmar (Burma)" },
             { "MN", "Mongolia" },
             { "new", "Kinewari" },
-            { "MO", "Macau SAR China" },
+            { "MO", "Makau SAR China" },
             { "MP", "Visiwa vya Mariana vya Kaskazini" },
             { "MQ", "Martinique" },
             { "MR", "Moritania" },
@@ -348,7 +349,7 @@ public class LocaleNames_sw extends OpenListResourceBundle {
             { "MY", "Malesia" },
             { "MZ", "Msumbiji" },
             { "NA", "Namibia" },
-            { "202", "Afrika Kusine mwa Jangwa la Sahara" },
+            { "202", "Afrika Kusini mwa Jangwa la Sahara" },
             { "type.ca.hebrew", "Kalenda ya Kiebrania" },
             { "type.co.dictionary", "Mpangilio wa Kamusi" },
             { "NC", "New Caledonia" },
@@ -510,7 +511,9 @@ public class LocaleNames_sw extends OpenListResourceBundle {
             { "wae", "Kiwalser" },
             { "WS", "Samoa" },
             { "wal", "Kiwolaytta" },
+            { "XA", "Lafudhi Bandia" },
             { "war", "Kiwaray" },
+            { "XB", "Lafudhi Bidi" },
             { "awa", "Kiawadhi" },
             { "061", "Polynesia" },
             { "XK", "Kosovo" },
@@ -636,13 +639,14 @@ public class LocaleNames_sw extends OpenListResourceBundle {
             { "ee", "Kiewe" },
             { "bfd", "Kibafut" },
             { "type.lb.normal", "Mtindo wa Kawaida wa Kukata Mstari" },
+            { "ro_MD", "Kimoldova cha Romania" },
             { "el", metaValue_el },
             { "en", "Kiingereza" },
             { "eo", "Kiesperanto" },
             { "type.co.big5han", "Mpangilio wa Kichina cha Jadi - Big5" },
             { "es", "Kihispania" },
             { "et", "Kiestonia" },
-            { "Hanb", "Hanb" },
+            { "Hanb", "Kihan chenye Bopomofo" },
             { "eu", "Kibaski" },
             { "Hang", "Kihangul" },
             { "shi", "Kitachelhit" },
