@@ -91,6 +91,7 @@ public class LocaleNames_ta extends OpenListResourceBundle {
         final String metaValue_te = "\u0ba4\u0bc6\u0bb2\u0bc1\u0b99\u0bcd\u0b95\u0bc1";
         final String metaValue_th = "\u0ba4\u0bbe\u0baf\u0bcd";
         final String metaValue_bug = "\u0baa\u0bc1\u0b95\u0bbf\u0ba9\u0bc0\u0bb8\u0bcd";
+        final String metaValue_ccp = "\u0b9a\u0b95\u0bcd\u0bae\u0bbe";
         final String metaValue_cop = "\u0b95\u0bbe\u0baa\u0bcd\u0b9f\u0bbf\u0b95\u0bcd";
         final String metaValue_got = "\u0b95\u0bcb\u0ba4\u0bbf\u0b95\u0bcd";
         final String metaValue_nqo = "\u0b8e\u0ba9\u0bcd\u2018\u0b95\u0bcb";
@@ -106,6 +107,7 @@ public class LocaleNames_ta extends OpenListResourceBundle {
             { "mwr", "\u0bae\u0bbe\u0bb0\u0bcd\u0bb5\u0bbe\u0bb0\u0bbf" },
             { "Tagb", "\u0ba4\u0b95\u0bcb\u0bb5\u0bbe\u0ba9\u0bbe" },
             { "Zsye", "\u0b8e\u0bae\u0bcb\u0b9c\u0bbf" },
+            { "ccp", metaValue_ccp },
             { "egy", "\u0baa\u0ba3\u0bcd\u0b9f\u0bc8\u0baf \u0b8e\u0b95\u0bbf\u0baa\u0bcd\u0ba4\u0bbf\u0baf\u0ba9\u0bcd" },
             { "raj", "\u0bb0\u0bbe\u0b9c\u0bb8\u0bcd\u0ba4\u0bbe\u0ba9\u0bbf" },
             { "Phag", "\u0baa\u0b95\u0bcd\u0bb8\u0bcd-\u0baa\u0bbe" },
@@ -139,7 +141,7 @@ public class LocaleNames_ta extends OpenListResourceBundle {
             { "AX", "\u0b86\u0bb2\u0ba8\u0bcd\u0ba4\u0bc1 \u0ba4\u0bc0\u0bb5\u0bc1\u0b95\u0bb3\u0bcd" },
             { "AZ", "\u0b85\u0b9a\u0bb0\u0bcd\u0baa\u0bc8\u0b9c\u0bbe\u0ba9\u0bcd" },
             { "BA", "\u0baa\u0bcb\u0bb8\u0bcd\u0ba9\u0bbf\u0baf\u0bbe & \u0bb9\u0bc6\u0bb0\u0bcd\u0bb8\u0b95\u0bcb\u0bb5\u0bbf\u0ba9\u0bbe" },
-            { "BB", "\u0baa\u0bbe\u0bb0\u0bcd\u0baa\u0b9f\u0bcb\u0bb8\u0bcd" },
+            { "BB", "\u0baa\u0bbe\u0bb0\u0bcd\u0baa\u0b9f\u0bbe\u0bb8\u0bcd" },
             { "ceb", "\u0b9a\u0bc6\u0baa\u0bc1\u0bb5\u0bbe\u0ba9\u0bcb" },
             { "BD", "\u0baa\u0b99\u0bcd\u0b95\u0bb3\u0bbe\u0ba4\u0bc7\u0bb7\u0bcd" },
             { "kum", "\u0b95\u0bc1\u0bae\u0bcd\u0b87\u0b95\u0bcd" },
@@ -161,7 +163,7 @@ public class LocaleNames_ta extends OpenListResourceBundle {
             { "BS", "\u0baa\u0bb9\u0bbe\u0bae\u0bbe\u0bb8\u0bcd" },
             { "xog", "\u0b9a\u0bcb\u0b95\u0bbe" },
             { "BT", "\u0baa\u0bc2\u0b9f\u0bbe\u0ba9\u0bcd" },
-            { "BV", "\u0baa\u0bca\u0bb5\u0bc7\u0b9f\u0bcd \u0ba4\u0bc0\u0bb5\u0bc1\u0b95\u0bb3\u0bcd" },
+            { "BV", "\u0baa\u0bca\u0bb5\u0bc7\u0b9f\u0bcd \u0ba4\u0bc0\u0bb5\u0bc1" },
             { "BW", "\u0baa\u0bcb\u0b9f\u0bcd\u0bb8\u0bcd\u0bb5\u0bbe\u0ba9\u0bbe" },
             { "BY", "\u0baa\u0bc6\u0bb2\u0bbe\u0bb0\u0bb8\u0bcd" },
             { "BZ", "\u0baa\u0bc6\u0bb2\u0bbf\u0bb8\u0bcd" },
@@ -293,7 +295,7 @@ public class LocaleNames_ta extends OpenListResourceBundle {
             { "HK", "\u0bb9\u0bbe\u0b99\u0bcd\u0b95\u0bbe\u0b99\u0bcd \u0b8e\u0bb8\u0bcd\u0b8f\u0b86\u0bb0\u0bcd \u0b9a\u0bc0\u0ba9\u0bbe" },
             { "HM", "\u0bb9\u0bc7\u0bb0\u0bcd\u0b9f\u0bcd \u0bae\u0bb1\u0bcd\u0bb1\u0bc1\u0bae\u0bcd \u0bae\u0bc6\u0b95\u0bcd\u0b9f\u0bca\u0ba9\u0bbe\u0bb2\u0bcd\u0b9f\u0bc1 \u0ba4\u0bc0\u0bb5\u0bc1\u0b95\u0bb3\u0bcd" },
             { "HN", "\u0bb9\u0bcb\u0ba3\u0bcd\u0b9f\u0bc2\u0bb0\u0bbe\u0bb8\u0bcd" },
-            { "HR", "\u0b95\u0bc1\u0bb0\u0bc7\u0bb7\u0bbf\u0baf\u0bbe" },
+            { "HR", "\u0b95\u0bc1\u0bb0\u0bcb\u0bb7\u0bbf\u0baf\u0bbe" },
             { "agq", "\u0b85\u0b95\u0bc6\u0bae\u0bcd" },
             { "gsw", "\u0bb8\u0bcd\u0bb5\u0bbf\u0bb8\u0bcd \u0b9c\u0bc6\u0bb0\u0bcd\u0bae\u0ba9\u0bcd" },
             { "type.ca.islamic-umalqura", "\u0b87\u0bb8\u0bcd\u0bb2\u0bbe\u0bae\u0bbf\u0baf \u0ba8\u0bbe\u0bb3\u0bcd\u0b95\u0bbe\u0b9f\u0bcd\u0b9f\u0bbf (\u0b89\u0bae\u0bcd-\u0b85\u0bb2\u0bcd-\u0b95\u0bc1\u0bb0\u0bbe)" },
@@ -388,7 +390,7 @@ public class LocaleNames_ta extends OpenListResourceBundle {
             { "MH", "\u0bae\u0bbe\u0bb0\u0bcd\u0bb7\u0bb2\u0bcd \u0ba4\u0bc0\u0bb5\u0bc1\u0b95\u0bb3\u0bcd" },
             { "ale", "\u0b85\u0bb2\u0bc2\u0b9f\u0bcd" },
             { "type.nu.vaii", "\u0bb5\u0bc8 \u0b8e\u0ba3\u0bcd\u0b95\u0bb3\u0bcd" },
-            { "MK", "\u0bae\u0bbe\u0b9a\u0bbf\u0b9f\u0bcb\u0ba9\u0bbf\u0baf\u0bbe" },
+            { "MK", "\u0bb5\u0b9f\u0b95\u0bcd\u0b95\u0bc1 \u0bae\u0bbe\u0b9a\u0bbf\u0b9f\u0bcb\u0ba9\u0bbf\u0baf\u0bbe" },
             { "ML", "\u0bae\u0bbe\u0bb2\u0bbf" },
             { "MM", "\u0bae\u0bbf\u0baf\u0bbe\u0ba9\u0bcd\u0bae\u0bbe\u0bb0\u0bcd (\u0baa\u0bb0\u0bcd\u0bae\u0bbe)" },
             { "MN", "\u0bae\u0b99\u0bcd\u0b95\u0bcb\u0bb2\u0bbf\u0baf\u0bbe" },
@@ -519,7 +521,7 @@ public class LocaleNames_ta extends OpenListResourceBundle {
             { "SX", "\u0b9a\u0bbf\u0ba9\u0bcd\u0b9f\u0bcd \u0bae\u0bbe\u0bb0\u0bcd\u0b9f\u0bc6\u0ba9\u0bcd" },
             { "SY", "\u0b9a\u0bbf\u0bb0\u0bbf\u0baf\u0bbe" },
             { "yao", "\u0baf\u0bbe\u0bb5\u0bcd" },
-            { "SZ", "\u0bb8\u0bcd\u0bb5\u0bbe\u0bb8\u0bbf\u0bb2\u0bbe\u0ba8\u0bcd\u0ba4\u0bc1" },
+            { "SZ", "\u0b8e\u0bb8\u0bcd\u0bb5\u0bbe\u0b9f\u0bcd\u0b9f\u0bc0\u0ba9\u0bbf" },
             { "arw", "\u0b85\u0bb0\u0bbe\u0bb5\u0bbe\u0b95\u0bcd" },
             { "yap", "\u0baf\u0bbe\u0baa\u0bc7\u0b9a\u0bc7" },
             { "TA", "\u0b9f\u0bbf\u0bb0\u0bbf\u0bb8\u0bcd\u0b9f\u0ba9\u0bcd \u0b9f\u0bbe \u0b95\u0bc1\u0ba9\u0bcd\u0bb9\u0bbe" },
@@ -535,7 +537,7 @@ public class LocaleNames_ta extends OpenListResourceBundle {
             { "TJ", "\u0ba4\u0b9c\u0bbf\u0b95\u0bbf\u0bb8\u0bcd\u0ba4\u0bbe\u0ba9\u0bcd" },
             { "029", "\u0b95\u0bb0\u0bc0\u0baa\u0bbf\u0baf\u0ba9\u0bcd" },
             { "TK", "\u0b9f\u0bcb\u0b95\u0bc7\u0bb2\u0bcb" },
-            { "TL", "\u0ba4\u0bc8\u0bae\u0bc2\u0bb0\u0bcd-\u0bb2\u0bc6\u0bb8\u0bcd\u0ba4\u0bc7" },
+            { "TL", "\u0ba4\u0bbf\u0bae\u0bcb\u0bb0\u0bcd-\u0bb2\u0bc6\u0bb8\u0bcd\u0ba4\u0bc7" },
             { "ybb", "\u0baf\u0bc6\u0bae\u0bcd\u0baa\u0bbe" },
             { "type.co.searchjl", "\u0bb9\u0b99\u0bcd\u0b95\u0bc1\u0bb2\u0bcd \u0bae\u0bc1\u0ba4\u0ba9\u0bcd\u0bae\u0bc8 \u0bae\u0bc6\u0baf\u0bcd\u0baf\u0bc6\u0bb4\u0bc1\u0ba4\u0bcd\u0ba4\u0bbf\u0ba9\u0bcd\u0baa\u0b9f\u0bbf \u0ba4\u0bc7\u0b9f\u0bc1" },
             { "TM", "\u0ba4\u0bc1\u0bb0\u0bcd\u0b95\u0bcd\u0bae\u0bc6\u0ba9\u0bbf\u0bb8\u0bcd\u0ba4\u0bbe\u0ba9\u0bcd" },
@@ -598,7 +600,9 @@ public class LocaleNames_ta extends OpenListResourceBundle {
             { "WS", "\u0b9a\u0bae\u0bcb\u0bb5\u0bbe" },
             { "wal", "\u0bb5\u0bcb\u0bb2\u0bbe\u0baf\u0bcd\u0b9f\u0bcd\u0b9f\u0bbe" },
             { "was", "\u0bb5\u0bbe\u0bb7\u0bcb" },
+            { "XA", "\u0baa\u0bcb\u0bb2\u0bbf \u0b89\u0b9a\u0bcd\u0b9a\u0bb0\u0bbf\u0baa\u0bcd\u0baa\u0bc1\u0b95\u0bb3\u0bcd" },
             { "war", "\u0bb5\u0bbe\u0bb0\u0bc7" },
+            { "XB", "\u0baa\u0bcb\u0bb2\u0bbf \u0baa\u0bc0\u0b9f\u0bbf" },
             { "awa", "\u0b85\u0bb5\u0ba4\u0bbf" },
             { "061", "\u0baa\u0bbe\u0bb2\u0bbf\u0ba9\u0bc7\u0bb7\u0bbf\u0baf\u0bbe" },
             { "XK", "\u0b95\u0bca\u0b9a\u0bcb\u0bb5\u0bcb" },
@@ -705,7 +709,7 @@ public class LocaleNames_ta extends OpenListResourceBundle {
             { "Linb", "\u0bb2\u0bbf\u0ba9\u0bbf\u0baf\u0bb0\u0bcd \u0baa\u0bbf" },
             { "sdh", "\u0ba4\u0bc6\u0bb1\u0bcd\u0b95\u0bc1 \u0b95\u0bc1\u0bb0\u0bcd\u0ba4\u0bbf\u0bb7\u0bcd" },
             { "ay", "\u0b85\u0baf\u0bcd\u0bae\u0bb0\u0bbe" },
-            { "az", "\u0b85\u0bb8\u0bb0\u0bcd\u0baa\u0bc8\u0b9c\u0bbe\u0ba9\u0bbf" },
+            { "az", "\u0b85\u0b9a\u0bb0\u0bcd\u0baa\u0bc8\u0b9c\u0bbe\u0ba9\u0bbf" },
             { "ba", "\u0baa\u0bb7\u0bcd\u0b95\u0bbf\u0bb0\u0bcd" },
             { "type.co.unihan", "\u0bb0\u0bc7\u0b9f\u0bbf\u0baf\u0ba9\u0bcd \u0bb8\u0bcd\u0b9f\u0bcd\u0bb0\u0bcb\u0b95\u0bcd \u0bb5\u0bb0\u0bbf\u0b9a\u0bc8 \u0bae\u0bc1\u0bb1\u0bc8" },
             { "be", "\u0baa\u0bc6\u0bb2\u0bbe\u0bb0\u0bc1\u0bb7\u0bbf\u0baf\u0ba9\u0bcd" },
@@ -1018,9 +1022,9 @@ public class LocaleNames_ta extends OpenListResourceBundle {
             { "dyo", "\u0b9c\u0bcb\u0bb2\u0bbe-\u0b83\u0baa\u0bcb\u0ba9\u0bcd\u0baf\u0bbf" },
             { "type.nu.jpan", "\u0b9c\u0baa\u0bcd\u0baa\u0bbe\u0ba9\u0bbf\u0baf \u0b8e\u0ba3\u0bcd\u0b95\u0bb3\u0bcd" },
             { "tr", "\u0ba4\u0bc1\u0bb0\u0bc1\u0b95\u0bcd\u0b95\u0bbf\u0bb7\u0bcd" },
+            { "Cakm", metaValue_ccp },
             { "ts", "\u0bb8\u0bcb\u0b99\u0bcd\u0b95\u0bbe" },
             { "swb", "\u0b95\u0bca\u0bae\u0bcb\u0bb0\u0bbf\u0baf\u0ba9\u0bcd" },
-            { "Cakm", "\u0b9a\u0b95\u0bcd\u0bae\u0bbe" },
             { "tt", "\u0b9f\u0bbe\u0b9f\u0bb0\u0bcd" },
             { "dyu", "\u0b9f\u0bcd\u0baf\u0bc2\u0bb2\u0bbe" },
             { "tw", "\u0b9f\u0bcd\u0bb5\u0bbf" },
@@ -1140,6 +1144,7 @@ public class LocaleNames_ta extends OpenListResourceBundle {
             { "type.nu.tamldec", "\u0ba4\u0bae\u0bbf\u0bb4\u0bcd \u0b87\u0bb2\u0b95\u0bcd\u0b95\u0b99\u0bcd\u0b95\u0bb3\u0bcd" },
             { "krc", "\u0b95\u0bb0\u0bbe\u0b9a\u0bc7-\u0baa\u0bb2\u0bcd\u0b95\u0bbe\u0bb0\u0bcd" },
             { "inh", "\u0b87\u0b99\u0bcd\u0b95\u0bc1\u0bb7\u0bcd" },
+            { "fa_AF", "\u0ba4\u0bbe\u0bb0\u0bbf" },
             { "krl", "\u0b95\u0bb0\u0bc7\u0bb2\u0bbf\u0baf\u0ba9\u0bcd" },
             { "efi", "\u0b8e\u0b83\u0baa\u0bbf\u0b95\u0bcd" },
             { "key.nu", "\u0b8e\u0ba3\u0bcd\u0b95\u0bb3\u0bcd" },
