@@ -142,7 +142,7 @@ public class LocaleNames_tg extends OpenListResourceBundle {
             { "FK", "\u04b6\u0430\u0437\u0438\u0440\u0430\u04b3\u043e\u0438 \u0424\u043e\u043b\u043a\u043b\u0435\u043d\u0434" },
             { "FM", "\u0428\u0442\u0430\u0442\u04b3\u043e\u0438 \u0424\u0435\u0434\u0435\u0440\u0430\u0442\u0438\u0432\u0438\u0438 \u041c\u0438\u043a\u0440\u043e\u043d\u0435\u0437\u0438\u044f" },
             { "FO", "\u04b6\u0430\u0437\u0438\u0440\u0430\u04b3\u043e\u0438 \u0424\u0430\u0440\u0435\u0440" },
-            { "FR", "\u0424\u0440\u0430\u043d\u0441\u0438\u044f" },
+            { "FR", "\u0424\u0430\u0440\u043e\u043d\u0441\u0430" },
             { "GA", "\u0413\u0430\u0431\u043e\u043d" },
             { "GB", "\u0428\u043e\u04b3\u0438\u0433\u0430\u0440\u0438\u0438 \u041c\u0443\u0442\u0442\u0430\u04b3\u0438\u0434\u0430" },
             { "GD", "\u0413\u0440\u0435\u043d\u0430\u0434\u0430" },
@@ -473,7 +473,19 @@ public class LocaleNames_tg extends OpenListResourceBundle {
             { "Latn", "\u041b\u043e\u0442\u0438\u043d\u04e3" },
             { "Zxxx", "\u041d\u043e\u043d\u0430\u0432\u0438\u0448\u0442\u0430" },
             { "Zzzz", "\u0421\u043a\u0440\u0438\u043f\u0442\u0438 \u043d\u043e\u043c\u0430\u044a\u043b\u0443\u043c" },
-            { "es_419", "\u0438\u0441\u043f\u0430\u043d\u04e3 (\u0410\u043c\u0435\u0440\u0438\u043a\u0430\u0438 \u041b\u043e\u0442\u0438\u043d\u04e3)" },
+            { "de_AT", "\u043d\u0435\u043c\u0438\u0441\u0438\u0438 \u0430\u0432\u0441\u0442\u0440\u0438\u044f\u0433\u04e3" },
+            { "de_CH", "\u043d\u0435\u043c\u0438\u0441\u0438\u0438 \u0448\u0432\u0435\u0439\u0441\u0430\u0440\u0438\u0438 \u0431\u043e\u043b\u043e\u04e3" },
+            { "en_AU", "\u0430\u043d\u0433\u043b\u0438\u0441\u0438\u0438 \u0430\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f\u0433\u04e3" },
+            { "en_CA", "\u0430\u043d\u0433\u043b\u0438\u0441\u0438\u0438 \u043a\u0430\u043d\u0430\u0434\u0430\u0433\u04e3" },
+            { "en_GB", "\u0430\u043d\u0433\u043b\u0438\u0441\u0438\u0438 \u0431\u0440\u0438\u0442\u0430\u043d\u04e3" },
+            { "en_US", "\u0430\u043d\u0433\u043b\u0438\u0441\u0438\u0438 \u0430\u043c\u0435\u0440\u0438\u043a\u043e\u04e3" },
+            { "es_ES", "\u0438\u0441\u043f\u0430\u043d\u0438\u0438 \u0430\u0432\u0440\u0443\u043f\u043e\u04e3" },
+            { "es_MX", "\u0438\u0441\u043f\u0430\u043d\u0438\u0438 \u043c\u0435\u043a\u0441\u0438\u043a\u043e\u04e3" },
+            { "fr_CA", "\u0444\u0440\u0430\u043d\u0441\u0443\u0437\u0438\u0438 \u043a\u0430\u043d\u0430\u0434\u0430\u0433\u04e3" },
+            { "fr_CH", "\u0444\u0440\u0430\u043d\u0441\u0443\u0437\u0438\u0438 \u0448\u0432\u0435\u0439\u0441\u0430\u0440\u04e3" },
+            { "pt_BR", "\u043f\u043e\u0440\u0442\u0443\u0433\u0430\u043b\u0438\u0438 \u0431\u0440\u0430\u0437\u0438\u043b\u0438\u044f\u0433\u04e3" },
+            { "pt_PT", "\u043f\u043e\u0440\u0442\u0443\u0433\u0430\u043b\u0438\u0438 \u0430\u0432\u0440\u0443\u043f\u043e\u04e3" },
+            { "es_419", "\u0438\u0441\u043f\u0430\u043d\u0438\u0438 \u0430\u043c\u0435\u0440\u0438\u043a\u043e\u0438\u0438 \u043b\u043e\u0442\u0438\u043d\u04e3" },
             { "zh_Hans", "\u0445\u0438\u0442\u043e\u0438\u0438 \u043e\u0441\u043e\u043d\u0444\u0430\u04b3\u043c" },
             { "zh_Hant", "\u0445\u0438\u0442\u043e\u0438\u0438 \u0430\u043d\u044a\u0430\u043d\u0430\u0432\u04e3" },
             { "type.nu.arab", "\u0420\u0430\u049b\u0430\u043c\u04b3\u043e\u0438 \u04b3\u0438\u043d\u0434\u0443-\u0430\u0440\u0430\u0431\u04e3" },
