@@ -322,7 +322,7 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "SV", "Salwador" },
             { "SX", "Sint-Marten" },
             { "SY", "Siri\u00fda" },
-            { "SZ", "Swazilend" },
+            { "SZ", "Eswatini" },
             { "TA", "Tristan-da-Kun\u00fda" },
             { "TC", "Terks we Ka\u00fdkos adalary" },
             { "TD", "\u00c7ad" },
@@ -456,7 +456,7 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "ln", "lingala dili" },
             { "lo", "laos dili" },
             { "lt", "litwa dili" },
-            { "lu", "luba-Katanga dili" },
+            { "lu", "luba-katanga dili" },
             { "lv", "laty\u015f dili" },
             { "mg", "malagasi\u00fd dili" },
             { "mh", "mar\u015fall dili" },
@@ -506,7 +506,7 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "sq", "alban dili" },
             { "sr", "serb dili" },
             { "ss", "swati dili" },
-            { "st", "g\u00fcnorta Soto dili" },
+            { "st", "g\u00fcnorta soto dili" },
             { "su", "sundan dili" },
             { "sv", "\u015fwed dili" },
             { "sw", "suahili dili" },
@@ -576,7 +576,7 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "dje", "zarma dili" },
             { "dsb", "a\u015faky lu\u017eits dili" },
             { "dua", "duala dili" },
-            { "dyo", "\u00fdola-Fonyi dili" },
+            { "dyo", "\u00fdola-fon\u00fdi dili" },
             { "dzg", "daza dili" },
             { "ebu", "embu dili" },
             { "efi", "efik dili" },
@@ -647,7 +647,7 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "men", "mende dili" },
             { "mer", "meru dili" },
             { "mfe", "moris\u00fden dili" },
-            { "mgh", "makua-Mitto dili" },
+            { "mgh", "makuwa-mito dili" },
             { "mgo", "meta dili" },
             { "mic", "mikmak dili" },
             { "min", "minangkabau dili" },
@@ -694,7 +694,7 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "scn", "sisili\u00fda dili" },
             { "sco", "\u015fotland dili" },
             { "seh", "sena dili" },
-            { "ses", "ko\u00fdraboro-Senni dili" },
+            { "ses", "ko\u00fdraboro-senni dili" },
             { "shi", "tahelhit dili" },
             { "shn", "\u015fan dili" },
             { "sma", "g\u00fcnorta saam dili" },
@@ -718,7 +718,7 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "tvl", "tuwalu dili" },
             { "twq", "tasawak dili" },
             { "tyv", "tuwa dili" },
-            { "tzm", "orta-Atlas tamazight dili" },
+            { "tzm", "orta-atlas tamazight dili" },
             { "udm", "udmurt dili" },
             { "umb", "umbundu dili" },
             { "und", "n\u00e4belli dil" },
@@ -785,6 +785,7 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "en_GB", "i\u0148lis dili (Be\u00fdik Britani\u00fda)" },
             { "en_US", "i\u0148lis dili (Amerika)" },
             { "es_ES", "ispan dili (\u00ddewropa)" },
+            { "fa_AF", "dari dili" },
             { "nl_BE", "flamand dili" },
             { "pt_PT", "portugal dili (\u00ddewropa)" },
             { "ro_MD", "moldaw dili" },
