@@ -72,7 +72,7 @@ public class LocaleNames_tr extends OpenListResourceBundle {
     protected final Object[][] getContents() {
         final String metaValue_CY = "K\u0131br\u0131s";
         final String metaValue_ET = "Etiyopya";
-        final String metaValue_jv = "Cava Dili";
+        final String metaValue_ko = "Korece";
         final String metaValue_bug = "Bugis";
         final String metaValue_ccp = "Chakma";
         final String metaValue_nqo = "N\u2019Ko";
@@ -170,7 +170,7 @@ public class LocaleNames_tr extends OpenListResourceBundle {
             { "CF", "Orta Afrika Cumhuriyeti" },
             { "CG", "Kongo - Brazavil" },
             { "CH", "\u0130svi\u00e7re" },
-            { "CI", "Fildi\u015fi Sahili" },
+            { "CI", "C\u00f4te d\u2019Ivoire" },
             { "CK", "Cook Adalar\u0131" },
             { "CL", "\u015eili" },
             { "Kthi", "Kaithi" },
@@ -192,7 +192,7 @@ public class LocaleNames_tr extends OpenListResourceBundle {
             { "DE", "Almanya" },
             { "goh", "Eski Y\u00fcksek Almanca" },
             { "ace", "A\u00e7ece" },
-            { "cgg", "Kigaca" },
+            { "cgg", "Kiga" },
             { "DG", "Diego Garcia" },
             { "gom", "Goa Konkanicesi" },
             { "type.nu.deva", "Devanagari Rakamlar\u0131" },
@@ -432,7 +432,7 @@ public class LocaleNames_tr extends OpenListResourceBundle {
             { "MS", "Montserrat" },
             { "MT", "Malta" },
             { "cps", "Capiznon" },
-            { "type.m0.ungegn", "UNGEGN" },
+            { "type.m0.ungegn", "UN GEGN Transliterasyon" },
             { "MU", "Mauritius" },
             { "alt", "G\u00fcney Altayca" },
             { "MV", "Maldivler" },
@@ -518,7 +518,7 @@ public class LocaleNames_tr extends OpenListResourceBundle {
             { "002", "Afrika" },
             { "njo", "Ao Naga" },
             { "003", "Kuzey Amerika" },
-            { "RE", "R\u00e9union" },
+            { "RE", "Reunion" },
             { "005", "G\u00fcney Amerika" },
             { "lfn", "Lingua Franca Nova" },
             { "jbo", "Lojban" },
@@ -549,7 +549,7 @@ public class LocaleNames_tr extends OpenListResourceBundle {
             { "015", "Kuzey Afrika" },
             { "SG", "Singapur" },
             { "SH", "Saint Helena" },
-            { "type.lb.strict", "Strict Line Break Style" },
+            { "type.lb.strict", "Kat\u0131 Sat\u0131r Sonu Stili" },
             { "017", "Orta Afrika" },
             { "SI", "Slovenya" },
             { "type.nu.mymrtlng", "Myanmar Tai Laing Rakamlar\u0131" },
@@ -569,7 +569,7 @@ public class LocaleNames_tr extends OpenListResourceBundle {
             { "SR", "Surinam" },
             { "aro", "Araona" },
             { "SS", "G\u00fcney Sudan" },
-            { "ST", "S\u00e3o Tom\u00e9 ve Pr\u00edncipe" },
+            { "ST", "Sao Tome ve Principe" },
             { "arq", "Cezayir Arap\u00e7as\u0131" },
             { "SV", "El Salvador" },
             { "ars", "Necd Arap\u00e7as\u0131" },
@@ -589,6 +589,7 @@ public class LocaleNames_tr extends OpenListResourceBundle {
             { "TC", "Turks ve Caicos Adalar\u0131" },
             { "yav", "Yangben" },
             { "TD", "\u00c7ad" },
+            { "Qaag", "Zawgyi" },
             { "TF", "Frans\u0131z G\u00fcney Topraklar\u0131" },
             { "ase", "Amerikan \u0130\u015faret Dili" },
             { "TG", "Togo" },
@@ -671,7 +672,9 @@ public class LocaleNames_tr extends OpenListResourceBundle {
             { "type.nu.mtei", "Meetei Mayek Rakamlar\u0131" },
             { "wal", "Valamo" },
             { "was", "Va\u015fo" },
+            { "XA", "Ps\u00f6do Aksanlar" },
             { "war", "Varay" },
+            { "XB", "Ps\u00f6do Bidi" },
             { "awa", "Awadhi" },
             { "061", "Polinezya" },
             { "XK", "Kosova" },
@@ -694,7 +697,7 @@ public class LocaleNames_tr extends OpenListResourceBundle {
             { "type.nu.cham", "Cham Rakamlar\u0131" },
             { "ZA", "G\u00fcney Afrika" },
             { "type.nu.sund", "Sunda Rakamlar\u0131" },
-            { "type.lb.loose", "Loose Line Break Style" },
+            { "type.lb.loose", "Serbest Sat\u0131r Sonu Stili" },
             { "Deva", "Devanagari" },
             { "type.nu.geor", "G\u00fcrc\u00fc Rakamlar\u0131" },
             { "type.co.zhuyin", "Zhuyin S\u0131ralamas\u0131" },
@@ -781,6 +784,7 @@ public class LocaleNames_tr extends OpenListResourceBundle {
             { "scn", "Sicilyaca" },
             { "aa", "Afar" },
             { "ab", "Abhazca" },
+            { "Aran", "Nest\u00e2lik" },
             { "bbc", "Batak Toba" },
             { "ae", "Avest\u00e7e" },
             { "af", "Afrikaanca" },
@@ -793,7 +797,7 @@ public class LocaleNames_tr extends OpenListResourceBundle {
             { "%%SOLBA", "Stolvizza/Solbica Leh\u00e7esi" },
             { "Jpan", "Japon" },
             { "ar", "Arap\u00e7a" },
-            { "Hrkt", "Katakana veya Hiragana" },
+            { "Hrkt", "Japon hece alfabeleri" },
             { "as", "Assamca" },
             { "sdc", "Sassari Sarduca" },
             { "Lina", "Lineer A" },
@@ -801,7 +805,7 @@ public class LocaleNames_tr extends OpenListResourceBundle {
             { "Linb", "Lineer B" },
             { "sdh", "G\u00fcney K\u00fcrt\u00e7esi" },
             { "ay", "Aymara" },
-            { "az", "Azerice" },
+            { "az", "Azerbaycan dili" },
             { "Khoj", "Khojki" },
             { "%%OSOJS", "Oseacco/Osojane Leh\u00e7esi" },
             { "ba", "Ba\u015fk\u0131rt\u00e7a" },
@@ -862,7 +866,7 @@ public class LocaleNames_tr extends OpenListResourceBundle {
             { "type.nu.grek", "Yunan Rakamlar\u0131" },
             { "ee", "Ewe" },
             { "bfd", "Bafut" },
-            { "type.lb.normal", "Normal Line Break Style" },
+            { "type.lb.normal", "Normal Sat\u0131r Sonu Stili" },
             { "ro_MD", "Moldovaca" },
             { "el", "Yunanca" },
             { "en", "\u0130ngilizce" },
@@ -872,12 +876,12 @@ public class LocaleNames_tr extends OpenListResourceBundle {
             { "type.co.big5han", "Geleneksel \u00c7ince S\u0131ralamas\u0131 - Big5" },
             { "es", "\u0130spanyolca" },
             { "et", "Estonca" },
-            { "Hanb", "Hanb" },
+            { "Hanb", "Han - Bopomofo" },
             { "eu", "Bask\u00e7a" },
             { "Buhd", "Buhid" },
             { "Hang", "Hang\u0131l" },
             { "Samr", "Samarit" },
-            { "shi", "Ta\u015felhit" },
+            { "shi", "Ta\u015felit" },
             { "hsb", "Yukar\u0131 Sorb\u00e7a" },
             { "Hani", "Han" },
             { "shn", "Shan dili" },
@@ -896,7 +900,7 @@ public class LocaleNames_tr extends OpenListResourceBundle {
             { "bgn", "Bat\u0131 Balochi" },
             { "yue", "Kantonca" },
             { "fo", "Faroe dili" },
-            { "type.m0.bgn", "BGN" },
+            { "type.m0.bgn", "US BGN Transliterasyon" },
             { "umb", "Umbundu" },
             { "fr", "Frans\u0131zca" },
             { "sid", "Sidamo dili" },
@@ -926,7 +930,7 @@ public class LocaleNames_tr extends OpenListResourceBundle {
             { "hz", "Herero dili" },
             { "frc", "Cajun Frans\u0131zcas\u0131" },
             { "%%FONIPA", "IPA Ses Bilimi" },
-            { "ia", "Interlingua" },
+            { "ia", "\u0130nterlingua" },
             { "Jamo", "Jamo" },
             { "id", "Endonezce" },
             { "type.nu.tibt", "Tibet Rakamlar\u0131" },
@@ -954,7 +958,7 @@ public class LocaleNames_tr extends OpenListResourceBundle {
             { "type.nu.lepc", "Lep\u00e7a Rakamlar\u0131" },
             { "bkm", "Kom" },
             { "sma", "G\u00fcney Laponcas\u0131" },
-            { "jv", metaValue_jv },
+            { "jv", "Cava dili" },
             { "Shaw", "Shavian" },
             { "mad", "Madura Dili" },
             { "smj", "Lule Laponcas\u0131" },
@@ -977,7 +981,7 @@ public class LocaleNames_tr extends OpenListResourceBundle {
             { "kl", "Gr\u00f6nland dili" },
             { "km", "Khmer dili" },
             { "kn", "Kannada dili" },
-            { "ko", "Korece" },
+            { "ko", metaValue_ko },
             { "kr", "Kanuri dili" },
             { "ks", "Ke\u015fmir dili" },
             { "Cirt", "Cirth" },
@@ -1050,6 +1054,7 @@ public class LocaleNames_tr extends OpenListResourceBundle {
             { "kaw", "Kawi" },
             { "dtp", "Orta Kadazan" },
             { "or", "Oriya Dili" },
+            { "Modi", "Modi" },
             { "os", "Oset\u00e7e" },
             { "bpy", "Bishnupriya" },
             { "kbd", "Kabardeyce" },
@@ -1099,7 +1104,7 @@ public class LocaleNames_tr extends OpenListResourceBundle {
             { "ro", "Rumence" },
             { "%%SAAHO", metaValue_ssy },
             { "type.nu.orya", "Oriya Rakamlar\u0131" },
-            { "type.nu.hanidec", "\u00c7in Rakamlar\u0131" },
+            { "type.nu.hanidec", "\u00c7in Ondal\u0131k Rakamlar\u0131" },
             { "ru", "Rus\u00e7a" },
             { "bss", "Akoose" },
             { "zbl", metaValue_zbl },
@@ -1125,16 +1130,16 @@ public class LocaleNames_tr extends OpenListResourceBundle {
             { "sl", "Slovence" },
             { "Gran", "Grantha" },
             { "sm", "Samoa dili" },
-            { "sn", "Shona" },
+            { "sn", "\u015eona dili" },
             { "so", "Somalice" },
             { "type.nu.arab", "Hint-Arap Rakamlar\u0131" },
             { "sq", "Arnavut\u00e7a" },
             { "sr", "S\u0131rp\u00e7a" },
             { "ss", "Sisvati" },
             { "type.cf.account", "Muhasebe Para Bi\u00e7imi" },
-            { "Java", metaValue_jv },
             { "st", "G\u00fcney Sotho dili" },
-            { "su", "Sunda Dili" },
+            { "Java", "Cava Dili" },
+            { "su", "Sunda dili" },
             { "%%NEDIS", "Natisone Leh\u00e7esi" },
             { "sv", "\u0130sve\u00e7\u00e7e" },
             { "sw", "Svahili dili" },
@@ -1176,8 +1181,8 @@ public class LocaleNames_tr extends OpenListResourceBundle {
             { "dzg", "Dazaga" },
             { "155", "Bat\u0131 Avrupa" },
             { "ug", "Uygurca" },
+            { "Kore", metaValue_ko },
             { "Ital", "Eski \u0130talyan" },
-            { "Kore", "Kore" },
             { "kgp", "Kaingang" },
             { "Zyyy", "Ortak" },
             { "uk", "Ukraynaca" },
@@ -1262,7 +1267,7 @@ public class LocaleNames_tr extends OpenListResourceBundle {
             { "Afak", "Afaka" },
             { "Bopo", "Bopomofo" },
             { "Perm", "Eski Permik" },
-            { "key.lb", "Line Break Style" },
+            { "key.lb", "Sat\u0131r Sonu Stili" },
             { "zu", "Zuluca" },
             { "type.co.phonebook", "Telefon Defteri S\u0131ralamas\u0131" },
             { "%%MONOTON", "Monotonik" },
@@ -1270,6 +1275,7 @@ public class LocaleNames_tr extends OpenListResourceBundle {
             { "Shrd", "Sharada" },
             { "kmb", "Kimbundu" },
             { "type.nu.jpanfin", "Finansal Japon Rakamlar\u0131" },
+            { "Cham", "Cham" },
             { "gez", "Geez" },
             { "mrj", "Ova \u00c7irmi\u015f\u00e7esi" },
             { "Syrn", "Do\u011fu S\u00fcryani" },
@@ -1320,12 +1326,13 @@ public class LocaleNames_tr extends OpenListResourceBundle {
             { "inh", "\u0130ngu\u015f\u00e7a" },
             { "krj", "Kinaray-a" },
             { "kri", "Krio" },
+            { "fa_AF", "Darice" },
             { "krl", "Karelyaca" },
             { "efi", "Efik" },
             { "tcy", "Tuluca" },
             { "key.nu", "Rakamlar" },
             { "kru", "Kurukh dili" },
-            { "ksb", "Shambala" },
+            { "ksb", "\u015eambala" },
             { "Telu", "Telugu" },
             { "ksf", "Bafia" },
         };
