@@ -74,7 +74,6 @@ public class LocaleNames_ur extends OpenListResourceBundle {
         final String metaValue_MD = "\u0645\u0627\u0644\u062f\u0648\u0648\u0627";
         final String metaValue_TR = "\u062a\u0631\u06a9\u06cc";
         final String metaValue_ar = "\u0639\u0631\u0628\u06cc";
-        final String metaValue_bn = "\u0628\u0646\u06af\u0627\u0644\u06cc";
         final String metaValue_bo = "\u062a\u0628\u062a\u06cc";
         final String metaValue_el = "\u06cc\u0648\u0646\u0627\u0646\u06cc";
         final String metaValue_gu = "\u06af\u062c\u0631\u0627\u062a\u06cc";
@@ -256,7 +255,6 @@ public class LocaleNames_ur extends OpenListResourceBundle {
             { "HT", "\u06c1\u06cc\u0679\u06cc" },
             { "HU", "\u06c1\u0646\u06af\u0631\u06cc" },
             { "IC", "\u06a9\u06cc\u0646\u0631\u06cc \u0622\u0626\u0644\u06cc\u0646\u0688\u0632" },
-            { "nan", "nan" },
             { "ID", "\u0627\u0646\u0688\u0648\u0646\u06cc\u0634\u06cc\u0627" },
             { "IE", "\u0622\u0626\u0631\u0644\u06cc\u0646\u0688" },
             { "nap", "\u0646\u06cc\u0627\u067e\u0648\u0644\u06cc\u0679\u0646" },
@@ -276,8 +274,8 @@ public class LocaleNames_ur extends OpenListResourceBundle {
             { "type.nu.beng", "\u0628\u0646\u06af\u0627\u0644\u06cc \u06c1\u0646\u062f\u0633\u06d2" },
             { "JE", "\u062c\u0631\u0633\u06cc" },
             { "type.ca.islamic", "\u0627\u0633\u0644\u0627\u0645\u06cc \u06a9\u06cc\u0644\u0646\u0688\u0631" },
-            { "Beng", metaValue_bn },
             { "JM", "\u062c\u0645\u0627\u0626\u06cc\u06a9\u0627" },
+            { "Beng", "\u0628\u0646\u06af\u0627\u0644\u06cc" },
             { "JO", "\u0627\u0631\u062f\u0646" },
             { "JP", "\u062c\u0627\u067e\u0627\u0646" },
             { "ain", "\u0627\u06cc\u0646\u0648" },
@@ -342,7 +340,7 @@ public class LocaleNames_ur extends OpenListResourceBundle {
             { "MR", "\u0645\u0648\u0631\u06cc\u0637\u0627\u0646\u06cc\u06c1" },
             { "MS", "\u0645\u0648\u0646\u0679\u0633\u06cc\u0631\u0627\u0679" },
             { "MT", "\u0645\u0627\u0644\u0679\u0627" },
-            { "type.m0.ungegn", "UN GEGN" },
+            { "type.m0.ungegn", "UN GEGN \u0679\u0631\u0627\u0646\u0633\u0644\u0679\u0631\u06cc\u0634\u0646" },
             { "MU", "\u0645\u0627\u0631\u06cc\u0634\u0633" },
             { "alt", "\u062c\u0646\u0648\u0628\u06cc \u0627\u0644\u0679\u0627\u0626\u06cc" },
             { "MV", "\u0645\u0627\u0644\u062f\u06cc\u067e" },
@@ -436,7 +434,7 @@ public class LocaleNames_ur extends OpenListResourceBundle {
             { "type.nu.taml", "\u0631\u0648\u0627\u06cc\u062a\u06cc \u062a\u0645\u0644 \u0627\u0639\u062f\u0627\u062f" },
             { "SR", "\u0633\u0648\u0631\u06cc\u0646\u0627\u0645" },
             { "SS", "\u062c\u0646\u0648\u0628\u06cc \u0633\u0648\u0688\u0627\u0646" },
-            { "ST", "\u0633\u0627\u0624 \u0679\u0648\u0645 \u0627\u0648\u0631 \u067e\u0631\u0646\u0633\u067e\u06d2" },
+            { "ST", "\u0633\u0627\u0624 \u0679\u0648\u0645\u06d2 \u0627\u0648\u0631 \u067e\u0631\u0646\u0633\u067e\u06d2" },
             { "SV", "\u0627\u0644 \u0633\u0644\u0648\u0627\u0688\u0648\u0631" },
             { "SX", "\u0633\u0646\u0679 \u0645\u0627\u0631\u0679\u0646" },
             { "SY", "\u0634\u0627\u0645" },
@@ -445,7 +443,7 @@ public class LocaleNames_ur extends OpenListResourceBundle {
             { "asa", "\u0622\u0633\u0648" },
             { "type.ms.ussystem", "\u067e\u06cc\u0645\u0627\u0626\u0634 \u06a9\u0627 \u0627\u0645\u0631\u06cc\u06a9\u06cc \u0646\u0638\u0627\u0645" },
             { "021", "\u0634\u0645\u0627\u0644\u06cc \u0627\u0645\u0631\u06cc\u06a9\u06c1 \u06a9\u0627 \u0639\u0644\u0627\u0642\u06c1" },
-            { "TC", "\u062a\u0631\u06a9\u0633 \u0627\u0648\u0631 \u06a9\u06cc\u06a9\u0627\u0624\u0633 \u062c\u0632\u0627\u0626\u0631" },
+            { "TC", "\u0679\u0631\u06a9\u0633 \u0627\u0648\u0631 \u06a9\u06cc\u06a9\u0648\u0633 \u062c\u0632\u0627\u0626\u0631" },
             { "yav", "\u06cc\u0627\u0646\u06af\u0628\u06cc\u0646" },
             { "TD", "\u0686\u0627\u0688" },
             { "TF", "\u0641\u0631\u0627\u0646\u0633\u06cc\u0633\u06cc \u062c\u0646\u0648\u0628\u06cc \u062e\u0637\u06d2" },
@@ -476,13 +474,12 @@ public class LocaleNames_ur extends OpenListResourceBundle {
             { "034", "\u062c\u0646\u0648\u0628\u06cc \u0627\u06cc\u0634\u06cc\u0627" },
             { "035", "\u062c\u0646\u0648\u0628 \u0645\u0634\u0631\u0642\u06cc \u0627\u06cc\u0634\u06cc\u0627" },
             { "UG", "\u06cc\u0648\u06af\u0646\u0688\u0627" },
-            { "hak", "hak" },
             { "type.co.pinyin", "\u067e\u0646 \u06cc\u0646 \u06a9\u06cc \u0686\u06be\u0679\u0646\u06cc \u06a9\u06cc \u062a\u0631\u062a\u06cc\u0628" },
             { "039", "\u062c\u0646\u0648\u0628\u06cc \u06cc\u0648\u0631\u067e" },
             { "Sinh", metaValue_si },
             { "UM", "\u0627\u0645\u0631\u06cc\u06a9\u06c1 \u0633\u06d2 \u0628\u0627\u06c1\u0631 \u06a9\u06d2 \u0686\u06be\u0648\u0679\u06d2 \u062c\u0632\u0627\u0626\u0632" },
             { "UN", "\u0627\u0642\u0648\u0627\u0645 \u0645\u062a\u062d\u062f\u06c1" },
-            { "US", "\u0631\u06cc\u0627\u0633\u062a\u06c1\u0627\u0626\u06d2 \u0645\u062a\u062d\u062f\u06c1" },
+            { "US", "\u0631\u06cc\u0627\u0633\u062a \u06c1\u0627\u0626\u06d2 \u0645\u062a\u062d\u062f\u06c1 \u0627\u0645\u0631\u06cc\u06a9\u06c1" },
             { "haw", "\u06c1\u0648\u0627\u0626\u06cc" },
             { "type.co.gb2312han", "\u0622\u0633\u0627\u0646 \u0686\u06cc\u0646\u06cc \u06a9\u06cc \u0686\u06be\u0679\u0627\u0626\u06cc \u06a9\u06cc \u062a\u0631\u062a\u06cc\u0628 - GB2312" },
             { "UY", "\u06cc\u0648\u0631\u0648\u06af\u0648\u0626\u06d2" },
@@ -523,7 +520,7 @@ public class LocaleNames_ur extends OpenListResourceBundle {
             { "wbp", "\u0648\u0627\u0631\u0644\u067e\u06cc\u0631\u06cc" },
             { "YE", "\u06cc\u0645\u0646" },
             { "nqo", "\u0627\u06cc\u0646\u06a9\u0648" },
-            { "type.co.standard", "\u0645\u0639\u06cc\u0627\u0631\u06cc \u0686\u06be\u0646\u0679\u0627\u0626\u06cc \u06a9\u06cc \u062a\u0631\u062a\u06cc\u0628" },
+            { "type.co.standard", "\u0645\u0639\u06cc\u0627\u0631\u06cc \u0686\u06be\u0627\u0646\u0679\u06cc \u06a9\u06cc \u062a\u0631\u062a\u06cc\u0628" },
             { "YT", "\u0645\u0627\u06cc\u0648\u0679" },
             { "ZA", "\u062c\u0646\u0648\u0628\u06cc \u0627\u0641\u0631\u06cc\u0642\u06c1" },
             { "type.lb.loose", "\u0688\u06be\u06cc\u0644\u0627 \u0644\u0627\u0626\u0646 \u0628\u0631\u06cc\u06a9 \u0627\u0646\u062f\u0627\u0632" },
@@ -577,6 +574,7 @@ public class LocaleNames_ur extends OpenListResourceBundle {
             { "scn", "\u0633\u06cc\u0633\u06cc\u0644\u06cc\u0646" },
             { "aa", "\u0627\u0641\u0627\u0631" },
             { "ab", "\u0627\u0628\u0642\u0627\u0632\u06cc\u0627\u0646" },
+            { "Aran", "\u0646\u0633\u062a\u0639\u0644\u06cc\u0642" },
             { "af", "\u0627\u0641\u0631\u06cc\u0642\u06cc" },
             { "ak", "\u0627\u06a9\u0627\u0646" },
             { "am", "\u0627\u0645\u06c1\u0627\u0631\u06cc" },
@@ -596,7 +594,7 @@ public class LocaleNames_ur extends OpenListResourceBundle {
             { "bg", "\u0628\u0644\u063a\u0627\u0631\u06cc" },
             { "bi", "\u0628\u0633\u0644\u0627\u0645\u0627" },
             { "bm", "\u0628\u0645\u0628\u0627\u0631\u0627" },
-            { "bn", metaValue_bn },
+            { "bn", "\u0628\u0646\u06af\u0644\u06c1" },
             { "bo", metaValue_bo },
             { "dgr", "\u062f\u0648\u06af\u0631\u06cc\u0628" },
             { "br", "\u0628\u0631\u06cc\u0679\u0646" },
@@ -650,14 +648,13 @@ public class LocaleNames_ur extends OpenListResourceBundle {
             { "Hant", "\u0631\u0648\u0627\u06cc\u062a\u06cc" },
             { "az_Arab", "\u0622\u0632\u0631\u0628\u0627\u0626\u06cc\u062c\u0627\u0646\u06cc (\u0639\u0631\u0628\u06cc)" },
             { "ff", "\u0641\u0648\u0644\u06c1" },
-            { "hsn", "hsn" },
             { "fi", "\u0641\u06cc\u0646\u06cc\u0634" },
             { "fj", metaValue_FJ },
             { "fon", "\u0641\u0648\u0646" },
             { "bgn", "\u0645\u063a\u0631\u0628\u06cc \u0628\u0644\u0648\u0686\u06cc" },
             { "yue", "\u06a9\u06cc\u0646\u0679\u0648\u0646\u06cc\u0632" },
             { "fo", "\u0641\u06cc\u0631\u0648\u0626\u06cc\u0632" },
-            { "type.m0.bgn", "US BGN" },
+            { "type.m0.bgn", "US BGN \u0679\u0631\u0627\u0646\u0633\u0644\u0679\u0631\u06cc\u0634\u0646" },
             { "umb", "\u0627\u0648\u0645\u0628\u0648\u0646\u062f\u0648" },
             { "fr", "\u0641\u0631\u0627\u0646\u0633\u06cc\u0633\u06cc" },
             { "fy", "\u0645\u063a\u0631\u0628\u06cc \u0641\u0631\u06cc\u0633\u06cc\u0626\u0646" },
@@ -703,7 +700,6 @@ public class LocaleNames_ur extends OpenListResourceBundle {
             { "ka", metaValue_ka },
             { "bla", "\u0633\u06a9\u0633\u06cc\u06a9\u0627" },
             { "mak", "\u0645\u06a9\u0627\u0633\u0631" },
-            { "wuu", "wuu" },
             { "sms", "\u0633\u06a9\u0648\u0644\u0679 \u0633\u0627\u0645\u06cc" },
             { "kg", "\u06a9\u0627\u0646\u06af\u0648" },
             { "ki", "\u06a9\u06cc\u06a9\u0648\u06cc\u0648" },
@@ -737,7 +733,7 @@ public class LocaleNames_ur extends OpenListResourceBundle {
             { "ListCompositionPattern", "{0}\u060c{1}" },
             { "mg", "\u0645\u0644\u0627\u06af\u0627\u0633\u06cc" },
             { "mh", "\u0645\u0627\u0631\u0634\u0644\u06cc\u0632" },
-            { "type.co.ducet", "\u0688\u06cc\u0641\u0627\u0644\u0679 \u06cc\u0648\u0646\u06cc\u06a9\u0648\u0688 \u06a9\u06cc \u0686\u06be\u0679\u0646\u06cc \u06a9\u06cc \u062a\u0631\u062a\u06cc\u0628" },
+            { "type.co.ducet", "\u0688\u06cc\u0641\u0627\u0644\u0679 \u06cc\u0648\u0646\u06cc \u06a9\u0648\u0688 \u0686\u06be\u0627\u0646\u0679\u06cc \u06a9\u06cc \u062a\u0631\u062a\u06cc\u0628" },
             { "mi", "\u0645\u0627\u0624\u0631\u06cc" },
             { "mk", "\u0645\u0642\u062f\u0648\u0646\u06cc\u0627\u0626\u06cc" },
             { "ml", "\u0645\u0627\u0644\u0627\u06cc\u0627\u0644\u0645" },
@@ -934,6 +930,7 @@ public class LocaleNames_ur extends OpenListResourceBundle {
             { "type.nu.tamldec", "\u062a\u0645\u0644 \u0627\u0639\u062f\u0627\u062f" },
             { "krc", "\u06a9\u0631\u0627\u0686\u06d2 \u0628\u0627\u0644\u06a9\u0631" },
             { "inh", "\u0627\u0646\u06af\u0648\u0634" },
+            { "fa_AF", "\u062f\u0631\u06cc" },
             { "krl", "\u06a9\u06cc\u0631\u0644\u06cc\u0646" },
             { "efi", "\u0627\u06cc\u0641\u0650\u06a9" },
             { "key.nu", "\u0627\u0639\u062f\u0627\u062f" },
