@@ -93,6 +93,7 @@ public class LocaleNames_uz extends OpenListResourceBundle {
             { "mwl", "miranda" },
             { "Zsym", "belgilar" },
             { "Zsye", "emoji" },
+            { "ccp", "chakma" },
             { "tem", "timne" },
             { "teo", "teso" },
             { "rap", "rapanui" },
@@ -246,7 +247,6 @@ public class LocaleNames_uz extends OpenListResourceBundle {
             { "HT", "Gaiti" },
             { "HU", "Vengriya" },
             { "IC", "Kanar orollari" },
-            { "nan", "nan" },
             { "ID", "Indoneziya" },
             { "IE", "Irlandiya" },
             { "nap", "neapolitan" },
@@ -459,7 +459,6 @@ public class LocaleNames_uz extends OpenListResourceBundle {
             { "034", "Janubiy Osiyo" },
             { "035", "Janubi-sharqiy Osiyo" },
             { "UG", "Uganda" },
-            { "hak", "hak" },
             { "039", "Janubiy Yevropa" },
             { "Sinh", metaValue_si },
             { "UM", "AQSH yondosh orollari" },
@@ -489,7 +488,9 @@ public class LocaleNames_uz extends OpenListResourceBundle {
             { "wae", "valis" },
             { "WS", "Samoa" },
             { "wal", "volamo" },
+            { "XA", "Qalbaki urg\u2018u" },
             { "war", "varay" },
+            { "XB", "Qalbaki Bidi" },
             { "awa", "avadxi" },
             { "061", "Polineziya" },
             { "XK", "Kosovo" },
@@ -617,7 +618,6 @@ public class LocaleNames_uz extends OpenListResourceBundle {
             { "type.nu.latn", "zamonaviy arab raqamlari" },
             { "Hant", "an\u2019anaviy xitoy" },
             { "ff", "fula" },
-            { "hsn", "hsn" },
             { "fi", "fincha" },
             { "fj", "fiji" },
             { "fon", "fon" },
@@ -667,7 +667,6 @@ public class LocaleNames_uz extends OpenListResourceBundle {
             { "ka", "gruzincha" },
             { "bla", "siksika" },
             { "mak", "makasar" },
-            { "wuu", "wuu" },
             { "sms", "skolt-saam" },
             { "ki", "kikuyu" },
             { "mas", "masay" },
@@ -888,6 +887,7 @@ public class LocaleNames_uz extends OpenListResourceBundle {
             { "type.nu.tamldec", "tamil raqamlari" },
             { "krc", "qorachoy-bolqor" },
             { "inh", "ingush" },
+            { "fa_AF", "dari" },
             { "krl", "karel" },
             { "efi", "efik" },
             { "key.nu", "raqamlar" },
