@@ -132,7 +132,7 @@ public class LocaleNames_wo extends OpenListResourceBundle {
             { "CC", "Duni Koko (Kilin)" },
             { "CF", "Repiblik S\u00e0ntar Afrik" },
             { "CH", "Siwis" },
-            { "CI", "Kodiwaar (C\u00f4te d\u2019Ivoire)" },
+            { "CI", "Kodiwaar" },
             { "CK", "Duni Kuuk" },
             { "CL", "Sili" },
             { "CM", "Kamerun" },
