@@ -688,6 +688,7 @@ public class LocaleNames_yue extends OpenListResourceBundle {
             { "was", "\u74e6\u7d39\u6587" },
             { "XA", "\u507d\u53e3\u97f3" },
             { "war", "\u74e6\u745e\u6587" },
+            { "XB", "\u507d Bidi" },
             { "awa", "\u963f\u74e6\u6587" },
             { "061", "\u73bb\u91cc\u5c3c\u897f\u4e9e" },
             { "XK", "\u79d1\u7d22\u6c83" },
@@ -1341,6 +1342,7 @@ public class LocaleNames_yue extends OpenListResourceBundle {
             { "inh", "\u5370\u53e4\u4ec0\u6587" },
             { "krj", "\u57fa\u90a3\u4f86\u963f\u6587" },
             { "kri", "\u585e\u62c9\u5229\u6602\u514b\u88cf\u5967\u723e\u6587" },
+            { "fa_AF", "\u9054\u91cc\u6587" },
             { "krl", "\u5361\u7d2f\u5229\u963f\u6587" },
             { "efi", "\u57c3\u83f2\u514b\u6587" },
             { "tcy", "\u5716\u76e7\u6587" },
