@@ -688,6 +688,7 @@ public class LocaleNames_yue_Hans extends OpenListResourceBundle {
             { "was", "\u74e6\u7ecd\u6587" },
             { "XA", "\u4f2a\u53e3\u97f3" },
             { "war", "\u74e6\u745e\u6587" },
+            { "XB", "\u4f2a Bidi" },
             { "awa", "\u963f\u74e6\u6587" },
             { "061", "\u73bb\u91cc\u5c3c\u897f\u4e9a" },
             { "XK", "\u79d1\u7d22\u6c83" },
@@ -1341,6 +1342,7 @@ public class LocaleNames_yue_Hans extends OpenListResourceBundle {
             { "inh", "\u5370\u53e4\u4ec0\u6587" },
             { "krj", "\u57fa\u90a3\u6765\u963f\u6587" },
             { "kri", "\u585e\u62c9\u5229\u6602\u514b\u91cc\u5965\u5c14\u6587" },
+            { "fa_AF", "\u8fbe\u91cc\u6587" },
             { "krl", "\u5361\u7d2f\u5229\u963f\u6587" },
             { "efi", "\u57c3\u83f2\u514b\u6587" },
             { "tcy", "\u56fe\u5362\u6587" },
