@@ -623,7 +623,7 @@ public class LocaleNames_zh_Hant extends OpenListResourceBundle {
             { "SX", "\u8377\u5c6c\u8056\u99ac\u4e01" },
             { "SY", "\u6558\u5229\u4e9e" },
             { "yao", "\u7464\u6587" },
-            { "SZ", "\u53f2\u74e6\u6fdf\u862d" },
+            { "SZ", "\u53f2\u74e6\u5e1d\u5c3c" },
             { "arw", "\u963f\u62c9\u74e6\u514b\u6587" },
             { "arz", "\u57c3\u53ca\u963f\u62c9\u4f2f\u6587" },
             { "ary", "\u6469\u6d1b\u54e5\u963f\u62c9\u4f2f\u6587" },
@@ -636,6 +636,7 @@ public class LocaleNames_zh_Hant extends OpenListResourceBundle {
             { "TC", "\u571f\u514b\u65af\u53ca\u958b\u79d1\u65af\u7fa4\u5cf6" },
             { "yav", "\u6d0b\u535e\u6587" },
             { "TD", "\u67e5\u5fb7" },
+            { "Qaag", "\u4f50\u57fa\u6587" },
             { "TF", "\u6cd5\u5c6c\u5357\u90e8\u5c6c\u5730" },
             { "ase", "\u7f8e\u570b\u624b\u8a9e" },
             { "TG", "\u591a\u54e5" },
@@ -840,6 +841,7 @@ public class LocaleNames_zh_Hant extends OpenListResourceBundle {
             { "scn", "\u897f\u897f\u91cc\u6587" },
             { "aa", "\u963f\u6cd5\u6587" },
             { "ab", "\u963f\u5e03\u54c8\u8332\u6587" },
+            { "Aran", "\u6ce2\u65af\u9ad4" },
             { "bbc", "\u5df4\u5854\u514b\u6258\u5df4\u6587" },
             { "ae", "\u963f\u7dad\u65af\u5854\u6587" },
             { "af", "\u5357\u975e\u8377\u862d\u6587" },
