@@ -106,9 +106,9 @@ public class LocaleNames_zu extends OpenListResourceBundle {
             { "nl_BE", "isi-Flemish" },
             { "AF", "i-Afghanistan" },
             { "AG", "i-Antigua ne-Barbuda" },
-            { "type.ca.ethiopic", "ikhalenda lesi-Ethiopic" },
+            { "type.ca.ethiopic", "Ikhalenda lesi-Ethiopic" },
             { "AI", "i-Anguilla" },
-            { "key.tz", "Izoni yesikhathi:" },
+            { "key.tz", "Isikhathi Sendawo" },
             { "AL", "i-Albania" },
             { "AM", "i-Armenia" },
             { "AO", "i-Angola" },
@@ -146,7 +146,7 @@ public class LocaleNames_zu extends OpenListResourceBundle {
             { "BW", "iBotswana" },
             { "BY", "i-Belarus" },
             { "BZ", "i-Belize" },
-            { "type.ca.persian", "ikhalenda lesi-Persian" },
+            { "type.ca.persian", "Ikhalenda lesi-Persian" },
             { "type.nu.hebr", "izinombolo zesi-Hebrew" },
             { "CA", "i-Canada" },
             { "CC", "i-Cocos (Keeling) Islands" },
@@ -206,7 +206,6 @@ public class LocaleNames_zu extends OpenListResourceBundle {
             { "ET", "i-Ethiopia" },
             { "EU", "i-European Union" },
             { "type.ca.gregorian", "ikhalenda lesi-Gregorian" },
-            { "EZ", "EZ" },
             { "chy", "isi-Cheyenne" },
             { "type.nu.gujr", "amadijithi esi-Gujarati" },
             { "ady", "isi-Adyghe" },
@@ -245,7 +244,7 @@ public class LocaleNames_zu extends OpenListResourceBundle {
             { "zxx", "akukho okuqukethwe kolimi" },
             { "de_AT", "isi-Austrian German" },
             { "HK", "i-Hong Kong SAR China" },
-            { "HM", "i-Heard Island ne-McDonald Islands" },
+            { "HM", "I-Heard & McDonald Island" },
             { "HN", "i-Honduras" },
             { "HR", "i-Croatia" },
             { "agq", "isi-Aghem" },
@@ -271,7 +270,7 @@ public class LocaleNames_zu extends OpenListResourceBundle {
             { "type.nu.thai", "amadijithi esi-Thai" },
             { "type.nu.beng", "izinombolo zesi-Bengali" },
             { "JE", "i-Jersey" },
-            { "type.ca.islamic", "ikhalenda lesi-Islamic" },
+            { "type.ca.islamic", "Ikhalenda lesi-Islamic" },
             { "JM", "i-Jamaica" },
             { "Beng", "isi-Bangla" },
             { "JO", "i-Jordan" },
@@ -327,7 +326,7 @@ public class LocaleNames_zu extends OpenListResourceBundle {
             { "MH", "i-Marshall Islands" },
             { "ale", "isi-Aleut" },
             { "type.nu.vaii", "Izinhlazu Zezinombolo ze-Vai" },
-            { "MK", "i-Macedonia" },
+            { "MK", "i-North Macedonia" },
             { "ML", "iMali" },
             { "MM", "i-Myanmar (Burma)" },
             { "MN", "i-Mongolia" },
@@ -344,12 +343,12 @@ public class LocaleNames_zu extends OpenListResourceBundle {
             { "MV", "i-Maldives" },
             { "MW", "iMalawi" },
             { "MX", "i-Mexico" },
-            { "type.ca.japanese", "ikhalenda lesi-Japanese" },
+            { "type.ca.japanese", "Ikhalenda lesi-Japanese" },
             { "MY", "i-Malaysia" },
             { "MZ", "i-Mozambique" },
             { "NA", "i-Namibia" },
             { "202", "Sub-Saharan Africa" },
-            { "type.ca.hebrew", "ikhalenda lesi-Hebrew" },
+            { "type.ca.hebrew", "Ikhalenda lesi-Hebrew" },
             { "type.co.dictionary", "Ukuhlunga kwesichazimazwi" },
             { "NC", "i-New Caledonia" },
             { "NE", "i-Niger" },
@@ -476,7 +475,7 @@ public class LocaleNames_zu extends OpenListResourceBundle {
             { "type.co.pinyin", "Ukuhlunga nge-Pinyin" },
             { "039", "i-Southern Europe" },
             { "Sinh", metaValue_si },
-            { "UM", "i-U.S. Minor Outlying Islands" },
+            { "UM", "I-U.S. Outlying Islands" },
             { "UN", "I-United Nations" },
             { "US", "i-United States" },
             { "haw", "isi-Hawaiian" },
@@ -529,7 +528,7 @@ public class LocaleNames_zu extends OpenListResourceBundle {
             { "ZW", "iZimbabwe" },
             { "ZZ", "iSifunda esingaziwa" },
             { "type.ms.metric", "isistimu ye-Metric" },
-            { "type.ca.iso8601", "ikhalenda le-ISO-8601" },
+            { "type.ca.iso8601", "Ikhalenda le-ISO-8601" },
             { "nso", "isi-Northern Sotho" },
             { "type.nu.telu", "amadijithi esi-Telegu" },
             { "loz", "isi-Lozi" },
@@ -619,7 +618,7 @@ public class LocaleNames_zu extends OpenListResourceBundle {
             { "es_419", "isi-Latin American Spanish" },
             { "dz", "isi-Dzongkha" },
             { "bez", "isi-Bena" },
-            { "type.ca.chinese", "ikhalenda lesi-Chinese" },
+            { "type.ca.chinese", "Ikhalenda lesi-Chinese" },
             { "dje", "isi-Zarma" },
             { "type.nu.grek", "izinombolo zesi-Greek" },
             { "ee", "isi-Ewe" },
@@ -770,7 +769,7 @@ public class LocaleNames_zu extends OpenListResourceBundle {
             { "pa", "isi-Punjabi" },
             { "dua", "isi-Duala" },
             { "pl", "isi-Polish" },
-            { "type.ca.dangi", "ikhalenda lesi-Dangi" },
+            { "type.ca.dangi", "Ikhalenda lesi-Dangi" },
             { "ps", "isi-Pashto" },
             { "pt", "isi-Portuguese" },
             { "key.co", "Uhlelo lokuhlunga" },
@@ -793,7 +792,7 @@ public class LocaleNames_zu extends OpenListResourceBundle {
             { "type.hc.h11", "isistimu yamahora angu-12 (0-11)" },
             { "rm", "isi-Romansh" },
             { "rn", "isi-Rundi" },
-            { "key.cu", "Ikharensi" },
+            { "key.cu", "Imali" },
             { "ro", "isi-Romanian" },
             { "type.nu.orya", "Amadijithi ase-Odia" },
             { "type.nu.hanidec", "izinombolo zezinombolo zesi-Chinese" },
@@ -866,7 +865,7 @@ public class LocaleNames_zu extends OpenListResourceBundle {
             { "kha", "isi-Khasi" },
             { "nds_NL", "isi-Low Saxon" },
             { "ve", "isi-Venda" },
-            { "type.ca.roc", "ikhalenda lesi-Minguo" },
+            { "type.ca.roc", "Ikhalenda lesi-Minguo" },
             { "vi", "isi-Vietnamese" },
             { "khq", "isi-Koyra Chiini" },
             { "key.hc", "Umjikelezo wehora (12 vs 24" },
@@ -925,6 +924,7 @@ public class LocaleNames_zu extends OpenListResourceBundle {
             { "type.nu.tamldec", "amadijithi esi-Tamil" },
             { "krc", "isi-Karachay-Balkar" },
             { "inh", "isi-Ingush" },
+            { "fa_AF", "isi-Dari" },
             { "krl", "isi-Karelian" },
             { "efi", "isi-Efik" },
             { "key.nu", "Izinombolo" },
