@@ -70,142 +70,174 @@ import sun.util.resources.TimeZoneNamesBundle;
 public class TimeZoneNames_kea extends TimeZoneNamesBundle {
     @Override
     protected final Object[][] getContents() {
-        final String[] Africa_Central = new String[] {
-               "Ora di Afrika Sentral",
+        final String[] GMT = new String[] {
+               "Ora M\u00e9diu di Greenwich",
                "",
                "",
                "",
                "",
                "",
             };
-        final String[] Australia_CentralWestern = new String[] {
-               "Ora Padr\u00e3u di Australia Sentru-Osidental",
+        final String[] Cuba = new String[] {
+               "Ora Padron di Kuba",
                "",
-               "Ora di Ver\u00e3u di Australia Sentru-Osidental",
+               "Ora di Veron di Kuba",
                "",
-               "Ora di Autralia Sentru-Osidental",
+               "Ora di Kuba",
+               "",
+            };
+        final String[] Alaska = new String[] {
+               "Ora Padron di Alaska",
+               "",
+               "Ora di Veron di Alaska",
+               "",
+               "Ora di Alaska",
+               "",
+            };
+        final String[] ETC_UTC = new String[] {
+               "Ora Universal Kordenadu",
+               "UTC",
+               "",
+               "",
+               "",
+               "",
+            };
+        final String[] Atlantic = new String[] {
+               "Ora Padron di Atl\u00e1ntiku",
+               "",
+               "Ora di Veron di Atl\u00e1ntiku",
+               "",
+               "Ora di Atl\u00e1ntiku",
+               "",
+            };
+        final String[] Cape_Verde = new String[] {
+               "Ora Padron di Kabu Verdi",
+               "",
+               "Ora di Veron de Kabu Verdi",
+               "",
+               "Ora di Kabu Verdi",
+               "",
+            };
+        final String[] Africa_Central = new String[] {
+               "Ora di \u00c1frika Sentral",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
+        final String[] Africa_Eastern = new String[] {
+               "Ora di \u00c1frika Oriental",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
+        final String[] Africa_Western = new String[] {
+               "Ora Padron di \u00c1frika Osidental",
+               "",
+               "Ora di Veron di \u00c1frika Osidental",
+               "",
+               "Ora di \u00c1frika Osidental",
                "",
             };
         final String[] Europe_Central = new String[] {
-               "Ora Padr\u00e3u di Europa Sentral",
+               "Ora Padron di Europa Sentral",
                "",
-               "Ora di Ver\u00e3u di Europa Sentral",
+               "Ora di Veron di Europa Sentral",
                "",
                "Ora di Europa Sentral",
                "",
             };
-        final String[] America_Eastern = new String[] {
-               "Ora Oriental Padr\u00e3u",
-               "",
-               "Ora Oriental di Ver\u00e3u",
-               "",
-               "Ora Oriental",
-               "",
-            };
-        final String[] Australia_Central = new String[] {
-               "Ora Padr\u00e3u di Australia Sentral",
-               "",
-               "Ora di Ver\u00e3u di Australia Sentral",
-               "",
-               "Ora di Australia Sentral",
-               "",
-            };
-        final String[] America_Pacific = new String[] {
-               "Ora di Pasifiku Padr\u00e3u",
-               "",
-               "Ora di Pasifiku di Ver\u00e3u",
-               "",
-               "Ora di Pasifiku",
-               "",
-            };
-        final String[] Africa_Eastern = new String[] {
-               "Ora di Afrika Oriental",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
-        final String[] Europe_Western = new String[] {
-               "Ora Padr\u00e3u di Europa Osidental",
-               "",
-               "Ora di Ver\u00e3u di Europa Osidental",
-               "",
-               "Ora di Europa Osidental",
-               "",
-            };
         final String[] Europe_Eastern = new String[] {
-               "Ora Padr\u00e3u di Europa Oriental",
+               "Ora Padron di Europa Oriental",
                "",
-               "Ora di Ver\u00e3u di Europa Oriental",
+               "Ora di Veron di Europa Oriental",
                "",
                "Ora di Europa Oriental",
                "",
             };
-        final String[] Atlantic = new String[] {
-               "Ora Padr\u00e3u di Atlantiku",
-               "",
-               "Ora di Ver\u00e3u di Atlantiku",
-               "",
-               "Ora di Atlantiku",
-               "",
-            };
-        final String[] Africa_Western = new String[] {
-               "Ora Padr\u00e3u di Afrika Osidental",
-               "",
-               "Ora di Ver\u00e3o di Afrika Osidental",
-               "",
-               "Ora di Afrika Osidental",
-               "",
-            };
-        final String[] EMPTY_ZONE = new String[] {
-               "",
-               "",
-               "",
+        final String[] Europe_Western = new String[] {
+               "Ora Padron di Europa Osidental",
                "",
+               "Ora di Veron di Europa Osidental",
                "",
+               "Ora di Europa Osidental",
                "",
             };
         final String[] Africa_Southern = new String[] {
-               "Ora di Sul di Afrika",
+               "Ora di Sul di \u00c1frika",
                "",
                "",
                "",
                "",
                "",
             };
-        final String[] Australia_Western = new String[] {
-               "Ora Padr\u00e3u di Australia Osidental",
-               "",
-               "Ora di Ver\u00e3u di Australia Osidental",
-               "",
-               "Ora di Australia Osidental",
-               "",
-            };
         final String[] America_Central = new String[] {
-               "Ora Sentral Padr\u00e3u",
+               "Ora Padron Sentral",
                "",
-               "Ora Sentral di Ver\u00e3u",
+               "Ora di Veron Sentral",
                "",
                "Ora Sentral",
                "",
             };
-        final String[] Australia_Eastern = new String[] {
-               "Ora Padr\u00e3u di Australia Oriental",
+        final String[] America_Eastern = new String[] {
+               "Ora Padron Oriental",
                "",
-               "Ora di Ver\u00e3u di Australia Oriental",
+               "Ora di Veron Oriental",
                "",
-               "Ora di Australia Oriental",
+               "Ora Oriental",
+               "",
+            };
+        final String[] America_Pacific = new String[] {
+               "Ora Padron di Pas\u00edfiku",
+               "",
+               "Ora di Veron di Pas\u00edfiku",
+               "",
+               "Ora di Pas\u00edfiku",
                "",
             };
         final String[] America_Mountain = new String[] {
-               "Ora di Montanha Padr\u00e3u",
+               "Ora Padron di Montanha",
                "",
-               "Ora di Ver\u00e3u di Montanha",
+               "Ora di Veron di Montanha",
                "",
                "Ora di Montanha",
                "",
             };
+        final String[] Australia_Central = new String[] {
+               "Ora Padron di Austr\u00e1lia Sentral",
+               "",
+               "Ora di Veron di Austr\u00e1lia Sentral",
+               "",
+               "Ora di Austr\u00e1lia Sentral",
+               "",
+            };
+        final String[] Australia_Eastern = new String[] {
+               "Ora Padron di Austr\u00e1lia Oriental",
+               "",
+               "Ora di Veron di Austr\u00e1lia Oriental",
+               "",
+               "Ora di Austr\u00e1lia Oriental",
+               "",
+            };
+        final String[] Australia_Western = new String[] {
+               "Ora Padron di Austr\u00e1lia Osidental",
+               "",
+               "Ora di Veron di Austr\u00e1lia Osidental",
+               "",
+               "Ora di Austr\u00e1lia Osidental",
+               "",
+            };
+        final String[] Australia_CentralWestern = new String[] {
+               "Ora Padron di Austr\u00e1lia Sentru-Osidental",
+               "",
+               "Ora di Veron di Austr\u00e1lia Sentru-Osidental",
+               "",
+               "Ora di Austr\u00e1lia Sentru-Osidental",
+               "",
+            };
         final Object[][] data = new Object[][] {
             { "America/Los_Angeles", America_Pacific },
             { "America/Denver", America_Mountain },
@@ -213,230 +245,298 @@ public class TimeZoneNames_kea extends TimeZoneNamesBundle {
             { "America/Chicago", America_Central },
             { "America/New_York", America_Eastern },
             { "America/Indianapolis", America_Eastern },
+            { "America/Anchorage", Alaska },
             { "America/Halifax", Atlantic },
+            { "America/Sitka", Alaska },
             { "Europe/Paris", Europe_Central },
+            { "GMT", GMT },
             { "Europe/Bucharest", Europe_Eastern },
-            { "UTC", EMPTY_ZONE },
-            { "Africa/Nairobi", Africa_Eastern },
-            { "Africa/Libreville", Africa_Western },
-            { "America/Marigot", Atlantic },
-            { "Africa/Maputo", Africa_Central },
-            { "America/El_Salvador", America_Central },
-            { "America/Kentucky/Monticello", America_Eastern },
-            { "America/Coral_Harbour", America_Eastern },
-            { "Africa/Cairo", Europe_Eastern },
-            { "Africa/Mbabane", Africa_Southern },
-            { "America/Aruba", Atlantic },
-            { "America/North_Dakota/Center", America_Central },
-            { "America/Guatemala", America_Central },
-            { "Australia/Hobart", Australia_Eastern },
-            { "PNT", America_Mountain },
-            { "America/Cayman", America_Eastern },
-            { "America/Belize", America_Central },
-            { "America/Panama", America_Eastern },
-            { "Europe/San_Marino", Europe_Central },
-            { "America/Indiana/Tell_City", America_Central },
-            { "America/Tijuana", America_Pacific },
-            { "America/Managua", America_Central },
-            { "America/Indiana/Petersburg", America_Eastern },
-            { "Europe/Brussels", Europe_Central },
-            { "Africa/Douala", Africa_Western },
-            { "America/Ojinaga", America_Mountain },
-            { "Europe/Warsaw", Europe_Central },
-            { "America/Tegucigalpa", America_Central },
-            { "Asia/Damascus", Europe_Eastern },
-            { "Europe/Luxembourg", Europe_Central },
-            { "ART", Europe_Eastern },
-            { "Europe/Zaporozhye", Europe_Eastern },
-            { "Africa/Brazzaville", Africa_Western },
-            { "Africa/Porto-Novo", Africa_Western },
-            { "Africa/Dar_es_Salaam", Africa_Eastern },
-            { "Atlantic/Madeira", Europe_Western },
-            { "America/Thunder_Bay", America_Eastern },
-            { "America/Grand_Turk", America_Eastern },
-            { "Africa/Addis_Ababa", Africa_Eastern },
-            { "Europe/Uzhgorod", Europe_Eastern },
-            { "America/Indiana/Marengo", America_Eastern },
-            { "Africa/Kigali", Africa_Central },
-            { "America/Creston", America_Mountain },
+            { "UTC", ETC_UTC },
             { "ACT", Australia_Central },
-            { "America/Mexico_City", America_Central },
-            { "Africa/Tunis", Europe_Central },
-            { "Europe/Andorra", Europe_Central },
-            { "Africa/Tripoli", Europe_Eastern },
-            { "Indian/Comoro", Africa_Eastern },
-            { "America/Matamoros", America_Central },
-            { "America/Blanc-Sablon", Atlantic },
-            { "Europe/Kaliningrad", Europe_Eastern },
-            { "Africa/Windhoek", Africa_Central },
-            { "Europe/Lisbon", Europe_Western },
-            { "PRT", Atlantic },
-            { "Europe/Oslo", Europe_Central },
-            { "Africa/Mogadishu", Africa_Eastern },
-            { "Australia/Perth", Australia_Western },
-            { "CST6CDT", America_Central },
-            { "Atlantic/Canary", Europe_Western },
-            { "America/Menominee", America_Central },
-            { "Europe/Malta", Europe_Central },
-            { "America/Resolute", America_Central },
-            { "Africa/Asmera", Africa_Eastern },
-            { "Europe/Busingen", Europe_Central },
-            { "Africa/Kampala", Africa_Eastern },
             { "AET", Australia_Eastern },
-            { "PST", America_Pacific },
-            { "SystemV/EST5", America_Eastern },
-            { "Africa/Malabo", Africa_Western },
-            { "Europe/Skopje", Europe_Central },
-            { "America/Edmonton", America_Mountain },
-            { "Europe/Podgorica", Europe_Central },
-            { "Europe/Sarajevo", Europe_Central },
-            { "Africa/Bujumbura", Africa_Central },
-            { "America/Santo_Domingo", Atlantic },
-            { "America/Glace_Bay", Atlantic },
-            { "Africa/Lagos", Africa_Western },
-            { "Europe/Kiev", Europe_Eastern },
-            { "Europe/Rome", Europe_Central },
-            { "America/Port-au-Prince", America_Eastern },
-            { "America/St_Barthelemy", Atlantic },
-            { "Africa/Luanda", Africa_Western },
-            { "America/Nipigon", America_Eastern },
-            { "America/Regina", America_Central },
-            { "Atlantic/Jan_Mayen", Europe_Central },
-            { "America/Dawson_Creek", America_Mountain },
-            { "Africa/Algiers", Europe_Central },
-            { "Europe/Mariehamn", Europe_Eastern },
-            { "America/St_Thomas", Atlantic },
-            { "Europe/Zurich", Europe_Central },
-            { "America/Anguilla", Atlantic },
-            { "Europe/Vilnius", Europe_Eastern },
-            { "America/Cancun", America_Eastern },
-            { "Africa/Maseru", Africa_Southern },
-            { "Europe/Gibraltar", Europe_Central },
-            { "Africa/Kinshasa", Africa_Western },
-            { "Australia/Sydney", Australia_Eastern },
-            { "Africa/Lubumbashi", Africa_Central },
-            { "timezone.excity.America/Indianapolis", "Indianapolis" },
-            { "America/St_Lucia", Atlantic },
-            { "Europe/Madrid", Europe_Central },
-            { "America/Bahia_Banderas", America_Central },
-            { "America/Montserrat", Atlantic },
-            { "America/Cambridge_Bay", America_Mountain },
-            { "Indian/Antananarivo", Africa_Eastern },
-            { "Europe/Vaduz", Europe_Central },
-            { "Australia/Brisbane", Australia_Eastern },
-            { "Indian/Mayotte", Africa_Eastern },
-            { "America/Barbados", Atlantic },
-            { "America/Louisville", America_Eastern },
-            { "America/Lower_Princes", Atlantic },
-            { "America/Vancouver", America_Pacific },
-            { "Africa/Blantyre", Africa_Central },
-            { "America/Detroit", America_Eastern },
-            { "Europe/Ljubljana", Europe_Central },
-            { "America/Thule", Atlantic },
-            { "America/Curacao", Atlantic },
-            { "Africa/Lusaka", Africa_Central },
-            { "America/Martinique", Atlantic },
-            { "Europe/Berlin", Europe_Central },
-            { "Europe/Chisinau", Europe_Eastern },
-            { "America/Puerto_Rico", Atlantic },
-            { "America/Rankin_Inlet", America_Central },
-            { "Europe/Stockholm", Europe_Central },
-            { "SystemV/CST6CDT", America_Central },
-            { "America/Tortola", Atlantic },
-            { "Europe/Budapest", Europe_Central },
-            { "Australia/Eucla", Australia_CentralWestern },
-            { "Europe/Zagreb", Europe_Central },
-            { "America/Port_of_Spain", Atlantic },
-            { "Europe/Helsinki", Europe_Eastern },
-            { "Asia/Beirut", Europe_Eastern },
-            { "Africa/Harare", Africa_Central },
-            { "Europe/Tallinn", Europe_Eastern },
-            { "Africa/Khartoum", Africa_Central },
-            { "Africa/Johannesburg", Africa_Southern },
-            { "Africa/Ndjamena", Africa_Western },
-            { "EAT", Africa_Eastern },
-            { "America/Rainy_River", America_Central },
-            { "Africa/Bangui", Africa_Western },
-            { "Europe/Belgrade", Europe_Central },
-            { "SystemV/AST4", Atlantic },
-            { "America/Yellowknife", America_Mountain },
-            { "America/Indiana/Vevay", America_Eastern },
-            { "Africa/Juba", Africa_Eastern },
-            { "Africa/Ceuta", Europe_Central },
-            { "America/Goose_Bay", Atlantic },
-            { "America/Swift_Current", America_Central },
-            { "Australia/Adelaide", Australia_Central },
-            { "America/Pangnirtung", America_Eastern },
-            { "Africa/Djibouti", Africa_Eastern },
-            { "Europe/Sofia", Europe_Eastern },
-            { "Africa/Niamey", Africa_Western },
-            { "Europe/Prague", Europe_Central },
-            { "America/Indiana/Vincennes", America_Eastern },
-            { "America/Whitehorse", America_Pacific },
-            { "America/Kralendijk", Atlantic },
-            { "ECT", Europe_Central },
-            { "America/Antigua", Atlantic },
-            { "America/Montreal", America_Eastern },
-            { "America/Inuvik", America_Mountain },
-            { "America/Iqaluit", America_Eastern },
-            { "Asia/Nicosia", Europe_Eastern },
-            { "America/Moncton", Atlantic },
-            { "Africa/Gaborone", Africa_Central },
-            { "America/Indiana/Winamac", America_Eastern },
-            { "SystemV/MST7MDT", America_Mountain },
-            { "America/St_Vincent", Atlantic },
-            { "Asia/Gaza", Europe_Eastern },
-            { "PST8PDT", America_Pacific },
-            { "timezone.excity.Etc/Unknown", "Sidadi Diskonxedu" },
-            { "America/Grenada", Atlantic },
-            { "Australia/Darwin", Australia_Central },
-            { "Atlantic/Faeroe", Europe_Western },
-            { "Europe/Bratislava", Europe_Central },
-            { "Antarctica/Casey", Australia_Western },
-            { "Europe/Copenhagen", Europe_Central },
-            { "Europe/Vienna", Europe_Central },
-            { "America/Merida", America_Central },
+            { "ART", Europe_Eastern },
+            { "AST", Alaska },
             { "CAT", Africa_Central },
-            { "Europe/Tirane", Europe_Central },
-            { "timezone.excity.America/Blanc-Sablon", "Blank-Sablon" },
-            { "SystemV/MST7", America_Mountain },
-            { "America/St_Kitts", Atlantic },
-            { "Arctic/Longyearbyen", Europe_Central },
-            { "Australia/Broken_Hill", Australia_Central },
-            { "America/Fort_Nelson", America_Mountain },
-            { "Europe/Riga", Europe_Eastern },
-            { "America/Dominica", Atlantic },
-            { "America/Guadeloupe", Atlantic },
-            { "Asia/Hebron", Europe_Eastern },
-            { "SystemV/PST8PDT", America_Pacific },
-            { "America/Boise", America_Mountain },
-            { "Australia/Currie", Australia_Eastern },
-            { "EST5EDT", America_Eastern },
-            { "America/North_Dakota/New_Salem", America_Central },
-            { "Australia/Melbourne", Australia_Eastern },
-            { "Atlantic/Bermuda", Atlantic },
-            { "America/Costa_Rica", America_Central },
-            { "America/Dawson", America_Pacific },
-            { "America/Shiprock", America_Mountain },
-            { "America/Winnipeg", America_Central },
-            { "Europe/Amsterdam", Europe_Central },
-            { "America/Indiana/Knox", America_Central },
-            { "timezone.excity.Atlantic/Bermuda", "Bermuda" },
-            { "America/North_Dakota/Beulah", America_Central },
-            { "Europe/Vatican", Europe_Central },
-            { "Asia/Amman", Europe_Eastern },
-            { "SystemV/AST4ADT", Atlantic },
             { "CST", America_Central },
-            { "America/Toronto", America_Eastern },
-            { "Australia/Lindeman", Australia_Eastern },
+            { "EAT", Africa_Eastern },
+            { "ECT", Europe_Central },
+            { "PNT", America_Mountain },
+            { "PRT", Atlantic },
+            { "PST", America_Pacific },
+            { "CST6CDT", America_Central },
+            { "EST5EDT", America_Eastern },
+            { "Etc/GMT", GMT },
+            { "Etc/UTC", ETC_UTC },
             { "MST7MDT", America_Mountain },
-            { "America/Monterrey", America_Central },
-            { "SystemV/EST5EDT", America_Eastern },
-            { "America/Nassau", America_Eastern },
-            { "America/Jamaica", America_Eastern },
-            { "Europe/Athens", Europe_Eastern },
+            { "PST8PDT", America_Pacific },
+            { "Asia/Gaza", Europe_Eastern },
+            { "Asia/Amman", Europe_Eastern },
+            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Lome", GMT },
+            { "Asia/Beirut", Europe_Eastern },
+            { "Asia/Hebron", Europe_Eastern },
+            { "Europe/Kiev", Europe_Eastern },
+            { "Europe/Oslo", Europe_Central },
+            { "Europe/Riga", Europe_Eastern },
+            { "Europe/Rome", Europe_Central },
+            { "Africa/Accra", GMT },
+            { "Africa/Cairo", Europe_Eastern },
+            { "Africa/Ceuta", Europe_Central },
+            { "Africa/Dakar", GMT },
+            { "Africa/Lagos", Africa_Western },
+            { "Africa/Tunis", Europe_Central },
+            { "America/Nome", Alaska },
+            { "Asia/Nicosia", Europe_Eastern },
+            { "Europe/Malta", Europe_Central },
+            { "Europe/Sofia", Europe_Eastern },
+            { "Europe/Vaduz", Europe_Central },
+            { "SystemV/AST4", Atlantic },
             { "SystemV/CST6", America_Central },
+            { "SystemV/EST5", America_Eastern },
+            { "SystemV/MST7", America_Mountain },
+            { "Africa/Asmera", Africa_Eastern },
+            { "Africa/Bamako", GMT },
+            { "Africa/Bangui", Africa_Western },
+            { "Africa/Banjul", GMT },
+            { "Africa/Bissau", GMT },
+            { "Africa/Douala", Africa_Western },
+            { "Africa/Harare", Africa_Central },
+            { "Africa/Kigali", Africa_Central },
+            { "Africa/Luanda", Africa_Western },
+            { "Africa/Lusaka", Africa_Central },
+            { "Africa/Malabo", Africa_Western },
+            { "Africa/Maputo", Africa_Central },
+            { "Africa/Maseru", Africa_Southern },
+            { "Africa/Niamey", Africa_Western },
+            { "America/Aruba", Atlantic },
+            { "America/Boise", America_Mountain },
+            { "America/Thule", Atlantic },
+            { "Asia/Damascus", Europe_Eastern },
+            { "Europe/Athens", Europe_Eastern },
+            { "Europe/Berlin", Europe_Central },
+            { "Europe/Dublin",
+                new String[] {
+                    "Ora M\u00e9diu di Greenwich",
+                    "",
+                    "Ora Padron di Irlanda",
+                    "",
+                    "",
+                    "",
+                }
+            },
+            { "Europe/Jersey", GMT },
+            { "Europe/Lisbon", Europe_Western },
+            { "Europe/London",
+                new String[] {
+                    "Ora M\u00e9diu di Greenwich",
+                    "",
+                    "Ora di Veron Brit\u00e1niku",
+                    "",
+                    "",
+                    "",
+                }
+            },
+            { "Europe/Madrid", Europe_Central },
             { "Europe/Monaco", Europe_Central },
+            { "Europe/Prague", Europe_Central },
+            { "Europe/Skopje", Europe_Central },
+            { "Europe/Tirane", Europe_Central },
+            { "Europe/Vienna", Europe_Central },
+            { "Europe/Warsaw", Europe_Central },
+            { "Europe/Zagreb", Europe_Central },
+            { "Europe/Zurich", Europe_Central },
+            { "Indian/Comoro", Africa_Eastern },
+            { "Africa/Abidjan", GMT },
+            { "Africa/Algiers", Europe_Central },
+            { "Africa/Conakry", GMT },
+            { "Africa/Kampala", Africa_Eastern },
+            { "Africa/Mbabane", Africa_Southern },
+            { "Africa/Nairobi", Africa_Eastern },
+            { "Africa/Tripoli", Europe_Eastern },
+            { "America/Belize", America_Central },
+            { "America/Cancun", America_Eastern },
+            { "America/Cayman", America_Eastern },
+            { "America/Dawson", America_Pacific },
+            { "America/Havana", Cuba },
+            { "America/Inuvik", America_Mountain },
+            { "America/Juneau", Alaska },
+            { "America/Merida", America_Central },
+            { "America/Nassau", America_Eastern },
+            { "America/Panama", America_Eastern },
+            { "America/Regina", America_Central },
+            { "Europe/Andorra", Europe_Central },
+            { "Europe/Belfast",
+                new String[] {
+                    "Ora M\u00e9diu di Greenwich",
+                    "",
+                    "Ora di Veron Brit\u00e1niku",
+                    "",
+                    "",
+                    "",
+                }
+            },
+            { "Europe/Tallinn", Europe_Eastern },
+            { "Europe/Vatican", Europe_Central },
+            { "Europe/Vilnius", Europe_Eastern },
+            { "Indian/Mayotte", Africa_Eastern },
+            { "Africa/Blantyre", Africa_Central },
+            { "Africa/Djibouti", Africa_Eastern },
+            { "Africa/Freetown", GMT },
+            { "Africa/Gaborone", Africa_Central },
+            { "Africa/Khartoum", Africa_Central },
+            { "Africa/Kinshasa", Africa_Western },
+            { "Africa/Monrovia", GMT },
+            { "Africa/Ndjamena", Africa_Western },
+            { "Africa/Sao_Tome", GMT },
+            { "Africa/Timbuktu", GMT },
+            { "Africa/Windhoek", Africa_Central },
+            { "America/Antigua", Atlantic },
+            { "America/Creston", America_Mountain },
+            { "America/Curacao", Atlantic },
+            { "America/Detroit", America_Eastern },
+            { "America/Grenada", Atlantic },
+            { "America/Iqaluit", America_Eastern },
+            { "America/Jamaica", America_Eastern },
+            { "America/Managua", America_Central },
+            { "America/Marigot", Atlantic },
+            { "America/Moncton", Atlantic },
+            { "America/Nipigon", America_Eastern },
+            { "America/Ojinaga", America_Mountain },
+            { "America/Tijuana", America_Pacific },
+            { "America/Toronto", America_Eastern },
+            { "America/Tortola", Atlantic },
+            { "America/Yakutat", Alaska },
+            { "Atlantic/Canary", Europe_Western },
+            { "Atlantic/Faeroe", Europe_Western },
+            { "Australia/Eucla", Australia_CentralWestern },
+            { "Australia/Perth", Australia_Western },
+            { "Europe/Belgrade", Europe_Central },
+            { "Europe/Brussels", Europe_Central },
+            { "Europe/Budapest", Europe_Central },
+            { "Europe/Busingen", Europe_Central },
+            { "Europe/Chisinau", Europe_Eastern },
+            { "Europe/Guernsey", GMT },
+            { "Europe/Helsinki", Europe_Eastern },
+            { "Europe/Sarajevo", Europe_Central },
+            { "Europe/Uzhgorod", Europe_Eastern },
+            { "SystemV/AST4ADT", Atlantic },
+            { "SystemV/CST6CDT", America_Central },
+            { "SystemV/EST5EDT", America_Eastern },
+            { "SystemV/MST7MDT", America_Mountain },
+            { "SystemV/PST8PDT", America_Pacific },
+            { "SystemV/YST9YDT", Alaska },
+            { "Africa/Bujumbura", Africa_Central },
+            { "Africa/Mogadishu", Africa_Eastern },
+            { "America/Anguilla", Atlantic },
+            { "America/Barbados", Atlantic },
+            { "America/Dominica", Atlantic },
+            { "America/Edmonton", America_Mountain },
+            { "America/Montreal", America_Eastern },
+            { "America/Resolute", America_Central },
+            { "America/Shiprock", America_Mountain },
+            { "America/St_Kitts", Atlantic },
+            { "America/St_Lucia", Atlantic },
+            { "America/Winnipeg", America_Central },
+            { "Antarctica/Casey", Australia_Western },
+            { "Antarctica/Troll", GMT },
+            { "Atlantic/Bermuda", Atlantic },
+            { "Atlantic/Madeira", Europe_Western },
+            { "Australia/Currie", Australia_Eastern },
+            { "Australia/Darwin", Australia_Central },
+            { "Australia/Hobart", Australia_Eastern },
+            { "Australia/Sydney", Australia_Eastern },
+            { "Europe/Amsterdam", Europe_Central },
+            { "Europe/Gibraltar", Europe_Central },
+            { "Europe/Ljubljana", Europe_Central },
+            { "Europe/Mariehamn", Europe_Eastern },
+            { "Europe/Podgorica", Europe_Central },
+            { "Europe/Stockholm", Europe_Central },
+            { "Africa/Libreville", Africa_Western },
+            { "Africa/Lubumbashi", Africa_Central },
+            { "Africa/Nouakchott", GMT },
+            { "Africa/Porto-Novo", Africa_Western },
+            { "America/Glace_Bay", Atlantic },
+            { "America/Goose_Bay", Atlantic },
+            { "America/Guatemala", America_Central },
+            { "America/Matamoros", America_Central },
+            { "America/Menominee", America_Central },
+            { "America/Monterrey", America_Central },
+            { "America/St_Thomas", Atlantic },
+            { "America/Vancouver", America_Pacific },
+            { "Europe/Bratislava", Europe_Central },
+            { "Europe/Copenhagen", Europe_Central },
+            { "Europe/Luxembourg", Europe_Central },
+            { "Europe/San_Marino", Europe_Central },
+            { "Europe/Zaporozhye", Europe_Eastern },
+            { "Africa/Addis_Ababa", Africa_Eastern },
+            { "Africa/Brazzaville", Africa_Western },
+            { "Africa/Ouagadougou", GMT },
+            { "America/Costa_Rica", America_Central },
+            { "America/Grand_Turk", America_Eastern },
+            { "America/Guadeloupe", Atlantic },
+            { "America/Kralendijk", Atlantic },
+            { "America/Louisville", America_Eastern },
+            { "America/Martinique", Atlantic },
+            { "America/Metlakatla", Alaska },
+            { "America/Montserrat", Atlantic },
+            { "America/St_Vincent", Atlantic },
+            { "America/Whitehorse", America_Pacific },
+            { "Atlantic/Jan_Mayen", Europe_Central },
+            { "Atlantic/Reykjavik", GMT },
+            { "Atlantic/St_Helena", GMT },
+            { "Australia/Adelaide", Australia_Central },
+            { "Australia/Brisbane", Australia_Eastern },
+            { "Australia/Lindeman", Australia_Eastern },
+            { "Europe/Isle_of_Man", GMT },
+            { "Europe/Kaliningrad", Europe_Eastern },
+            { "Africa/Johannesburg", Africa_Southern },
+            { "America/El_Salvador", America_Central },
+            { "America/Fort_Nelson", America_Mountain },
+            { "America/Mexico_City", America_Central },
+            { "America/Pangnirtung", America_Eastern },
+            { "America/Puerto_Rico", Atlantic },
+            { "America/Rainy_River", America_Central },
+            { "America/Tegucigalpa", America_Central },
+            { "America/Thunder_Bay", America_Eastern },
+            { "America/Yellowknife", America_Mountain },
+            { "Arctic/Longyearbyen", Europe_Central },
+            { "Atlantic/Cape_Verde", Cape_Verde },
+            { "Australia/Melbourne", Australia_Eastern },
+            { "Indian/Antananarivo", Africa_Eastern },
+            { "Africa/Dar_es_Salaam", Africa_Eastern },
+            { "America/Blanc-Sablon", Atlantic },
+            { "America/Danmarkshavn", GMT },
+            { "America/Dawson_Creek", America_Mountain },
+            { "America/Indiana/Knox", America_Central },
+            { "America/Rankin_Inlet", America_Central },
+            { "America/Cambridge_Bay", America_Mountain },
+            { "America/Coral_Harbour", America_Eastern },
+            { "America/Indiana/Vevay", America_Eastern },
+            { "America/Lower_Princes", Atlantic },
+            { "America/Port_of_Spain", Atlantic },
+            { "America/Santo_Domingo", Atlantic },
+            { "America/St_Barthelemy", Atlantic },
+            { "America/Swift_Current", America_Central },
+            { "Australia/Broken_Hill", Australia_Central },
+            { "America/Bahia_Banderas", America_Central },
+            { "America/Port-au-Prince", America_Eastern },
+            { "America/Indiana/Marengo", America_Eastern },
+            { "America/Indiana/Winamac", America_Eastern },
+            { "America/Indiana/Tell_City", America_Central },
+            { "America/Indiana/Vincennes", America_Eastern },
+            { "America/Indiana/Petersburg", America_Eastern },
+            { "America/Kentucky/Monticello", America_Eastern },
+            { "America/North_Dakota/Beulah", America_Central },
+            { "America/North_Dakota/Center", America_Central },
+            { "timezone.excity.Etc/Unknown", "Sidadi diskonxedu" },
+            { "America/North_Dakota/New_Salem", America_Central },
+            { "timezone.excity.America/Cancun", "Kankun" },
+            { "timezone.excity.America/Chicago", "Xikagu" },
+            { "timezone.excity.Atlantic/Bermuda", "Bermuda" },
+            { "timezone.excity.America/Chihuahua", "Xiu\u00e1ua" },
+            { "timezone.excity.America/Costa_Rica", "Kosta Rika" },
+            { "timezone.excity.America/Blanc-Sablon", "Blank-Sablon" },
+            { "timezone.excity.America/Indianapolis", "Indianapolis" },
         };
         return data;
     }
