@@ -70,92 +70,12 @@ import sun.util.resources.TimeZoneNamesBundle;
 public class TimeZoneNames_ps_PK extends TimeZoneNamesBundle {
     @Override
     protected final Object[][] getContents() {
-        final String[] Japan = new String[] {
-               "\u062f \u062c\u0627\u067e\u0627\u0646 \u0645\u0639\u064a\u0627\u0631\u064a \u0648\u062e\u062a",
+        final String[] Apia = new String[] {
+               "\u0627\u067e\u06cc\u0627 \u0645\u0639\u064a\u0627\u0631\u064a \u0648\u062e\u062a",
                "",
-               "\u062c\u0627\u067e\u0627\u0646 \u062f \u0631\u06bc\u0627 \u0648\u0631\u0681\u06d2 \u0648\u062e\u062a",
+               "\u062f \u0627\u067e\u06cc\u0627 \u062f \u0648\u0631\u0681\u06d2 \u0648\u062e\u062a",
                "",
-               "\u062c\u0627\u067e\u0627\u0646 \u062f \u0648\u062e\u062a",
-               "",
-            };
-        final String[] America_Eastern = new String[] {
-               "\u062e\u062a\u064a\u0681 \u0645\u0639\u064a\u0627\u0631\u064a \u0648\u062e\u062a",
-               "",
-               "\u062e\u062a\u064a\u0681 \u062f \u0631\u06bc\u0627 \u0648\u0631\u0681\u06d2 \u0648\u062e\u062a",
-               "",
-               "\u062e\u062a\u06cc\u0681 \u0648\u062e\u062a",
-               "",
-            };
-        final String[] Hawaii_Aleutian = new String[] {
-               "\u0647\u0648\u0627\u06cc\u06cc \u0627\u0644\u06cc\u0648\u062a\u06cc\u0646 \u0645\u0639\u06cc\u0627\u0631\u06cc \u0648\u062e\u062a",
-               "",
-               "\u0647\u0648\u0627\u06cc\u06cc \u0627\u0644\u06cc\u0648\u062a\u06cc\u0646 \u0631\u06bc\u0627 \u0648\u0631\u0681\u06d2 \u0648\u062e\u062a",
-               "",
-               "\u0647\u0648\u0627\u06cc\u06cc \u0627\u0644\u06cc\u0648\u062a\u06cc\u0646 \u0648\u062e\u062a",
-               "",
-            };
-        final String[] Lord_Howe = new String[] {
-               "\u0631\u0628 \u0647\u0627\u06cc \u0645\u0639\u06cc\u0627\u0631\u064a \u0648\u062e\u062a",
-               "",
-               "\u0631\u0628 \u0647\u0627\u0648 \u062f \u0648\u0631\u0681\u06d2 \u062f \u0631\u06bc\u0627 \u0648\u062e\u062a",
-               "",
-               "\u0631\u0628 \u0647\u0627\u06cc \u0648\u062e\u062a",
-               "",
-            };
-        final String[] New_Zealand = new String[] {
-               "\u062f \u0646\u06cc\u0648\u0632\u06cc \u0644\u06cc\u0646\u0688 \u0645\u0639\u06cc\u0627\u0631\u064a \u0648\u062e\u062a",
-               "",
-               "\u062f \u0646\u06cc\u0648\u0632\u06cc \u0644\u06cc\u0646\u0688 \u062f \u0648\u0631\u0681\u06d2 \u062f \u0631\u06bc\u0627 \u0648\u062e\u062a",
-               "",
-               "\u062f \u0646\u06cc\u0648\u0632\u06cc \u0644\u06cc\u0646\u0688 \u0648\u062e\u062a",
-               "",
-            };
-        final String[] America_Pacific = new String[] {
-               "\u062f \u067e\u06cc\u0633\u0641\u06a9 \u0645\u0639\u064a\u0627\u0631\u064a \u0648\u062e\u062a",
-               "",
-               "\u067e\u06cc\u0633\u0641\u06a9 \u062f \u0631\u06bc\u0627 \u0648\u0631\u0681\u06d2 \u0648\u062e\u062a",
-               "",
-               "\u067e\u06cc\u0633\u0641\u06a9 \u0648\u062e\u062a",
-               "",
-            };
-        final String[] Europe_Western = new String[] {
-               "\u062f \u0644\u0648\u062f\u06cc\u0681\u06d2 \u0627\u0631\u0648\u067e\u0627 \u0645\u0639\u06cc\u0627\u0631\u064a \u0648\u062e\u062a",
-               "",
-               "\u062f \u0644\u0648\u062f\u06cc\u0681\u06d2 \u0627\u0648\u0631\u067e\u0627 \u062f \u0627\u0648\u0693\u064a \u0648\u062e\u062a",
-               "",
-               "\u0644\u0648\u06d0\u062f\u064a\u0632\u06d2 \u0627\u0631\u0648\u067e\u0627 \u0648\u062e\u062a",
-               "",
-            };
-        final String[] Samoa = new String[] {
-               "\u0633\u0645\u0648\u0689 \u0645\u0639\u064a\u0627\u0631\u064a \u0648\u062e\u062a",
-               "",
-               "\u062f \u0633\u0645\u0648\u0627 \u062f \u0648\u0631\u0681\u06d2 \u0631\u0648\u069a\u0627\u0646\u0647 \u06a9\u0648\u0644",
-               "",
-               "\u0633\u0645\u0648\u0627 \u0648\u062e\u062a",
-               "",
-            };
-        final String[] Newfoundland = new String[] {
-               "\u062f \u0646\u0648\u064a \u0641\u06cc\u0644\u0689\u0644\u06cc\u0646\u0689 \u0645\u0639\u06cc\u0627\u0631\u06cc \u0648\u062e\u062a",
-               "",
-               "\u062f \u0646\u0648\u064a \u0641\u06cc\u0644\u0689\u0644\u06cc\u0646\u0689 \u0631\u06bc\u0627 \u0648\u0631\u0681\u06d2 \u0648\u062e\u062a",
-               "",
-               "\u062f \u0646\u0648\u064a \u0641\u06cc\u0644\u0689\u0644\u06cc\u0646\u0689 \u0648\u062e\u062a",
-               "",
-            };
-        final String[] Atlantic = new String[] {
-               "\u0627\u062a\u0644\u0627\u0646\u062a\u06cc\u06a9 \u0645\u0639\u064a\u0627\u0631\u064a \u0648\u062e\u062a",
-               "",
-               "\u0627\u062a\u0644\u0627\u0646\u062a\u06cc\u06a9 \u062f \u0631\u06bc\u0627 \u0648\u0631\u0681\u06d2 \u0648\u062e\u062a",
-               "",
-               "\u0627\u062a\u0644\u0627\u0646\u062a\u06cc\u06a9 \u062f \u0648\u062e\u062a",
-               "",
-            };
-        final String[] Mexico_Pacific = new String[] {
-               "\u0645\u06a9\u0633\u06cc\u06a9\u0646 \u067e\u06cc\u0633\u0641\u06a9 \u0645\u0639\u06cc\u0627\u0631\u06cc \u0648\u062e\u062a",
-               "",
-               "\u0645\u06a9\u0633\u06cc\u06a9\u0646 \u067e\u06cc\u0633\u0641\u06a9 \u0631\u06bc\u0627 \u0648\u0631\u0681\u06d2 \u0648\u062e\u062a",
-               "",
-               "\u0645\u06a9\u0633\u06cc\u06a9\u0646 \u067e\u06cc\u0633\u0641\u06a9 \u0648\u062e\u062a",
+               "\u0627\u067e\u06cc\u0627 \u0648\u062e\u062a",
                "",
             };
         final String[] Cuba = new String[] {
@@ -163,103 +83,47 @@ public class TimeZoneNames_ps_PK extends TimeZoneNamesBundle {
                "",
                "\u06a9\u06cc\u0648\u0628\u0627 \u062f \u0631\u06bc\u0627 \u0648\u0631\u0681\u06d2 \u0648\u062e\u062a",
                "",
-               "\u06a9\u06cc\u0648\u0628\u0627 \u062f \u0648\u062e\u062a",
-               "",
-            };
-        final String[] Pierre_Miquelon = new String[] {
-               "\u0633\u06cc\u0646\u067c \u067e\u06cc\u06cc\u0631\u0627 \u0648 \u0645\u064a\u06a9\u0644\u064a\u0646 \u0645\u0639\u06cc\u0627\u0631\u06cc \u0648\u062e\u062a",
-               "",
-               "\u0633\u06cc\u0646\u067c \u067e\u06cc\u06cc\u0631\u0627 \u0648 \u0645\u064a\u06a9\u0644\u064a\u0646 \u0631\u06bc\u0627 \u0648\u0631\u0681\u06d2 \u0648\u062e\u062a",
-               "",
-               "\u0633\u06cc\u0646\u067c \u067e\u06cc\u06cc\u0631\u0627 \u0648 \u0645\u064a\u06a9\u0644\u064a\u0646 \u0648\u062e\u062a",
-               "",
-            };
-        final String[] French_Southern = new String[] {
-               "\u062f \u0641\u0631\u0627\u0646\u0633\u06d2 \u0633\u0648\u06cc\u0644 \u0627\u0648 \u0627\u0646\u067c\u0627\u0631\u067c\u064a\u06a9 \u0648\u062e\u062a",
-               "",
-               "",
-               "",
-               "",
+               "\u06a9\u064a\u0648\u0628\u0627 \u0648\u062e\u062a",
                "",
             };
         final String[] Iran = new String[] {
-               "\u062f \u0627\u06cc\u0631\u0627\u0646 \u0645\u0639\u064a\u0627\u0631\u064a \u0648\u062e\u062a",
+               "\u0627\u06cc\u0631\u0627\u0646 \u0645\u0639\u064a\u0627\u0631\u064a \u0648\u062e\u062a",
                "",
                "\u062f \u0627\u06cc\u0631\u0627\u0646 \u062f \u0648\u0631\u0681\u06d2 \u0648\u062e\u062a",
                "",
-               "\u062f \u0627\u06cc\u0631\u0627\u0646 \u0648\u062e\u062a",
+               "\u0627\u06cc\u0631\u0627\u0646 \u0648\u062e\u062a",
                "",
             };
-        final String[] EMPTY_ZONE = new String[] {
-               "",
-               "",
-               "",
+        final String[] China = new String[] {
+               "\u0686\u06cc\u0646 \u0645\u0639\u06cc\u0627\u0631\u064a \u0648\u062e\u062a",
                "",
+               "\u062f \u0686\u064a\u0646 \u062f \u0631\u06bc\u0627 \u0648\u0631\u0681\u06d2 \u0648\u062e\u062a",
                "",
+               "\u0686\u064a\u0646 \u0648\u062e\u062a",
                "",
             };
-        final String[] Mexico_Northwest = new String[] {
-               "\u062f \u0634\u0645\u0627\u0644 \u0644\u0648\u06cc\u062f\u06cc\u0681 \u0645\u06a9\u0633\u06cc\u06a9\u0648 \u0645\u0639\u06cc\u0627\u0631\u064a \u0648\u062e\u062a",
+        final String[] Japan = new String[] {
+               "\u062c\u0627\u067e\u0627\u0646 \u0645\u0639\u064a\u0627\u0631\u064a \u0648\u062e\u062a",
                "",
-               "\u062f \u0634\u0645\u0627\u0644 \u0644\u0648\u06cc\u062f\u06cc\u0681 \u0645\u06a9\u0633\u06cc\u06a9\u0648 \u0631\u06bc\u0627 \u0648\u0631\u0681\u06d2 \u0648\u062e\u062a",
+               "\u062c\u0627\u067e\u0627\u0646 \u062f \u0631\u06bc\u0627 \u0648\u0631\u0681\u06d2 \u0648\u062e\u062a",
                "",
-               "\u062f \u0634\u0645\u0627\u0644 \u0644\u0648\u06cc\u062f\u06cc\u0681 \u0645\u06a9\u0633\u06cc\u06a9\u0648 \u0648\u062e\u062a",
-               "",
-            };
-        final String[] Israel = new String[] {
-               "\u062f \u0627\u0633\u0631\u0627\u06cc\u06cc\u0644 \u0645\u0639\u064a\u0627\u0631\u064a \u0648\u062e\u062a",
-               "",
-               "\u062f \u0627\u0633\u0631\u0627\u06cc\u06cc\u0644\u0648 \u062f \u0648\u0631\u0681\u06d2 \u0648\u062e\u062a",
-               "",
-               "\u062f \u0627\u0633\u0631\u0627\u06cc\u06cc\u0644 \u0648\u062e\u062a",
+               "\u062c\u0627\u067e\u0627\u0646 \u0648\u062e\u062a",
                "",
             };
         final String[] Korea = new String[] {
-               "\u06a9\u0648\u0631\u064a\u0627 \u0645\u0639\u064a\u0627\u0631\u064a \u0648\u062e\u062a",
+               "\u06a9\u0648\u0631\u064a\u0627\u064a\u064a \u0645\u0639\u064a\u0627\u0631\u064a \u0648\u062e\u062a",
                "",
                "\u062f \u06a9\u0648\u0631\u06cc\u0627 \u062f \u0648\u0631\u0681\u06d2 \u062f \u0648\u0631\u0681\u06d2 \u0648\u062e\u062a",
                "",
-               "\u06a9\u0648\u0631\u064a\u0627 \u0648\u062e\u062a",
+               "\u06a9\u0648\u0631\u064a\u0627\u064a\u064a \u0648\u062e\u062a",
                "",
             };
-        final String[] Line_Islands = new String[] {
-               "\u062f \u06a9\u0631\u069a\u06d2 \u067c\u0627\u067c\u0648\u0628\u064a \u0648\u062e\u062a",
+        final String[] Samoa = new String[] {
+               "\u0633\u0645\u0648\u0627 \u0645\u0639\u064a\u0627\u0631\u064a \u0648\u062e\u062a",
                "",
+               "\u062f \u0633\u0645\u0648\u0627 \u062f \u0648\u0631\u0681\u06d2 \u0631\u0648\u069a\u0627\u0646\u0647 \u06a9\u0648\u0644",
                "",
-               "",
-               "",
-               "",
-            };
-        final String[] Australia_Western = new String[] {
-               "\u062f \u0627\u0633\u067c\u0631\u0627\u0644\u06cc\u0627 \u0644\u0648\u06cc\u062f\u06cc\u0632 \u0645\u0639\u06cc\u0627\u0631",
-               "",
-               "\u062f \u0627\u0633\u067c\u0631\u0627\u0644\u06cc\u0627 \u0644\u0648\u06cc\u062f\u06cc\u0681 \u062f \u0648\u0631\u0681\u06d2 \u0648\u062e\u062a",
-               "",
-               "\u062f \u0644\u0648\u06cc\u062f\u06cc\u0681 \u0622\u0633\u067c\u0631\u0627\u0644\u06cc\u0627 \u0648\u062e\u062a",
-               "",
-            };
-        final String[] America_Central = new String[] {
-               "\u0645\u0631\u06a9\u0632\u064a \u0645\u0639\u064a\u0627\u0631\u064a \u0648\u062e\u062a",
-               "",
-               "\u0645\u0631\u06a9\u0632\u064a \u0631\u06bc\u0627 \u0648\u0631\u0681\u06d2 \u0648\u062e\u062a",
-               "",
-               "\u0645\u0631\u06a9\u0632\u064a \u0648\u062e\u062a",
-               "",
-            };
-        final String[] America_Mountain = new String[] {
-               "\u062f \u063a\u0631\u0647 \u0645\u0639\u064a\u0627\u0631\u064a \u0648\u062e\u062a",
-               "",
-               "\u062f \u063a\u0631\u0647 \u062f \u0631\u06bc\u0627 \u0648\u0631\u0681\u06d2 \u0648\u062e\u062a",
-               "",
-               "\u062f \u063a\u0631\u0647 \u062f \u0648\u062e\u062a",
-               "",
-            };
-        final String[] Arabian = new String[] {
-               "\u0639\u0631\u0628\u064a \u0645\u0639\u06cc\u0627\u0631\u064a \u0648\u062e\u062a",
-               "",
-               "\u062f \u0639\u0631\u0628\u064a \u0648\u0631\u0681\u067e\u0627\u06bc\u06d2 \u0648\u062e\u062a",
-               "",
-               "\u0639\u0631\u0628\u064a \u0648\u062e\u062a",
+               "\u0633\u0645\u0648\u0627 \u0648\u062e\u062a",
                "",
             };
         final String[] Alaska = new String[] {
@@ -270,20 +134,156 @@ public class TimeZoneNames_ps_PK extends TimeZoneNamesBundle {
                "\u0627\u0644\u0627\u0633\u06a9\u0627 \u0648\u062e\u062a",
                "",
             };
-        final String[] Apia = new String[] {
-               "\u062f \u0627\u067e\u06cc\u0627 \u0645\u0639\u064a\u0627\u0631\u064a \u0648\u062e\u062a",
+        final String[] Israel = new String[] {
+               "\u0627\u0633\u0631\u0627\u06cc\u06cc\u0644 \u0645\u0639\u064a\u0627\u0631\u064a \u0648\u062e\u062a",
                "",
-               "\u062f \u0627\u067e\u06cc\u0627 \u062f \u0648\u0631\u0681\u06d2 \u0648\u062e\u062a",
+               "\u062f \u0627\u0633\u0631\u0627\u06cc\u06cc\u0644\u0648 \u062f \u0648\u0631\u0681\u06d2 \u0648\u062e\u062a",
                "",
-               "\u062f \u0627\u067e\u06cc\u0627 \u0648\u062e\u062a",
+               "\u0627\u0633\u0631\u0627\u06cc\u06cc\u0644 \u0648\u062e\u062a",
                "",
             };
-        final String[] China = new String[] {
-               "\u0686\u06cc\u0646 \u0645\u0639\u06cc\u0627\u0631\u064a \u0648\u062e\u062a",
+        final String[] Arabian = new String[] {
+               "\u0639\u0631\u0628\u064a \u0645\u0639\u06cc\u0627\u0631\u064a \u0648\u062e\u062a",
                "",
-               "\u062f \u0686\u064a\u0646 \u062f \u0631\u06bc\u0627 \u0648\u0631\u0681\u06d2 \u0648\u062e\u062a",
+               "\u062f \u0639\u0631\u0628\u064a \u0648\u0631\u0681\u067e\u0627\u06bc\u06d2 \u0648\u062e\u062a",
                "",
-               "\u0686\u064a\u0646 \u0648\u062e\u062a",
+               "\u0639\u0631\u0628\u064a \u0648\u062e\u062a",
+               "",
+            };
+        final String[] Atlantic = new String[] {
+               "\u0627\u062a\u0644\u0627\u0646\u062a\u06cc\u06a9 \u0645\u0639\u064a\u0627\u0631\u064a \u0648\u062e\u062a",
+               "",
+               "\u0627\u062a\u0644\u0627\u0646\u062a\u06cc\u06a9 \u062f \u0631\u06bc\u0627 \u0648\u0631\u0681\u06d2 \u0648\u062e\u062a",
+               "",
+               "\u0627\u062a\u0644\u0627\u0646\u062a\u06cc\u06a9 \u0648\u062e\u062a",
+               "",
+            };
+        final String[] Lord_Howe = new String[] {
+               "\u0644\u0627\u0631\u0689 \u0647\u0648\u064a \u0645\u0639\u064a\u0627\u0631\u064a \u0648\u062e\u062a",
+               "",
+               "\u0631\u0628 \u0647\u0627\u0648 \u062f \u0648\u0631\u0681\u06d2 \u062f \u0631\u06bc\u0627 \u0648\u062e\u062a",
+               "",
+               "\u0644\u0627\u0631\u0689 \u0647\u0648\u064a \u0648\u062e\u062a",
+               "",
+            };
+        final String[] EMPTY_ZONE = new String[] {
+               "",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
+        final String[] New_Zealand = new String[] {
+               "\u0646\u064a\u0648\u0632\u064a \u0644\u06d0\u0646\u0689 \u0645\u0639\u064a\u0627\u0631\u064a \u0648\u062e\u062a",
+               "",
+               "\u062f \u0646\u06cc\u0648\u0632\u06cc \u0644\u06cc\u0646\u0688 \u062f \u0648\u0631\u0681\u06d2 \u062f \u0631\u06bc\u0627 \u0648\u062e\u062a",
+               "",
+               "\u0646\u064a\u0648\u0632\u064a \u0644\u06d0\u0646\u0689 \u0648\u062e\u062a",
+               "",
+            };
+        final String[] Line_Islands = new String[] {
+               "\u062f \u06a9\u0631\u069a\u06d2 \u067c\u0627\u067c\u0648\u0628\u064a \u0648\u062e\u062a",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
+        final String[] Newfoundland = new String[] {
+               "\u062f \u0646\u0648\u064a \u0641\u06cc\u0644\u0689\u0644\u06cc\u0646\u0689 \u0645\u0639\u06cc\u0627\u0631\u06cc \u0648\u062e\u062a",
+               "",
+               "\u062f \u0646\u0648\u064a \u0641\u06cc\u0644\u0689\u0644\u06cc\u0646\u0689 \u0631\u06bc\u0627 \u0648\u0631\u0681\u06d2 \u0648\u062e\u062a",
+               "",
+               "\u0646\u064a\u0648 \u0641\u0627\u0648\u0646\u0689\u0644\u06d0\u0646\u0689 \u0648\u062e\u062a",
+               "",
+            };
+        final String[] Europe_Western = new String[] {
+               "\u062f \u0644\u0648\u062f\u06cc\u0681\u06d2 \u0627\u0631\u0648\u067e\u0627 \u0645\u0639\u06cc\u0627\u0631\u064a \u0648\u062e\u062a",
+               "",
+               "\u062f \u0644\u0648\u062f\u06cc\u0681\u06d2 \u0627\u0648\u0631\u067e\u0627 \u062f \u0627\u0648\u0693\u064a \u0648\u062e\u062a",
+               "",
+               "\u0644\u0648\u06d0\u062f\u064a\u0632\u06d2 \u0627\u0631\u0648\u067e\u0627 \u0648\u062e\u062a",
+               "",
+            };
+        final String[] Mexico_Pacific = new String[] {
+               "\u0645\u06a9\u0633\u06cc\u06a9\u0646 \u067e\u06cc\u0633\u0641\u06a9 \u0645\u0639\u06cc\u0627\u0631\u06cc \u0648\u062e\u062a",
+               "",
+               "\u0645\u06a9\u0633\u06cc\u06a9\u0646 \u067e\u06cc\u0633\u0641\u06a9 \u0631\u06bc\u0627 \u0648\u0631\u0681\u06d2 \u0648\u062e\u062a",
+               "",
+               "\u0645\u06a9\u0633\u06cc\u06a9\u0646 \u067e\u06cc\u0633\u0641\u06a9 \u0648\u062e\u062a",
+               "",
+            };
+        final String[] America_Central = new String[] {
+               "\u0645\u0631\u06a9\u0632\u064a \u0645\u0639\u064a\u0627\u0631\u064a \u0648\u062e\u062a",
+               "",
+               "\u0645\u0631\u06a9\u0632\u064a \u0631\u06bc\u0627 \u0648\u0631\u0681\u06d2 \u0648\u062e\u062a",
+               "",
+               "\u0645\u0631\u06a9\u0632\u064a \u0648\u062e\u062a",
+               "",
+            };
+        final String[] America_Eastern = new String[] {
+               "\u062e\u062a\u064a\u0681 \u0645\u0639\u064a\u0627\u0631\u064a \u0648\u062e\u062a",
+               "",
+               "\u062e\u062a\u064a\u0681 \u062f \u0631\u06bc\u0627 \u0648\u0631\u0681\u06d2 \u0648\u062e\u062a",
+               "",
+               "\u062e\u062a\u06cc\u0681 \u0648\u062e\u062a",
+               "",
+            };
+        final String[] America_Pacific = new String[] {
+               "\u062f \u067e\u06cc\u0633\u0641\u06a9 \u0645\u0639\u064a\u0627\u0631\u064a \u0648\u062e\u062a",
+               "",
+               "\u067e\u06cc\u0633\u0641\u06a9 \u062f \u0631\u06bc\u0627 \u0648\u0631\u0681\u06d2 \u0648\u062e\u062a",
+               "",
+               "\u067e\u06cc\u0633\u0641\u06a9 \u0648\u062e\u062a",
+               "",
+            };
+        final String[] French_Southern = new String[] {
+               "\u062f \u0641\u0631\u0627\u0646\u0633\u06d2 \u0633\u0648\u06cc\u0644 \u0627\u0648 \u0627\u0646\u067c\u0627\u0631\u067c\u064a\u06a9 \u0648\u062e\u062a",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
+        final String[] Hawaii_Aleutian = new String[] {
+               "\u0647\u0648\u0627\u06cc\u06cc \u0627\u0644\u06cc\u0648\u062a\u06cc\u0646 \u0645\u0639\u06cc\u0627\u0631\u06cc \u0648\u062e\u062a",
+               "",
+               "\u0647\u0648\u0627\u06cc\u06cc \u0627\u0644\u06cc\u0648\u062a\u06cc\u0646 \u0631\u06bc\u0627 \u0648\u0631\u0681\u06d2 \u0648\u062e\u062a",
+               "",
+               "\u0647\u0648\u0627\u06cc\u06cc \u0627\u0644\u06cc\u0648\u062a\u06cc\u0646 \u0648\u062e\u062a",
+               "",
+            };
+        final String[] Pierre_Miquelon = new String[] {
+               "\u0633\u06cc\u0646\u067c \u067e\u06cc\u06cc\u0631\u0627 \u0648 \u0645\u064a\u06a9\u0644\u064a\u0646 \u0645\u0639\u06cc\u0627\u0631\u06cc \u0648\u062e\u062a",
+               "",
+               "\u0633\u06cc\u0646\u067c \u067e\u06cc\u06cc\u0631\u0627 \u0648 \u0645\u064a\u06a9\u0644\u064a\u0646 \u0631\u06bc\u0627 \u0648\u0631\u0681\u06d2 \u0648\u062e\u062a",
+               "",
+               "\u0633\u06cc\u0646\u067c \u067e\u06cc\u06cc\u0631\u0627 \u0648 \u0645\u064a\u06a9\u0644\u064a\u0646 \u0648\u062e\u062a",
+               "",
+            };
+        final String[] America_Mountain = new String[] {
+               "\u062f \u063a\u0631\u0647 \u0645\u0639\u064a\u0627\u0631\u064a \u0648\u062e\u062a",
+               "",
+               "\u062f \u063a\u0631\u0647 \u062f \u0631\u06bc\u0627 \u0648\u0631\u0681\u06d2 \u0648\u062e\u062a",
+               "",
+               "\u062f \u063a\u0631\u0647 \u062f \u0648\u062e\u062a",
+               "",
+            };
+        final String[] Mexico_Northwest = new String[] {
+               "\u062f \u0634\u0645\u0627\u0644 \u0644\u0648\u06cc\u062f\u06cc\u0681 \u0645\u06a9\u0633\u06cc\u06a9\u0648 \u0645\u0639\u06cc\u0627\u0631\u064a \u0648\u062e\u062a",
+               "",
+               "\u062f \u0634\u0645\u0627\u0644 \u0644\u0648\u06cc\u062f\u06cc\u0681 \u0645\u06a9\u0633\u06cc\u06a9\u0648 \u0631\u06bc\u0627 \u0648\u0631\u0681\u06d2 \u0648\u062e\u062a",
+               "",
+               "\u062f \u0634\u0645\u0627\u0644 \u0644\u0648\u06cc\u062f\u06cc\u0681 \u0645\u06a9\u0633\u06cc\u06a9\u0648 \u0648\u062e\u062a",
+               "",
+            };
+        final String[] Australia_Western = new String[] {
+               "\u0622\u0633\u062a\u0631\u0627\u0644\u0648\u064a \u0644\u0648\u06d0\u062f\u064a\u0681 \u0645\u0639\u064a\u0627\u0631\u064a \u0648\u062e\u062a",
+               "",
+               "\u062f \u0627\u0633\u067c\u0631\u0627\u0644\u06cc\u0627 \u0644\u0648\u06cc\u062f\u06cc\u0681 \u062f \u0648\u0631\u0681\u06d2 \u0648\u062e\u062a",
+               "",
+               "\u0644\u0648\u06d0\u062f\u064a\u0681 \u0622\u0633\u062a\u0631\u0627\u0644\u064a\u0627 \u0648\u062e\u062a",
                "",
             };
         final Object[][] data = new Object[][] {
@@ -302,159 +302,159 @@ public class TimeZoneNames_ps_PK extends TimeZoneNamesBundle {
             { "Asia/Tokyo", Japan },
             { "Asia/Shanghai", China },
             { "UTC", EMPTY_ZONE },
-            { "Asia/Aden", Arabian },
-            { "CTT", China },
-            { "America/Marigot", Atlantic },
-            { "America/El_Salvador", America_Central },
-            { "America/Kentucky/Monticello", America_Eastern },
-            { "America/Coral_Harbour", America_Eastern },
-            { "Pacific/Pago_Pago", Samoa },
-            { "America/Aruba", Atlantic },
-            { "America/North_Dakota/Center", America_Central },
-            { "America/Guatemala", America_Central },
-            { "PNT", America_Mountain },
-            { "America/Cayman", America_Eastern },
-            { "America/Belize", America_Central },
-            { "America/Panama", America_Eastern },
-            { "Asia/Baghdad", Arabian },
-            { "America/Indiana/Tell_City", America_Central },
-            { "America/Tijuana", America_Pacific },
-            { "America/Managua", America_Central },
-            { "America/Indiana/Petersburg", America_Eastern },
-            { "JST", Japan },
-            { "America/Chihuahua", Mexico_Pacific },
-            { "America/Ojinaga", America_Mountain },
-            { "America/Tegucigalpa", America_Central },
-            { "MIT", Apia },
-            { "America/Miquelon", Pierre_Miquelon },
-            { "Antarctica/South_Pole", New_Zealand },
-            { "Atlantic/Madeira", Europe_Western },
-            { "America/Thunder_Bay", America_Eastern },
-            { "America/Grand_Turk", America_Eastern },
             { "AST", Alaska },
-            { "America/Indiana/Marengo", America_Eastern },
-            { "America/Creston", America_Mountain },
-            { "America/Mexico_City", America_Central },
-            { "Pacific/Kiritimati", Line_Islands },
-            { "America/Matamoros", America_Central },
-            { "America/Blanc-Sablon", Atlantic },
-            { "Asia/Riyadh", Arabian },
-            { "Europe/Lisbon", Europe_Western },
-            { "Asia/Harbin", China },
+            { "CNT", Newfoundland },
+            { "CST", America_Central },
+            { "CTT", China },
+            { "JST", Japan },
+            { "MIT", Apia },
+            { "NST", New_Zealand },
+            { "PNT", America_Mountain },
             { "PRT", Atlantic },
-            { "Australia/Perth", Australia_Western },
-            { "CST6CDT", America_Central },
-            { "Atlantic/Canary", Europe_Western },
-            { "Asia/Kuwait", Arabian },
-            { "SystemV/HST10", Hawaii_Aleutian },
-            { "Antarctica/McMurdo", New_Zealand },
-            { "America/Menominee", America_Central },
-            { "America/Adak", Hawaii_Aleutian },
-            { "Asia/Macau", China },
-            { "America/Resolute", America_Central },
             { "PST", America_Pacific },
-            { "SystemV/EST5", America_Eastern },
-            { "America/Edmonton", America_Mountain },
-            { "America/Santo_Domingo", Atlantic },
-            { "Pacific/Auckland", New_Zealand },
-            { "America/Glace_Bay", Atlantic },
+            { "CST6CDT", America_Central },
+            { "EST5EDT", America_Eastern },
+            { "MST7MDT", America_Mountain },
+            { "PST8PDT", America_Pacific },
+            { "Asia/Aden", Arabian },
+            { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
-            { "America/Port-au-Prince", America_Eastern },
-            { "America/St_Barthelemy", Atlantic },
-            { "America/Nipigon", America_Eastern },
-            { "America/Regina", America_Central },
-            { "America/Dawson_Creek", America_Mountain },
-            { "America/St_Thomas", Atlantic },
-            { "America/Anguilla", Atlantic },
-            { "Asia/Bahrain", Arabian },
-            { "America/Hermosillo", Mexico_Pacific },
-            { "America/Cancun", America_Eastern },
             { "Asia/Seoul", Korea },
-            { "America/St_Lucia", Atlantic },
-            { "America/Bahia_Banderas", America_Central },
-            { "America/Montserrat", Atlantic },
+            { "Asia/Harbin", China },
+            { "Asia/Kuwait", Arabian },
+            { "Asia/Riyadh", Arabian },
+            { "Asia/Tehran", Iran },
+            { "America/Adak", Hawaii_Aleutian },
+            { "America/Nome", Alaska },
+            { "Asia/Baghdad", Arabian },
+            { "Asia/Bahrain", Arabian },
+            { "Pacific/Apia", Apia },
+            { "SystemV/AST4", Atlantic },
+            { "SystemV/CST6", America_Central },
+            { "SystemV/EST5", America_Eastern },
+            { "SystemV/MST7", America_Mountain },
+            { "America/Aruba", Atlantic },
+            { "America/Boise", America_Mountain },
+            { "America/Thule", Atlantic },
+            { "Europe/Lisbon", Europe_Western },
+            { "SystemV/HST10", Hawaii_Aleutian },
+            { "America/Belize", America_Central },
+            { "America/Cancun", America_Eastern },
+            { "America/Cayman", America_Eastern },
+            { "America/Dawson", America_Pacific },
             { "America/Havana", Cuba },
+            { "America/Inuvik", America_Mountain },
+            { "America/Juneau", Alaska },
+            { "America/Merida", America_Central },
+            { "America/Nassau", America_Eastern },
+            { "America/Panama", America_Eastern },
+            { "America/Regina", America_Central },
+            { "Asia/Chongqing", China },
+            { "Asia/Pyongyang", Korea },
+            { "Pacific/Midway", Samoa },
+            { "America/Antigua", Atlantic },
+            { "America/Creston", America_Mountain },
+            { "America/Curacao", Atlantic },
+            { "America/Detroit", America_Eastern },
+            { "America/Grenada", Atlantic },
+            { "America/Iqaluit", America_Eastern },
+            { "America/Jamaica", America_Eastern },
+            { "America/Managua", America_Central },
+            { "America/Marigot", Atlantic },
+            { "America/Moncton", Atlantic },
+            { "America/Nipigon", America_Eastern },
+            { "America/Ojinaga", America_Mountain },
+            { "America/Tijuana", America_Pacific },
+            { "America/Toronto", America_Eastern },
+            { "America/Tortola", Atlantic },
+            { "America/Yakutat", Alaska },
+            { "Atlantic/Canary", Europe_Western },
+            { "Atlantic/Faeroe", Europe_Western },
+            { "Australia/Perth", Australia_Western },
+            { "SystemV/AST4ADT", Atlantic },
+            { "SystemV/CST6CDT", America_Central },
+            { "SystemV/EST5EDT", America_Eastern },
+            { "SystemV/MST7MDT", America_Mountain },
+            { "SystemV/PST8PDT", America_Pacific },
+            { "SystemV/YST9YDT", Alaska },
+            { "America/Anguilla", Atlantic },
+            { "America/Barbados", Atlantic },
+            { "America/Dominica", Atlantic },
+            { "America/Edmonton", America_Mountain },
+            { "America/Mazatlan", Mexico_Pacific },
+            { "America/Miquelon", Pierre_Miquelon },
+            { "America/Montreal", America_Eastern },
+            { "America/Resolute", America_Central },
+            { "America/Shiprock", America_Mountain },
+            { "America/St_Kitts", Atlantic },
+            { "America/St_Lucia", Atlantic },
+            { "America/Winnipeg", America_Central },
+            { "Antarctica/Casey", Australia_Western },
+            { "Atlantic/Bermuda", Atlantic },
+            { "Atlantic/Madeira", Europe_Western },
+            { "Indian/Kerguelen", French_Southern },
+            { "Pacific/Auckland", New_Zealand },
+            { "Pacific/Johnston", Hawaii_Aleutian },
+            { "America/Chihuahua", Mexico_Pacific },
+            { "America/Glace_Bay", Atlantic },
+            { "America/Goose_Bay", Atlantic },
+            { "America/Guatemala", America_Central },
+            { "America/Matamoros", America_Central },
+            { "America/Menominee", America_Central },
+            { "America/Monterrey", America_Central },
+            { "America/St_Thomas", Atlantic },
+            { "America/Vancouver", America_Pacific },
+            { "Pacific/Pago_Pago", Samoa },
+            { "America/Costa_Rica", America_Central },
+            { "America/Grand_Turk", America_Eastern },
+            { "America/Guadeloupe", Atlantic },
+            { "America/Hermosillo", Mexico_Pacific },
+            { "America/Kralendijk", Atlantic },
+            { "America/Louisville", America_Eastern },
+            { "America/Martinique", Atlantic },
+            { "America/Metlakatla", Alaska },
+            { "America/Montserrat", Atlantic },
+            { "America/St_Vincent", Atlantic },
+            { "America/Whitehorse", America_Pacific },
+            { "Antarctica/McMurdo", New_Zealand },
+            { "Pacific/Kiritimati", Line_Islands },
+            { "America/El_Salvador", America_Central },
+            { "America/Fort_Nelson", America_Mountain },
+            { "America/Mexico_City", America_Central },
+            { "America/Pangnirtung", America_Eastern },
+            { "America/Puerto_Rico", Atlantic },
+            { "America/Rainy_River", America_Central },
+            { "America/Tegucigalpa", America_Central },
+            { "America/Thunder_Bay", America_Eastern },
+            { "America/Yellowknife", America_Mountain },
+            { "Australia/Lord_Howe", Lord_Howe },
+            { "America/Blanc-Sablon", Atlantic },
+            { "America/Dawson_Creek", America_Mountain },
+            { "America/Indiana/Knox", America_Central },
+            { "America/Rankin_Inlet", America_Central },
             { "America/Santa_Isabel", Mexico_Northwest },
             { "America/Cambridge_Bay", America_Mountain },
-            { "timezone.excity.America/Lower_Princes", "\u062f \u06a9\u0645\u062a\u0631 \u0634\u0647\u0632\u0627\u062f\u0647 \u062f\u0631\u06d2 \u0645\u06cc\u0627\u0634\u062a\u0646\u06cd" },
-            { "America/Barbados", Atlantic },
-            { "America/Louisville", America_Eastern },
-            { "America/Lower_Princes", Atlantic },
-            { "America/Vancouver", America_Pacific },
-            { "America/Detroit", America_Eastern },
-            { "Pacific/Johnston", Hawaii_Aleutian },
-            { "America/Thule", Atlantic },
-            { "America/Curacao", Atlantic },
-            { "America/Martinique", Atlantic },
-            { "America/Puerto_Rico", Atlantic },
-            { "America/Rankin_Inlet", America_Central },
-            { "SystemV/CST6CDT", America_Central },
-            { "America/Tortola", Atlantic },
-            { "America/Port_of_Spain", Atlantic },
-            { "America/Nome", Alaska },
-            { "NST", New_Zealand },
-            { "America/Rainy_River", America_Central },
-            { "SystemV/AST4", Atlantic },
-            { "Asia/Tehran", Iran },
-            { "America/Yellowknife", America_Mountain },
-            { "America/Juneau", Alaska },
-            { "CNT", Newfoundland },
+            { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
-            { "Pacific/Midway", Samoa },
-            { "America/Goose_Bay", Atlantic },
+            { "America/Lower_Princes", Atlantic },
+            { "America/Port_of_Spain", Atlantic },
+            { "America/Santo_Domingo", Atlantic },
+            { "America/St_Barthelemy", Atlantic },
             { "America/Swift_Current", America_Central },
-            { "America/Metlakatla", Alaska },
-            { "America/Pangnirtung", America_Eastern },
-            { "America/Indiana/Vincennes", America_Eastern },
-            { "America/Whitehorse", America_Pacific },
-            { "America/Kralendijk", Atlantic },
-            { "America/Antigua", Atlantic },
-            { "America/Montreal", America_Eastern },
-            { "America/Inuvik", America_Mountain },
-            { "America/Iqaluit", America_Eastern },
-            { "America/Moncton", Atlantic },
+            { "Antarctica/South_Pole", New_Zealand },
+            { "America/Bahia_Banderas", America_Central },
+            { "America/Port-au-Prince", America_Eastern },
+            { "America/Indiana/Marengo", America_Eastern },
             { "America/Indiana/Winamac", America_Eastern },
-            { "SystemV/MST7MDT", America_Mountain },
-            { "Asia/Pyongyang", Korea },
-            { "America/St_Vincent", Atlantic },
-            { "PST8PDT", America_Pacific },
-            { "America/Grenada", Atlantic },
-            { "Atlantic/Faeroe", Europe_Western },
-            { "America/Yakutat", Alaska },
-            { "Antarctica/Casey", Australia_Western },
-            { "SystemV/YST9YDT", Alaska },
-            { "America/Merida", America_Central },
-            { "America/Mazatlan", Mexico_Pacific },
-            { "timezone.excity.Africa/Harare", "\u0647\u0631\u0627\u0631\u06d2" },
-            { "SystemV/MST7", America_Mountain },
-            { "America/St_Kitts", Atlantic },
-            { "America/Fort_Nelson", America_Mountain },
-            { "America/Dominica", Atlantic },
-            { "America/Guadeloupe", Atlantic },
-            { "Indian/Kerguelen", French_Southern },
-            { "SystemV/PST8PDT", America_Pacific },
-            { "America/Boise", America_Mountain },
-            { "EST5EDT", America_Eastern },
-            { "America/North_Dakota/New_Salem", America_Central },
-            { "Atlantic/Bermuda", Atlantic },
-            { "America/Costa_Rica", America_Central },
-            { "America/Dawson", America_Pacific },
-            { "America/Shiprock", America_Mountain },
-            { "America/Winnipeg", America_Central },
-            { "Asia/Chongqing", China },
-            { "America/Indiana/Knox", America_Central },
+            { "America/Indiana/Tell_City", America_Central },
+            { "America/Indiana/Vincennes", America_Eastern },
+            { "America/Indiana/Petersburg", America_Eastern },
+            { "America/Kentucky/Monticello", America_Eastern },
             { "America/North_Dakota/Beulah", America_Central },
-            { "SystemV/AST4ADT", Atlantic },
-            { "Pacific/Apia", Apia },
-            { "CST", America_Central },
-            { "Australia/Lord_Howe", Lord_Howe },
-            { "America/Toronto", America_Eastern },
-            { "MST7MDT", America_Mountain },
-            { "America/Monterrey", America_Central },
-            { "SystemV/EST5EDT", America_Eastern },
-            { "America/Nassau", America_Eastern },
-            { "America/Jamaica", America_Eastern },
-            { "SystemV/CST6", America_Central },
+            { "America/North_Dakota/Center", America_Central },
+            { "timezone.excity.Africa/Harare", "\u0647\u0631\u0627\u0631\u06d2" },
+            { "America/North_Dakota/New_Salem", America_Central },
+            { "timezone.excity.America/Lower_Princes", "\u062f \u06a9\u0645\u062a\u0631 \u0634\u0647\u0632\u0627\u062f\u0647 \u062f\u0631\u06d2 \u0645\u06cc\u0627\u0634\u062a\u0646\u06cd" },
         };
         return data;
     }
