@@ -70,14 +70,6 @@ import sun.util.resources.TimeZoneNamesBundle;
 public class TimeZoneNames_sah extends TimeZoneNamesBundle {
     @Override
     protected final Object[][] getContents() {
-        final String[] Volgograd = new String[] {
-               "\u0412\u043e\u043b\u0433\u043e\u0433\u0440\u0430\u0434 \u0441\u04af\u0440\u04af\u043d \u043a\u044d\u043c\u044d",
-               "",
-               "\u0412\u043e\u043b\u0433\u043e\u0433\u0440\u0430\u0434 \u0441\u0430\u0439\u044b\u04a5\u04a5\u044b \u043a\u044d\u043c\u044d",
-               "",
-               "\u0412\u043e\u043b\u0433\u043e\u0433\u0440\u0430\u0434 \u043a\u044d\u043c\u044d",
-               "",
-            };
         final String[] Iran = new String[] {
                "\u0418\u0440\u0430\u0430\u043d \u0441\u04af\u0440\u04af\u043d \u043a\u044d\u043c\u044d",
                "",
@@ -86,16 +78,24 @@ public class TimeZoneNames_sah extends TimeZoneNamesBundle {
                "\u0418\u0440\u0430\u0430\u043d \u043a\u044d\u043c\u044d",
                "",
             };
-        final String[] Moscow = new String[] {
-               "\u041c\u043e\u0441\u043a\u0443\u0431\u0430 \u0441\u04af\u0440\u04af\u043d \u043a\u044d\u043c\u044d",
+        final String[] Omsk = new String[] {
+               "\u041e\u043c\u0441\u043a\u0430\u0439 \u0441\u04af\u0440\u04af\u043d \u043a\u044d\u043c\u044d",
                "",
-               "\u041c\u043e\u0441\u043a\u0443\u0431\u0430 \u0441\u0430\u0439\u044b\u04a5\u04a5\u044b \u043a\u044d\u043c\u044d",
+               "\u041e\u043c\u0441\u043a\u0430\u0439 \u0441\u0430\u0439\u044b\u04a5\u04a5\u044b \u043a\u044d\u043c\u044d",
                "",
-               "\u041c\u043e\u0441\u043a\u0443\u0431\u0430 \u043a\u044d\u043c\u044d",
+               "\u041e\u043c\u0441\u043a\u0430\u0439 \u043a\u044d\u043c\u044d",
                "",
             };
-        final String[] EMPTY_ZONE = new String[] {
+        final String[] China = new String[] {
+               "\u041a\u044b\u0442\u0430\u0439 \u0441\u04af\u0440\u04af\u043d \u043a\u044d\u043c\u044d",
                "",
+               "\u041a\u044b\u0442\u0430\u0439 \u0441\u0430\u0439\u044b\u04a5\u04a5\u044b \u043a\u044d\u043c\u044d",
+               "",
+               "\u041a\u044b\u0442\u0430\u0439 \u043a\u044d\u043c\u044d",
+               "",
+            };
+        final String[] India = new String[] {
+               "\u0418\u0438\u043d\u0434\u0438\u0439\u044d \u0441\u04af\u0440\u04af\u043d \u043a\u044d\u043c\u044d",
                "",
                "",
                "",
@@ -110,12 +110,44 @@ public class TimeZoneNames_sah extends TimeZoneNamesBundle {
                "\u0414\u044c\u043e\u043f\u043f\u0443\u043e\u043d \u043a\u044d\u043c\u044d",
                "",
             };
-        final String[] Pakistan = new String[] {
-               "\u041f\u0430\u043a\u0438\u0441\u0442\u0430\u0430\u043d \u0441\u04af\u0440\u04af\u043d \u043a\u044d\u043c\u044d",
+        final String[] Korea = new String[] {
+               "\u041a\u044d\u0440\u0438\u044d\u0439 \u0441\u04af\u0440\u04af\u043d \u043a\u044d\u043c\u044d",
                "",
-               "\u041f\u0430\u043a\u0438\u0441\u0442\u0430\u0430\u043d \u0441\u0430\u0439\u044b\u04a5\u04a5\u044b \u043a\u044d\u043c\u044d",
+               "\u041a\u044d\u0440\u0438\u044d\u0439 \u0441\u0430\u0439\u044b\u04a5\u04a5\u044b \u043a\u044d\u043c\u044d",
                "",
-               "\u041f\u0430\u043a\u0438\u0441\u0442\u0430\u0430\u043d \u043a\u044d\u043c\u044d",
+               "\u041a\u044d\u0440\u0438\u044d\u0439 \u043a\u044d\u043c\u044d",
+               "",
+            };
+        final String[] Moscow = new String[] {
+               "\u041c\u043e\u0441\u043a\u0443\u0431\u0430 \u0441\u04af\u0440\u04af\u043d \u043a\u044d\u043c\u044d",
+               "",
+               "\u041c\u043e\u0441\u043a\u0443\u0431\u0430 \u0441\u0430\u0439\u044b\u04a5\u04a5\u044b \u043a\u044d\u043c\u044d",
+               "",
+               "\u041c\u043e\u0441\u043a\u0443\u0431\u0430 \u043a\u044d\u043c\u044d",
+               "",
+            };
+        final String[] Arabian = new String[] {
+               "\u0410\u0440\u0430\u0430\u0431 \u0441\u04af\u0440\u04af\u043d \u043a\u044d\u043c\u044d",
+               "",
+               "\u0410\u0440\u0430\u0430\u0431 \u0441\u0430\u0439\u044b\u04a5\u04a5\u044b \u043a\u044d\u043c\u044d",
+               "",
+               "\u0410\u0440\u0430\u0430\u0431 \u043a\u044d\u043c\u044d",
+               "",
+            };
+        final String[] Armenia = new String[] {
+               "\u042d\u0440\u043c\u044d\u044d\u043d \u0441\u04af\u0440\u04af\u043d \u043a\u044d\u043c\u044d",
+               "",
+               "\u042d\u0440\u043c\u044d\u044d\u043d \u0441\u0430\u0439\u044b\u04a5\u04a5\u044b \u043a\u044d\u043c\u044d",
+               "",
+               "\u042d\u0440\u043c\u044d\u044d\u043d \u043a\u044d\u043c\u044d",
+               "",
+            };
+        final String[] Georgia = new String[] {
+               "\u041a\u0443\u0440\u0443\u0441\u0443\u0443\u043d \u0441\u04af\u0440\u04af\u043d \u043a\u044d\u043c\u044d",
+               "",
+               "\u041a\u0443\u0440\u0443\u0441\u0443\u0443\u043d \u0441\u0430\u0439\u044b\u04a5\u04a5\u044b \u043a\u044d\u043c\u044d",
+               "",
+               "\u041a\u0443\u0440\u0443\u0441\u0443\u0443\u043d \u043a\u044d\u043c\u044d",
                "",
             };
         final String[] Magadan = new String[] {
@@ -126,52 +158,12 @@ public class TimeZoneNames_sah extends TimeZoneNamesBundle {
                "\u041c\u0430\u0433\u0430\u0434\u0430\u0430\u043d \u043a\u044d\u043c\u044d",
                "",
             };
-        final String[] Sakhalin = new String[] {
-               "\u0421\u0430\u0445\u0430\u043b\u044b\u044b\u043d \u0441\u04af\u0440\u04af\u043d \u043a\u044d\u043c\u044d",
+        final String[] Yakutsk = new String[] {
+               "\u0414\u044c\u043e\u043a\u0443\u0443\u0441\u043a\u0430\u0439 \u0441\u04af\u0440\u04af\u043d \u043a\u044d\u043c\u044d",
                "",
-               "\u0421\u0430\u0445\u0430\u043b\u044b\u044b\u043d \u0441\u0430\u0439\u044b\u04a5\u04a5\u044b \u043a\u044d\u043c\u044d",
+               "\u0414\u044c\u043e\u043a\u0443\u0443\u0441\u043a\u0430\u0439 \u0441\u0430\u0439\u044b\u04a5\u04a5\u044b \u043a\u044d\u043c\u044d",
                "",
-               "\u0421\u0430\u0445\u0430\u043b\u0438\u0438\u043d \u043a\u044d\u043c\u044d",
-               "",
-            };
-        final String[] Korea = new String[] {
-               "\u041a\u044d\u0440\u0438\u044d\u0439 \u0441\u04af\u0440\u04af\u043d \u043a\u044d\u043c\u044d",
-               "",
-               "\u041a\u044d\u0440\u0438\u044d\u0439 \u0441\u0430\u0439\u044b\u04a5\u04a5\u044b \u043a\u044d\u043c\u044d",
-               "",
-               "\u041a\u044d\u0440\u0438\u044d\u0439 \u043a\u044d\u043c\u044d",
-               "",
-            };
-        final String[] Omsk = new String[] {
-               "\u041e\u043c\u0441\u043a\u0430\u0439 \u0441\u04af\u0440\u04af\u043d \u043a\u044d\u043c\u044d",
-               "",
-               "\u041e\u043c\u0441\u043a\u0430\u0439 \u0441\u0430\u0439\u044b\u04a5\u04a5\u044b \u043a\u044d\u043c\u044d",
-               "",
-               "\u041e\u043c\u0441\u043a\u0430\u0439 \u043a\u044d\u043c\u044d",
-               "",
-            };
-        final String[] Australia_Western = new String[] {
-               "\u0410\u0440\u0495\u0430\u0430 \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u0441\u04af\u0440\u04af\u043d \u043a\u044d\u043c\u044d",
-               "",
-               "\u0410\u0440\u0495\u0430\u0430 \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u0441\u0430\u0439\u044b\u04a5\u04a5\u044b \u043a\u044d\u043c\u044d",
-               "",
-               "\u0410\u0440\u0495\u0430\u0430 \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u043a\u044d\u043c\u044d",
-               "",
-            };
-        final String[] Kyrgystan = new String[] {
-               "\u041a\u044b\u0440\u0433\u044b\u0441\u0442\u0430\u0430\u043d \u043a\u044d\u043c\u044d",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
-        final String[] Australia_Central = new String[] {
-               "\u041a\u0438\u0438\u043d \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u0441\u04af\u0440\u04af\u043d \u043a\u044d\u043c\u044d",
-               "",
-               "\u041a\u0438\u0438\u043d \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u0441\u0430\u0439\u044b\u04a5\u04a5\u044b \u043a\u044d\u043c\u044d",
-               "",
-               "\u041a\u0438\u0438\u043d \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u043a\u044d\u043c\u044d",
+               "\u0414\u044c\u043e\u043a\u0443\u0443\u0441\u043a\u0430\u0439 \u043a\u044d\u043c\u044d",
                "",
             };
         final String[] Mongolia = new String[] {
@@ -182,6 +174,54 @@ public class TimeZoneNames_sah extends TimeZoneNamesBundle {
                "\u0423\u043b\u0430\u043d \u0411\u0430\u0430\u0442\u0430\u0440 \u043a\u044d\u043c\u044d",
                "",
             };
+        final String[] Pakistan = new String[] {
+               "\u041f\u0430\u043a\u0438\u0441\u0442\u0430\u0430\u043d \u0441\u04af\u0440\u04af\u043d \u043a\u044d\u043c\u044d",
+               "",
+               "\u041f\u0430\u043a\u0438\u0441\u0442\u0430\u0430\u043d \u0441\u0430\u0439\u044b\u04a5\u04a5\u044b \u043a\u044d\u043c\u044d",
+               "",
+               "\u041f\u0430\u043a\u0438\u0441\u0442\u0430\u0430\u043d \u043a\u044d\u043c\u044d",
+               "",
+            };
+        final String[] Sakhalin = new String[] {
+               "\u0421\u0430\u0445\u0430\u043b\u044b\u044b\u043d \u0441\u04af\u0440\u04af\u043d \u043a\u044d\u043c\u044d",
+               "",
+               "\u0421\u0430\u0445\u0430\u043b\u044b\u044b\u043d \u0441\u0430\u0439\u044b\u04a5\u04a5\u044b \u043a\u044d\u043c\u044d",
+               "",
+               "\u0421\u0430\u0445\u0430\u043b\u0438\u0438\u043d \u043a\u044d\u043c\u044d",
+               "",
+            };
+        final String[] Kyrgystan = new String[] {
+               "\u041a\u044b\u0440\u0433\u044b\u0441\u0442\u0430\u0430\u043d \u043a\u044d\u043c\u044d",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
+        final String[] Volgograd = new String[] {
+               "\u0412\u043e\u043b\u0433\u043e\u0433\u0440\u0430\u0434 \u0441\u04af\u0440\u04af\u043d \u043a\u044d\u043c\u044d",
+               "",
+               "\u0412\u043e\u043b\u0433\u043e\u0433\u0440\u0430\u0434 \u0441\u0430\u0439\u044b\u04a5\u04a5\u044b \u043a\u044d\u043c\u044d",
+               "",
+               "\u0412\u043e\u043b\u0433\u043e\u0433\u0440\u0430\u0434 \u043a\u044d\u043c\u044d",
+               "",
+            };
+        final String[] EMPTY_ZONE = new String[] {
+               "",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
+        final String[] Krasnoyarsk = new String[] {
+               "\u041a\u0440\u0430\u0441\u043d\u043e\u044f\u0440\u0441\u043a\u0430\u0439 \u0441\u04af\u0440\u04af\u043d \u043a\u044d\u043c\u044d",
+               "",
+               "\u041a\u0440\u0430\u0441\u043d\u043e\u044f\u0440\u0441\u043a\u0430\u0439 \u0441\u0430\u0439\u044b\u04a5\u04a5\u044b \u043a\u044d\u043c\u044d",
+               "",
+               "\u041a\u0440\u0430\u0441\u043d\u043e\u044f\u0440\u0441\u043a\u0430\u0439 \u043a\u044d\u043c\u044d",
+               "",
+            };
         final String[] New_Zealand = new String[] {
                "\u0421\u0430\u04a5\u0430 \u0421\u044d\u0439\u043b\u044d\u043d\u0434 \u0441\u04af\u0440\u04af\u043d \u043a\u044d\u043c\u044d",
                "",
@@ -190,30 +230,6 @@ public class TimeZoneNames_sah extends TimeZoneNamesBundle {
                "\u0421\u0430\u04a5\u0430 \u0417\u0435\u043b\u0430\u043d\u0434\u0438\u044f \u043a\u044d\u043c\u044d",
                "",
             };
-        final String[] Australia_Eastern = new String[] {
-               "\u0418\u043b\u0438\u043d \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u0441\u04af\u0440\u04af\u043d \u043a\u044d\u043c\u044d",
-               "",
-               "\u0418\u043b\u0438\u043d \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u0441\u0430\u0439\u044b\u04a5\u04a5\u044b \u043a\u044d\u043c\u044d",
-               "",
-               "\u0418\u043b\u0438\u043d \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u043a\u044d\u043c\u044d",
-               "",
-            };
-        final String[] Yakutsk = new String[] {
-               "\u0414\u044c\u043e\u043a\u0443\u0443\u0441\u043a\u0430\u0439 \u0441\u04af\u0440\u04af\u043d \u043a\u044d\u043c\u044d",
-               "",
-               "\u0414\u044c\u043e\u043a\u0443\u0443\u0441\u043a\u0430\u0439 \u0441\u0430\u0439\u044b\u04a5\u04a5\u044b \u043a\u044d\u043c\u044d",
-               "",
-               "\u0414\u044c\u043e\u043a\u0443\u0443\u0441\u043a\u0430\u0439 \u043a\u044d\u043c\u044d",
-               "",
-            };
-        final String[] Arabian = new String[] {
-               "\u0410\u0440\u0430\u0430\u0431 \u0441\u04af\u0440\u04af\u043d \u043a\u044d\u043c\u044d",
-               "",
-               "\u0410\u0440\u0430\u0430\u0431 \u0441\u0430\u0439\u044b\u04a5\u04a5\u044b \u043a\u044d\u043c\u044d",
-               "",
-               "\u0410\u0440\u0430\u0430\u0431 \u043a\u044d\u043c\u044d",
-               "",
-            };
         final String[] Novosibirsk = new String[] {
                "\u041d\u043e\u0432\u043e\u0441\u0438\u0431\u0438\u0440\u0441\u043a\u0430\u0439 \u0441\u04af\u0440\u04af\u043d \u043a\u044d\u043c\u044d",
                "",
@@ -230,60 +246,36 @@ public class TimeZoneNames_sah extends TimeZoneNamesBundle {
                "\u0412\u043b\u0430\u0434\u0438\u0432\u043e\u0441\u0442\u043e\u043a \u043a\u044d\u043c\u044d",
                "",
             };
-        final String[] Georgia = new String[] {
-               "\u041a\u0443\u0440\u0443\u0441\u0443\u0443\u043d \u0441\u04af\u0440\u04af\u043d \u043a\u044d\u043c\u044d",
+        final String[] Yekaterinburg = new String[] {
+               "\u0415\u043a\u0430\u0442\u0435\u0440\u0438\u043d\u0431\u0443\u0443\u0440 \u0441\u04af\u0440\u04af\u043d \u043a\u044d\u043c\u044d",
                "",
-               "\u041a\u0443\u0440\u0443\u0441\u0443\u0443\u043d \u0441\u0430\u0439\u044b\u04a5\u04a5\u044b \u043a\u044d\u043c\u044d",
+               "\u0415\u043a\u0430\u0442\u0435\u0440\u0438\u043d\u0431\u0443\u0443\u0440 \u0441\u0430\u0439\u044b\u04a5\u04a5\u044b \u043a\u044d\u043c\u044d",
                "",
-               "\u041a\u0443\u0440\u0443\u0441\u0443\u0443\u043d \u043a\u044d\u043c\u044d",
+               "\u0415\u043a\u0430\u0442\u0435\u0440\u0438\u043d\u0431\u0443\u0440\u0433 \u043a\u044d\u043c\u044d",
                "",
             };
-        final String[] Choibalsan = new String[] {
-               "\u0427\u043e\u0439\u0431\u0430\u043b\u0441\u0430\u043d \u0441\u04af\u0440\u04af\u043d \u043a\u044d\u043c\u044d",
+        final String[] Australia_Central = new String[] {
+               "\u041a\u0438\u0438\u043d \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u0441\u04af\u0440\u04af\u043d \u043a\u044d\u043c\u044d",
                "",
-               "\u0427\u043e\u0439\u0431\u0430\u043b\u0441\u0430\u043d \u0441\u0430\u0439\u044b\u04a5\u04a5\u044b \u043a\u044d\u043c\u044d",
+               "\u041a\u0438\u0438\u043d \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u0441\u0430\u0439\u044b\u04a5\u04a5\u044b \u043a\u044d\u043c\u044d",
                "",
-               "\u0427\u043e\u0439\u0431\u0430\u043b\u0441\u0430\u043d \u043a\u044d\u043c\u044d",
+               "\u041a\u0438\u0438\u043d \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u043a\u044d\u043c\u044d",
                "",
             };
-        final String[] China = new String[] {
-               "\u041a\u044b\u0442\u0430\u0439 \u0441\u04af\u0440\u04af\u043d \u043a\u044d\u043c\u044d",
+        final String[] Australia_Eastern = new String[] {
+               "\u0418\u043b\u0438\u043d \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u0441\u04af\u0440\u04af\u043d \u043a\u044d\u043c\u044d",
                "",
-               "\u041a\u044b\u0442\u0430\u0439 \u0441\u0430\u0439\u044b\u04a5\u04a5\u044b \u043a\u044d\u043c\u044d",
+               "\u0418\u043b\u0438\u043d \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u0441\u0430\u0439\u044b\u04a5\u04a5\u044b \u043a\u044d\u043c\u044d",
                "",
-               "\u041a\u044b\u0442\u0430\u0439 \u043a\u044d\u043c\u044d",
+               "\u0418\u043b\u0438\u043d \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u043a\u044d\u043c\u044d",
                "",
             };
-        final String[] Armenia = new String[] {
-               "\u042d\u0440\u043c\u044d\u044d\u043d \u0441\u04af\u0440\u04af\u043d \u043a\u044d\u043c\u044d",
-               "",
-               "\u042d\u0440\u043c\u044d\u044d\u043d \u0441\u0430\u0439\u044b\u04a5\u04a5\u044b \u043a\u044d\u043c\u044d",
-               "",
-               "\u042d\u0440\u043c\u044d\u044d\u043d \u043a\u044d\u043c\u044d",
-               "",
-            };
-        final String[] Krasnoyarsk = new String[] {
-               "\u041a\u0440\u0430\u0441\u043d\u043e\u044f\u0440\u0441\u043a\u0430\u0439 \u0441\u04af\u0440\u04af\u043d \u043a\u044d\u043c\u044d",
-               "",
-               "\u041a\u0440\u0430\u0441\u043d\u043e\u044f\u0440\u0441\u043a\u0430\u0439 \u0441\u0430\u0439\u044b\u04a5\u04a5\u044b \u043a\u044d\u043c\u044d",
-               "",
-               "\u041a\u0440\u0430\u0441\u043d\u043e\u044f\u0440\u0441\u043a\u0430\u0439 \u043a\u044d\u043c\u044d",
-               "",
-            };
-        final String[] Kazakhstan_Western = new String[] {
-               "\u0410\u0440\u0495\u0430\u0430 \u041a\u0430\u0437\u0430\u0445\u0441\u0442\u0430\u0430\u043d \u043a\u044d\u043c\u044d",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
-        final String[] India = new String[] {
-               "\u0418\u0438\u043d\u0434\u0438\u0439\u044d \u0441\u04af\u0440\u04af\u043d \u043a\u044d\u043c\u044d",
-               "",
-               "",
+        final String[] Australia_Western = new String[] {
+               "\u0410\u0440\u0495\u0430\u0430 \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u0441\u04af\u0440\u04af\u043d \u043a\u044d\u043c\u044d",
                "",
+               "\u0410\u0440\u0495\u0430\u0430 \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u0441\u0430\u0439\u044b\u04a5\u04a5\u044b \u043a\u044d\u043c\u044d",
                "",
+               "\u0410\u0440\u0495\u0430\u0430 \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u043a\u044d\u043c\u044d",
                "",
             };
         final String[] Kazakhstan_Eastern = new String[] {
@@ -294,117 +286,117 @@ public class TimeZoneNames_sah extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Yekaterinburg = new String[] {
-               "\u0415\u043a\u0430\u0442\u0435\u0440\u0438\u043d\u0431\u0443\u0443\u0440 \u0441\u04af\u0440\u04af\u043d \u043a\u044d\u043c\u044d",
+        final String[] Kazakhstan_Western = new String[] {
+               "\u0410\u0440\u0495\u0430\u0430 \u041a\u0430\u0437\u0430\u0445\u0441\u0442\u0430\u0430\u043d \u043a\u044d\u043c\u044d",
+               "",
+               "",
                "",
-               "\u0415\u043a\u0430\u0442\u0435\u0440\u0438\u043d\u0431\u0443\u0443\u0440 \u0441\u0430\u0439\u044b\u04a5\u04a5\u044b \u043a\u044d\u043c\u044d",
                "",
-               "\u0415\u043a\u0430\u0442\u0435\u0440\u0438\u043d\u0431\u0443\u0440\u0433 \u043a\u044d\u043c\u044d",
                "",
             };
         final Object[][] data = new Object[][] {
             { "Asia/Tokyo", Japan },
             { "Asia/Shanghai", China },
             { "UTC", EMPTY_ZONE },
-            { "Asia/Aden", Arabian },
-            { "Asia/Aqtobe", Kazakhstan_Western },
-            { "CTT", China },
-            { "Asia/Vladivostok", Vladivostok },
-            { "Asia/Aqtau", Kazakhstan_Western },
-            { "timezone.excity.Asia/Irkutsk", "\u0418\u0440\u043a\u0443\u0442\u0441\u043a\u0430\u0439" },
-            { "timezone.excity.Asia/Ulaanbaatar", "\u0423\u043b\u0430\u043d \u0411\u0430\u0430\u0442\u0430\u0440" },
-            { "Europe/Moscow", Moscow },
-            { "Australia/Hobart", Australia_Eastern },
-            { "Asia/Ulaanbaatar", Mongolia },
-            { "Asia/Baghdad", Arabian },
-            { "Asia/Sakhalin", Sakhalin },
-            { "timezone.excity.Asia/Novosibirsk", "\u041d\u043e\u0432\u043e\u0441\u0438\u0431\u0438\u0440\u0441\u043a\u0430\u0439" },
-            { "timezone.excity.Asia/Baghdad", "\u0411\u0430\u0433\u0434\u0430\u0430\u0434" },
-            { "Asia/Yerevan", Armenia },
-            { "JST", Japan },
-            { "timezone.excity.Asia/Srednekolymsk", "\u041e\u0440\u0442\u043e \u0425\u0430\u043b\u044b\u043c\u0430" },
-            { "timezone.excity.Asia/Kamchatka", "\u041a\u0430\u043c\u0447\u0430\u0430\u0442\u043a\u0430" },
-            { "NST", New_Zealand },
-            { "Asia/Yakutsk", Yakutsk },
-            { "timezone.excity.Asia/Samarkand", "\u0421\u0430\u043c\u0430\u0440\u043a\u0430\u0430\u043d" },
-            { "timezone.excity.Asia/Yakutsk", "\u0414\u044c\u043e\u043a\u0443\u0443\u0441\u043a\u0430\u0439" },
-            { "timezone.excity.Europe/Simferopol", "\u0421\u0438\u043c\u0444\u0435\u0440\u043e\u043f\u043e\u043b\u044c" },
-            { "Asia/Tehran", Iran },
-            { "Asia/Oral", Kazakhstan_Western },
-            { "timezone.excity.Asia/Omsk", "\u041e\u043c\u0441\u043a\u0430\u0439" },
-            { "Antarctica/South_Pole", New_Zealand },
-            { "Australia/Adelaide", Australia_Central },
-            { "timezone.excity.Asia/Chita", "\u0427\u0438\u0442\u0430\u0430" },
-            { "timezone.excity.Asia/Colombo", "\u041a\u043e\u043b\u043e\u043c\u0431\u043e" },
-            { "Asia/Qostanay", Kazakhstan_Eastern },
-            { "Asia/Almaty", Kazakhstan_Eastern },
-            { "Europe/Simferopol", Moscow },
             { "ACT", Australia_Central },
-            { "Asia/Tbilisi", Georgia },
-            { "Asia/Novosibirsk", Novosibirsk },
-            { "timezone.excity.Asia/Anadyr", "\u0410\u043d\u0430\u0430\u0434\u044b\u0440" },
-            { "timezone.excity.Asia/Ashgabat", "\u0410\u0441\u0445\u0430\u0431\u0430\u0430\u0442" },
-            { "timezone.excity.Asia/Urumqi", "\u0423\u0440\u0443\u043c\u0447\u0443" },
-            { "NET", Armenia },
-            { "timezone.excity.Asia/Barnaul", "\u0411\u0430\u0440\u043d\u0430\u0443\u043b" },
-            { "timezone.excity.Asia/Sakhalin", "\u0421\u0430\u0445\u0430\u043b\u0438\u0438\u043d" },
-            { "Asia/Riyadh", Arabian },
-            { "timezone.excity.Asia/Magadan", "\u041c\u0430\u0433\u0430\u0434\u0430\u0430\u043d" },
-            { "Asia/Pyongyang", Korea },
-            { "Asia/Karachi", Pakistan },
-            { "Asia/Harbin", China },
-            { "Asia/Novokuznetsk", Krasnoyarsk },
-            { "timezone.excity.Etc/Unknown", "\u0411\u0438\u043b\u043b\u0438\u0431\u044d\u0442" },
-            { "Australia/Perth", Australia_Western },
-            { "Asia/Atyrau", Kazakhstan_Western },
-            { "Australia/Darwin", Australia_Central },
-            { "Asia/Khandyga", Yakutsk },
-            { "Asia/Qyzylorda", Kazakhstan_Western },
-            { "Asia/Chita", Yakutsk },
-            { "timezone.excity.Asia/Krasnoyarsk", "\u041a\u0440\u0430\u0441\u043d\u043e\u044f\u0440\u0441\u043a\u0430\u0439" },
-            { "Asia/Kuwait", Arabian },
-            { "Antarctica/McMurdo", New_Zealand },
-            { "Asia/Calcutta", India },
-            { "Antarctica/Casey", Australia_Western },
-            { "Asia/Macau", China },
-            { "timezone.excity.Asia/Ust-Nera", "\u0423\u0443\u0441 \u041d\u044c\u0430\u0440\u0430" },
-            { "timezone.excity.Asia/Damascus", "\u0414\u0430\u043c\u0430\u0430\u0441" },
-            { "Asia/Krasnoyarsk", Krasnoyarsk },
-            { "timezone.excity.Asia/Choibalsan", "\u0427\u043e\u0439\u0431\u0430\u043b\u0441\u0430\u043d" },
             { "AET", Australia_Eastern },
-            { "timezone.excity.Asia/Baku", "\u0411\u0430\u043a\u0443\u0443" },
-            { "timezone.excity.Europe/Moscow", "\u041c\u043e\u0441\u043a\u0443\u0431\u0430" },
-            { "timezone.excity.Asia/Dubai", "\u0414\u0443\u0431\u0430\u0430\u0439" },
-            { "Australia/Broken_Hill", Australia_Central },
-            { "Europe/Minsk", Moscow },
-            { "Pacific/Auckland", New_Zealand },
-            { "Asia/Qatar", Arabian },
-            { "Asia/Magadan", Magadan },
-            { "Asia/Ust-Nera", Vladivostok },
-            { "timezone.excity.Asia/Khandyga", "\u0425\u0430\u0430\u043d\u0434\u044b\u0433\u0430" },
-            { "timezone.excity.Europe/Kaliningrad", "\u041a\u0430\u043b\u0438\u043d\u0438\u043d\u0433\u0440\u0430\u0434" },
-            { "Australia/Currie", Australia_Eastern },
-            { "Australia/Melbourne", Australia_Eastern },
-            { "Asia/Bahrain", Arabian },
-            { "timezone.excity.Asia/Kabul", "\u041a\u0430\u0431\u0443\u0443\u043b" },
-            { "Asia/Chongqing", China },
+            { "CTT", China },
+            { "JST", Japan },
+            { "NET", Armenia },
+            { "NST", New_Zealand },
             { "PLT", Pakistan },
-            { "timezone.excity.Europe/Ulyanovsk", "\u0423\u043b\u044c\u044f\u043d\u043e\u0432\u0441\u043a\u0430\u0439" },
-            { "Asia/Seoul", Korea },
-            { "Australia/Sydney", Australia_Eastern },
-            { "timezone.excity.Asia/Yekaterinburg", "\u0415\u043a\u0430\u0442\u0435\u0440\u0438\u043d\u0431\u0443\u0443\u0440" },
-            { "Asia/Choibalsan", Choibalsan },
-            { "Asia/Colombo", India },
+            { "Asia/Aden", Arabian },
             { "Asia/Omsk", Omsk },
-            { "Australia/Lindeman", Australia_Eastern },
-            { "Australia/Brisbane", Australia_Eastern },
-            { "timezone.excity.Europe/Astrakhan", "\u0410\u0430\u0441\u0442\u0440\u0430\u0445\u0430\u043d" },
-            { "timezone.excity.Europe/Samara", "\u0421\u0430\u043c\u0430\u0430\u0440\u0430" },
-            { "Europe/Volgograd", Volgograd },
-            { "Asia/Yekaterinburg", Yekaterinburg },
+            { "Asia/Oral", Kazakhstan_Western },
+            { "Asia/Aqtau", Kazakhstan_Western },
+            { "Asia/Chita", Yakutsk },
+            { "Asia/Macau", China },
+            { "Asia/Qatar", Arabian },
+            { "Asia/Seoul", Korea },
+            { "Asia/Almaty", Kazakhstan_Eastern },
+            { "Asia/Aqtobe", Kazakhstan_Western },
+            { "Asia/Atyrau", Kazakhstan_Western },
+            { "Asia/Harbin", China },
+            { "Asia/Kuwait", Arabian },
+            { "Asia/Riyadh", Arabian },
+            { "Asia/Tehran", Iran },
+            { "Asia/Baghdad", Arabian },
+            { "Asia/Bahrain", Arabian },
             { "Asia/Bishkek", Kyrgystan },
-            { "timezone.excity.Europe/Istanbul", "\u0421\u0442\u0430\u043c\u0431\u0443\u0443\u043b" },
+            { "Asia/Colombo", India },
+            { "Asia/Karachi", Pakistan },
+            { "Asia/Magadan", Magadan },
+            { "Asia/Tbilisi", Georgia },
+            { "Asia/Yakutsk", Yakutsk },
+            { "Asia/Yerevan", Armenia },
+            { "Europe/Minsk", Moscow },
+            { "Asia/Calcutta", India },
+            { "Asia/Khandyga", Yakutsk },
+            { "Asia/Qostanay", Kazakhstan_Eastern },
+            { "Asia/Sakhalin", Sakhalin },
+            { "Asia/Ust-Nera", Vladivostok },
+            { "Europe/Moscow", Moscow },
+            { "Asia/Chongqing", China },
+            { "Asia/Pyongyang", Korea },
+            { "Asia/Qyzylorda", Kazakhstan_Western },
+            { "Asia/Choibalsan", Mongolia },
+            { "Australia/Perth", Australia_Western },
+            { "Antarctica/Casey", Australia_Western },
+            { "Asia/Krasnoyarsk", Krasnoyarsk },
+            { "Asia/Novosibirsk", Novosibirsk },
+            { "Asia/Ulaanbaatar", Mongolia },
+            { "Asia/Vladivostok", Vladivostok },
+            { "Australia/Currie", Australia_Eastern },
+            { "Australia/Darwin", Australia_Central },
+            { "Australia/Hobart", Australia_Eastern },
+            { "Australia/Sydney", Australia_Eastern },
+            { "Europe/Volgograd", Volgograd },
+            { "Pacific/Auckland", New_Zealand },
+            { "Asia/Novokuznetsk", Krasnoyarsk },
+            { "Europe/Simferopol", Moscow },
+            { "Antarctica/McMurdo", New_Zealand },
+            { "Asia/Yekaterinburg", Yekaterinburg },
+            { "Australia/Adelaide", Australia_Central },
+            { "Australia/Brisbane", Australia_Eastern },
+            { "Australia/Lindeman", Australia_Eastern },
+            { "Australia/Melbourne", Australia_Eastern },
+            { "Antarctica/South_Pole", New_Zealand },
+            { "Australia/Broken_Hill", Australia_Central },
+            { "timezone.excity.Asia/Baku", "\u0411\u0430\u043a\u0443\u0443" },
+            { "timezone.excity.Asia/Omsk", "\u041e\u043c\u0441\u043a\u0430\u0439" },
+            { "timezone.excity.Asia/Chita", "\u0427\u0438\u0442\u0430\u0430" },
+            { "timezone.excity.Asia/Dubai", "\u0414\u0443\u0431\u0430\u0430\u0439" },
+            { "timezone.excity.Asia/Kabul", "\u041a\u0430\u0431\u0443\u0443\u043b" },
             { "timezone.excity.Asia/Almaty", "\u0410\u043b\u043c\u0430\u0442\u044b" },
+            { "timezone.excity.Asia/Anadyr", "\u0410\u043d\u0430\u0430\u0434\u044b\u0440" },
+            { "timezone.excity.Asia/Urumqi", "\u0423\u0440\u0443\u043c\u0447\u0443" },
+            { "timezone.excity.Etc/Unknown", "\u0411\u0438\u043b\u043b\u0438\u0431\u044d\u0442" },
+            { "timezone.excity.Asia/Baghdad", "\u0411\u0430\u0433\u0434\u0430\u0430\u0434" },
+            { "timezone.excity.Asia/Barnaul", "\u0411\u0430\u0440\u043d\u0430\u0443\u043b" },
+            { "timezone.excity.Asia/Colombo", "\u041a\u043e\u043b\u043e\u043c\u0431\u043e" },
+            { "timezone.excity.Asia/Irkutsk", "\u0418\u0440\u043a\u0443\u0442\u0441\u043a\u0430\u0439" },
+            { "timezone.excity.Asia/Magadan", "\u041c\u0430\u0433\u0430\u0434\u0430\u0430\u043d" },
+            { "timezone.excity.Asia/Yakutsk", "\u0414\u044c\u043e\u043a\u0443\u0443\u0441\u043a\u0430\u0439" },
+            { "timezone.excity.Asia/Ashgabat", "\u0410\u0441\u0445\u0430\u0431\u0430\u0430\u0442" },
+            { "timezone.excity.Asia/Damascus", "\u0414\u0430\u043c\u0430\u0430\u0441" },
+            { "timezone.excity.Asia/Khandyga", "\u0425\u0430\u0430\u043d\u0434\u044b\u0433\u0430" },
+            { "timezone.excity.Asia/Sakhalin", "\u0421\u0430\u0445\u0430\u043b\u0438\u0438\u043d" },
+            { "timezone.excity.Asia/Ust-Nera", "\u0423\u0443\u0441 \u041d\u044c\u0430\u0440\u0430" },
+            { "timezone.excity.Europe/Moscow", "\u041c\u043e\u0441\u043a\u0443\u0431\u0430" },
+            { "timezone.excity.Europe/Samara", "\u0421\u0430\u043c\u0430\u0430\u0440\u0430" },
+            { "timezone.excity.Asia/Kamchatka", "\u041a\u0430\u043c\u0447\u0430\u0430\u0442\u043a\u0430" },
+            { "timezone.excity.Asia/Samarkand", "\u0421\u0430\u043c\u0430\u0440\u043a\u0430\u0430\u043d" },
+            { "timezone.excity.Asia/Choibalsan", "\u0427\u043e\u0439\u0431\u0430\u043b\u0441\u0430\u043d" },
+            { "timezone.excity.Europe/Istanbul", "\u0421\u0442\u0430\u043c\u0431\u0443\u0443\u043b" },
+            { "timezone.excity.Asia/Krasnoyarsk", "\u041a\u0440\u0430\u0441\u043d\u043e\u044f\u0440\u0441\u043a\u0430\u0439" },
+            { "timezone.excity.Asia/Novosibirsk", "\u041d\u043e\u0432\u043e\u0441\u0438\u0431\u0438\u0440\u0441\u043a\u0430\u0439" },
+            { "timezone.excity.Asia/Ulaanbaatar", "\u0423\u043b\u0430\u043d \u0411\u0430\u0430\u0442\u0430\u0440" },
+            { "timezone.excity.Europe/Astrakhan", "\u0410\u0430\u0441\u0442\u0440\u0430\u0445\u0430\u043d" },
+            { "timezone.excity.Europe/Ulyanovsk", "\u0423\u043b\u044c\u044f\u043d\u043e\u0432\u0441\u043a\u0430\u0439" },
+            { "timezone.excity.Europe/Simferopol", "\u0421\u0438\u043c\u0444\u0435\u0440\u043e\u043f\u043e\u043b\u044c" },
+            { "timezone.excity.Asia/Srednekolymsk", "\u041e\u0440\u0442\u043e \u0425\u0430\u043b\u044b\u043c\u0430" },
+            { "timezone.excity.Asia/Yekaterinburg", "\u0415\u043a\u0430\u0442\u0435\u0440\u0438\u043d\u0431\u0443\u0443\u0440" },
+            { "timezone.excity.Europe/Kaliningrad", "\u041a\u0430\u043b\u0438\u043d\u0438\u043d\u0433\u0440\u0430\u0434" },
         };
         return data;
     }
